---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2000-08-18;267
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20000928&codiceRedaz=000G0304&dataVigenza=20251104
dataGU: 20000928
codiceRedaz: 000G0304
dataVigenza: 20251104
---

# Testo unico delle leggi sull'ordinamento degli enti locali.

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87 della Costituzione;

Visto l'articolo 14 della legge 23 agosto 1988, n. 400;

Visto l'articolo 31 della legge 3 agosto 1999, n. 265, recante delega al Governo per l'adozione di un testo unico in materia di ordinamento degli enti locali;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 20 aprile 2000;

Acquisiti i pareri delle competenti Commissioni del Senato della Repubblica e della Camera dei Deputati;

Udito il parere del Consiglio di Stato, espresso nell'adunanza generale dell'8 giugno 2000;

Acquisito il parere della Conferenza Stato-citta' ed autonomie locali e della Conferenza unificata, istituita ai sensi del decreto legislativo 28 agosto 1997, n. 281;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 4 agosto 2000;

Sulla proposta del Ministro dell'interno, di concerto con i Ministri per gli affari regionali e della giustizia;

Emana il seguente decreto legislativo:

## Articolo 1.

1. E' approvato l'unito testo unico delle leggi sull'ordinamento degli enti locali, composto di 275 articoli.

## ORDINAMENTO ISTITUZIONALE TITOLO I DISPOSIZIONI GENERALI

### Articolo 1 - oggetto

1. Il presente testo unico contiene i principi e le disposizioni in materia di ordinamento degli enti locali.

2. Le disposizioni del presente testo unico non si applicano alle regioni a statuto speciale e alle province autonome di Trento e di Bolzano se incompatibili con le attribuzioni previste dagli statuti e dalle relative norme di attuazione.

3. La legislazione in materia di ordinamento degli enti locali e di disciplina dell'esercizio delle funzioni ad essi conferite enuncia espressamente i principi che costituiscono limite inderogabile per la loro autonomia normativa. L'entrata in vigore di nuove leggi che enunciano tali principi abroga le norme statutarie con essi incompatibili. Gli enti locali adeguano gli statuti entro 120 giorni dalla data di entrata in vigore delle leggi suddette.

4. Ai sensi dell'articolo 128 della Costituzione le leggi della Repubblica non possono introdurre deroghe al presente testo unico se non mediante espressa modificazione delle sue disposizioni.

### Articolo 2 - Ambito di applicazione

1. Ai fini del presente testo unico si intendono per enti locali i comuni, le province, le citta' metropolitane, le comunita' montane, le comunita' isolane e le unioni di comuni.

2. Le norme sugli enti locali previste dal presente testo unico si applicano, altresi', salvo diverse disposizioni, ai consorzi cui partecipano enti locali, con esclusione di quelli che gestiscono attivita' aventi rilevanza economica ed imprenditoriale e, ove previsto dallo statuto, dei consorzi per la gestione dei servizi sociali.

### Articolo 3 - Autonomia dei comuni e delle province

1. Le comunita' locali, ordinate in comuni e province, sono autonome.

2. Il comune e' l'ente locale che rappresenta la propria comunita', ne cura gli interessi e ne promuove lo sviluppo.

3. La provincia, ente locale intermedio tra comune e regione, rappresenta la propria comunita', ne cura gli interessi, ne promuove e ne coordina lo sviluppo.

4. I comuni e le province hanno autonomia statutaria, normativa, organizzativa e amministrativa, nonche' autonomia impositiva e finanziaria nell'ambito dei propri statuti e regolamenti e delle leggi di coordinamento della finanza pubblica.

5. I comuni e le province sono titolari di funzioni proprie e di quelle conferite loro con legge dello Stato e della regione, secondo il principio di sussidiarieta'. I comuni e le province svolgono le loro funzioni anche attraverso le attivita' che possono essere adeguatamente. esercitate dalla autonoma iniziativa dei cittadini e delle loro formazioni sociali.

### Articolo 4 - Sistema regionale delle autonomie locali

1. Ai sensi dell'articolo 117, primo e secondo comma, e dell'articolo 118, primo comma della Costituzione, le regioni, ferme restando le funzioni che attengono ad esigenze di carattere unitario nei rispettivi territori, organizzano l'esercizio delle funzioni amministrative a livello locale attraverso i comuni e le province.

2. Ai fini di cui al comma 1, le leggi regionali si conformano ai principi stabiliti dal presente testo unico in ordine alle funzioni del comune e della provincia, identificando nelle materie e nei casi previsti dall'articolo 117 della Costituzione, gli interessi comunali e provinciali in rapporto alle caratteristiche della popolazione e del territorio.

3. La generalita' dei compiti e delle funzioni amministrative e' attribuita ai comuni alle province e alle comunita' montane, in base ai principi di cui all'articolo, 4, comma 3, della legge del 15 marzo 1997, n. 59, secondo le loro dimensioni territoriali. associative ed organizzative, con esclusione delle sole funzioni che richiedono l'unitario esercizio a livello regionale.

4. La legge regionale indica i principi della cooperazione dei comuni e delle province tra loro e con la regione, al fine di realizzare un efficiente sistema delle autonomie locali al servizio dello sviluppo economico, sociale e civile.

5. Le regioni, nell'ambito della propria autonomia legislativa, prevedono strumenti e procedure di raccordo e concertazione, anche permanenti, che diano luogo a forme di cooperazione strutturali e funzionali, al fine di consentire la collaborazione e l'azione coordinata fra regioni ed enti locali nell'ambito delle rispettive competenze.

### Articolo 5 - Programmazione regionale e locale

1. La regione indica gli obiettivi generali della programmazione economico sociale e territoriale e su questi ripartisce le risorse destinate al finanziamento del programma di investimenti degli enti locali.

2. Comuni e province concorrono alla determinazione degli obiettivi contenuti nei piani e programmi dello Stato e delle regioni e provvedono, per quanto di propria competenza, alla loro specificazione ed attuazione.

3. La legge regionale stabilisce forme e modi della partecipazione degli enti locali alla formazione dei piani e programmi regionali e degli altri provvedimenti della regione.

4. La legge regionale indica i criteri e fissa le procedure per gli atti e gli strumenti della programmazione socio-economica e della pianificazione territoriale dei comuni e delle province rilevanti ai fini dell'attuazione dei programmi regionali.

5. La legge regionale disciplina altresi', con norme di carattere generale. modi e procedimenti per la verifica della compatibilita' fra gli strumenti di cui al comma 4 e i programmi regionali, ove esistenti.

### Articolo 6

Statuti comunali e provinciali

1. I comuni e le province adottano il proprio statuto.

2. Lo statuto, nell'ambito dei principi fissati dal presente testo unico, stabilisce le norme fondamentali dell'organizzazione dell'ente e, in particolare, specifica le attribuzioni degli organi e le forme di garanzia e di partecipazione delle minoranze, i modi di esercizio della rappresentanza legale dell'ente, anche in giudizio. Lo Statuto stabilisce, altresi', i criteri generali in materia di organizzazione dell'ente, le forme di collaborazione fra comuni e province, della partecipazione popolare, del decentramento, dell'accesso dei cittadini, alle informazioni e ai procedimenti amministrativi, lo stemma e il gonfalone e quanto ulteriormente previsto dal presente testo unico.

3. Gli statuti comunali e provinciali stabiliscono norme per assicurare condizioni di pari opportunita' tra uomo e donna ai sensi della legge 10 aprile 1991, n. 125, e per ((garantire)) la presenza di entrambi i sessi nelle giunte e negli organi collegiali ((non elettivi)) del comune e della provincia, nonche' degli enti, aziende ed istituzioni da essi dipendenti.

4. Gli statuti sono deliberati dai rispettivi consigli con il voto favorevole dei due terzi dei consiglieri assegnati. Qualora tale maggioranza non venga raggiunta, la votazione e' ripetuta in successive sedute da tenersi entro trenta giorni e lo statuto e' approvato se ottiene per due volte il voto favorevole della maggioranza assoluta dei consiglieri assegnati. Le disposizioni di cui al presente comma si applicano anche alle modifiche statutarie.

5. Dopo l'espletamento, del controllo da parte del competente organo regionale, lo statuto e' pubblicato nel bollettino ufficiale della regione, affisso all'albo pretorio dell'ente per trenta giorni consecutivi ed inviato al Ministero dell'interno per essere inserito nella raccolta ufficiale degli statuti. Lo statuto entra in vigore decorsi trenta giorni dalla sua affissione all'albo pretorio dell'ente.

6. L'ufficio del Ministero dell'interno, istituito per la raccolta e la conservazione degli statuti comunali e provinciali, cura anche adeguate forme di pubblicita' degli statuti stessi.

### Art. 7. - Regolamenti

1. Nel rispetto dei principi fissati dalla legge e dello statuto, il comune e la provincia adottano regolamenti nelle materie di propria competenza ed in particolare per l'organizzazione e il funzionamento delle istituzioni e degli organismi di partecipazione, per il funzionamento degli organi e degli uffici e per l'esercizio delle funzioni.

### Art. 7-bis. - Sanzioni amministrative

1. Salvo diversa disposizione di legge, per le violazioni delle disposizioni dei regolamenti comunali e provinciali si applica la sanzione amministrativa pecuniaria da 25 euro a 500 euro.

((

1-bis. La sanzione amministrativa di cui al comma 1 si applica anche alle violazioni alle ordinanze adottate dal sindaco e dal presidente della provincia sulla base di disposizioni di legge, ovvero di specifiche norme regolamentari.

))

2. L'organo competente a irrogare la sanzione amministrativa e' individuato ai sensi dell'articolo 17 della legge 24 novembre 1981, n. 689.

### Articolo 8 - Partecipazione popolare

1. I comuni, anche su base di quartiere o di frazione, valorizzano le libere forme associative e promuovono organismi di partecipazione popolare all'amministrazione locale. I rapporti di tali forme associative sono disciplinati dallo statuto.

2. Nel procedimento relativo, all'adozione di atti che incidono su situazioni giuridiche soggettive devono essere previste forme di partecipazione degli interessati secondo le modalita' stabilite dallo statuto, nell'osservanza dei principi stabiliti dalla legge 7 agosto 1990, n. 241.

3. Nello statuto devono essere previste forme di consultazione della popolazione nonche' procedure per l'ammissione di istanze, petizioni e proposte di cittadini singoli o associati dirette a promuovere interventi per la migliore tutela di interessi collettivi e devono essere, altresi', determinate le garanzie per il loro tempestivo esame. Possono essere, altresi', previsti referendum anche su richiesta di un adeguato numero di cittadini.

4. Le consultazioni e i referendum di cui al presente articolo devono riguardare materie di esclusiva competenza locale e non possono avere luogo in coincidenza con operazioni elettorali provinciali, comunali e circoscrizionali.

5. Lo statuto, ispirandosi ai principi di cui alla legge 8 marzo 1994, n. 203, e al decreto legislativo 25 luglio 1998, n. 286, promuove forme di partecipazione alla vita pubblica locale dei cittadini dell'Unione europea e degli stranieri regolarmente soggiornanti.

### Articolo 9 - Azione popolare e delle associazioni di protezione ambientale

1. Ciascun elettore puo' far valere in giudizio le azioni e i ricorsi che spettano al comune e alla provincia.

2. Il giudice ordina l'integrazione del contraddittorio nei confronti del comune ovvero della provincia. In caso di soccombenza, le spese sono a carico di chi ha promosso l'azione o il ricorso, salvo che l'ente costituendosi abbia aderito alle azioni e ai ricorsi promossi dall'elettore.

3. (( COMMA ABROGATO DAL D.LGS. 3 APRILE 2006, N. 152 )).

### Articolo 10 - Diritto di accesso e di informazione

1. Tutti gli atti dell'amministrazione comunale e provinciale sono pubblici, ad eccezione di quelli riservati per espressa indicazione di legge o per effetto di una temporanea e motivata dichiarazione del sindaco o del presidente della provincia che ne vieti l'esibizione, conformemente a quanto previsto dal regolamento, in quanto la loro diffusione possa pregiudicare il diritto alla riservatezza delle persone, dei gruppi o delle imprese.

2. Il regolamento assicura ai cittadini, singoli e associati, il diritto di accesso agli atti amministrativi e disciplina il rilascio di copie di atti previo pagamento dei soli costi; individua, con norme di organizzazione degli uffici e dei servizi, i responsabili dei procedimenti; detta le norme necessarie per assicurare ai cittadini l'informazione sullo stato degli atti e delle procedure e sull'ordine di esame di domande, progetti e provvedimenti che comunque li riguardino; assicura il diritto dei cittadini di accedere, in generale, alle informazioni di cui e' in possesso l'amministrazione.

3. Al fine di rendere effettiva la partecipazione dei cittadini all'attivita' dell'amministrazione, gli enti locali assicurano l'accesso alle strutture, ed ai servizi gli enti, alle organizzazioni di volontariato e alle associazioni.

### Articolo 11 - Difensore civico

1. Lo statuto comunale e quello provinciale possono prevedere l'istituzione del difensore civico con compiti di garanzia dell'imparzialita' e del buon andamento della pubblica amministrazione comunale o provinciale, segnalando, anche di propria iniziativa, gli abusi, le disfunzioni, le carenze ed i ritardi dell'amministrazione nei confronti dei cittadini.

2. Lo statuto disciplina l'elezione, le prerogative ed i mezzi del difensore civico nonche' i suoi rapporti con il consiglio comunale o provinciale.

3. Il difensore civico comunale e quello provinciale svolgono altresi' la funzione di controllo nell'ipotesi prevista all'articolo 127. (40) ((41))

--------------- AGGIORNAMENTO (40) La L. 23 dicembre 2009, n. 191, ha disposto (con l'art. 2, comma 186, lettera a)) che "In relazione alle riduzioni del contributo ordinario di cui al comma 183, i comuni devono altresi' adottare le seguenti misure: a) soppressione della figura del difensore civico di cui all'articolo 11 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267; [. . .]". --------------- AGGIORNAMENTO (41) La L. 23 dicembre 2009, n. 191, come modificata dal D.L. 25 gennaio 2010, n. 2, convertito con modificazioni dalla L. 26 marzo 2010, n. 42, ha disposto (con l'art. 2, comma 186, lettera a)) che "Al fine del coordinamento della finanza pubblica e per il contenimento della spesa pubblica, i comuni devono adottare le seguenti misure: a) soppressione della figura del difensore civico comunale di cui all'articolo 11 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267. Le funzioni del difensore civico comunale possono essere attribuite, mediante apposita convenzione, al difensore civico della provincia nel cui territorio rientra il relativo comune. In tale caso il difensore civico provinciale assume la denominazione di "difensore civico territoriale" ed e' competente a garantire l'imparzialita' e il buon andamento della pubblica amministrazione, segnalando, anche di propria iniziativa, gli abusi, le disfunzioni, le carenze e i ritardi dell'amministrazione nei confronti dei cittadini; [. . .]".

### Articolo 12 - Sistemi informativi e statistici

1. Gli enti locali esercitano i compiti conoscitivi e informativi concernenti le loro funzioni in modo da assicurare, anche tramite sistemi informativo-statistici automatizzati, la circolazione delle conoscenze e delle informazioni fra le amministrazioni, per consentirne, quando prevista, la fruizione su tutto il territorio nazionale.

2. Gli enti locali, nello svolgimento delle attivita' di rispettiva competenza e nella conseguente verifica dei risultati, utilizzano sistemi informativo-statistici che operano in collegamento con gli uffici di statistica in applicazione del decreto legislativo 6 settembre 1989, n. 322. E' in ogni caso assicurata l'integrazione dei sistemi informativo-statistici settoriali con il sistema statistico nazionale.

3. Le misure necessarie sono adottate con le procedure e gli strumenti di cui agli articoli 6 e 9 del decreto legislativo 28 agosto 1997, n. 281.

## SOGGETTI CAPO I Comune

### Articolo 13 - Funzioni

1. Spettano al comune tutte le funzioni amministrative che riguardano la popolazione ed il territorio comunale, precipuamente nei settori organici dei servizi alla persona e alla comunita', dell'assetto ed utilizzazione del territorio e dello sviluppo economico, salvo quanto non sia espressamente attribuito ad altri soggetti dalla legge statale o regionale, secondo le rispettive competenze.

2. Il comune, per l'esercizio delle funzioni in ambiti territoriali adeguati, attua forme sia di decentramento sia di cooperazione con altri comuni e con la provincia.

### Articolo 14 - Compiti del comune per servizi di competenza statale

1. Il comune gestisce i servizi elettorali, di stato civile, di anagrafe, di leva militare e di statistica.

2. Le relative funzioni sono esercitate dal sindaco quale ufficiale del Governo, ai sensi dell'articolo 54.

3. Ulteriori funzioni amministrative per servizi di competenza statale possono essere affidate ai comuni dalla legge che regola anche i relativi rapporti finanziari, assicurando le risorse necessarie.

### Articolo 15 - Modifiche territoriali fusione ed istituzione di comuni

1. A norma degli articoli 117 e 133 della Costituzione, le regioni possono modificare le circoscrizioni territoriali dei comuni sentite le popolazioni interessate, nelle forme previste dalla legge regionale. Salvo i casi di fusione tra piu' comuni, non possono essere istituiti nuovi comuni con popolazione inferiore ai 10.000 abitanti o la cui costituzione comporti, come conseguenza, che altri comuni scendano sotto tale limite.

2. I comuni che hanno dato avvio al procedimento di fusione ai sensi delle rispettive leggi regionali possono, anche prima dell'istituzione del nuovo ente, mediante approvazione di testo conforme da parte di tutti i consigli comunali, definire lo statuto che entrera' in vigore con l'istituzione del nuovo comune e rimarra' vigente fino alle modifiche dello stesso da parte degli organi del nuovo comune istituito. Lo statuto del nuovo comune dovra' prevedere che alle comunita' dei comuni oggetto della fusione siano assicurate adeguate forme di partecipazione e di decentramento dei servizi.

2-bis. Ai fini della partecipazione dei consiglieri comunali all'attivita' degli organi istituiti ai sensi delle rispettive leggi regionali sul procedimento di fusione, si applicano le disposizioni di cui al titolo III, capo IV, ed i conseguenti oneri per permessi retribuiti, gettoni di presenza e rimborsi delle spese di viaggio sono posti a carico delle regioni medesime.

3. Al fine di favorire la fusione dei comuni, oltre ai contributi della regione, lo Stato eroga, per i dieci anni decorrenti dalla fusione stessa, appositi contributi straordinari commisurati ad una quota dei trasferimenti spettanti ai singoli comuni che si fondono. (56)(97)

((3-bis. Per le fusioni dei comuni realizzate a decorrere dal 1° gennaio 2014, i contributi straordinari di cui al comma 3 sono erogati per ulteriori cinque anni))

4. La denominazione delle borgate e frazioni e' attribuita ai comuni ai sensi dell'articolo 118 della Costituzione.

------------- AGGIORNAMENTO (56) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 20, comma 1) che "A decorrere dall'anno 2013, il contributo straordinario ai comuni che danno luogo alla fusione, di cui all'articolo 15, comma 3, del citato testo unico di cui al decreto legislativo n. 267 del 2000, e' commisurato al 20 per cento dei trasferimenti erariali attribuiti per l'anno 2010, nel limite degli stanziamenti finanziari previsti". Ha inoltre disposto (con l'art. 20, comma 2) che "Le disposizioni di cui al comma 1 si applicano per le fusioni di comuni realizzate negli anni 2012 e successivi". ------------- AGGIORNAMENTO (97) La L. 27 dicembre 2017, n. 205, ha disposto (con l'art. 1, comma 869) che "La dotazione finanziaria dei contributi straordinari di cui all'articolo 15, comma 3, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' incrementata a decorrere dall'anno 2018 di 10 milioni di euro annui. All'onere derivante dalla disposizione di cui al primo periodo, pari a 10 milioni di euro annui a decorrere dall'anno 2018, si provvede mediante corrispondente riduzione del contributo di cui al comma 24 dell'articolo 1 della legge 28 dicembre 2015, n. 208".

### Articolo 16 - Municipi

1. Nei comuni istituiti mediante fusione di due o piu' comuni contigui lo statuto comunale puo' prevedere l'istituzione di municipi nei territori delle comunita' di origine o di alcune di esse.

2. Lo statuto e il regolamento disciplinano l'organizzazione e le funzioni dei municipi, potendo prevedere anche organi eletti a suffragio universale diretto. Si applicano agli amministratori dei municipi le norme previste per gli amministratori dei comuni con pari popolazione.

### Articolo 17 - Circoscrizioni di decentramento comunale

1. I comuni con popolazione superiore a 250.000 abitanti articolano il loro territorio per istituire le circoscrizioni di decentramento, quali organismi di partecipazione, di consultazione e di gestione di servizi di base, nonche' di esercizio delle funzioni delegate dal comune. ((Il limite di cui al primo periodo non si applica al comune capoluogo della citta' metropolitana)). (32)

2. L'organizzazione e le funzioni delle circoscrizioni sono disciplinate dallo statuto comunale e da apposito regolamento.

3. I comuni con popolazione tra i 100.000 e i 250.000 abitanti possono articolare il territorio per istituire le circoscrizioni di decentramento ai sensi di quanto previsto dal comma 2. La popolazione media delle circoscrizioni non puo' essere inferiore a 30.000 abitanti. (32)

4. Gli organi delle circoscrizioni rappresentano le esigenze della popolazione delle circoscrizioni nell'ambito dell'unita' del comune e sono eletti nelle forme stabilite dallo statuto e dal regolamento.

5. Nei comuni con popolazione superiore a 300.000 abitanti lo statuto puo' prevedere particolari e piu' accentuate forme di decentramento di funzioni e di autonomia organizzativa e funzionale, determinando, altresi', anche con il rinvio alla normativa applicabile ai comuni aventi uguale popolazione, gli organi di tali forme di decentramento, lo status dei componenti e le relative modalita' di elezione, nomina o designazione. Le modalita' di elezione dei consigli circoscrizionali e la nomina o la designazione dei componenti degli organi esecutivi sono comunque disciplinate in modo da garantire il rispetto del principio della parita' di accesso delle donne e degli uomini alle cariche elettive, secondo le disposizioni dell'articolo 73, commi 1 e 3, e agli uffici pubblici. Il consiglio comunale puo' deliberare, a maggioranza assoluta dei consiglieri assegnati, la revisione della delimitazione territoriale delle circoscrizioni esistenti e la conseguente istituzione delle nuove forme di autonomia ai sensi della normativa statutaria. (40) (41)

------------- AGGIORNAMENTO (32) Il D.L. 31 dicembre 2007, n. 248, convertito con modificazioni dalla L. 28 febbraio 2008, n. 31, ha disposto (con l'art. 42-bis, comma 1) che "Le disposizioni di cui all'articolo 2, comma 29, della legge 24 dicembre 2007, n. 244, si applicano a decorrere dalle elezioni successive alla data di entrata in vigore della legge di conversione del presente decreto". ------------- AGGIORNAMENTO (40) La L. 23 dicembre 2009, n. 191, ha disposto (con l'art. 2, comma 186, lettera b)) che "In relazione alle riduzioni del contributo ordinario di cui al comma 183, i comuni devono altresi' adottare le seguenti misure: [. . .] b) soppressione delle circoscrizioni di decentramento comunale di cui all'articolo 17 del citato testo unico di cui al decreto legislativo n. 267 del 2000, e successive modificazioni;" ------------- AGGIORNAMENTO (41) La L. 23 dicembre 2009, n. 191, come modificata dal D.L. 25 gennaio 2010, n. 2, convertito con modificazioni dalla L. 26 marzo 2010, n. 42, ha disposto (con l'art. 2, comma 186, lettera b)) che "Al fine del coordinamento della finanza pubblica e per il contenimento della spesa pubblica, i comuni devono adottare le seguenti misure: [. . .] b) soppressione delle circoscrizioni di decentramento comunale di cui all'articolo 17 del citato testo unico di cui al decreto legislativo n. 267 del 2000, e successive modificazioni, tranne che per i comuni con popolazione superiore a 250.000 abitanti, che hanno facolta' di articolare il loro territorio in circoscrizioni, la cui popolazione media non puo' essere inferiore a 30.000 abitanti; e' fatto salvo il comma 5, dell'articolo 17, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267;"

### Articolo 18 - Titolo di citta'

1. Il titolo di citta' puo' essere concesso con decreto del Presidente della Repubblica su proposta del Ministro dell'interno ai comuni insigni per ricordi, monumenti storici e per l'attuale importanza.

## Provincia

### Articolo 19 - Funzioni

1. Spettano alla provincia le funzioni amministrative di interesse provinciale che riguardino vaste zone intercomunali o l'intero territorio provinciale nei seguenti settori:

- a) difesa del suolo, tutela e valorizzazione dell'ambiente e prevenzione delle calamita';
- b) tutela e valorizzazione delle risorse idriche ed energetiche;
- c) valorizzazione dei beni culturali;
- d) viabilita' e trasporti;
- e) protezione della flora e della fauna parchi e riserve naturali;
- f) caccia e pesca nelle acque interne;
- g) organizzazione dello smaltimento dei rifiuti a livello provinciale, rilevamento, disciplina e controllo degli scarichi delle acque e delle emissioni atmosferiche e sonore;
- h) servizi sanitari, di igiene e profilassi pubblica, attribuiti dalla legislazione statale e regionale;
- i) compiti connessi alla istruzione secondaria di secondo grado ed artistica ed alla formazione professionale, compresa l'edilizia scolastica, attribuiti dalla legislazione statale e regionale;
- l) raccolta ed elaborazione dati, assistenza tecnico-amministrativa agli enti locali.

2. La provincia, in collaborazione con i comuni e sulla base di programmi da essa proposti promuove e coordina attivita', nonche' realizza opere di rilevante interesse provinciale sia nel settore economico, produttivo, commerciale e turistico, sia in quello sociale, culturale e sportivo.

3. La gestione di tali attivita' ed opere avviene attraverso le forme previste dal presente testo unico per la gestione dei servizi pubblici locali.

### Articolo 20 - Compiti di programmazione

1. La provincia:

- a) raccoglie e coordina le proposte avanzate dai comuni, ai fini della programmazione economica, territoriale ed ambientale della regione;
- b) concorre alla determinazione del programma regionale di sviluppo e degli altri programmi e piani regionali secondo norme dettate dalla legge regionale;
- c) formula e adotta con riferimento alle previsioni e agli obiettivi del programma regionale di sviluppo propri programmi pluriennali sia di carattere generale che settoriale e promuove il coordinamento dell'attivita' programmatoria dei comuni.

2. La provincia, inoltre, ferme restando le competenze dei comuni ed in attuazione della legislazione e dei programmi regionali, predispone ed adotta il piano territoriale di coordinamento che determina gli indirizzi generali di assetto del territorio e, in particolare, indica:

- a) le diverse destinazioni del territorio in relazione alla prevalente vocazione delle sue parti;
- b) la localizzazione di massima delle maggiori infrastrutture e delle principali linee di comunicazione;
- c) le linee di intervento per la sistemazione idrica, idrogeologica ed idraulico-forestale ed in genere per il consolidamento del suolo e la regimazione delle acque;
- d) le aree nelle quali sia opportuno istituire parchi o riserve naturali.

3. I programmi pluriennali e il piano territoriale di coordinamento sono trasmessi alla regione ai fini di accertarne la conformita' agli indirizzi regionali della programmazione socio-economica e territoriale.

4. La legge regionale detta le procedure di approvazione, nonche' norme che assicurino il concorso dei comuni alla formazione dei programmi pluriennali e dei piani territoriali di coordinamento.

5. Ai fini del coordinamento e dell'approvazione degli strumenti di pianificazione territoriale predisposti dai comuni, la provincia esercita le funzioni ad essa attribuite dalla regione ed ha, in ogni caso, il compito di accertare la compatibilita' di detti strumenti con le previsioni del piano territoriale di coordinamento.

6. Gli enti e le amministrazioni pubbliche, nell'esercizio delle rispettive competenze, si conformano ai piani territoriali di coordinamento delle province e tengono conto dei loro programmi pluriennali.

### Articolo 21 - ((Revisione delle circoscrizioni provinciali))

1. ((COMMA ABROGATO DALLA L. 23 DICEMBRE 2009, N. 191, COME MODIFICATA DAL D.L. 5 GENNAIO 2010, N. 2, CONVERTITO CON MODIFICAZIONI DALLA L. 26 MARZO 2010, N. 42)).

2. ((COMMA ABROGATO DALLA L. 23 DICEMBRE 2009, N. 191, COME MODIFICATA DAL D.L. 5 GENNAIO 2010, N. 2, CONVERTITO CON MODIFICAZIONI DALLA L. 26 MARZO 2010, N. 42)).

3. Per la revisione delle circoscrizioni provinciali e l'istituzione di nuove province i comuni esercitano l'iniziativa di cui all'articolo 133 della Costituzione, tenendo conto dei seguenti criteri ed indirizzi:

- a) ciascun territorio provinciale deve corrispondere alla zona entro la quale si svolge la maggior parte dei rapporti sociali, economici e culturali della popolazione residente;
- b) ciascun territorio provinciale deve avere dimensione tale, per ampiezza, entita' demografica, nonche' per le attivita' produttive esistenti o possibili, da consentire una programmazione dello sviluppo che possa favorire il riequilibrio economico, sociale e culturale del territorio provinciale e regionale;
- c) l'intero territorio di ogni comune deve far parte di una sola provincia;
- d) l'iniziativa dei comuni, di cui all'articolo 133 della Costituzione, deve conseguire l'adesione della maggioranza dei comuni dell'area interessata, che rappresentino, comunque, la maggioranza della popolazione complessiva dell'area stessa, con delibera assunta a maggioranza assoluta dei consiglieri assegnati;
- e) di norma, la popolazione delle province risultanti dalle modificazioni territoriali non deve essere inferiore a 200.000 abitanti;
- f) l'istituzione di nuove province non comporta necessariamente l'istituzione di uffici provinciali delle amministrazioni dello Stato e degli altri enti pubblici;
- g) le province preesistenti debbono garantire alle nuove, in proporzione al territorio ed alla popolazione trasferiti, personale, beni, strumenti operativi e risorse finanziarie adeguati.

4. Ai sensi del secondo comma dell'articolo 117 della Costituzione le regioni emanano norme intese a promuovere e coordinare l'iniziativa dei comuni di cui alla lettera d) del comma 3.

## Aree metropolitane

### Articolo 22

((ARTICOLO ABROGATO DAL D.L. 6 LUGLIO 2012, N. 95, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 135)) ((69))

--------------- AGGIORNAMENTO (69) Successivamente la Corte Costituzionale, con sentenza 3 - 19 luglio 2013, n. 220 (in G.U. 1a s.s. 24/7/2013, n. 30), ha dichiarato l'illegittimita' costituzionale dell'art. 18 del D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135 (che ha disposto l'abrogazione del presente articolo).

### Articolo 23

((ARTICOLO ABROGATO DAL D.L. 6 LUGLIO 2012, N. 95, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 135)) ((69))

--------------- AGGIORNAMENTO (69) Successivamente la Corte Costituzionale, con sentenza 3 - 19 luglio 2013, n. 220 (in G.U. 1a s.s. 24/7/2013, n. 30), ha dichiarato l'illegittimita' costituzionale dell'art. 18 del D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135 (che ha disposto l'abrogazione del presente articolo).

### Articolo 24 - Esercizio coordinato di funzioni

1. La regione, previa intesa con gli enti locali interessati, puo' definire ambiti sovracomunali per l'esercizio coordinato delle funzioni degli enti locali, attraverso forme associative e di cooperazione, nelle seguenti materie: a)pianificazione territoriale; b) reti infrastrutturali e servizi a rete; c) piani di traffico intercomunali; d) tutela e valorizzazione dell'ambiente e rilevamento dell'inquinamento atmosferico; e) interventi di difesa del suolo e di tutela idrogeologica; f) raccolta, distribuzione e depurazione delle acque; g) smaltimento dei rifiuti; h) grande distribuzione commerciale; i) attivita' culturali; l) funzioni dei sindaci ai sensi dell'articolo 50, comma 7. Le disposizioni regionali emanate ai sensi del comma 1 si applicano fino all'istituzione della citta' metropolitana.

### Articolo 25 - Revisione delle circoscrizioni comunali

1. Istituita la citta' metropolitana, la regione, previa intesa con gli enti locali interessati, puo' procedere alla revisione delle circoscrizioni territoriali dei comuni compresi nell'area metropolitana.

### Articolo 26 - Norma transitoria

1. Sono fatte salvo le leggi regionali vigenti in materia di aree metropolitane.

2. La legge istitutiva della citta' metropolitana stabilisce i termini per il conferimento, da parte della regione, dei compiti e delle funzioni amministrative in base ai principi dell'articolo 4, comma 3, della legge 15 marzo 1997, n. 59, e le modalita' per l'esercizio dell'intervento sostitutivo da parte del Governo in analogia a quanto previsto dall'articolo 3, comma 4, del decreto legislativo 31 marzo 1998, n. 112.

## Comunita' montane

### Articolo 27 - Natura e ruolo

1. Le comunita' montane sono unioni di comuni, enti locali costituiti fra comuni montani e parzialmente montani, anche appartenenti a province diverse, per la valorizzazione delle zone montane per l'esercizio di funzioni proprie, di funzioni conferite e per l'esercizio associato delle funzioni comunali.

2. La comunita' montana ha un organo rappresentativo e un organo esecutivo composti da sindaci, assessori o consiglieri dei comuni partecipanti. Il presidente puo' cumulare la carica con quella di sindaco di uno dei comuni della comunita'. I rappresentanti dei comuni della comunita' montana sono eletti dai consigli dei comuni partecipanti con il sistema del voto limitato garantendo la rappresentanza delle minoranze.

3. La regione individua, concordandoli nelle sedi concertative di cui all'articolo 4, gli ambiti o le zone omogenee per la costituzione delle comunita' montane, in modo da consentire gli interventi per la valorizzazione della montagna e l'esercizio associato delle funzioni comunali. La costituzione della comunita' montana avviene con provvedimento del presidente della giunta regionale.

4. La legge regionale disciplina le comunita' montane stabilendo in particolare:

- a) le modalita' di approvazione dello statuto;
- b) le procedure di concertazione;
- c) la disciplina dei piani zonali e dei programmi annuali;
- d) i criteri di ripartizione tra le comunita' montane dei finanziamenti regionali e di quelli dell'Unione europea;
- e) i rapporti con gli altri enti operanti nel territorio.

5. La legge regionale puo' escludere dalla comunita' montana i comuni parzialmente montani nei quali la popolazione residente nel territorio montano sia inferiore al 15 per cento della popolazione complessiva, restando sempre esclusi i capoluoghi di provincia e i comuni con popolazione complessiva superiore a 40.000 abitanti. L'esclusione non priva i rispettivi territori montani dei benefici e degli interventi speciali per la montagna stabiliti dall'Unione europea e dalle leggi statali e regionali. La legge regionale puo' prevedere, altresi', per un piu' efficace esercizio delle funzioni e dei servizi svolti in forma associata, l'inclusione dei comuni confinanti, con popolazione non superiore a 20.000 abitanti, che siano parte integrante del sistema geografico e socioeconomico della comunita'.

6. Al comune montano nato dalla fusione dei comuni il cui territorio coincide con quello di una comunita' montana sono assegnate le funzioni e le risorse attribuite alla stessa in base a norme comunitarie, nazionali e regionali. Tale disciplina si applica anche nel caso in cui il comune sorto dalla fusione comprenda comuni non montani. Con la legge regionale istitutiva del nuovo comune si provvede allo scioglimento della comunita' montana.

7. Ai fini della graduazione e differenziazione degli interventi di competenza delle regioni e delle comunita' montane, le regioni, con propria legge, possono provvedere ad individuare nell'ambito territoriale delle singole comunita' montane fasce altimetriche di territorio, tenendo conto dell'andamento orografico, del clima, della vegetazione, delle difficolta' nell'utilizzazione agricola del suolo, della fragilita' ecologica, dei rischi ambientali e della realta' socio-economica.

8. Ove in luogo di una preesistente comunita' montana vengano costituite piu' comunita' montane, ai nuovi enti spettano nel complesso i trasferimenti erariali attribuiti all'ente originario, ripartiti in attuazione dei criteri stabiliti dall'articolo 36 del decreto legislativo 30 dicembre 1992, n. 504, e successive modificazioni.

### Articolo 28 - Funzioni

1. L'esercizio associato di funzioni proprie dei comuni o a questi conferite dalla regione spetta alle comunita' montane. Spetta, altresi', alle comunita' montane l'esercizio di ogni altra funzione ad esse conferita dai comuni, dalla provincia e dalla regione.

2. Spettano alle comunita' montane le funzioni attribuite dalla legge e gli interventi speciali per la montagna stabiliti dalla Unione europea o dalle leggi statali e regionali.

3. Le comunita' montane adottano piani pluriennali di opere ed interventi e individuano gli strumenti idonei a perseguire gli obiettivi dello sviluppo socioeconomico, ivi compresi quelli previsti dalla Unione europea, dallo Stato e dalla regione, che possono concorrere alla realizzazione dei programmi annuali operativi di esecuzione del piano.

4. Le comunita' montane, attraverso le indicazioni urbanistiche del piano pluriennale di sviluppo, concorrono alla formazione del piano territoriale di coordinamento.

5. Il piano pluriennale di sviluppo socioeconomico ed i suoi aggiornamenti sono adottati dalle comunita' montane ed approvati dalla provincia secondo le procedure previste dalla legge regionale.

6. Gli interventi finanziari disposti dalle comunita' montane e da altri soggetti pubblici a favore della montagna sono destinati esclusivamente ai territori classificati montani.

7. Alle comunita' montane si applicano le disposizioni dell'articolo 32, comma 5.

### Articolo 29 - Comunita' isolane o di arcipelago

1. In ciascuna isola o arcipelago di isole, ad eccezione della Sicilia e della Sardegna, ove esistono piu' comuni puo' essere istituita, dai comuni interessati, la comunita' isolana o dell'arcipelago, cui si estendono le norme sulle comunita' montane.

## Forme associative

### Articolo 30 - Convenzioni

1. Al fine di svolgere in modo coordinato funzioni e servizi determinati, gli enti locali possono stipulare tra loro apposite convenzioni.

2. Le convenzioni devono stabilire i fini, la durata, le forme di consultazione degli enti contraenti, i loro rapporti finanziari ed i reciproci obblighi e garanzie.

3. Per la gestione a tempo determinato di uno specifico servizio o per la realizzazione di un'opera lo Stato e la regione, nelle materie di propria competenza, possono prevedere forme di convenzione obbligatoria fra enti locali, previa statuizione di un disciplinare-tipo.

4. Le convenzioni di cui al presente articolo possono prevedere anche la costituzione di uffici comuni che operano con personale distaccato dagli enti partecipanti, ai quali affidare l'esercizio delle funzioni pubbliche in luogo degli enti partecipanti all'accordo, ovvero la delega di funzioni da parte degli enti partecipanti all'accordo a favore di uno di essi, che opera in luogo e per conto degli enti deleganti.

### Art. 31. - Consorzi

1. Gli enti locali per la gestione associata di uno o piu' servizi e l'esercizio associato di funzioni possono costituire un consorzio secondo le norme previste per le aziende speciali di cui all'articolo 114, in quanto compatibili. Al consorzio possono partecipare altri enti pubblici, quando siano a cio' autorizzati, secondo le leggi alle quali sono soggetti.

2. A tal fine i rispettivi consigli approvano a maggioranza assoluta dei componenti una convenzione ai sensi dell'articolo 30, unitamente allo statuto del consorzio.

3. In particolare la convenzione deve disciplinare le nomine e le competenze degli organi consortili coerentemente a quanto disposto dai commi 8, 9 e 10 dell'articolo 50 e dell'articolo 42, comma 2, lettera m), e prevedere la trasmissione, agli enti aderenti, degli atti fondamentali del consorzio; lo statuto, in conformita' alla convenzione, deve disciplinare l'organizzazione, la nomina e le funzioni degli organi consortili.

4. Salvo quanto previsto dalla convenzione e dallo statuto per i consorzi, ai quali partecipano a mezzo dei rispettivi rappresentanti legali anche enti diversi dagli enti locali, l'assemblea del consorzio e' composta dai rappresentanti degli enti associati nella persona del sindaco, del presidente o di un loro delegato, ciascuno con responsabilita' pari alla quota di partecipazione fissata dalla convenzione e dallo statuto.

5. L'assemblea elegge il consiglio di amministrazione e ne approva gli atti fondamentali previsti dallo statuto.

6. Tra gli stessi enti locali non puo' essere costituito piu' di un consorzio.

7. In caso di rilevante interesse pubblico, la legge dello Stato puo' prevedere la costituzione di consorzi obbligatori per l'esercizio di determinate funzioni e servizi. La stessa legge ne demanda l'attuazione alle leggi regionali.

8. Ai consorzi che gestiscono attivita' (( di cui all'articolo 113-bis )), si applicano le norme previste per le aziende speciali.

### Articolo 32 - (Unione di comuni)

1. L'unione di comuni e' l'ente locale costituito da due o piu' comuni, di norma contermini, finalizzato all'esercizio associato di funzioni e servizi. Ove costituita in prevalenza da comuni montani, essa assume la denominazione di unione di comuni montani e puo' esercitare anche le specifiche competenze di tutela e di promozione della montagna attribuite in attuazione dell'articolo 44, secondo comma, della Costituzione e delle leggi in favore dei territori montani.

2. Ogni comune puo' far parte di una sola unione di comuni. Le unioni di comuni possono stipulare apposite convenzioni tra loro o con singoli comuni.

3. Gli organi dell'unione, presidente, giunta e consiglio, sono formati, senza nuovi o maggiori oneri per la finanza pubblica, da amministratori in carica dei comuni associati e a essi non possono essere attribuite retribuzioni, gettoni e indennita' o emolumenti in qualsiasi forma percepiti. Il presidente e' scelto tra i sindaci dei comuni associati e la giunta tra i componenti dell'esecutivo dei comuni associati. Il consiglio e' composto da un numero di consiglieri definito nello statuto, eletti dai singoli consigli dei comuni associati tra i propri componenti, garantendo la rappresentanza delle minoranze e assicurando la rappresentanza di ogni comune.

4. L'unione ha potesta' statutaria e regolamentare e ad essa si applicano, in quanto compatibili e non derogati con le disposizioni della legge recante disposizioni sulle citta' metropolitane, sulle province, sulle unioni e fusioni di comuni, i principi previsti per l'ordinamento dei comuni, con particolare riguardo allo status degli amministratori, all'ordinamento finanziario e contabile, al personale e all'organizzazione. Lo statuto dell'unione stabilisce le modalita' di funzionamento degli organi e ne disciplina i rapporti. In fase di prima istituzione lo statuto dell'unione e' approvato dai consigli dei comuni partecipanti e le successive modifiche sono approvate dal consiglio dell'unione.

5. All'unione sono conferite dai comuni partecipanti le risorse umane e strumentali necessarie all'esercizio delle funzioni loro attribuite. Fermi restando i vincoli previsti dalla normativa vigente in materia di personale, la spesa sostenuta per il personale dell'Unione non puo' comportare, in sede di prima applicazione, il superamento della somma delle spese di personale sostenute precedentemente dai singoli comuni partecipanti. A regime, attraverso specifiche misure di razionalizzazione organizzativa e una rigorosa programmazione dei fabbisogni, devono essere assicurati progressivi risparmi di spesa in materia di personale. ((I comuni possono cedere, anche parzialmente, le proprie capacita' assunzionali all'unione di comuni di cui fanno parte)).

5-bis. Previa apposita convenzione, i sindaci dei comuni facenti parte dell'Unione possono delegare le funzioni di ufficiale dello stato civile e di anagrafe a personale idoneo dell'Unione stessa, o dei singoli comuni associati, fermo restando quanto previsto dall'articolo 1, comma 3, e dall'articolo 4, comma 2, del decreto del Presidente della Repubblica 3 novembre 2000, n. 396, recante regolamento per la revisione e la semplificazione dell'ordinamento dello stato civile, a norma dell'articolo 2, comma 12, della legge 15 maggio 1997, n. 127.

5-ter. Il presidente dell'unione di comuni si avvale del segretario di un comune facente parte dell'unione, senza che cio' comporti l'erogazione di ulteriori indennita' e, comunque, senza nuovi o maggiori oneri per la finanza pubblica. Sono fatti salvi gli incarichi per le funzioni di segretario gia' affidati ai dipendenti delle unioni o dei comuni anche ai sensi del comma 557 dell'articolo 1 della legge 30 dicembre 2004, n. 311. Ai segretari delle unioni di comuni si applicano le disposizioni dell'articolo 8 della legge 23 marzo 1981, n. 93, e successive modificazioni.

6. L'atto costitutivo e lo statuto dell'unione sono approvati dai consigli dei comuni partecipanti con le procedure e con la maggioranza richieste per le modifiche statutarie. Lo statuto individua le funzioni svolte dall'unione e le corrispondenti risorse.

7. Alle unioni competono gli introiti derivanti dalle tasse, dalle tariffe e dai contributi sui servizi ad esse affidati.

8. Gli statuti delle unioni sono inviati al Ministero dell'interno per le finalita' di cui all'articolo 6, commi 5 e 6.

------------- AGGIORNAMENTO (49) Il D.L. 13 agosto 2011, n. 138, convertito con modificazioni dalla L. 14 settembre 2011, n. 148, ha disposto (con l'art. 16, comma 3) che "All'unione di cui al comma 1, in deroga all'articolo 32, commi 2, 3 e 5, secondo periodo, del citato testo unico di cui al decreto legislativo n. 267 del 2000, si applica la disciplina di cui al presente articolo". Ha inoltre disposto (con l'art. 16, comma 29) che "Le disposizioni di cui al presente articolo si applicano ai comuni appartenenti alle regioni a statuto speciale ed alle province autonome di Trento e di Bolzano nel rispetto degli statuti delle regioni e province medesime, delle relative norme di attuazione e secondo quanto previsto dall'articolo 27 della legge 5 maggio 2009, n. 42".

### Articolo 33 - Esercizio associato di funzioni e servizi da parte dei comuni

1. Le regioni, nell'emanazione delle leggi di conferimento delle funzioni ai comuni, attuano il trasferimento delle funzioni nei confronti della generalita' dei comuni.

2. Al fine di favorire l'esercizio associato delle funzioni dei comuni di minore dimensione demografica, le regioni individuano livelli ottimali di esercizio delle stesse, concordandoli nelle sedi concertative di cui all'articolo 4. Nell'ambito della previsione regionale, i comuni esercitano le funzioni in forma associata, individuando autonomamente i soggetti, le forme e le metodologie, entro il termine temporale indicato dalla legislazione regionale. Decorso inutilmente il termine di cui sopra la regione esercita il potere sostitutivo nelle forme stabilite dalla legge stessa.

3. Le regioni predispongono, concordandolo con i comuni nelle apposite sedi concertative, un programma di individuazione degli ambiti per la gestione associata sovracomunale di funzioni e servizi, realizzato anche attraverso le unioni, che puo' prevedere altresi' la modifica di circoscrizioni comunali e i criteri per la corresponsione di contributi e incentivi alla progressiva unificazione. Il programma e' aggiornato ogni tre anni, tenendo anche conto delle unioni di comuni regolarmente costituite.

4. Al fine di favorire il processo di riorganizzazione sovracomunale dei servizi, delle funzioni e delle strutture, le regioni provvedono a disciplinare, con proprie leggi, nell'ambito del programma territoriale di cui al comma 3, le forme di incentivazione dell'esercizio associato delle funzioni da parte dei comuni, con l'eventuale previsione nel proprio bilancio di un apposito fondo. A tale fine, oltre a quanto stabilito dal comma 3 e dagli articoli 30 e 32, le regioni si attengono ai seguenti principi fondamentali:

- a) nella disciplina delle incentivazioni: 1) favoriscono il massimo grado di integrazione tra i comuni, graduando la corresponsione dei benefici in relazione al livello di unificazione, rilevato mediante specifici indicatori con riferimento alla tipologia ed alle caratteristiche delle funzioni e dei servizi associati o trasferiti in modo tale da erogare il massimo dei contributi nelle ipotesi di massima integrazione; 2) prevedono in ogni caso una maggiorazione dei contributi nelle ipotesi di fusione e di unione, rispetto alle altre forme di gestione sovracomunale;
- b) promuovono le unioni di comuni, senza alcun vincolo alla successiva fusione, prevedendo comunque ulteriori benefici da corrispondere alle unioni che autonomamente deliberino, su conforme proposta dei consigli comunali interessati, di procedere alla fusione.

### Articolo 34 - Accordi di programma

1. Per la definizione e l'attuazione di opere, di interventi o di programmi di intervento che richiedono, per la loro completa realizzazione, l'azione integrata e coordinata di comuni, di province e regioni, di amministrazioni statali e di altri soggetti pubblici, o comunque di due o piu' tra i soggetti predetti, il presidente della regione o il presidente della provincia o il sindaco, in relazione alla competenza primaria o prevalente sull'opera o sugli interventi o sui programmi di intervento, promuove la conclusione di un accordo di programma, anche su richiesta di uno o piu' dei soggetti interessati, per assicurare il coordinamento delle azioni e per determinarne i tempi, le modalita', il finanziamento ed ogni altro connesso adempimento.

2. L'accordo puo' prevedere altresi' procedimenti di arbitrato, nonche' interventi surrogatori di eventuali inadempienze dei soggetti partecipanti.

3. Per verificare la possibilita' di concordare l'accordo di programma, il presidente della regione o il presidente della provincia o il sindaco convoca una conferenza tra i rappresentanti di tutte le amministrazioni interessate.

((4. L'accordo, consistente nel consenso unanime del presidente della regione, del presidente della provincia, dei sindaci e delle altre amministrazioni interessate, deve essere sottoscritto entro sessanta giorni dalla comunicazione dell'esito positivo della conferenza di cui al comma 3 ed e' approvato con atto formale del presidente della regione o del presidente della provincia o del sindaco e pubblicato nel Bollettino ufficiale della regione. L'accordo, qualora adottato con decreto del presidente della regione, produce gli effetti dell'intesa di cui all'articolo 81 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, determinando le eventuali e conseguenti variazioni degli strumenti urbanistici e sostituendo i permessi di costruire, sempre che vi sia l'assenso del comune interessato))

5. Ove l'accordo comporti variazione degli strumenti urbanistici, l'adesione del sindaco allo stesso deve essere ratificata dal consiglio comunale entro trenta giorni a pena di decadenza.

6. Per l'approvazione di progetti di opere pubbliche comprese nei programmi dell'amministrazione e per le quali siano immediatamente utilizzabili i relativi finanziamenti si procede a norma dei precedenti commi. L'approvazione dell'accordo di programma comporta la dichiarazione di pubblica utilita', indifferibilita' ed urgenza delle medesime opere; tale dichiarazione cessa di avere efficacia se le opere non hanno avuto inizio entro tre anni.

7. La vigilanza sull'esecuzione dell'accordo di programma e gli eventuali interventi sostitutivi sono svolti da un collegio presieduto dal presidente della regione o dal presidente della provincia o dal sindaco e composto da rappresentanti degli enti locali interessati, nonche' dal commissario del Governo nella regione o dal prefetto nella provincia interessata se all'accordo partecipano amministrazioni statali o enti pubblici nazionali.

8. Allorche' l'intervento o il programma di intervento comporti il concorso di due o piu' regioni finitime, la conclusione dell'accordo di programma e' promossa dalla Presidenza del Consiglio dei Ministri, a cui spetta convocare la conferenza di cui al comma 3. Il collegio di vigilanza di cui al comma 7 e' in tal caso presieduto da un rappresentante della Presidenza del Consiglio dei Ministri ed e' composto dai rappresentanti di tutte le regioni che hanno partecipato all'accordo. La Presidenza del Consiglio dei Ministri esercita le funzioni attribuite dal comma 7 al commissario del Governo ed al prefetto.

### Articolo 35 - Norma transitoria

1. L'adozione delle leggi regionali previste dall'articolo 33, comma 4, avviene entro il 21 febbraio 2001. Trascorso inutilmente tale termine, il Governo, entro i successivi sessanta giorni, sentite le regioni inadempienti e la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, provvede a dettare la relativa disciplina nel rispetto dei principi enunciati nel citato articolo del presente testo unico. La disciplina adottata nell'esercizio dei poteri sostitutivi si applica fino alla data di entrata in vigore della legge regionale.

## ORGANI CAPO I Organi di governo del comune e della provincia

### Articolo 36 - Organi di governo

1. Sono organi di governo del comune il consiglio, la giunta, il sindaco.

2. Sono organi di governo della provincia il consiglio, la giunta, il presidente.

### Articolo 37 - Composizione dei consigli

1. Il consiglio comunale e' composto dal sindaco e:

- a) da 60 membri nei comuni con popolazione superiore ad un milione di abitanti;
- b) da 50 membri nei comuni con popolazione superiore a 500.000 abitanti;
- c) da 46 membri nei comuni con popolazione superiore a 250.000 abitanti.
- d) da 40 membri nei comuni con popolazione superiore a 100.000 abitanti o che, pur avendo popolazione inferiore, siano capoluoghi di provincia;
- e) da 30 membri nei comuni con popolazione superiore a 30.000 abitanti;
- f) da 20 membri nei comuni con popolazione superiore a 10.000 abitanti;
- g) da 16 membri nei comuni con popolazione superiore a 3.000 abitanti;
- h) da 12 membri negli altri comuni.

2. Il consiglio provinciale e' composto dal presidente della provincia e:

- a) da 45 membri nelle province con popolazione residente superiore a 1.400.000 abitanti;
- b) da 36 membri nelle province con popolazione residente superiore a 700.000 abitanti;
- c) da 30 membri nelle province con popolazione residente superiore a 300.000 abitanti;
- d) da 24 membri nelle altre province.

3. Il presidente della provincia e i consiglieri provinciali rappresentano la intera provincia.

4. La popolazione e' determinata in base ai risultati dell'ultimo censimento ufficiale.

### Art. 38. - Consigli comunali e provinciali

1. L'elezione dei consigli comunali e provinciali, la loro durata in carica, il numero dei consiglieri e la loro posizione giuridica sono regolati dal presente testo unico.

2. Il funzionamento dei consigli, nel quadro dei principi stabiliti dallo statuto, e' disciplinato dal regolamento, approvato a maggioranza assoluta, che prevede, in particolare, le modalita' per la convocazione e per la presentazione e la discussione delle proposte. Il regolamento indica altresi' il numero dei consiglieri necessario per la validita' delle sedute, prevedendo che in ogni caso debba esservi la presenza di almeno un terzo dei consiglieri assegnati per legge all'ente, senza computare a tale fine il sindaco e il presidente della provincia.

3. I consigli sono dotati di autonomia funzionale e organizzativa. Con norme regolamentari i comuni e le province fissano le modalita' per fornire ai consigli servizi, attrezzature e risorse finanziarie. Nei comuni con popolazione superiore a 15.000 abitanti e nelle province possono essere previste strutture apposite per il funzionamento dei consigli. Con il regolamento di cui al comma 2 i consigli disciplinano la gestione di tutte le risorse attribuite per il proprio funzionamento e per quello dei gruppi consiliari regolarmente costituiti.

4. I consiglieri entrano in carica all'atto della proclamazione ovvero, in caso di surrogazione, non appena adottata dal consiglio la relativa deliberazione.

5. I consigli durano in carica sino all'elezione dei nuovi, limitandosi, dopo la pubblicazione del decreto di indizione dei comizi elettorali, ad adottare gli atti urgenti e improrogabili.

6. Quando lo statuto lo preveda, il consiglio si avvale di commissioni costituite nel proprio seno con criterio proporzionale. Il regolamento determina i poteri delle commissioni e ne disciplina l'organizzazione e le forme di pubblicita' dei lavori.

7. Le sedute del consiglio e delle commissioni sono pubbliche salvi i casi previsti dal regolamento ((e, nei comuni con popolazione fino a 15.000 abitanti, si tengono preferibilmente in un arco temporale non coincidente con l'orario di lavoro dei partecipanti)). ((49))

8. Le dimissioni dalla carica di consigliere, indirizzate al rispettivo consiglio, devono essere presentate personalmente ed assunte immediatamente al protocollo dell'ente nell'ordine temporale di presentazione. Le dimissioni non presentate personalmente devono essere autenticate ed inoltrate al protocollo per il tramite di persona delegata con atto autenticato in data non anteriore a cinque giorni. Esse sono irrevocabili, non necessitano di presa d'atto e sono immediatamente efficaci. Il consiglio, entro e non oltre dieci giorni, deve procedere alla surroga dei consiglieri dimissionari, con separate deliberazioni, seguendo l'ordine di presentazione delle dimissioni quale risulta dal protocollo. Non si fa luogo alla surroga qualora, ricorrendone i presupposti, si debba procedere allo scioglimento del consiglio a norma dell'articolo 141.

9. In occasione delle riunioni del consiglio vengono esposte all'esterno degli edifici, ove si tengono, la bandiera della Repubblica italiana e quella dell'Unione europea per il tempo in cui questi esercita le rispettive funzioni e attivita'. Sono fatte salve le ulteriori disposizioni emanate sulla base della legge 5 febbraio 1998, n. 22, concernente disposizioni generali sull'uso della bandiera italiana ed europea.

--------------- AGGIORNAMENTO (49) Il D.L. 13 agosto 2011, n. 138, convertito con modificazioni dalla L. 14 settembre 2011, n. 148, ha disposto (con l'art. 16, comma 29) che "Le disposizioni di cui al presente articolo si applicano ai comuni appartenenti alle regioni a statuto speciale ed alle province autonome di Trento e di Bolzano nel rispetto degli statuti delle regioni e province medesime, delle relative norme di attuazione e secondo quanto previsto dall'articolo 27 della legge 5 maggio 2009, n. 42".

### Articolo 39 - Presidenza dei consigli comunali e provinciali

1. I consigli provinciali e i consigli comunali dei comuni con popolazione superiore a 15.000 abitanti sono presieduti da un presidente eletto tra i consiglieri nella prima seduta del consiglio. Al presidente del consiglio sono attribuiti, tra gli altri, i poteri di convocazione e direzione dei lavori e delle attivita' del consiglio. Quando lo statuto non dispone diversamente, le funzioni vicarie di presidente del consiglio sono esercitate dal consigliere anziano individuato secondo le modalita' di cui all'articolo 40. Nei comuni con popolazione sino a 15.000 abitanti lo statuto puo' prevedere la figura del presidente del consiglio.

2. Il presidente del consiglio comunale o provinciale e' tenuto a riunire il consiglio in un termine non superiore ai venti giorni, quando lo richiedano un quinto dei consiglieri, o il sindaco o il presidente della provincia, inserendo all'ordine del giorno le questioni richieste.

3. Nei comuni con popolazione inferiore ai 15.000 abitanti il consiglio e' presieduto dal sindaco che provvede anche alla convocazione del consiglio salvo differente previsione statutaria.

4. Il presidente del consiglio comunale o provinciale assicura una adeguata e preventiva informazione ai gruppi consiliari ed ai singoli consiglieri sulle questioni sottoposte al consiglio.

5. In caso di inosservanza degli obblighi di convocazione del consiglio, previa diffida, provvede il prefetto.

### Articolo 40 - Convocazione della prima seduta del consiglio

1. La prima seduta del consiglio comunale e provinciale deve essere convocata entro il termine perentorio di dieci giorni dalla proclamazione e deve tenersi entro il termine di dieci giorni dalla convocazione.

2. Nei comuni con popolazione superiore ai 15.000 abitanti, la prima seduta, e' convocata dal sindaco ed e' presieduta dal consigliere anziano fino alla elezione del presidente del consiglio. La seduta prosegue poi sotto la presidenza del presidente del consiglio per la comunicazione dei componenti della giunta e per gli ulteriori adempimenti. E' consigliere anziano colui che ha ottenuto la maggior cifra individuale ai sensi dell'articolo 73 con esclusione del sindaco neoeletto e dei candidati alla carica di sindaco. proclamati consiglieri ai sensi del comma 11 del medesimo articolo 73.

3. Qualora il consigliere anziano sia assente o rifiuti di presiedere l'assemblea, la presidenza e' assunta dal consigliere che, nella graduatoria di anzianita' determinata secondo i criteri di cui al comma 2, occupa il posto immediatamente successivo.

4. La prima seduta del consiglio provinciale e' presieduta e convocata dal presidente della provincia sino alla elezione del presidente del consiglio.

5. Nei comuni con popolazione inferiore ai 15.000 abitanti, la prima seduta del consiglio e' convocata e presieduta dal sindaco sino all'elezione del presidente del consiglio. 6. le disposizioni di cui ai commi 2, 3, 4, 5 si applicano salvo diversa previsione regolamentare nel quadro dei principi stabiliti dallo statuto.

### Articolo 41 - Adempimenti della prima seduta

1. Nella prima seduta il consiglio comunale e provinciale, prima di deliberare su qualsiasi altro oggetto, ancorche' non sia stato prodotto alcun reclamo, deve esaminare la condizione degli eletti a norma del capo II titolo III e dichiarare la ineleggibilita' di essi quando sussista alcuna delle cause ivi previste, provvedendo secondo la procedura indicata dall'articolo 69.

2. Il consiglio comunale, nella prima seduta, elegge tra i propri componenti la commissione elettorale comunale ai sensi degli articoli 12 e seguenti del decreto del Presidente della Repubblica 20 marzo 1967, n. 223.

### Art. 41-bis.

((ARTICOLO ABROGATO DAL D.LGS. 14 MARZO 2013, N. 33))

### Art. 42. - Attribuzioni dei consigli

1. Il consiglio e' l'organo di indirizzo e di controllo politico-amministrativo.

2. Il consiglio ha competenza limitatamente ai seguenti atti fondamentali:

- a) statuti dell'ente e delle aziende speciali, regolamenti salva l'ipotesi di cui all'articolo 48, comma 3, criteri generali in materia di ordinamento degli uffici e dei servizi;
- b) programmi, relazioni previsionali e programmatiche, piani finanziari, programmi triennali e elenco annuale dei lavori pubblici, bilanci annuali e pluriennali e relative variazioni, rendiconto, piani territoriali ed urbanistici, programmi annuali e pluriennali per la loro attuazione, eventuali deroghe ad essi, pareri da rendere per dette materie;
- c) convenzioni tra i comuni e quelle tra i comuni e provincia, costituzione e modificazione di forme associative;
- d) istituzione, compiti e norme sul funzionamento degli organismi di decentramento e di partecipazione;
- e) organizzazione dei pubblici servizi, costituzione di istituzioni e aziende speciali, concessione dei pubblici servizi, partecipazione dell'ente locale a societa' di capitali, affidamento di attivita' o servizi mediante convenzione;
- f) istituzione e ordinamento dei tributi, con esclusione della determinazione delle relative aliquote; disciplina generale delle tariffe per la fruizione dei beni e dei servizi;
- g) indirizzi da osservare da parte delle aziende pubbliche e degli enti dipendenti, sovvenzionati o sottoposti a vigilanza;
- h) contrazione di mutui e aperture di credito non previste espressamente in atti fondamentali del consiglio ed emissioni di prestiti obbligazionari;
- i) spese che impegnino i bilanci per gli esercizi successivi, escluse quelle relative alle locazioni di immobili ed alla somministrazione e fornitura di beni e servizi a carattere continuativo;
- l) acquisti e alienazioni immobiliari, relative permute, appalti e concessioni che non siano previsti espressamente in atti fondamentali del consiglio o che non ne costituiscano mera esecuzione e che, comunque, non rientrino nella ordinaria amministrazione di funzioni e servizi di competenza della giunta, del segretario o di altri funzionari;
- m) definizione degli indirizzi per la nomina e la designazione dei rappresentanti del comune presso enti, aziende ed istituzioni, nonche' nomina dei rappresentanti del consiglio presso enti, aziende ed istituzioni ad esso espressamente riservata dalla legge.

3. Il consiglio, nei modi disciplinati dallo statuto, partecipa altresi' alla definizione, all'adeguamento e alla verifica periodica dell'attuazione delle linee programmatiche da parte del sindaco o del presidente della provincia e dei singoli assessori.

4. Le deliberazioni in ordine agli argomenti di cui al presente articolo non possono essere adottate in via d'urgenza da altri organi del comune o della provincia, salvo quelle attinenti alle variazioni di bilancio adottate dalla giunta da sottoporre a ratifica del consiglio nei sessanta giorni successivi, a pena di decadenza. ((64))

--------------- AGGIORNAMENTO (64) Il D.L. 8 aprile 2013, n. 35, convertito con modificazioni dalla L. 6 giugno 2013, n. 64, ha disposto (con l'art. 1, comma 13) che "Gli enti locali che non possono far fronte ai pagamenti dei debiti certi liquidi ed esigibili maturati alla data del 31 dicembre 2012, ovvero dei debiti per i quali sia stata emessa fattura o richiesta equivalente di pagamento entro il predetto termine a causa di carenza di liquidita', in deroga agli articoli 42, 203 e 204 del decreto legislativo 18 agosto 2000, n. 267, chiedono alla Cassa depositi e prestiti S.p.A., secondo le modalita' stabilite nell'addendum di cui al comma 11, entro il 30 aprile 2013 l'anticipazione di liquidita' da destinare ai predetti pagamenti".

### Articolo 43 - Diritti dei consiglieri

1. I consiglieri comunali e provinciali hanno diritto di iniziativa su ogni questione sottoposta alla deliberazione del consiglio. Hanno inoltre il diritto di chiedere la convocazione del consiglio secondo le modalita' dettate dall'articolo 39, comma 2, e di presentare interrogazioni e mozioni.

2. I consiglieri comunali e provinciali hanno diritto di ottenere dagli uffici, rispettivamente, del comune e della provincia, nonche' dalle loro aziende ed enti dipendenti, tutte le notizie e le informazioni in loro possesso, utili all'espletamento del proprio mandato. Essi sono tenuti al segreto nei casi specificamente determinati dalla legge.

3. Il sindaco o il presidente della provincia o gli assessori da essi delegati rispondono, entro 30 giorni, alle interrogazioni e ad ogni altra istanza di sindacato ispettivo presentata dai consiglieri. Le modalita' della presentazione di tali atti e delle relative risposte sono disciplinate dallo statuto e dal regolamento consiliare.

4. Lo statuto stabilisce i casi di decadenza per la mancata partecipazione alle sedute e le relative procedure, garantendo il diritto del consigliere a far valere le cause giustificative.

### Articolo 44 - Garanzia delle minoranze e controllo consiliare

1. Lo statuto prevede le forme di garanzia e di partecipazione delle minoranze attribuendo alle opposizioni la presidenza delle commissioni consiliari aventi funzioni di controllo o di garanzia, ove costituite.

2. Il consiglio comunale o provinciale, a maggioranza assoluta dei propri membri, puo' istituire al proprio interno commissioni di indagine sull'attivita' dell'amministrazione. I poteri, la composizione ed il funzionamento delle suddette commissioni sono disciplinati dallo statuto e dal regolamento consiliare.

### Articolo 45 - Surrogazione e supplenza dei consiglieri provinciali, comunali e circoscrizionali

1. Nei consigli provinciali, comunali e circoscrizionali il seggio che durante il quinquennio rimanga vacante per qualsiasi causa, anche se sopravvenuta, e' attribuito al candidato che nella medesima lista segue immediatamente l'ultimo eletto.

2. Nel caso di sospensione di un consigliere ai sensi dell'articolo 59, il consiglio, nella prima adunanza successiva alla notifica del provvedimento di sospensione, procede alla temporanea sostituzione affidando la supplenza per l'esercizio delle funzioni di consigliere al candidato della stessa lista che ha riportato, dopo gli eletti, il maggior numero di voti. La supplenza ha termine con la cessazione della sospensione. Qualora sopravvenga la decadenza si fa luogo alla surrogazione a norma del comma 1.

### Articolo 46 - Elezione del sindaco e del presidente della provincia - Nomina della giunta

1. Il sindaco e il presidente della provincia sono eletti dai cittadini a suffragio universale e diretto secondo le disposizioni dettate dalla legge e sono membri dei rispettivi consigli.

2. Il sindaco e il presidente della provincia nominano ((, nel rispetto del principio di pari opportunita' tra donne e uomini, garantendo la presenza di entrambi i sessi,)) i componenti della giunta, tra cui un vicesindaco e un vicepresidente, e ne danno comunicazione al consiglio nella prima seduta successiva alla elezione.

3. Entro il termine fissato dallo statuto, il sindaco o il presidente della provincia, sentita la giunta, presenta al consiglio le linee programmatiche relative alle azioni e ai progetti da realizzare nel corso del mandato.

4. Il sindaco e il presidente della provincia possono revocare uno o piu' assessori, dandone motivata comunicazione al consiglio.

### Articolo 47 - Composizione delle giunte

1. La giunta comunale e la giunta provinciale sono composte rispettivamente dal sindaco e dal presidente della provincia, che le presiedono, e da un numero di assessori, stabilito dagli statuti, che non deve essere superiore a un terzo, arrotondato aritmeticamente, del numero dei consiglieri comunali e provinciali, computando a tale fine il sindaco e il presidente della provincia, e comunque non superiore a (( dodici ))unita'. ((31))

2. Gli statuti, nel rispetto di quanto stabilito dal comma 1, possono fissare il numero degli assessori ovvero il numero massimo degli stessi.

3. Nei comuni con popolazione superiore a 15.000 abitanti e nelle province gli assessori sono nominati dal sindaco o dal presidente della provincia, anche al di fuori dei componenti del consiglio, fra i cittadini in possesso dei requisiti di candidabilita', eleggibilita' e compatibilita' alla carica di consigliere.

4. Nei comuni con popolazione inferiore a 15.000 abitanti lo statuto puo' prevedere la nomina ad assessore di cittadini non facenti parte del consiglio ed in possesso dei requisiti di candidabilita', eleggibilita' e compatibilita' alla carica di consigliere.

5. Fino all'adozione delle norme statutarie di cui al comma 1, le giunte comunali e provinciali sono composte da un numero, di assessori stabilito rispettivamente nelle seguenti misure:

- a) non superiore a 4 nei comuni con popolazione inferiore a 10.000 abitanti; non superiore a 6 nei comuni con popolazione compresa tra 10.001 e 100.000 abitanti; non superiore a 10 nei comuni con popolazione compresa tra 100.001 e 250.000 abitanti e nei capoluoghi di provincia con popolazione inferiore a 100.000 abitanti; non superiore a 12 nei comuni con popolazione compresa tra 250.001 e 500.000 abitanti; non superiore a 14 nei comuni con popolazione compresa tra 500.001 e 1.000.000 di abitanti e non superiore a 16 nei comuni con popolazione superiore a 1.000.000 di abitanti;
- b) non superiore a 6 per le province a cui sono assegnati 24 consiglieri; non superiore a 8 per le province a cui sono assegnati 30 consiglieri; non superiore a 10 per le province a cui sono assegnati 36 consiglieri; non superiore a 12 per quelle a cui sono assegnati 45 consiglieri. --------------- AGGIORNAMENTO (31) La L. 24 dicembre 2007, n. 244, ha disposto (con l'art. 2, comma 23) che la presente modifica "entra in vigore a decorrere dalle prossime elezioni amministrative locali".

### Articolo 48 - Competenze delle giunte

1. La giunta collabora con il sindaco o con il presidente della provincia nel governo del comune o della provincia ed opera attraverso deliberazioni collegiali. ((Nei comuni con popolazione fino a 15.000 abitanti, le riunioni della giunta si tengono preferibilmente in un arco temporale non coincidente con l'orario di lavoro dei partecipanti)). ((49))

2. La giunta compie tutti gli atti rientranti ai sensi dell'articolo 107, commi 1 e 2, nelle funzioni degli organi di governo, che non siano riservati dalla legge al consiglio e che non ricadano nelle competenze, previste dalle leggi o dallo statuto, del sindaco o del presidente della provincia o degli organi di decentramento; collabora con il sindaco e con il presidente della provincia nell'attuazione degli indirizzi generali del consiglio; riferisce annualmente al consiglio sulla propria attivita' e svolge attivita' propositive e di impulso nei confronti dello stesso.

3. E', altresi', di competenza della giunta l'adozione dei regolamenti sull'ordinamento degli uffici e dei servizi, nel rispetto dei criteri generali stabiliti dal consiglio.

--------------- AGGIORNAMENTO (49) Il D.L. 13 agosto 2011, n. 138, convertito con modificazioni dalla L. 14 settembre 2011, n. 148, ha disposto (con l'art. 16, comma 29) che "Le disposizioni di cui al presente articolo si applicano ai comuni appartenenti alle regioni a statuto speciale ed alle province autonome di Trento e di Bolzano nel rispetto degli statuti delle regioni e province medesime, delle relative norme di attuazione e secondo quanto previsto dall'articolo 27 della legge 5 maggio 2009, n. 42".

### Art. 49. - (( (Pareri dei responsabili dei servizi). ))

((

1. Su ogni proposta di deliberazione sottoposta alla Giunta e al Consiglio che non sia mero atto di indirizzo deve essere richiesto il parere, in ordine alla sola regolarita' tecnica, del responsabile del servizio interessato e, qualora comporti riflessi diretti o indiretti sulla situazione economico-finanziaria o sul patrimonio dell'ente, del responsabile di ragioneria in ordine alla regolarita' contabile. I pareri sono inseriti nella deliberazione.

2. Nel caso in cui l'ente non abbia i responsabili dei servizi, il parere e' espresso dal segretario dell'ente, in relazione alle sue competenze.

3. I soggetti di cui al comma 1 rispondono in via amministrativa e contabile dei pareri espressi.

4. Ove la Giunta o il Consiglio non intendano conformarsi ai pareri di cui al presente articolo, devono darne adeguata motivazione nel testo della deliberazione.

))

### Articolo 50 - Competenze del sindaco e del presidente della provincia

1. Il sindaco e il presidente della provincia sono gli organi responsabili dell'amministrazione del comune e della provincia.

2. Il sindaco e il presidente della provincia rappresentano l'ente, convocano e presiedono la giunta, nonche' il consiglio quando non e' previsto il presidente del consiglio, e sovrintendono al funzionamento dei servizi e degli uffici e all'esecuzione degli atti.

3. Salvo quanto previsto dall'articolo 107 essi esercitano le funzioni loro attribuite dalle leggi, dallo statuto e dai regolamenti e sovrintendono altresi' all'espletamento delle funzioni statali e regionali attribuite o delegate al comune e alla provincia.

4. Il sindaco esercita altresi' le altre funzioni attribuitegli quale autorita' locale nelle materie previste da specifiche disposizioni di legge.

5. In particolare, in caso di emergenze sanitarie o di igiene pubblica a carattere esclusivamente locale le ordinanze contingibili e urgenti sono adottate dal sindaco, quale rappresentante della comunita' locale. Le medesime ordinanze sono adottate dal sindaco, quale rappresentante della comunita' locale, in relazione all'urgente necessita' di interventi volti a superare situazioni di grave incuria o degrado del territorio, dell'ambiente e del patrimonio culturale o di pregiudizio del decoro e della vivibilita' urbana, con particolare riferimento alle esigenze di tutela della tranquillita' e del riposo dei residenti, anche intervenendo in materia di orari di vendita, anche per asporto, e di somministrazione di bevande alcoliche e superalcoliche. Negli altri casi l'adozione dei provvedimenti d'urgenza ivi compresa la costituzione di centri e organismi di referenza o assistenza, spetta allo Stato o alle regioni in ragione della dimensione dell'emergenza e dell'eventuale interessamento di piu' ambiti territoriali regionali.

6. In caso di emergenza che interessi il territorio di piu' comuni, ogni sindaco adotta le misure necessarie fino a quando non intervengano i soggetti competenti ai sensi del precedente comma.

7. Il sindaco, altresi', coordina e riorganizza, sulla base degli indirizzi espressi dal consiglio comunale e nell'ambito dei criteri eventualmente indicati dalla regione, gli orari degli esercizi commerciali, dei pubblici esercizi e dei servizi pubblici, nonche', d'intesa con i responsabili territorialmente competenti delle amministrazioni interessate, gli orari di apertura al pubblico degli uffici pubblici localizzati nel territorio, al fine di armonizzare l'espletamento dei servizi con le esigenze complessive e generali degli utenti.

7-bis. Il Sindaco, al fine di assicurare il soddisfacimento delle esigenze di tutela della tranquillita' e del riposo dei residenti nonche' dell'ambiente e del patrimonio culturale in determinate aree delle citta' interessate da afflusso particolarmente rilevante di persone, anche in relazione allo svolgimento di specifici eventi, ((o in altre aree comunque interessate da fenomeni di aggregazione notturna,)) nel rispetto dell'articolo 7 della legge 7 agosto 1990, n. 241, puo' disporre, per un periodo comunque non superiore a trenta giorni, con ordinanza non contingibile e urgente, limitazioni in materia di orari di vendita, anche per asporto, e di somministrazione di bevande alcoliche e superalcoliche ((, nonche' limitazioni degli orari di vendita degli esercizi del settore alimentare o misto, e delle attivita' artigianali di produzione e vendita di prodotti di gastronomia pronti per il consumo immediato e di erogazione di alimenti e bevande attraverso distributori automatici)). ((7-bis.1. L'inosservanza delle ordinanze emanate dal Sindaco ai sensi del comma 7-bis e' punita con la sanzione amministrativa pecuniaria del pagamento di una somma da 500 euro a 5.000 euro. Qualora la stessa violazione sia stata commessa per due volte in un anno, si applicano le disposizioni di cui all'articolo 12, comma 1, del decreto-legge 20 febbraio 2017, n. 14, convertito, con modificazioni, dalla legge 18 aprile 2017, n. 48, anche se il responsabile ha proceduto al pagamento della sanzione in misura ridotta, ai sensi dell'articolo 16 della legge 24 novembre 1981, n. 689)).

7-ter. Nelle materie di cui al comma 5, secondo periodo, i comuni possono adottare regolamenti ai sensi del presente testo unico.

8. Sulla base degli indirizzi stabiliti dal consiglio il sindaco e il presidente della provincia provvedono alla nomina, alla designazione e alla revoca dei rappresentanti del comune e della provincia presso enti, aziende ed istituzioni.

9. Tutte le nomine e le designazioni debbono essere effettuate entro quarantacinque giorni dall'insediamento ovvero entro i termini di scadenza del precedente incarico. In mancanza, il comitato regionale di controllo adotta i provvedimenti sostitutivi ai sensi dell'articolo 136.

10. Il sindaco e il presidente della provincia nominano i responsabili degli uffici e dei servizi, attribuiscono e definiscono gli incarichi dirigenziali e quelli di collaborazione esterna secondo le modalita' ed i criteri stabiliti dagli articoli 109 e 110, nonche' dai rispettivi statuti e regolamenti comunali e provinciali.

11. Il sindaco e il presidente della provincia prestano davanti al consiglio, nella seduta di insediamento, il giuramento di osservare lealmente la Costituzione italiana.

12. Distintivo del sindaco e' la fascia tricolore con lo stemma della Repubblica e lo stemma del comune, da portarsi a tracolla. Distintivo del presidente della provincia e' una fascia di colore azzurro con lo stemma della Repubblica e lo stemma della propria provincia, da portare a tracolla.

### Articolo 51 - Durata del mandato del sindaco, del presidente della provincia e dei consigli. Limitazione dei mandati

1. Il sindaco e il consiglio comunale, il presidente della provincia e il consiglio provinciale durano in carica per un periodo di cinque anni.

2. Chi ha ricoperto per due mandati consecutivi la carica di sindaco e di presidente della provincia non e', allo scadere del secondo mandato, immediatamente ricandidabile alle medesime cariche. ((Per i sindaci dei comuni con popolazione fino a 15.000 abitanti, il limite previsto dal primo periodo si applica allo scadere del terzo mandato. Le disposizioni di cui ai precedenti periodi non si applicano ai comuni con popolazione fino a 5.000 abitanti.))

3. Per l'ipotesi di cui al comma 2, primo periodo, e' consentito un terzo mandato consecutivo se uno dei due mandati precedenti ha avuto durata inferiore a due anni, sei mesi e un giorno, per causa diversa dalle dimissioni volontarie.

### Articolo 52 - Mozione di sfiducia

1. Il voto del consiglio comunale o del consiglio provinciale contrario ad una proposta del sindaco, del presidente della provincia o delle rispettive giunte non comporta le dimissioni degli stessi.

2. Il sindaco, il presidente della provincia e le rispettive giunte cessano dalla carica in caso di approvazione di una mozione di sfiducia votata per appello nominale dalla maggioranza assoluta dei componenti il consiglio. La mozione di sfiducia deve essere motivata e sottoscritta da almeno due quinti dei consiglieri assegnati, senza computare a tal fine il sindaco e il presidente della provincia, e viene messa in discussione non prima di dieci giorni e non oltre trenta giorni dalla sua presentazione. Se la mozione viene approvata, si procede allo scioglimento del consiglio e alla nomina di un commissario ai sensi dell'articolo 141.

### Articolo 53 - imissioni, impedimento, rimozione, decadenza, sospensione o decesso del sindaco o del presidente della provincia

1. In caso di impedimento permanente, rimozione, decadenza o decesso del sindaco o del presidente della provincia, la giunta decade e si procede allo scioglimento del consiglio. Il consiglio e la giunta rimangono in carica sino alla elezione del nuovo consiglio e del nuovo sindaco o presidente della provincia. Sino alle predette elezioni, le funzioni del sindaco e del presidente della provincia sono svolte, rispettivamente, dal vicesindaco e dal vicepresidente.

2. Il vicesindaco ed il vicepresidente sostituiscono il sindaco e il presidente della provincia in caso di assenza o di impedimento temporaneo, nonche' nel caso di sospensione dall'esercizio della funzione ai sensi dell'articolo 59.

3. Le dimissioni presentate dal sindaco o dal presidente della provincia diventano efficaci ed irrevocabili trascorso il termine di 20 giorni dalla loro presentazione al consiglio. In tal caso si procede allo scioglimento del rispettivo consiglio, con contestuale nomina di un commissario.

4. Lo scioglimento del consiglio comunale o provinciale determina in ogni caso la decadenza del sindaco o del presidente della provincia nonche' delle rispettive giunte.

### Art. 54. - (Attribuzioni del sindaco nelle funzioni di competenza statale)

1. Il sindaco, quale ufficiale del Governo, sovrintende:

- a) all'emanazione degli atti che gli sono attribuiti dalla legge e dai regolamenti in materia di ordine e sicurezza pubblica;
- b) allo svolgimento delle funzioni affidategli dalla legge in materia di pubblica sicurezza e di polizia giudiziaria;
- c) alla vigilanza su tutto quanto possa interessare la sicurezza e l'ordine pubblico, informandone preventivamente il prefetto.

2. Il sindaco, nell'esercizio delle funzioni di cui al comma 1, concorre ad assicurare anche la cooperazione della polizia locale con le Forze di polizia statali, nell'ambito delle direttive di coordinamento impartite dal Ministro dell'interno - Autorita' nazionale di pubblica sicurezza.

3. Il sindaco, quale ufficiale del Governo, sovrintende, altresi', alla tenuta dei registri di stato civile e di popolazione e agli adempimenti demandatigli dalle leggi in materia elettorale, di leva militare e di statistica.

4. Il sindaco, quale ufficiale del Governo, adotta con atto motivato provvedimenti, anche contingibili e urgenti nel rispetto dei principi generali dell'ordinamento, al fine di prevenire e di eliminare gravi pericoli che minacciano l'incolumita' pubblica e la sicurezza urbana. I provvedimenti di cui al presente comma sono preventivamente comunicati al prefetto anche ai fini della predisposizione degli strumenti ritenuti necessari alla loro attuazione. (48)

((

4-bis. I provvedimenti adottati ai sensi del comma 4 concernenti l'incolumita' pubblica sono diretti a tutelare l'integrita' fisica della popolazione, quelli concernenti la sicurezza urbana sono diretti a prevenire e contrastare l'insorgere di fenomeni criminosi o di illegalita', quali lo spaccio di stupefacenti, lo sfruttamento della prostituzione, la tratta di persone, l'accattonaggio con impiego di minori e disabili, ovvero riguardano fenomeni di abusivismo, quale l'illecita occupazione di spazi pubblici, o di violenza, anche legati all'abuso di alcool o all'uso di sostanze stupefacenti.

))

5. Qualora i provvedimenti dai sindaci ai sensi dei commi 1 e 4 comportino conseguenze sull'ordinata convivenza delle popolazioni dei comuni contigui o limitrofi, il prefetto indice un'apposita conferenza alla quale prendono parte i sindaci interessati, il presidente della provincia e, qualora ritenuto opportuno, soggetti pubblici e privati dell'ambito territoriale interessato dall'intervento.

5-bis. Il Sindaco segnala alle competenti autorita', giudiziaria o di pubblica sicurezza, la condizione irregolare dello straniero o del cittadino appartenente ad uno Stato membro dell'Unione europea, per la eventuale adozione di provvedimenti di espulsione o di allontanamento dal territorio dello Stato.

6. In casi di emergenza, connessi con il traffico o con l'inquinamento atmosferico o acustico, ovvero quando a causa di circostanze straordinarie si verifichino particolari necessita' dell'utenza o per motivi di sicurezza urbana, il sindaco puo' modificare gli orari degli esercizi commerciali, dei pubblici esercizi e dei servizi pubblici, nonche', d'intesa con i responsabili territorialmente competenti delle amministrazioni interessate, gli orari di apertura al pubblico degli uffici pubblici localizzati nel territorio, adottando i provvedimenti di cui al comma 4.

7. Se l'ordinanza adottata ai sensi del comma 4 e' rivolta a persone determinate e queste non ottemperano all'ordine impartito, il sindaco puo' provvedere d'ufficio a spese degli interessati, senza pregiudizio dell'azione penale per i reati in cui siano incorsi.

8. Chi sostituisce il sindaco esercita anche le funzioni di cui al presente articolo.

9. Al fine di assicurare l'attuazione dei provvedimenti adottati dai sindaci ai sensi del presente articolo, il prefetto, ove le ritenga necessarie, dispone, fermo restando quanto previsto dal secondo periodo del comma 4, le misure adeguate per assicurare il concorso delle Forze di polizia. Nell'ambito delle funzioni di cui al presente articolo, il prefetto puo' altresi' disporre ispezioni per accertare il regolare svolgimento dei compiti affidati, nonche' per l'acquisizione di dati e notizie interessanti altri servizi di carattere generale.

10. Nelle materie previste dai commi 1 e 3, nonche' dall'articolo 14, il sindaco, previa comunicazione al prefetto, puo' delegare l'esercizio delle funzioni ivi indicate al presidente del consiglio circoscrizionale; ove non siano costituiti gli organi di decentramento comunale, il sindaco puo' conferire la delega a un consigliere comunale per l'esercizio delle funzioni nei quartieri e nelle frazioni.

11. Nelle fattispecie di cui ai commi 1, 3 e 4, nel caso di inerzia del sindaco o del suo delegato nell'esercizio delle funzioni previste dal comma 10, il prefetto puo' intervenire con proprio provvedimento.

12. Il Ministro dell'interno puo' adottare atti di indirizzo per l'esercizio delle funzioni previste dal presente articolo da parte del sindaco.

------------- AGGIORNAMENTO (48) La Corte Costituzionale, con sentenza 4 - 7 aprile 2011, n. 115 (in G.U. 1a s.s. 13/4/2011, n. 16), ha dichiarato "l'illegittimita' costituzionale dell'art. 54, comma 4, del decreto legislativo 18 agosto 2000, n. 267 (Testo unico delle leggi sull'ordinamento degli enti locali), come sostituito dall'art. 6 del decreto-legge 23 maggio 2008, n. 92 (Misure urgenti in materia di sicurezza pubblica), convertito, con modificazioni, dall'art. 1, comma 1, della legge 24 luglio 2008, n. 125, nella parte in cui comprende la locuzione «, anche» prima delle parole «contingibili e urgenti»".

## Incandidabilita', ineleggibilita', incompatibilita'

### Articolo 55 - Elettorato passivo

1. Sono eleggibili a sindaco, presidente della provincia, consigliere comunale, provinciale e circoscrizionale gli elettori di un qualsiasi comune della Repubblica che abbiano compiuto il diciottesimo anno di eta', nel primo giorno fissato per la votazione.

2. Per l'eleggibilita' alle elezioni comunali dei cittadini dell'Unione europea residenti nella Repubblica si applicano le disposizioni del decreto legislativo 12 aprile 1996, n. 197.

### Articolo 56 - Requisiti della candidatura

1. Nessuno puo' presentarsi come candidato a consigliere in piu' di due province o in piu' di due comuni o in piu' di due circoscrizioni, quando le elezioni si svolgano nella stessa data. I consiglieri provinciali, comunali o di circoscrizione in carica non possono candidarsi, rispettivamente, alla medesima carica in altro consiglio provinciale, comunale o circoscrizionale.

2. Nessuno puo' essere candidato alla carica di sindaco o di presidente della provincia in piu' di un comune ovvero di una provincia.

### Articolo 57 - Obbligo di opzione

1. Il candidato che sia eletto contemporaneamente consigliere in due province, in due comuni, in due circoscrizioni, deve optare per una delle cariche entro cinque giorni dall'ultima deliberazione di convalida. Nel caso di mancata opzione rimane eletto nel consiglio della provincia, del comune o della circoscrizione in cui ha riportato il maggior numero di voti in percentuale rispetto al numero dei votanti ed e' surrogato nell'altro consiglio.

### Art. 58.

((ARTICOLO ABROGATO DALLA L. 31 DICEMBRE 2012, N. 235)) ((63))

------------- AGGIORNAMENTO (63) Il D.Lgs. 31 dicembre 2012, n. 235 ha disposto (con l'art. 17, comma 2) che "Dalla data di cui al comma 1, i richiami agli articoli 58 e 59 del decreto legislativo 18 agosto 2000, n. 267, ovunque presenti, si intendono riferiti, rispettivamente, agli articoli 10 e 11 del presente testo unico".

### Art. 59.

((ARTICOLO ABROGATO DALLA L. 31 DICEMBRE 2012, N. 235)) ((63))

------------- AGGIORNAMENTO (63) Il D.Lgs. 31 dicembre 2012, n. 235 ha disposto (con l'art. 17, comma 2) che "Dalla data di cui al comma 1, i richiami agli articoli 58 e 59 del decreto legislativo 18 agosto 2000, n. 267, ovunque presenti, si intendono riferiti, rispettivamente, agli articoli 10 e 11 del presente testo unico".

### Art. 60. - Ineleggibilita'

1. Non sono eleggibili a sindaco, presidente della provincia, consigliere comunale, consigliere metropolitano, provinciale e circoscrizionale: 1) il Capo della polizia, i vice capi della polizia, gli ispettori generali di pubblica sicurezza che prestano servizio presso il Ministero dell'interno, i dipendenti civili dello Stato che svolgono le funzioni di direttore generale o equiparate o superiori; 2) nel territorio, nel quale esercitano le loro funzioni, i Commissari di Governo, i prefetti della Repubblica, i vice prefetti ed i funzionari di pubblica sicurezza; 3) NUMERO ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66; 4) nel territorio, nel quale esercitano il loro ufficio, gli ecclesiastici ed i ministri di culto, che hanno giurisdizione e cura di anime e coloro che ne fanno ordinariamente le veci; 5) i titolari di organi individuali ed i componenti di organi collegiali che esercitano poteri di controllo istituzionale sull'amministrazione del comune o della provincia nonche' i dipendenti che dirigono o coordinano i rispettivi uffici. 6) nel territorio, nel quale esercitano le loro funzioni, i magistrati addetti alle corti di appello, ai tribunali, ai tribunali amministrativi regionali, nonche' i giudici di pace; 7) i dipendenti del comune e della provincia per i rispettivi consigli; 8) il direttore generale, il direttore amministrativo e il direttore sanitario delle aziende sanitarie locali ed ospedaliere; 9) i legali rappresentanti ed i dirigenti delle strutture convenzionate per i consigli del comune il cui territorio coincide con il territorio dell'azienda sanitaria locale o ospedaliera con cui sono convenzionati o lo ricomprende, ovvero dei comuni che concorrono a costituire l'azienda sanitaria locale o ospedaliera con cui sono convenzionate; (39) 10) i legali rappresentanti ed i dirigenti delle societa' per azioni con capitale superiore al 50 per cento rispettivamente del comune o della provincia; 11) gli amministratori ed i dipendenti con funzioni di rappresentanza o con poteri di organizzazione o coordinamento del personale di istituto, consorzio o azienda dipendente rispettivamente dal comune o dalla provincia; 12) i sindaci, presidenti di provincia, consiglieri metropolitani, consiglieri comunali, provinciali o circoscrizionali in carica, rispettivamente, in altro comune, citta' metropolitana, provincia o circoscrizione.

2. Le cause di ineleggibilita' di cui al numero 8) non hanno effetto se le funzioni esercitate siano cessate almeno centottanta giorni prima della data di scadenza dei periodi di durata degli organi ivi indicati. In caso di scioglimento anticipato delle rispettive assemblee elettive, le cause di ineleggibilita' non hanno effetto se le funzioni esercitate siano cessate entro i sette giorni successivi alla data del provvedimento di scioglimento. Il direttore generale, il direttore amministrativo ed il direttore sanitario, in ogni caso, non sono eleggibili nei collegi elettorali nei quali sia ricompreso, in tutto o in parte, il territorio dell'azienda sanitaria locale o ospedaliera presso la quale abbiano esercitato le proprie funzioni in un periodo compreso nei sei mesi antecedenti la data di accettazione della candidatura. I predetti, ove si siano candidati e non siano stati eletti, non possono esercitare per un periodo di cinque anni le loro funzioni in aziende sanitarie locali e ospedaliere comprese, in tutto o in parte, nel collegio elettorale nel cui ambito si sono svolte le elezioni.

3. Le cause di ineleggibilita' previste nei numeri 1), 2), 4), 5), 6), 7), 9), 10), 11) e 12) non hanno effetto se l'interessato cessa dalle funzioni per dimissioni, trasferimento, revoca dell'incarico o del comando, collocamento in aspettativa non retribuita non oltre il giorno fissato per la presentazione delle candidature. ((La causa di ineleggibilita' prevista nel numero 12) non ha effetto nei confronti del sindaco in caso di elezioni contestuali nel comune nel quale l'interessato e' gia' in carica e in quello nel quale intende candidarsi)).

4. Le strutture convenzionate, di cui al numero 9) del comma 1, sono quelle indicate negli articoli 43 e 44 della legge 23 dicembre 1978, n. 833.

5. La pubblica amministrazione e' tenuta ad adottare i provvedimenti di cui al comma 3 entro cinque giorni dalla richiesta. Ove l'amministrazione non provveda, la domanda di dimissioni o aspettativa accompagnata dalla effettiva cessazione delle funzioni ha effetto dal quinto giorno successivo alla presentazione.

6. La cessazione delle funzioni importa la effettiva astensione da ogni atto inerente all'ufficio rivestito.

7. L'aspettativa e' concessa anche in deroga ai rispettivi ordinamenti per tutta la durata del mandato, ai sensi dell'articolo 81.

8. Non possono essere collocati in aspettativa i dipendenti assunti a tempo determinato.

9. Le cause di ineleggibilita' previsto dal numero 9) del comma 1 non si applicano per la carica di consigliere provinciale.

--------------- AGGIORNAMENTO (39) La Corte costituzionale, con sentenza 26 gennaio-6 febbraio 2009, n. 27 (in G.U. 1° s.s. 11/2/2009, n. 6) ha dichiarato l'illegittimita' costituzionale del comma 1, numero 9), del presente articolo 60 "nella parte in cui prevede l'ineleggibilita' dei direttori sanitari delle strutture convenzionate per i consigli del comune il cui territorio coincide con il territorio dell'azienda sanitaria locale o ospedaliera con cui sono convenzionate o lo ricomprende, ovvero dei comuni che concorrono a costituire l'azienda sanitaria locale o ospedaliera con cui sono convenzionate"

### Art. 61. - (( Ineleggibilita' e incompatibilita' alla carica di sindaco e presidente di provincia ))

1. Non puo' essere eletto alla carica di sindaco o di presidente della provincia: 1) il ministro di un culto; 2) coloro che hanno ascendenti o discendenti ovvero parenti o affini fino al secondo grado che coprano nelle rispettive amministrazioni il posto di segretario comunale o provinciale ((. . .)) (1)

((1-bis. Non possono ricoprire la carica di sindaco o di presidente di provincia coloro che hanno ascendenti o discendenti ovvero parenti o affini fino al secondo grado che coprano nelle rispettive amministrazioni il posto di appaltatore di lavori o di servizi comunali o provinciali o in qualunque modo loro fideiussore.))

--------------- AGGIORNAMENTO (1) La Corte costituzionale, con sentenza 23-31 ottobre 2000, n. 450 (in G.U. 1a s.s. 8/11/2000, n. 46) ha dichiarato l'illegittimita' costituzionale del presente articolo 61, n. 2, "nella parte in cui stabilisce che chi ha ascendenti o discendenti ovvero parenti o affini fino al secondo grado che rivestano la qualita' di appaltatore di lavori o di servizi comunali non puo' essere eletto alla carica di sindaco, anziche' stabilire che chi si trova in detta situazione non puo' ricoprire la carica di sindaco."

### Articolo 62 - Decadenza dalla carica di sindaco e di presidente della provincia

1. Fermo restando quanto previsto dall'articolo 7 del decreto del Presidente della Repubblica 30 marzo 1957, n. 361, e dall'articolo 5 del decreto legislativo 20 dicembre 1993, n. 533, l'accettazione della candidatura a deputato o senatore comporta, in ogni caso, per i sindaci dei comuni con popolazione superiore ai 20.000 abitanti e per i presidenti delle province la decadenza dalle cariche elettive ricoperte.

### Art. 63. - Incompatibilita'

1. Non puo' ricoprire la carica di sindaco, presidente della provincia, consigliere comunale, ((consigliere metropolitano,)) provinciale o circoscrizionale: 1) l'amministratore o il dipendente con poteri di rappresentanza o di coordinamento di ente, istituto o azienda soggetti a vigilanza in cui vi sia almeno il 20 per cento di partecipazione, rispettivamente da parte del comune o della provincia o che dagli stessi riceva, in via continuativa, una sovvenzione in tutto o in parte facoltativa, quando la parte facoltativa superi nell'anno il dieci per cento del totale delle entrate dell'ente; 2) colui che, come titolare, amministratore, dipendente con poteri di rappresentanza o di coordinamento ha parte, direttamente o indirettamente, in servizi, esazioni di diritti, somministrazioni o appalti, nell'interesse del comune o della provincia, ovvero in societa' ed imprese volte al profitto di privati, sovvenzionate da detti enti in modo continuativo, quando le sovvenzioni non siano dovute in forza di una legge dello Stato o della regione , fatta eccezione per i comuni con popolazione non superiore a 3.000 abitanti qualora la partecipazione dell'ente locale di appartenenza sia inferiore al 3 per cento e fermo restando quanto disposto dall'articolo 1, comma 718, della legge 27 dicembre 2006, n. 296; 3) il consulente legale, amministrativo e tecnico che presta opera in modo continuativo in favore delle imprese di cui ai numeri 1) e 2) del presente comma; 4) colui che ha lite pendente, in quanto parte di un procedimento civile od amministrativo, rispettivamente, con il comune o la provincia. La pendenza di una lite in materia tributaria ovvero di una lite promossa ai sensi dell'articolo 9 del presente decreto non determina incompatibilita'. Qualora il contribuente venga eletto amministratore comunale, competente a decidere sul suo ricorso e' la commissione del comune capoluogo di circondario sede di tribunale ovvero sezione staccata di tribunale. Qualora il ricorso sia proposto contro tale comune, competente a decidere e' la commissione del comune capoluogo di provincia. Qualora il ricorso sia proposto contro quest'ultimo comune, competente a decidere e', in ogni caso, la commissione del comune capoluogo di regione. Qualora il ricorso sia proposto contro quest'ultimo comune, competente a decidere e' la commissione del capoluogo di provincia territorialmente piu' vicino. La lite promossa a seguito di o conseguente a sentenza di condanna determina incompatibilita' soltanto in caso di affermazione di responsabilita' con sentenza passata in giudicato. La costituzione di parte civile nel processo penale non costituisce causa di incompatibilita'. La presente disposizione si applica anche ai procedimenti in corso; 5) colui che, per fatti compiuti allorche' era amministratore o impiegato, rispettivamente, del comune o della provincia ovvero di istituto o azienda da esso dipendente, o vigilato, e' stato, con sentenza passata in giudicato, dichiarato responsabile verso l'ente, istituto od azienda e non ha ancora estinto il debito; 6) colui che, avendo un debito liquido ed esigibile, rispettivamente, verso il comune o la provincia ovvero verso istituto od azienda da essi dipendenti e' stato legalmente messo in mora ovvero, avendo un debito liquido ed esigibile per imposte, tasse e tributi nei riguardi di detti enti, abbia ricevuto invano notificazione dell'avviso di cui all'articolo 46 del decreto del Presidente della Repubblica 29 settembre 1973, n. 602; 7) colui che, nel corso del mandato, viene a trovarsi in una condizione di ineleggibilita' prevista nei precedenti articoli.

2. L'ipotesi di cui al numero 2) del comma 1 non si applica a coloro che hanno parte in cooperative o consorzi di cooperative, iscritte regolarmente nei registri pubblici.

3. L'ipotesi di cui al numero 4) del comma 1 non si applica agli amministratori per fatto connesso con l'esercizio del mandato. (67)

-------------- AGGIORNAMENTO (67) La Corte Costituzionale, con sentenza 3 - 5 giugno 2013, n. 120 (in G.U. 1a s.s. 12/6/2013, n. 24), ha dichiarato "l'illegittimita' costituzionale dell'articolo 63 del decreto legislativo 18 agosto 2000, n. 267 (Testo unico delle leggi sull'ordinamento degli enti locali), nella parte in cui non prevede l'incompatibilita' tra la carica di parlamentare e quella di sindaco di un Comune con popolazione superiore ai 20.000 abitanti".

### Art. 64. - Incompatibilita' tra consigliere comunale e provinciale e assessore nella rispettiva giunta

1. La carica di assessore e' incompatibile con la carica di consigliere comunale e provinciale.

2. Qualora un consigliere comunale o provinciale assuma la carica di assessore nella rispettiva giunta, cessa dalla carica di consigliere all'atto dell'accettazione della nomina, ed al suo posto subentra il primo dei non eletti. 3. le disposizioni di cui ai commi 1 e 2 non si applicano ai comuni con popolazione sino a 15.000 abitanti. 4. Il coniuge, gli ascendenti, i discendenti, i parenti e affini entro il terzo grado, del sindaco o del presidente della giunta provinciale, non possono far parte della rispettiva giunta ne' essere nominati rappresentanti del comune e della provincia. ((150))

---------------- AGGIORNAMENTO (150) La Corte Costituzionale con sentenza 20 marzo - 18 giugno 2024, n. 107 (in G.U. 1ª s.s. 19/06/2024, n. 25), ha dichiarato "l'illegittimita' costituzionale dell'art. 64, comma 4, del decreto legislativo 18 agosto 2000, n. 267 (Testo unico delle leggi sull'ordinamento degli enti locali), nella parte in cui prevede che non possono far parte della giunta, ne' essere nominati rappresentanti del comune e della provincia, gli affini entro il terzo grado del sindaco o del presidente della giunta provinciale, anche quando l'affinita' deriva da un matrimonio rispetto al quale il giudice abbia pronunciato, con sentenza passata in giudicato, lo scioglimento o la cessazione degli effetti civili per una delle cause previste dall'art. 3 della legge 1° dicembre 1970, n. 898 (Disciplina dei casi di scioglimento del matrimonio)".

### Articolo 65 - (( (Incompatibilita' per consigliere regionale, comunale e circoscrizionale). ))

((

1. Le cariche di presidente provinciale, nonche' di sindaco e di assessore dei comuni compresi nel territorio della regione, sono incompatibili con la carica di consigliere regionale.

2. Le cariche di consigliere comunale e circoscrizionale sono incompatibili, rispettivamente, con quelle di consigliere comunale di altro comune e di consigliere circoscrizionale di altra circoscrizione, anche di altro comune.

3. La carica di consigliere comunale e' incompatibile con quella di consigliere di una circoscrizione dello stesso o di altro comune))

### Articolo 66 - Incompatibilita' per gli organi delle aziende sanitarie locali e ospedaliere

1. La carica di direttore generale, di direttore amministrativo e di direttore sanitario delle aziende sanitarie locali e ospedaliere e' incompatibile con quella di consigliere provinciale, di sindaco, di assessore comunale, di presidente o di assessore della comunita' montana.

### Articolo 67 - Esimente alle cause di ineleggibilita' o incompatibilita'

1. Non costituiscono cause di ineleggibilita' o di incompatibilita' gli incarichi e le funzioni conferite ad amministratori del comune, della provincia e della circoscrizione previsti da norme di legge, statuto o regolamento in ragione del mandato elettivo.

### Articolo 68 - Perdita delle condizioni di eleggibilita' e incompatibilita'

1. La perdita delle condizioni di eleggibilita' previste dal presente capo importa la decadenza dalla carica di sindaco, presidente della provincia, consigliere comunale, provinciale o circoscrizionale.

2. Le cause di incompatibilita', sia che esistano al momento della elezione sia che sopravvengano ad essa, importano la decadenza dalle predette cariche.

3. Ai fini della rimozione delle cause di ineleggibilita' sopravvenute alle elezioni ovvero delle cause di incompatibilita' sono applicabili le disposizioni di cui ai commi 2, 3, 5, 6 e 7 dell'articolo 60.

4. La cessazione dalle funzioni deve avere luogo entro dieci giorni dalla data in cui e' venuta a concretizzarsi la causa di ineleggibilita' o di incompatibilita'.

### Articolo 69 - Contestazione delle cause di ineleggibilita' ed incompatibilita'

1. Quando successivamente alla elezione si verifichi qualcuna delle condizioni previste dal presente capo come causa di ineleggibilita' ovvero esista al momento della elezione o si verifichi successivamente qualcuna delle condizioni di incompatibilita' previste dal presente capo il consiglio di cui l'interessato fa parte gliela contesta.

2. L'amministratore locale ha dieci giorni di tempo per formulare osservazioni o per eliminare le cause di ineleggibilita' sopravvenute o di incompatibilita'.

3. Nel caso in cui venga proposta azione di accertamento in sede giurisdizionale ai sensi del successivo articolo 70, il temine di dieci giorni previsto dal comma 2 decorre dalla data di notificazione del ricorso.

4. Entro i 10 giorni successivi alla scadenza del termine di cui al comma 2 il consiglio delibera definitivamente e, ove ritenga sussistente la causa di ineleggibilita' o di incompatibilita', invita l'amministratore a rimuoverla o ad esprimere, se del caso, la opzione per la carica che intende conservare.

5. Qualora l'amministratore non vi provveda entro i successivi 10 giorni il consiglio lo dichiara decaduto. Contro la deliberazione adottata e' ammesso ricorso giurisdizionale al tribunale competente per territorio.

6. La deliberazione deve essere, nel giorno successivo, depositata nella segreteria del consiglio e notificata, entro i cinque giorni successivi, a colui che e' stato dichiarato decaduto.

7. Le deliberazioni di cui al presente articolo sono adottate di ufficio o su istanza di qualsiasi elettore.

### Articolo 70 - Azione popolare

1. La decadenza dalla carica di sindaco, presidente della provincia, consigliere comunale, provinciale o circoscrizionale puo' essere promossa in prima istanza da qualsiasi cittadino elettore del comune, o da chiunque altro vi abbia interesse davanti al tribunale civile, ((. . .)). ((52))

2. L'azione puo' essere promossa anche dal prefetto.

((3. Alle controversie previste dal presente articolo si applica l'articolo 22 del decreto legislativo 1° settembre 2011, n. 150.))

((52))

4. ((COMMA ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)). ((52)) --------------- AGGIORNAMENTO (52) Il D.Lgs. 1 settembre 2011, n. 150 ha disposto (con l'art. 36, comma 1) che "Le norme del presente decreto si applicano ai procedimenti instaurati successivamente alla data di entrata in vigore dello stesso." Ha inoltre disposto (con l'art. 36, comma 2) che "Le norme abrogate o modificate dal presente decreto continuano ad applicarsi alle controversie pendenti alla data di entrata in vigore dello stesso."

## Sistema elettorale

### Articolo 71 - Elezione del sindaco e del consiglio comunale nei comuni sino ai 15.000 abitanti

1. Nei comuni con popolazione sino a 15.000 abitanti, l'elezione dei consiglieri comunali si effettua con sistema maggioritario contestualmente alla elezione del sindaco.

2. Con la lista di candidati al consiglio comunale deve essere anche presentato il nome e cognome del candidato alla carica di sindaco e il programma amministrativo da affiggere all'albo pretorio.

3. Ciascuna candidatura alla carica di sindaco e' collegata ad una lista di candidati alla carica di consigliere comunale, comprendente un numero di candidati non superiore al numero dei consiglieri da eleggere e non inferiore ai tre quarti.

3-bis. Nelle liste dei candidati e' assicurata la rappresentanza di entrambi i sessi. Nelle medesime liste, nei comuni con popolazione compresa tra 5.000 e 15.000 abitanti, nessuno dei due sessi puo' essere rappresentato in misura superiore ai due terzi dei candidati, con arrotondamento all'unita' superiore qualora il numero dei candidati del sesso meno rappresentato da comprendere nella lista contenga una cifra decimale inferiore a 50 centesimi. (125)

4. Nella scheda e' indicato, a fianco del contrassegno, il candidato alla carica di sindaco.

5. Ciascun elettore ha diritto di votare per un candidato alla carica di sindaco, segnando il relativo contrassegno. Puo' altresi' esprimere un voto di preferenza per un candidato alla carica di consigliere comunale compreso nella lista collegata al candidato alla carica di sindaco prescelto, scrivendone il cognome nella apposita riga stampata sotto il medesimo contrassegno. Nei comuni con popolazione compresa tra 5.000 e 15.000 abitanti, ciascun elettore puo' esprimere, nelle apposite righe stampate sotto il medesimo contrassegno, uno o due voti di preferenza, scrivendo il cognome di non piu' di due candidati compresi nella lista collegata al candidato alla carica di sindaco prescelto. Nel caso di espressione di due preferenze, esse devono riguardare candidati di sesso diverso della stessa lista, pena l'annullamento della seconda preferenza.

6. E' proclamato eletto sindaco il candidato alla carica che ottiene il maggior numero di voti. In caso di parita' di voti si procede ad un turno di ballottaggio fra i due candidati che hanno ottenuto il maggior numero di voti, da effettuarsi la seconda domenica successiva. In caso di ulteriore parita' viene eletto il piu' anziano di eta'.

7. A ciascuna lista di candidati alla carica di consigliere si intendono attribuiti tanti voti quanti sono i voti conseguiti dal candidato alla carica di sindaco ad essa collegato.

8. Alla lista collegata al candidato alla carica di sindaco che ha riportato il maggior numero di voti sono attribuiti due terzi dei seggi assegnati al consiglio, con arrotondamento all'unita' superiore qualora il numero dei consiglieri da assegnare alla lista contenga una cifra decimale superiore a 50 centesimi. I restanti seggi sono ripartiti proporzionalmente fra le altre liste. A tal fine si divide la cifra elettorale di ciascuna lista successivamente per 1, 2, 3, 4,... sino a concorrenza del numero dei seggi da assegnare e quindi si scelgono, tra i quozienti cosi' ottenuti, i piu' alti, in numero eguale a quello dei seggi da assegnare, disponendoli in una graduatoria decrescente. Ciascuna lista ottiene tanti seggi quanti sono i quozienti ad essa appartenenti compresi nella graduatoria. A parita' di quoziente, nelle cifre intere e decimali, il posto e' attribuito alla lista che ha ottenuto la maggiore cifra elettorale e, a parita' di quest'ultima, per sorteggio.

9. Nell'ambito di ogni lista i candidati sono proclamati eletti consiglieri comunali secondo l'ordine delle rispettive cifre individuali, costituite dalla cifra di lista aumentata dei voti di preferenza A parita' di cifra, sono proclamati eletti i candidati che precedono nell'ordine di lista. Il primo seggio spettante a ciascuna lista di minoranza e' attribuito al candidato alla carica di sindaco della lista medesima.

10. Ove sia stata ammessa e votata una sola lista, sono eletti tutti i candidati compresi nella lista ed il candidato a sindaco collegato, purche' essa abbia riportato un numero di voti validi non inferiore al 50 per cento dei votanti ed il numero dei votanti non sia stato inferiore al 50 per cento degli elettori iscritti nelle liste elettorali del comune. Qualora non si siano raggiunte tali percentuali, la elezione e' nulla. (119) (129) ((149))

11. In caso di decesso di un candidato alla carica di sindaco, intervenuto dopo la presentazione delle candidature e prima del giorno fissato per le elezioni, si procede al rinvio delle elezioni con le modalita' stabilite dall'articolo 18, terzo, quarto e quinto comma del decreto del Presidente della Repubblica 16 maggio 1960, n. 570, consentendo, in ogni caso, l'integrale rinnovo del procedimento di presentazione di tutte le liste e candidature a sindaco e a consigliere comunale.

--------------- AGGIORNAMENTO (119) Il D.L. 5 marzo 2021, n. 25, convertito con modificazioni dalla L. 3 maggio 2021, n. 58, ha disposto (con l'art. 2, comma 1-bis) che "Per l'anno 2021, in considerazione del permanere del quadro epidemiologico da COVID-19 complessivamente e diffusamente grave su tutto il territorio nazionale e a causa delle oggettive difficolta' di movimento all'interno dei singoli Stati e fra diversi Stati, per l'elezione del sindaco e del consiglio comunale nei comuni sino a 15.000 abitanti, in deroga a quanto previsto dalle disposizioni di cui al comma 10 dell'articolo 71 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, ove sia stata ammessa e votata una sola lista, sono eletti tutti i candidati compresi nella lista ed il candidato a sindaco collegato, purche' essa abbia riportato un numero di voti validi non inferiore al 50 per cento dei votanti ed il numero dei votanti non sia stato inferiore al 40 per cento degli elettori iscritti nelle liste elettorali del comune. Qualora non siano raggiunte tali percentuali, l'elezione e' nulla". Ha inoltre disposto (con l'art. 2, comma 1-ter) che "In considerazione del permanere del quadro epidemiologico da COVID-19 e delle oggettive difficolta' di movimento all'interno dei singoli Stati e fra diversi Stati, per l'elezione del sindaco e del consiglio comunale nei comuni sino a 15.000 abitanti, in deroga a quanto previsto dall'articolo 71, comma 10, del citato testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, per la determinazione del numero degli elettori iscritti nelle liste elettorali del comune non si tiene conto degli elettori iscritti all'Anagrafe degli italiani residenti all'estero (AIRE) che non esercitano il diritto di voto". --------------- AGGIORNAMENTO (125) La Corte Costituzionale, con sentenza 25 gennaio - 10 marzo 2022, n. 62, (in G.U. 1a s.s. 16/03/2022, n. 11), ha dichiarato "l'illegittimita' costituzionale del combinato disposto degli artt. 71, comma 3-bis, del decreto legislativo 18 agosto 2000, n. 267 (Testo unico delle leggi sull'ordinamento degli enti locali) e 30, primo comma, lettere d-bis) ed e), del d.P.R. 16 maggio 1960, n. 570 (Testo unico delle leggi per la composizione e la elezione degli organi delle Amministrazioni comunali), nella parte in cui non prevede l'esclusione delle liste che non assicurano la rappresentanza di entrambi i sessi nei comuni con popolazione inferiore a 5.000 abitanti". --------------- AGGIORNAMENTO (129) Il D.L. 4 maggio 2022, n. 41, convertito con modificazioni dalla L. 30 giugno 2022, n. 84, ha disposto (con l'art. 6, comma 2) che "Per l'anno 2022, per l'elezione del sindaco e del consiglio comunale nei comuni con popolazione sino a 15.000 abitanti, in deroga a quanto previsto dalle disposizioni di cui al comma 10 dell'articolo 71 del testo unico delle leggi sull'ordinamento degli enti locali di cui al decreto legislativo 18 agosto 2000, n. 267, ove sia stata ammessa e votata una sola lista, sono eletti tutti i candidati compresi nella lista e il candidato a sindaco collegato, purche' essa abbia riportato un numero di voti validi non inferiore al 50 per cento dei votanti e il numero dei votanti non sia stato inferiore al 40 per cento degli elettori iscritti nelle liste elettorali del comune. Qualora non siano raggiunte tali percentuali, l'elezione e' nulla". --------------- AGGIORNAMENTO (149) Il D.L. 29 gennaio 2024, n. 7 ha disposto (con l'art. 4, comma 2) che "Limitatamente all'anno 2024, per l'elezione del sindaco e del consiglio comunale nei comuni con popolazione fino a 15.000 abitanti, in deroga a quanto previsto dalle disposizioni di cui all'articolo 71, comma 10, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, ove sia stata ammessa e votata una sola lista, sono eletti tutti i candidati compresi nella lista e il candidato a sindaco collegato, purche' essa abbia riportato un numero di voti validi non inferiore al 50 per cento dei votanti e il numero dei votanti non sia stato inferiore al 40 per cento degli elettori iscritti nelle liste elettorali del comune. Qualora non siano raggiunte tali percentuali, l'elezione e' nulla".

### Art. 72. - Elezione del sindaco nei comuni con popolazione superiore a 15.000 abitanti

1. Nei comuni con popolazione superiore a 15.000 abitanti, il sindaco e' eletto a suffragio universale e diretto, contestualmente all'elezione del consiglio comunale.

2. Ciascun candidato alla carica di sindaco deve dichiarare all'atto della presentazione della candidatura il collegamento con una o piu' liste presentate per l'elezione del consiglio comunale. La dichiarazione ha efficacia solo se convergente con analoga dichiarazione resa dai delegati delle liste interessate.

3. La scheda per l'elezione del sindaco e' quella stessa utilizzata per l'elezione del consiglio. La scheda reca i nomi e i cognomi dei candidati alla carica di sindaco, scritti entro un apposito rettangolo, ((sotto ai quali)) sono riportati i contrassegni della lista o delle liste con cui il candidato e' collegato. Tali contrassegni devono essere riprodotti sulle schede con il diametro di centimetri 3 . Ciascun elettore puo', con un unico voto, votare per un candidato alla carica di sindaco e per una delle liste ad esso collegate, tracciando un segno sul contrassegno di una di tali liste. Ciascun elettore puo' altresi' votare per un candidato alla carica di sindaco, anche non collegato alla lista prescelta, tracciando un segno sul relativo rettangolo. 4.E' proclamato eletto sindaco il candidato alla carica che ottiene la maggioranza assoluta dei voti validi. 5. Qualora nessun candidato ottenga la maggioranza di cui al comma 4, si procede ad un secondo turno elettorale che ha luogo la seconda domenica successiva a quella del primo. Sono ammessi al secondo turno i due candidati alla carica di sindaco che hanno ottenuto al primo turno il maggior numero di voti. In caso di parita' di voti tra i candidati, e' ammesso al ballottaggio il candidato collegato con la lista o il gruppo di liste per l'elezione del consiglio comunale che ha conseguito la maggiore cifra elettorale complessiva. A parita' di cifra elettorale, partecipa al ballottaggio il candidato piu' anziano di eta'. 6. In caso di impedimento permanente o decesso di uno dei candidati ammessi al ballottaggio ai sensi del comma 5, secondo periodo, partecipa al ballottaggio il candidato che segue nella graduatoria. Detto ballottaggio ha luogo la domenica successiva al decimo giorno dal verificarsi dell'evento. 7. Per i candidati ammessi al ballottaggio rimangono fermi i collegamenti con le liste per l'elezione del consiglio dichiarati al primo turno. I candidati ammessi al ballottaggio hanno tuttavia facolta', entro sette giorni dalla prima votazione, di dichiarare il collegamento con ulteriori liste rispetto a quelle con cui e' stato effettuato il collegamento nel primo turno. Tutte le dichiarazioni di collegamento hanno efficacia solo se convergenti con analoghe dichiarazioni rese dai delegati delle liste interessate. 8. La scheda per il ballottaggio comprende il nome e il cognome dei candidati alla carica di sindaco, scritti entro l'apposito rettangolo, sotto il quale sono riprodotti i simboli delle liste collegate. Il voto si esprime tracciando un segno sul rettangolo entro il quale e' scritto il nome del candidato prescelto. 9. Dopo il secondo turno e' proclamato eletto sindaco il candidato che ha ottenuto il maggior numero di voti validi. In caso di parita' di voti. e' proclamato eletto sindaco il candidato collegato. ai sensi del comma 7, con la lista o il gruppo di liste per l'elezione del consiglio comunale che ha conseguito la maggiore cifra elettorale complessiva. A parita' di cifra elettorale, e' proclamato eletto sindaco il candidato piu' anziano d'eta'.

### Art. 73. - Elezione del consiglio comunale nei comuni con popolazione superiore a 15.000 abitanti

1. Le liste per l'elezione del consiglio comunale devono comprendere un numero di candidati non superiore al numero dei consiglieri da eleggere e non inferiore ai due terzi, con arrotondamento all'unita' superiore qualora il numero dei consiglieri da comprendere nella lista contenga una cifra decimale superiore a 50 centesimi.((Nelle liste dei candidati nessuno dei due sessi puo' essere rappresentato in misura superiore a due terzi, con arrotondamento all'unita' superiore qualora il numero dei candidati del sesso meno rappresentato da comprendere nella lista contenga una cifra decimale inferiore a 50 centesimi)).

2. Con la lista di candidati al consiglio comunale deve essere anche presentato il nome e cognome del candidato alla carica di sindaco e il programma amministrativo da affiggere all'albo pretorio. Piu' liste possono presentare lo stesso candidato alla carica di sindaco. In tal caso le liste debbono presentare il medesimo programma amministrativo e si considerano fra di loro collegate.

3. Il voto alla lista viene espresso, ai sensi del comma 3 dell'art. 72, tracciando un segno sul contrassegno della lista prescelta. ((Ciascun elettore puo' altresi' esprimere, nelle apposite righe stampate sotto il medesimo contrassegno, uno o due voti di preferenza, scrivendo il cognome di non piu' di due candidati compresi nella lista da lui votata. Nel caso di espressione di due preferenze, esse devono riguardare candidati di sesso diverso della stessa lista, pena l'annullamento della seconda preferenza)). I contrassegni devono essere riprodotti sulle schede con il diametro di centimetri 3.

4. L'attribuzione dei seggi alle liste e' effettuata successivamente alla proclamazione dell'elezione del sindaco al termine del primo o del secondo turno.

5. La cifra elettorale di una lista e' costituita dalla somma dei voti validi riportati dalla lista stessa in tutte le sezioni del comune.

6. La cifra individuale di ciascun candidato a consigliere comunale e' costituita dalla cifra di lista aumentata dei voti di preferenza.

7. Non sono ammesse all'assegnazione dei seggi quelle liste che abbiano ottenuto al primo turno meno del 3 per cento dei voti validi e che non appartengano a nessun gruppo di liste che abbia superato tale soglia.

8. Salvo quanto disposto dal comma 10, per l'assegnazione del numero dei consiglieri a ciascuna lista o a ciascun gruppo di liste collegate, nel turno di elezione del sindaco, con i rispettivi candidati alla carica di sindaco si divide la cifra elettorale di ciascuna lista o gruppo di liste collegate successivamente per 1, 2, 3, 4, sino a concorrenza del numero dei consiglieri da eleggere e quindi si scelgono, fra i quozienti cosi ottenuti, i piu' alti, in numero eguale a quello dei consiglieri da eleggere, disponendoli in una graduatoria decrescente. Ciascuna lista o gruppo di liste avra' tanti rappresentanti quanti sono i quozienti ad essa appartenenti compresi nella graduatoria. A parita' di quoziente, nelle cifre intere e decimali, il posto e' attribuito alla lista o gruppo di liste che ha ottenuto la maggiore cifra elettorale e, a parita' di quest'ultima, per sorteggio. Se ad una lista spettano piu' posti di quanti sono i suoi candidati, i posti eccedenti sono distribuiti, fra le altre liste, secondo l'ordine dei quozienti.

9. Nell'ambito di ciascun gruppo di liste collegate la cifra elettorale di ciascuna di esse, corrispondente ai voti riportati nel primo turno, e' divisa per 1, 2, 3, 4,... sino a concorrenza del numero dei seggi spettanti al gruppo di liste. Si determinano in tal modo i quozienti piu' alti e, quindi, il numero dei seggi spettanti ad ogni lista.

10. Qualora un candidato alla carica di sindaco sia proclamato eletto al primo turno, alla lista o al gruppo di liste a lui collegate che non abbia gia' conseguito, ai sensi del comma 8, almeno il 60 per cento dei seggi del consiglio, ma abbia ottenuto almeno il 40 per cento dei voti validi, viene assegnato il 60 per cento dei seggi, sempreche' nessuna altra lista o altra gruppo di liste collegate abbia superato il 50 per cento dei voti validi. Qualora un candidato alla carica di sindaco sia proclamato eletto al secondo turno, alla lista o al gruppo di liste ad esso collegate che non abbia gia' conseguito, ai sensi del comma 8, almeno il 60 per cento dei seggi del consiglio, viene assegnato il 60 per cento dei seggi, sempreche' nessuna altra lista o altro gruppo di liste collegate al primo turno abbia gia' superato nel turno medesimo il 50 per cento dei voti validi. I restanti seggi vengono assegnati alle altre liste o gruppi di liste collegate ai sensi del comma 8.

11. Una volta determinato il numero dei seggi spettanti a ciascuna lista o gruppo di liste collegate, sono in primo luogo proclamati eletti alla carica di consigliere i candidati alla carica di sindaco, non risultati eletti, collegati a ciascuna lista che abbia ottenuto almeno un seggio. In caso di collegamento di piu' liste al medesimo candidato alla carica di sindaco risultato non eletto, il seggio spettante a quest'ultimo e' detratto dai seggi complessivamente attribuiti al gruppo di liste collegate.

12. Compiute le operazioni di cui al comma 11 sono proclamati eletti consiglieri comunali i candidati di ciascuna lista secondo l'ordine delle rispettive cifre individuali. In caso di parita' di cifra individuale, sono proclamati eletti i candidati che precedono nell'ordine di lista.

### Art. 74. - Elezione del presidente della provincia

1. Il presidente della provincia e' eletto a suffragio universale e diretto, contestualmente alla elezione del consiglio provinciale. La circoscrizione per l'elezione del presidente della provincia coincide con il territorio provinciale.

2. Oltre a quanto previsto dall'art. 14 della legge 8 marzo 1951, n. 122, e successive modificazioni, il deposito, l'affissione presso l'albo pretorio della provincia e la presentazione delle candidature alla carica di consigliere provinciale e di presidente della provincia sono disciplinati dalle disposizioni di cui all'art. 3, commi 3 e 4, della legge 25 marzo 1993, n. 81, in quanto compatibili.

3. All'atto di presentare la propria candidatura ciascun candidato alla carica di presidente della provincia deve dichiarare di collegarsi ad almeno uno dei gruppi di candidati per l'elezione del consiglio provinciale. La dichiarazione di collegamento ha efficacia solo se convergente con analoga dichiarazione resa dai delegati dei gruppi interessati.

4. La scheda per l'elezione del presidente della provincia e' quella stessa utilizzata per l'elezione del consiglio e reca, alla destra del nome e cognome di ciascun candidato alla carica di presidente della provincia, il contrassegno o i contrassegni del gruppo o dei gruppi di candidati al consiglio cui il candidato ha dichiarato di collegarsi. Alla destra di ciascun contrassegno e' riportato il nome e cognome del candidato al consiglio provinciale facente parte del gruppo di candidati contraddistinto da quel contrassegno. (( I contrassegni devono essere riprodotti sulle schede con il diametro di centimetri 3 )).

5. Ciascun elettore puo' votare per uno dei candidati al consiglio provinciale tracciando un segno sul relativo contrassegno. Ciascun elettore puo', altresi', votare sia per un candidato alla carica di presidente della provincia, tracciando un segno sul relativo rettangolo, sia per uno dei candidati al consiglio provinciale ad esso collegato, tracciando anche un segno sul relativo contrassegno. Il voto espresso nei modi suindicati si intende attribuito sia al candidato alla carica di consigliere provinciale corrispondente al contrassegno votato sia al candidato alla carica di presidente della provincia. Ciascun elettore puo', infine, votare per un candidato alla carica di presidente della provincia tracciando un segno sul relativo rettangolo. Il voto in tal modo espresso si intende attribuito solo al candidato alla carica di presidente della provincia.

6. E' proclamato eletto presidente della provincia il candidato alla carica che ottiene la maggioranza assoluta dei voti validi.

7. Qualora nessun candidato ottenga la maggioranza di cui al comma 6, si procede ad un secondo turno elettorale che ha luogo la seconda domenica successiva a quella del primo. Sono ammessi al secondo turno i due candidati alla carica di presidente della provincia che hanno ottenuto al primo turno il maggior numero di voti. In caso di parita' di voti fra il secondo ed il terzo candidato e' ammesso al ballottaggio il piu' anziano di eta'.

8. In caso di impedimento permanente o decesso di uno dei candidati ammessi al ballottaggio, partecipa al secondo turno il candidato che segue nella graduatoria. Detto ballottaggio dovra' aver luogo la domenica successiva al decimo giorno dal verificarsi dell'evento.

9. I candidati ammessi al ballottaggio mantengono i collegamenti con i gruppi di candidati al consiglio provinciale dichiarati al primo turno. I candidati ammessi al ballottaggio hanno facolta' entro sette giorni dalla prima votazione, di dichiarare il collegamento con ulteriori gruppi di candidati rispetto a quelli con cui e' stato effettuato il collegamento nel primo turno. La dichiarazione ha efficacia solo se convergente con analoga dichiarazione resa dai delegati dei gruppi interessati.

10. La scheda per il ballottaggio comprende il nome ed il cognome dei candidati alla carica di presidente della provincia, scritti entro l'apposito rettangolo, sotto il quale sono riprodotti i simboli dei gruppi di candidati collegati. Il voto si esprime tracciando un segno sul rettangolo entro il quale e' scritto il nome del candidato prescelto.

11. Dopo il secondo turno e' proclamato eletto presidente della provincia il candidato che ha ottenuto il maggior numero di voti validi. In caso di parita' di voti, e' proclamato eletto presidente della provincia il candidato collegato con il gruppo o i gruppi di candidati per il consiglio provinciale che abbiano conseguito la maggiore cifra elettorale complessiva. A parita' di cifra elettorale, e' proclamato eletto il candidato piu' anziano di eta'.

### Articolo 75 - Elezione del consiglio provinciale

1. L'elezione dei consiglieri provinciali e' effettuata sulla base di collegi uninominali e secondo le disposizioni dettate dalla legge 8 marzo 1951, n. 122, e successive modificazioni, in quanto compatibili con le norme di cui all'articolo 74 e al presente articolo.

2. Con il gruppo di candidati collegati deve essere anche presentato il nome e cognome del candidato alla carica di presidente della provincia e il programma amministrativo da affiggere all'albo pretorio. Piu' gruppi possono presentare lo stesso candidato alla carica di presidente della provincia. In tal caso i gruppi debbono presentare il medesimo programma amministrativo e si considerano fra di loro collegati.

3. L'attribuzione dei seggi del consiglio provinciale ai gruppi di candidati collegati e' effettuata dopo la proclamazione dell'elezione del presidente della provincia.

4. La cifra elettorale di ogni gruppo e' data dal totale dei voti validi ottenuti da tutti i candidati del gruppo stesso nei singoli collegi della provincia.

5. Non sono ammessi all'assegnazione dei seggi i gruppi di candidati che abbiano ottenuto al primo turno meno del 3 per cento dei voti validi e che non appartengano a nessuna coalizione di gruppi che abbia superato tale soglia.

6. Per l'assegnazione dei seggi a ciascun gruppo di candidati collegati, si divide la cifra elettorale conseguita da ciascun gruppo di candidati successivamente per 1, 2, 3, 4,.... sino a concorrenza del numero di consiglieri da eleggere. Quindi tra i quozienti cosi' ottenuti si scelgono i piu' alti, in numero eguale a quello dei consiglieri da eleggere, disponendoli in una graduatoria decrescente. A ciascun gruppo di candidati sono assegnati tanti rappresentanti quanti sono i quozienti ad esso appartenenti compresi nella graduatoria. A parita' di quoziente, nelle cifre intere e decimali, il posto e' attribuito al gruppo di candidati che ha ottenuto la maggior cifra elettorale e, a parita' di quest'ultima, per sorteggio. Se ad un gruppo spettano piu' posti di quanti sono i suoi candidati, i posti eccedenti sono distribuiti tra gli altri gruppi, secondo l'ordine dei quozienti.

7. Le disposizioni di cui al comma 6 si applicano quando il gruppo o i gruppi di candidati collegati al candidato proclamato eletto presidente della provincia abbiano conseguito almeno il 60 per cento dei seggi assegnati al consiglio provinciale.

8. Qualora il gruppo o i gruppi di candidati collegati al candidato proclamato eletto presidente della provincia non abbiano conseguito almeno il 60 per cento dei seggi assegnati al consiglio provinciale, a tale gruppo o gruppi di candidati viene assegnato il 60 per cento dei seggi, con arrotondamento all'unita' superiore qualora il numero dei consiglieri da attribuire al gruppo o ai gruppi contenga una cifra decimale superiore a 50 centesimi. In caso di collegamento di piu' gruppi con il candidato proclamato eletto presidente, per determinare il numero di seggi spettanti a ciascun gruppo, si dividono le rispettive cifre elettorali corrispondenti ai voti riportati al primo turno, per 1, 2, 3, 4,... sino a concorrenza del numero dei seggi da assegnare. Si determinano in tal modo i quozienti piu' alti e, quindi, il numero dei seggi spettanti ad ogni gruppo di candidati.

9. I restanti seggi sono attribuiti agli altri gruppi di candidati ai sensi del comma 6.

10. Una volta determinato il numero dei seggi spettanti a ciascun gruppo di candidati, sono in primo luogo proclamati eletti alla carica di consigliere i candidati alla carica di presidente della provincia non risultati eletti, collegati a ciascun gruppo di candidati che abbia ottenuto almeno un seggio. In caso di collegamento di piu' gruppi con il candidato alla carica di presidente della provincia non eletto, il seggio spettante a quest'ultimo e' detratto dai seggi complessivamente attribuiti ai gruppi di candidati collegati.

11. Compiute le operazioni di cui al comma 10 sono proclamati eletti consiglieri provinciali i candidati di ciascun gruppo secondo l'ordine delle rispettive cifre individuali.

12. La cifra individuale dei candidati a consigliere provinciale viene determinata moltiplicando il numero dei voti validi ottenuto da ciascun candidato per cento e dividendo il prodotto per il totale dei voti validi espressi nel collegio per i candidati a consigliere provinciale. Nel caso di candidature presentate in piu' di un collegio si assume, ai fini della graduatoria, la maggiore cifra individuale riportata dal candidato.

### Articolo 76 - Anagrafe degli amministratori locali e regionali

1. Avvenuta la proclamazione degli eletti, il competente ufficio del Ministero dell'interno in materia elettorale raccoglie i dati relativi agli eletti a cariche locali e regionali nella apposita anagrafe degli amministratori locali, nonche' i dati relativi alla tenuta ed all'aggiornamento anche in corso di mandato.

2. L'anagrafe e' costituita dalle notizie relative agli eletti nei comuni, province e regioni concernenti i dati anagrafici, la lista o gruppo di appartenenza o di collegamento, il titolo di studio e la professione esercitata. I dati sono acquisiti presso comuni, province e regioni, anche attraverso i sistemi di comunicazione telematica.

3. Per gli amministratori non elettivi l'anagrafe e' costituita dai dati indicati al comma 2 consensualmente forniti dagli amministratori stessi.

4. Al fine di assicurare la massima trasparenza e' riconosciuto a chiunque il diritto di prendere visione ed estrarre copia, anche su supporto informatico, dei dati contenuti nell'anagrafe.

## Status degli amministratori locali

### Articolo 77 - Definizione di amministratore locale

1. La Repubblica tutela il diritto di ogni cittadino chiamato a ricoprire cariche pubbliche nelle amministrazioni degli enti locali ad espletare il mandato, disponendo del tempo, dei servizi e delle risorse necessari ed usufruendo di indennita' e di rimborsi spese nei modi e nei limiti previsti dalla legge.

2. Il presente capo disciplina il regime delle aspettative, dei permessi e delle indennita' degli amministratori degli enti locali. Per amministratori si intendono, ai soli fini del presente capo, i sindaci, anche metropolitani, i presidenti delle province, i consiglieri dei comuni anche metropolitani e delle province, i componenti delle giunte comunali, metropolitane e provinciali, i presidenti dei consigli comunali, metropolitani e provinciali, i presidenti, i consiglieri e gli assessori delle comunita' montane, i componenti degli organi delle unioni di comuni e dei consorzi fra enti locali, nonche' i componenti degli organi di decentramento.

### Articolo 78 - Doveri e condizione giuridica

1. Il comportamento degli amministratori, nell'esercizio delle proprie funzioni, deve essere improntato all'imparzialita' e al principio di buona amministrazione, nel pieno rispetto della distinzione tra le funzioni, competenze e responsabilita' degli amministratori di cui all'articolo 77, comma 2, e quelle proprie dei dirigenti delle rispettive amministrazioni.

2. Gli amministratori di cui all'articolo 77, comma 2, devono astenersi dal prendere parte alla discussione ed alla votazione di delibere riguardanti interessi propri o di loro parenti o affini sino al quarto grado. L'obbligo di astensione non si applica ai provvedimenti normativi o di carattere generale, quali i piani urbanistici, se non nei casi in cui sussista una correlazione immediata e diretta fra il contenuto della deliberazione e specifici interessi dell'amministratore o di parenti o affini fino al quarto grado.

3. I componenti la giunta comunale competenti in materia di urbanistica, di edilizia e di lavori pubblici devono astenersi dall'esercitare attivita' professionale in materia di edilizia privata e pubblica nel territorio da essi amministrato.

4. Nel caso di piani urbanistici, ove la correlazione immediata e diretta di cui al comma 2 sia stata accertata con sentenza passata in giudicato, le parti di strumento urbanistico che costituivano oggetto della correlazione sono annullate e sostituite mediante nuova variante urbanistica parziale. Nelle more dell'accertamento di tale stato di correlazione immediata e diretta tra il contenuto della deliberazione e specifici interessi dell'amministratore o di parenti o affini e' sospesa la validita' delle relative disposizioni del piano urbanistico.

5. Al sindaco ed al presidente della provincia, nonche' agli assessori ed ai consiglieri comunali e provinciali e' vietato ricoprire incarichi e assumere consulenze presso enti ed istituzioni dipendenti o comunque sottoposti al controllo ed alla vigilanza dei relativi comuni e province.

6. Gli amministratori lavoratori dipendenti, pubblici e privati, non possono essere soggetti, se non per consenso espresso, a trasferimenti durante l'esercizio del mandato. La richiesta dei predetti lavoratori di avvicinamento al luogo in cui viene svolto il mandato amministrativo deve essere esaminata dal datore di lavoro con criteri di priorita'. ((...)).

### Articolo 79 - Permessi e licenze

1. I lavoratori dipendenti, pubblici e privati, componenti dei consigli comunali, provinciali, metropolitani, delle comunita' montane e delle unioni di comuni, nonche' dei consigli circoscrizionali dei comuni con popolazione superiore a 500.000 abitanti, hanno diritto di assentarsi dal servizio per il tempo strettamente necessario per la partecipazione a ciascuna seduta dei rispettivi consigli e per il raggiungimento del luogo di suo svolgimento. Nel caso in cui i consigli si svolgano in orario serale, i predetti lavoratori hanno diritto di non riprendere il lavoro prima delle ore 8 del giorno successivo; nel caso in cui i lavori dei consigli si protraggano oltre la mezzanotte, hanno diritto di assentarsi dal servizio per l'intera giornata successiva. (50)

2. COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66.

3. I lavoratori dipendenti facenti parte delle giunte comunali, provinciali, metropolitane, delle comunita' montane, nonche' degli organi esecutivi dei consigli circoscrizionali, dei municipi, delle unioni di comuni e dei consorzi fra enti locali, ovvero facenti parte delle commissioni consiliari o circoscrizionali formalmente istituite nonche' delle commissioni comunali previste per legge, ovvero membri delle conferenze del capogruppo e degli organismi di pari opportunita', previsti dagli statuti e dai regolamenti consiliari, hanno diritto di assentarsi dal servizio per partecipare alle riunioni degli organi di cui fanno parte per la loro effettiva durata. Il diritto di assentarsi di cui al presente comma comprende il tempo per raggiungere il luogo della riunione e rientrare al posto di lavoro. PERIODO ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66.

4. I componenti degli organi esecutivi dei comuni, delle province, delle citta' metropolitane, delle unioni di comuni, delle comunita' montane e dei consorzi fra enti locali, e i presidenti dei consigli comunali, provinciali e circoscrizionali, nonche' i presidenti dei gruppi consiliari delle province e dei comuni con popolazione superiore a 15.000 abitanti, hanno diritto, oltre ai permessi di cui ai precedenti commi, di assentarsi dai rispettivi posti di lavoro per un massimo di 24 ore lavorative al mese, elevate a 48 ore per i sindaci, presidenti delle province, sindaci metropolitani, presidenti delle comunita' montane, presidenti dei consigli provinciali e dei comuni con popolazione superiore a 30.000 abitanti. ((96))

5. I lavoratori dipendenti di cui al presente articolo hanno diritto ad ulteriori permessi non retribuiti sino ad un massimo di 24 ore lavorative mensili qualora risultino necessari per l'espletamento del mandato.

6. L'attivita' ed i tempi di espletamento del mandato per i quali i lavoratori chiedono ed ottengono permessi, retribuiti e non retribuiti, devono essere prontamente e puntualmente documentati mediante attestazione dell'ente.

--------------- AGGIORNAMENTO (50) Il D.L. 13 agosto 2011, n. 138, convertito con modificazioni dalla L. 14 settembre 2011, n. 148, ha disposto (con l'art. 16, comma 29) che "Le disposizioni di cui al presente articolo si applicano ai comuni appartenenti alle regioni a statuto speciale ed alle province autonome di Trento e di Bolzano nel rispetto degli statuti delle regioni e province medesime, delle relative norme di attuazione e secondo quanto previsto dall'articolo 27 della legge 5 maggio 2009, n. 42". --------------- AGGIORNAMENTO (96) Il D.L. 17 ottobre 2016, n. 189, convertito con modificazioni dalla L. 15 dicembre 2016, n. 229, come modificato dal D.L. 16 ottobre 2017, n. 148, convertito con modificazioni dalla L. 4 dicembre 2017, n. 172, ha disposto (con l'art. 44, comma 2-bis) che "Nei Comuni di cui agli allegati 1, 2 e 2-bis del presente decreto, i limiti previsti dal comma 4 dell'articolo 79 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, per la fruizione di permessi e di licenze sono aumentati rispettivamente a 48 ore lavorative al mese, elevate a 96 ore per i comuni con popolazione superiore a 30.000 abitanti".

### Art. 80. - Oneri per permessi retribuiti

1. Le assenze dal servizio di cui ai commi 1, 2, 3 e 4 dell'articolo 79 sono retribuite al lavoratore dal datore di lavoro. (( Gli oneri per i permessi retribuiti dei lavoratori dipendenti da privati o da enti pubblici economici sono a carico dell'ente presso il quale gli stessi lavoratori esercitano le funzioni pubbliche di cui all'articolo 79. )) L'ente, su richiesta documentata del datore di lavoro, e' tenuto a rimborsare quanto dallo stesso corrisposto, per retribuzioni ed assicurazioni, per le ore o giornate di effettiva assenza del lavoratore. Il rimborso viene effettuato dall'ente entro trenta giorni dalla richiesta. Le somme rimborsate sono esenti da imposta sul valore aggiunto ai sensi dell'articolo 8, comma 35, della legge 11 marzo 1988. n. 67.

### Articolo 81 - Aspettative

1.(( I sindaci, i presidenti delle province, i presidenti dei consigli comunali e provinciali, i presidenti dei consigli circoscrizionali dei comuni di cui all'articolo 22, comma 1, i presidenti delle comunita' montane e delle unioni di comuni, nonche' i membri delle giunte di comuni e province )), che siano lavoratori dipendenti possono essere collocati a richiesta in aspettativa non retribuita per tutto il periodo di espletamento del mandato. Il periodo di aspettativa e' considerato come servizio effettivamente prestato, nonche' come legittimo impedimento per il compimento del periodo di prova. (( I consiglieri di cui all'articolo 77, comma 2, se a domanda collocati in aspettativa non retribuita per il periodo di espletamento del mandato, assumono a proprio carico l'intero pagamento degli oneri previdenziali, assistenziali e di ogni altra natura previsti dall'articolo 86 )).

### Art. 82. - Indennita'

1. Il decreto di cui al comma 8 del presente articolo determina una indennita' di funzione, nei limiti fissati dal presente articolo, per il sindaco, il presidente della provincia, il sindaco metropolitano, il presidente della comunita' montana, i presidenti dei consigli circoscrizionali dei soli comuni capoluogo di provincia , i presidenti dei consigli comunali e provinciali, nonche' i componenti degli organi esecutivi dei comuni e ove previste delle loro articolazioni, delle province, delle citta' metropolitane, delle comunita' montane, delle unioni di comuni e dei consorzi fra enti locali. Tale indennita' e' dimezzata per i lavoratori dipendenti che non abbiano richiesto l'aspettativa.

2. I consiglieri comunali e provinciali hanno diritto di percepire, nei limiti fissati dal presente capo, un gettone di presenza per la partecipazione a consigli e commissioni. In nessun caso l'ammontare percepito nell'ambito di un mese da un consigliere puo' superare l'importo pari ad un quarto dell'indennita' massima prevista per il rispettivo sindaco o presidente in base al decreto di cui al comma 8. Nessuna indennita' e' dovuta ai consiglieri circoscrizionali ad eccezione dei consiglieri circoscrizionali delle citta' metropolitane per i quali l'ammontare del gettone di presenza non puo' superare l'importo pari ad un quarto dell'indennita' prevista per il rispettivo presidente.In nessun caso gli oneri a carico dei predetti enti per i permessi retribuiti dei lavoratori dipendenti da privati o da enti pubblici economici possono mensilmente superare, per ciascun consigliere circoscrizionale, l'importo pari ad un quarto dell'indennita' prevista per il rispettivo presidente. (48)

3. Ai soli fini dell'applicazione delle norme relative al divieto di cumulo tra pensione e redditi, le indennita' di cui ai commi 1 e 2 non sono assimilabili ai redditi da lavoro di qualsiasi natura.

4. COMMA ABROGATO DALLA L. 24 DICEMBRE 2007, N. 244.

5. Le indennita' di funzione previste dal presente capo non sono tra loro cumulabili. L'interessato opta per la percezione di una delle due indennita' ovvero per la percezione del 50 per cento di ciascuna.

6. COMMA ABROGATO DALLA L. 24 DICEMBRE 2007, N. 244.

7. Agli amministratori ai quali viene corrisposta l'indennita' di funzione prevista dal presente capo non e' dovuto alcun gettone per la partecipazione a sedute degli organi collegiali del medesimo ente, ne' di commissioni che di quell'organo costituiscono articolazioni interne ed esterne.

8. La misura delle indennita' di funzione e dei gettoni di presenza di cui al presente articolo e' determinata, senza maggiori oneri a carico del bilancio dello Stato, con decreto del Ministro dell'interno, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, ai sensi dell'articolo 17, Comma 3, della legge 23 agosto 1988, n. 400, sentita la Conferenza Stato-citta' ed autonomie locali nel rispetto dei seguenti criteri:

- a) equiparazione del trattamento per categorie di amministratori;
- b) articolazione delle indennita' in rapporto con la dimensione demografica degli enti, tenuto conto delle fluttuazioni stagionali della popolazione, della percentuale delle entrate proprie dell'ente rispetto al totale delle entrate, nonche' dell'ammontare del bilancio di parte corrente;
- c) articolazione dell'indennita' di funzione dei presidenti dei consigli, dei vice sindaci e dei vice presidenti delle province, degli assessori, in rapporto alla misura della stessa stabilita per il sindaco e per il presidente della provincia. Al presidente e agli assessori delle unioni di comuni, dei consorzi fra enti locali e delle comunita' montane sono attribuite le indennita' di funzione nella misura massima del 50 per cento dell'indennita' prevista per un comune avente popolazione pari alla popolazione dell'unione di comuni, del consorzio fra enti locali o alla popolazione montana della comunita' montana;
- d) definizione di speciali indennita' di funzione per gli amministratori delle citta' metropolitane in relazione alle particolari funzioni ad esse assegnate;
- e) LETTERA SOPPRESSA DAL D.L. 31 MAGGIO 2010, N. 78, CONVERTITO CON MODIFICAZIONI DALLA L. 30 LUGLIO 2010, N. 122.
- f) previsione dell'integrazione dell'indennita' dei sindaci e dei presidenti di provincia, a fine mandato, con una somma pari a una indennita' mensile, spettante per ciascun anno di mandato.

8-bis. La misura dell'indennita' di funzione di cui al presente articolo spettante ai sindaci dei comuni con popolazione fino a 3.000 abitanti e' incrementata fino all'85 per cento della misura dell'indennita' spettante ai sindaci dei comuni con popolazione fino a 5.000 abitanti.

9. Su richiesta della Conferenza Stato-citta' ed autonomie locali si' puo' procedere alla revisione del decreto ministeriale di cui al comma 8 con la medesima procedura ivi indicata.

10. Il decreto ministeriale di cui al comma 8 e' rinnovato ogni tre anni ai fini dell'adeguamento della misura delle indennita' e dei gettoni di presenza sulla base della media degli indici annuali dell'ISTAT di variazione del costo della vita applicando, alle misure stabilite per l'anno precedente, la variazione verificatasi nel biennio nell'indice dei prezzi al consumo rilevata dall'ISTAT e pubblicata nella Gazzetta Ufficiale relativa al mese di luglio di inizio ed al mese di giugno di termine del biennio.

11. La corresponsione dei gettoni di presenza e' comunque subordinata alla effettiva partecipazione del consigliere a consigli e commissioni; il regolamento ne stabilisce termini e modalita'. (35) (47) ((109)) (93) (96)

--------------- AGGIORNAMENTO (35) Il D.L. 25 giugno 2008, n.112 convertito, con modificazioni, dalla L. 6 agosto 2008, n. 133 ha disposto che (con l'art. 61, comma 10) "A decorrere dal 1° gennaio 2009 le indennita' di funzione ed i gettoni di presenza indicati nell'articolo 82 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, e successive modificazioni, sono rideterminati con una riduzione del 30 per cento rispetto all'ammontare risultante alla data del 30 giugno 2008 per gli enti indicati nel medesimo articolo 82 che nell'anno precedente non hanno rispettato il patto di stabilita'. Sino al 2011 e' sospesa la possibilita' di incremento prevista nel comma 10 dell'articolo 82 del citato testo unico di cui al decreto legislativo n. 267 del 2000." --------------- AGGIORNAMENTO (47) La L. 13 dicembre 2010, n. 220, ha disposto (con l'art. 1, comma 120) che "Le indennita` di funzione e i gettoni di presenza indicati nell'articolo 82 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, e successive modificazioni, sono rideterminati con una riduzione del 30 per cento rispetto all'ammontare risultante alla data del 30 giugno 2008 per gli enti locali che nell'anno precedente non hanno rispettato il patto di stabilita` interno". --------------- AGGIORNAMENTO (48) Il D.L. 29 dicembre 2010, n. 225, convertito con modificazioni dalla L. 26 febbraio 2011, n. 10, ha disposto (con l'art. 2, comma 9-ter) che il terzo periodo del comma 2 del presente articolo si interpreta, con effetto dalla data di entrata in vigore della legge di conversione del medesimo decreto, nel senso che "per le citta' metropolitane si intendono i comuni capoluogo di regione come individuati negli articoli 23 e 24 della legge 5 maggio 2009, n. 42, e successive modificazioni". --------------- AGGIORNAMENTO (93) Il D.L. 17 ottobre 2016, n. 189, convertito con modificazioni dalla L. 15 dicembre 2016, n. 229, come modificato dal D.L. 9 febbraio 2017, n. 8, convertito con modificazioni dalla L. 7 aprile 2017, n. 45, ha disposto (con l'art. 44, comma 2-bis) che "In deroga alle disposizioni di cui all'articolo 82 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e all'articolo 1, comma 136, della legge 7 aprile 2014, n. 56, al sindaco e agli assessori dei comuni di cui all'articolo 1, comma 1, del presente decreto con popolazione inferiore a 5.000 abitanti, in cui sia stata individuata da un'ordinanza sindacale una 'zona rossa', e' data facolta' di applicare l'indennita' di funzione prevista dal regolamento di cui al decreto del Ministro dell'interno 4 aprile 2000, n. 119, per la classe di comuni con popolazione compresa tra 10.001 e 30.000 abitanti, come rideterminata in base alle disposizioni di cui all'articolo 61, comma 10, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, per la durata di un anno dalla data di entrata in vigore della presente disposizione, con oneri a carico del bilancio comunale". --------------- AGGIORNAMENTO (96) Il D.L. 17 ottobre 2016, n. 189, convertito con modificazioni dalla L. 15 dicembre 2016, n. 229, come modificato dal D.L. 16 ottobre 2017, n. 148, convertito con modificazioni dalla L. 4 dicembre 2017, n. 172, ha disposto (con l'art. 44, comma 2-bis) che "In deroga alle disposizioni di cui all'articolo 82 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e all'articolo 1, comma 136, della legge 7 aprile 2014, n. 56, al sindaco e agli assessori dei comuni di cui all'articolo 1, comma 1, del presente decreto con popolazione inferiore a 5.000 abitanti, in cui sia stata individuata da un'ordinanza sindacale una 'zona rossa', e' data facolta' di applicare l'indennita' di funzione prevista dal regolamento di cui al decreto del Ministro dell'interno 4 aprile 2000, n. 119, per la classe di comuni con popolazione compresa tra 10.001 e 30.000 abitanti, come rideterminata in base alle disposizioni di cui all'articolo 61, comma 10, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, per la durata di due anni dalla data di entrata in vigore della presente disposizione, con oneri a carico del bilancio comunale". -------------- AGGIORNAMENTO (109) La L. 27 dicembre 2019, n. 160, nel modificare l'art. 2, comma 25, lettera d) della L. 24 dicembre 2007, n. 244, ha conseguentemente disposto (con l'art. 1, comma 552) che "Le disposizioni di cui all'articolo 2, comma 25, lettera d), della legge 24 dicembre 2007, n. 244, e all'articolo 76, comma 3, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, sono da intendersi riferite al divieto di applicare incrementi ulteriori rispetto all'ammontare dei gettoni di presenza e delle indennita' spettanti agli amministratori locali e gia' in godimento alla data di entrata in vigore delle suddette disposizioni, fermi restando gli incrementi qualora precedentemente determinati secondo le disposizioni vigenti fino a tale data".

### Articolo 83 - (Divieto di cumulo)

1. I parlamentari nazionali ed europei, nonche' i consiglieri regionali non possono percepire i gettoni di presenza ((o altro emolumento comunque denominato)) previsti dal presente capo.

2. Salve le disposizioni previste per le forme associative degli enti locali, gli amministratori locali di cui all'articolo 77, comma 2, non percepiscono alcun compenso (( . . . )) per la partecipazione ad organi o commissioni comunque denominate, se tale partecipazione e' connessa all'esercizio delle proprie funzioni pubbliche.

3. In caso di cariche incompatibili, le indennita' di funzione non sono cumulabili; ai soggetti che si trovano in tale condizione, fino al momento dell'esercizio dell'opzione o comunque sino alla rimozione della condizione di incompatibilita', l'indennita' per la carica sopraggiunta non viene corrisposta.

### Articolo 84 - (Rimborso delle spese di viaggio)

1. Agli amministratori che, in ragione del loro mandato, si rechino fuori del capoluogo del comune ove ha sede il rispettivo ente, previa autorizzazione del capo dell'amministrazione, nel caso di componenti degli organi esecutivi, ovvero del presidente del consiglio, nel caso di consiglieri, ((e' dovuto)) esclusivamente il rimborso delle spese di viaggio effettivamente sostenute (( . . . )) nella misura fissata con decreto del Ministro dell'interno e del Ministro dell'economia e delle finanze, d'intesa con la Conferenza Stato-citta' ed autonomie locali.

2. La liquidazione del rimborso delle spese e' effettuata dal dirigente competente, su richiesta dell'interessato, corredata della documentazione delle spese di viaggio e soggiorno effettivamente sostenute e di una dichiarazione sulla durata e sulle finalita' della missione.

3. Agli amministratori che risiedono fuori del capoluogo del comune ove ha sede il rispettivo ente spetta il rimborso per le sole spese di viaggio effettivamente sostenute per la partecipazione ad ognuna delle sedute dei rispettivi organi assembleari ed esecutivi, nonche' per la presenza necessaria presso la sede degli uffici per lo svolgimento delle funzioni proprie o delegate.

### Articolo 85 - Partecipazione alle associazioni rappresentative degli enti locali

1. Le norme stabilite dal presente capo, relative alla posizione, al trattamento e al permessi dei lavoratori pubblici e privati chiamati a funzioni elettive, si applicano anche per la partecipazione dei rappresentanti degli enti locali alle associazioni internazionali, nazionali e regionali tra enti locali.

2. Le spese che gli enti locali ritengono di sostenere, per la partecipazione dei componenti dei propri organi alle riunioni e alle attivita' degli organi nazionali e regionali delle associazioni, fanno carico ai bilanci degli enti stessi.

### Articolo 86 - Oneri previdenziali, assistenziali e assicurativi e disposizioni fiscali e assicurative

1. L'amministrazione locale prevede a proprio carico, dandone comunicazione tempestiva ai datori di lavoro, il versamento degli oneri assistenziali, previdenziali e assicurativi ai rispettivi istituti per i sindaci, per i presidenti di provincia, per i presidenti di comunita' montane, di unioni di comuni e di consorzi fra enti locali, per gli assessori provinciali e per gli assessori dei comuni con popolazione superiore a 10.000 abitanti, per i presidenti dei consigli dei comuni con popolazione superiore a 50.000 abitanti, per i presidenti dei consigli provinciali che siano collocati in aspettativa non retribuita ai sensi del presente testo unico. La medesima disposizione si applica per i presidenti dei consigli circoscrizionali nei casi in cui il comune abbia attuato nei loro confronti un effettivo decentramento di funzioni e per i presidenti delle aziende anche consortili fino all'approvazione della riforma in materia di servizi pubblici locali che si trovino nelle condizioni previste dall'articolo 81.

2. Agli amministratori locali che non siano lavoratori dipendenti e che rivestano le cariche di cui al comma 1 l'amministrazione locale provvede, allo stesso titolo previsto dal comma 1, al pagamento di una cifra forfettaria annuale, versata per quote mensili. Con decreto dei Ministri dell'interno, del lavoro e della previdenza sociale e del tesoro, del bilancio e della programmazione economica sono stabiliti i criteri per la determinazione delle quote forfettarie in coerenza con quanto previsto per i lavoratori dipendenti, da conferire alla forma pensionistica presso la quale il soggetto era iscritto o continua ad essere iscritto alla data dell'incarico.

3. L'amministrazione locale provvede, altresi', a rimborsare al datore di lavoro la quota annuale di accantonamento per l'indennita' di fine rapporto entro i limiti di un dodicesimo dell'indennita' di carica annua da parte dell'ente e per l'eventuale residuo da parte dell'amministratore.

4. Alle indennita' di funzione e ai gettoni di presenza si applicano le disposizioni di cui all'articolo 26, comma 1, delle legge 23 dicembre 1994, n. 724.

((5. Gli enti locali di cui all'articolo 2 del presente testo unico, senza nuovi o maggiori oneri per la finanza pubblica, possono assicurare i propri amministratori contro i rischi conseguenti all'espletamento del loro mandato. Il rimborso delle spese legali per gli amministratori locali e' ammissibile, senza nuovi o maggiori oneri per la finanza pubblica, nel limite massimo dei parametri stabiliti dal decreto di cui all'articolo 13, comma 6, della legge 31 dicembre 2012, n. 247, nel caso di conclusione del procedimento con sentenza di assoluzione o di emanazione di un provvedimento di archiviazione, in presenza dei seguenti requisiti:

a) assenza di conflitto di interessi con l'ente amministrato;

b) presenza di nesso causale tra funzioni esercitate e fatti giuridicamente rilevanti;

c) assenza di dolo o colpa grave))

6. Al fine di conferire certezza alla posizione previdenziale e assistenziale dei soggetti destinatari dei benefici di cui al comma 1 e' consentita l'eventuale ripetizione degli oneri assicurativi, assistenziali e previdenziali, entro cinque anni dalla data del loro versamento, se precedente alla data di entrata in vigore della legge 3 agosto 1999, n. 265, ed entro tre anni se successiva.

### Articolo 87 - Consigli di amministrazione delle aziende speciali

1. Fino all'approvazione della riforma in materia di servizi pubblici locali, ai componenti dei consigli di amministrazione delle aziende speciali anche consortili si applicano le disposizioni contenute nell'articolo 78, comma 2, nell'articolo 79, commi 3 e 4, nell'articolo 81, nell'articolo 85 e nell'articolo 86.

## ORGANIZZAZIONE E PERSONALE CAPO I Uffici e personale

### Articolo 88 - Disciplina applicabile agli uffici ed al personale degli enti locali

1. All'ordinamento degli uffici e del personale degli enti locali, ivi compresi i dirigenti ed i segretari comunali e provinciali, si applicano le disposizioni del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni ed integrazioni, e le altre disposizioni di legge in materia di organizzazione e lavoro nelle pubbliche amministrazioni nonche' quelle contenute nel presente testo unico.

### Articolo 89 - Fonti

1. Gli enti locali disciplinano, con propri regolamenti, in conformita' allo statuto, l'ordinamento generale degli uffici e dei servizi, in base a criteri di autonomia, funzionalita' ed economicita' di gestione e secondo principi di professionalita' e responsabilita'.

2. La potesta' regolamentare degli enti locali si esercita, tenendo conto di quanto demandato alla contrattazione collettiva nazionale, nelle seguenti materie:

- a) responsabilita' giuridiche attinenti ai singoli operatori nell'espletamento delle procedure amministrative;
- b) organi, uffici, modi di conferimento della titolarita' dei medesimi;
- c) principi fondamentali di organizzazione degli uffici;
- d) procedimenti di selezione per l'accesso al lavoro e di avviamento al lavoro;
- e) ruoli, dotazioni organiche e loro consistenza complessiva;
- f) garanzia della liberta' di insegnamento ed autonomia professionale nello svolgimento dell'attivita' didattica, scientifica e di ricerca;
- g) disciplina della responsabilita' e delle incompatibilita' tra impiego nelle pubbliche amministrazioni ed altre attivita' e casi di divieto di cumulo di impieghi e incarichi pubblici.

3. I regolamenti di cui al comma 1, nella definizione delle procedure per le assunzioni, fanno riferimento ai principi fissati dall'articolo 36 del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni ed integrazioni.

4. In mancanza di disciplina regolamentare sull'ordinamento degli uffici e dei servizi o per la parte non disciplinata dalla stessa, si applica la procedura di reclutamento prevista dal decreto del Presidente della Repubblica 9 maggio 1994, n. 487.

5. Gli enti locali, nel rispetto dei principi fissati dal presente testo unico, provvedono alla rideterminazione delle proprie dotazioni organiche, nonche' all'organizzazione e gestione del personale nell'ambito della propria autonomia normativa ed organizzativa con i soli limiti derivanti dalle proprie capacita' di bilancio e dalle esigenze di esercizio delle funzioni, dei servizi e dei compiti loro attribuiti. Restano salve le disposizioni dettate dalla normativa concernente gli enti locali dissestati e strutturalmente deficitari.

6. Nell'ambito delle leggi, nonche' dei regolamenti di cui al comma 1, le determinazioni per l'organizzazione degli uffici e le misure inerenti alla gestione dei rapporti di lavoro sono assunte dai soggetti preposti alla gestione con la capacita' e i poteri del privato datore di lavoro.

### Articolo 90 - Uffici di supporto agli organi di direzione politica

1. Il regolamento sull'ordinamento degli uffici e dei servizi puo' prevedere la costituzione di uffici posti alle dirette dipendenze del sindaco, del presidente della provincia, della giunta o degli assessori, per l'esercizio delle funzioni di indirizzo e di controllo loro attribuite dalla legge, costituiti da dipendenti dell'ente, ovvero, salvo che per gli enti dissestati o strutturalmente deficitari, da collaboratori assunti con contratto a tempo determinato, i quali, se dipendenti da una pubblica amministrazione, sono collocati in aspettativa senza assegni. ((139))

2. Al personale assunto con contratto di lavoro subordinato a tempo determinato si applica il contratto collettivo nazionale di lavoro del personale degli enti locali. (110)

3. Con provvedimento motivato della giunta, al personale di cui al comma 2 il trattamento economico accessorio previsto dai contratti collettivi puo' essere sostituito da un unico emolumento comprensivo dei compensi per il lavoro straordinario, per la produttivita' collettiva e per la qualita' della prestazione individuale.

3-bis. Resta fermo il divieto di effettuazione di attivita' gestionale anche nel caso in cui nel contratto individuale di lavoro il trattamento economico, prescindendo dal possesso del titolo di studio, e' parametrato a quello dirigenziale.

------------ AGGIORNAMENTO (110) Il D.L. 30 dicembre 2019, n. 162, convertito con modificazioni dalla L. 28 febbraio 2020, n. 8, ha disposto (con l'art. 18-ter, comma 1) che "Nell'articolo 90, comma 2, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, le parole: "contratto di lavoro subordinato a tempo determinato" si interpretano nel senso che il contratto stesso non puo' avere durata superiore al mandato elettivo del sindaco o del presidente della provincia in carica, anche in deroga alla disciplina di cui all'articolo 36 del decreto legislativo 30 marzo 2001, n. 165, e alle disposizioni del contratto collettivo nazionale di lavoro che prevedano specifiche limitazioni temporali alla durata dei contratti a tempo determinato". --------------- AGGIORNAMENTO (139) Il D.L. 24 febbraio 2023, n. 13, convertito con modificazioni dalla L. 21 aprile 2023, n. 41, ha disposto (con l'art. 8, comma 2) che "Al fine di assicurare la continuita' dell'azione amministrativa e facilitare la realizzazione degli investimenti finanziati, in tutto o in parte, con le risorse del PNRR ovvero con le risorse dei programmi cofinanziati dall'Unione europea e dei programmi operativi complementari alle programmazioni europee 2014-2020 e 2021-2027, ai rapporti di collaborazione instaurati ai sensi dell'articolo 110 del decreto legislativo n. 267 del 2000 non si applicano, fino al 31 dicembre 2026, le disposizioni di cui al comma 4 del medesimo articolo 110. Per le medesime finalita' di cui al primo periodo e fino al 31 dicembre 2026, non si applica nei confronti degli enti locali dichiarati in dissesto o che si trovino in situazioni strutturalmente deficitarie il divieto di cui all'articolo 90, comma 1, del citato decreto legislativo n. 267 del 2000."

### Articolo 91 - Assunzioni

1. Gli enti locali adeguano i propri ordinamenti ai principi di funzionalita' e di ottimizzazione delle risorse per il migliore funzionamento dei servizi compatibilmente con le disponibilita' finanziarie e di bilancio. Gli organi di vertice delle amministrazioni locali sono tenuti alla programmazione triennale del fabbisogno di personale, comprensivo delle unita' di cui alla legge 12 marzo 1999, n. 68, finalizzata alla riduzione programmata delle spese del personale.

2. Gli enti locali ai quali non si applicano discipline autorizzatorie delle assunzioni, programmano le proprie politiche di assunzioni adeguandosi ai principi di riduzione complessiva della spesa di personale, in particolare per nuove assunzioni, di cui ai commi 2-bis, 3, 3-bis e 3-ter dell'articolo 39 del decreto legislativo 27 dicembre 1997, n. 449, per quanto applicabili, realizzabili anche mediante l'incremento della quota di personale ad orario ridotto o con altre tipologie contrattuali flessibili nel quadro delle assunzioni compatibili con gli obiettivi della programmazione e giustificate dai processi di riordino o di trasferimento di funzioni e competenze.

3. Gli enti locali che non versino nelle situazioni strutturalmente deficitarie possono prevedere concorsi interamente riservati al personale dipendente, solo in relazione a particolari profili o figure professionali caratterizzati da una professionalita' acquisita esclusivamente all'interno dell'ente.

4. Per gli enti locali le graduatorie concorsuali rimangono efficaci per un termine di tre anni dalla data di pubblicazione per l'eventuale copertura dei posti che si venissero a rendere successivamente vacanti e disponibili, fatta eccezione per i posti istituiti o trasformati successivamente all'indizione del concorso medesimo.

### Articolo 92 - Rapporti di lavoro a tempo determinato e a tempo parziale

1. Gli enti locali possono costituire rapporti di lavoro a tempo parziale e a tempo determinato, pieno o parziale, nel rispetto della disciplina vigente in materia. I dipendenti degli enti locali a tempo parziale, purche' autorizzati dall'amministrazione di appartenenza, possono prestare attivita' lavorativa presso altri enti.

2. Nei comuni interessati da mutamenti demografici stagionali in relazione a flussi turistici o a particolari manifestazioni anche a carattere periodico, al fine di assicurare il mantenimento di adeguati livelli quantitativi e qualitativi dei servizi pubblici, il regolamento puo' prevedere particolari modalita' di selezione per l'assunzione del personale a tempo determinato per esigenze temporanee o stagionali, secondo criteri di rapidita' e trasparenza ed escludendo ogni forma di discriminazione. Si applicano, in ogni caso, le disposizioni dei commi 7 e 8 dell'articolo 36 del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni ed integrazioni.

### Articolo 93 - Responsabilita' patrimoniale

1. Per gli amministratori e per il personale degli enti locali si osservano le disposizioni vigenti in materia di responsabilita' degli impiegati civili dello Stato.

2. Il tesoriere ed ogni altro agente contabile che abbia maneggio di pubblico denaro o sia incaricato della gestione dei beni degli enti locali, nonche' coloro che si ingeriscano negli incarichi attribuiti a detti agenti devono rendere il conto della loro gestione e sono soggetti alla giurisdizione della Corte dei conti secondo le norme e le procedure previste dalle leggi vigenti.

3. Gli agenti contabili degli enti locali, salvo che la Corte dei conti lo richieda, non sono tenuti alla trasmissione della documentazione occorrente per il giudizio di conto di cui all'articolo 74 del regio decreto 18 novembre 1923, n. 2440, ed agli articoli 44 e seguenti del regio decreto 12 luglio 1934, n. 1214.

4. L'azione di responsabilita' si prescrive in cinque anni dalla commissione del fatto. La responsabilita' nei confronti degli amministratori e dei dipendenti dei comuni e delle province e' personale e non si estende agli eredi salvo il caso in cui vi sia stato illecito arricchimento del dante causa e conseguente illecito arricchimento degli eredi stessi.

### Articolo 94 - Responsabilita' disciplinare

1. Qualora ricorra alcuna delle condizioni di cui alle lettere a), b), c), d) ed e) del comma 1 dell'articolo 58, nonche' alle lettere a), b) e c) del comma 1 dell'articolo 59 nei confronti del personale dipendente delle amministrazioni locali, compresi gli enti ivi indicati, si fa luogo alla immediata sospensione dell'interessato dalla funzione o dall'ufficio ricoperti. La sospensione e' disposta dal responsabile dell'ufficio secondo la specifica competenza, con le modalita' e procedure previste dai rispettivi ordinamenti. A tal fine i provvedimenti emanati dal giudice sono comunicati, a cura della cancelleria del tribunale o della segreteria del pubblico ministero, ai responsabili delle amministrazioni o enti locali indicati nelle predette disposizioni.

2. Al personale dipendente di cui al comma precedente si applicano altresi' le disposizioni del comma 5 dell'articolo 58 e del comma 6 dell'articolo 59 previa attivazione del procedimento disciplinare.

### Articolo 95 - Dati sul personale degli enti locali

1. Il Ministero dell'interno aggiorna periodicamente, sentiti l'Associazione nazionale comuni italiani (Anci), l'Unione delle province d'Italia (Upi) e l'Unione nazionale comuni, comunita' enti montani (Uncem), i dati del censimento generale del personale in servizio presso gli enti locali.

2. Resta ferma la disciplina sulla banca dati sulle dotazioni organiche degli enti locali prevista dall'articolo 16-ter del decreto-legge 18 gennaio 1993, n. 8, convertito, con modificazioni, dalla legge 19 marzo 1993, n. 68.

### Articolo 96 - Riduzione degli organismi collegiali

1. Al fine di conseguire risparmi di spese e recuperi di efficienza nei tempi dei procedimenti amministrativi i consigli e le giunte, secondo le rispettive competenze, con provvedimento da emanare entro sei mesi dall'inizio di ogni esercizio finanziario, individuano i comitati, le commissioni, i consigli ed ogni altro organo collegiale con funzioni amministrative ritenuti indispensabili per la realizzazione dei fini istituzionali dell'amministrazione o dell'ente interessato. Gli organismi non identificati come indispensabili sono soppressi a decorrere dal mese successivo all'emanazione del provvedimento. Le relative funzioni sono attribuite all'ufficio che riveste preminente competenza nella materia.

## Segretari comunali e provinciali

### Articolo 97 - Ruolo e funzioni

1. Il comune e la provincia hanno un segretario titolare dipendente dall'Agenzia autonoma per la gestione dell'albo dei segretari comunali e provinciali, di cui all'articolo 102 e iscritto all'albo di cui all'articolo 98.

2. Il segretario comunale e provinciale svolge compiti di collaborazione e funzioni di assistenza giuridico-amministrativa nei confronti degli organi dell'ente in ordine alla conformita' dell'azione amministrativa alle leggi, allo statuto ed ai regolamenti.

3. Il sindaco e il presidente della provincia, ove si avvalgano della facolta' prevista dal comma 1 dell'articolo 108, contestualmente al provvedimento di nomina del direttore generale disciplinano, secondo l'ordinamento dell'ente e nel rispetto del loro distinti ed autonomi ruoli, i rapporti tra il segretario ed il direttore generale.

4. Il segretario sovrintende allo svolgimento delle funzioni dei dirigenti e ne coordina l'attivita', salvo quando ai sensi e per gli effetti del comma 1 dell'articolo 108 il sindaco e il presidente della provincia abbiano nominato il direttore generale. Il segretario inoltre:

- a) partecipa con funzioni consultive, referenti e di assistenza alle riunioni del consiglio e della giunta e ne cura la verbalizzazione;
- b) esprime il parere di cui all'articolo 49, in relazione alle sue competenze, nel caso in cui l'ente non abbia responsabili dei servizi;
- c) ((roga, su richiesta dell'ente, i contratti nei quali l'ente e' parte e autentica)) scritture private ed atti unilaterali nell'interesse dell'ente;
- d) esercita ogni altra funzione attribuitagli dallo statuto o dai regolamenti, o conferitagli dal sindaco o dal presidente della provincia;
- e) esercita le funzioni di direttore generale nell'ipotesi prevista dall'articolo 108, comma 4.

5. Il regolamento sull'ordinamento degli uffici e dei servizi, puo' prevedere un vicesegretario per coadiuvare il segretario e sostituirlo nei casi di vacanza, assenza o impedimento.

6. Il rapporto di lavoro dei segretari comunali e provinciali e' disciplinato dai contratti collettivi ai sensi del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni ed integrazioni.

### Articolo 98 - Albo nazionale

1. L'albo nazionale dei segretari comunali e provinciali, al quale si accede per concorso, e' articolato in sezioni regionali.

2. Il numero complessivo degli iscritti all'albo non puo' essere superiore al numero dei comuni e delle province ridotto del numero delle sedi unificate, maggiorato di una percentuale determinata ogni due anni dal consiglio di amministrazione dell'Agenzia di cui all'articolo 102 e funzionale all'esigenza di garantire una adeguata opportunita' di scelta da parte dei sindaci e dei presidenti di provincia.

3. I comuni possono stipulare convenzioni per l'ufficio di segretario comunale comunicandone l'avvenuta costituzione alla Sezione regionale dell'Agenzia.((Tali convenzioni possono essere stipulate anche tra comune e provincia e tra province)).

4. L'iscrizione all'albo e' subordinata al possesso dell'abilitazione concessa dalla Scuola superiore per la formazione e la specializzazione dei dirigenti della pubblica amministrazione locale ovvero dalla sezione autonoma della Scuola superiore dell'amministrazione dell'interno.

5. Al relativo corso si accede mediante concorso nazionale a cui possono partecipare i laureati in giurisprudenza, scienze politiche, economia.

### Articolo 99 - Nomina

1. Il sindaco e il presidente della provincia nominano il segretario, che dipende funzionalmente dal capo dell'amministrazione, scegliendolo tra gli iscritti all'albo di cui all'articolo 98.

2. Salvo quanto disposto dall'articolo 100, la nomina ha durata corrispondente a quella del mandato del sindaco o del presidente della provincia che lo ha nominato. Il segretario cessa automaticamente dall'incarico con la cessazione del mandato del sindaco e del presidente della provincia, continuando ad esercitare le funzioni sino alla nomina del nuovo segretario.

3. La nomina e' disposta non prima di sessanta giorni e non oltre centoventi giorni dalla data di insediamento del sindaco e del presidente della provincia, decorsi i quali il segretario e' confermato.

### Articolo 100 - Revoca

1. Il segretario puo' essere revocato con provvedimento motivato del sindaco o del presidente della provincia, previa deliberazione della giunta, per violazione dei doveri d'ufficio.

### Art. 101. - Disponibilita' e mobilita'

1. Il segretario comunale o provinciale non confermato, revocato o comunque privo di incarico e' collocato in posizione di disponibilita' per la durata massima di (( due anni )).

2. Durante il periodo di disponibilita' rimane iscritto all'albo ed e' posto a disposizione dell'Agenzia autonoma di cui all'articolo 102 per le attivita' dell'Agenzia stessa o per l'attivita' di consulenza, nonche' per incarichi di supplenza e di reggenza, ovvero per l'espletamento di funzioni corrispondenti alla qualifica rivestita presso altre amministrazioni pubbliche che lo richiedano con oneri a carico dell'ente presso cui presta servizio. Per il periodo di disponibilita' al segretario compete il trattamento economico in godimento in relazione agli incarichi conferiti.

2-bis. Durante il periodo in cui il segretario comunale o provinciale e' utilizzato in posizione di distacco, comando, aspettativa, fuori ruolo o altra analoga posizione presso altre amministrazioni pubbliche e in ogni altro caso previsto dalla legge, il termine di collocamento in disponibilita' resta sospeso.

3. Nel caso di collocamento in disponibilita' per mancato raggiungimento di risultati imputabile al segretario oppure motivato da gravi e ricorrenti violazioni dei doveri d'ufficio, allo stesso, salva diversa sanzione, compete il trattamento economico tabellare spettante per la sua qualifica detratti i compensi percepiti a titolo di indennita' per l'espletamento degli incarichi di cui al comma 2.

4. Decorsi (( due anni )) senza che abbia preso servizio in qualita' di titolare in altra sede il segretario viene collocato d'ufficio in mobilita' presso altre pubbliche amministrazioni nella piena salvaguardia della posizione giuridica ed economica.

4-bis. Le disposizioni di cui all'articolo 23-bis del decreto legislativo 30 marzo 2001, n. 165, si applicano ai segretari comunali e provinciali equiparati ai dirigenti statali ai fini delle procedure di mobilita' per effetto del contratto collettivo nazionale di lavoro. Alla cessazione dell'incarico, il segretario comunale o provinciale viene collocato nella posizione di disponibilita' nell'ambito dell'albo di appartenenza.

### Art. 102.

ARTICOLO ABROGATO DAL D.L. 31 MAGGIO 2010, N. 78, CONVERTITO CON MODIFICAZIONI DALLA L. 30 LUGLIO 2010, N. 122 .(44) ((54))

------------- AGGIORNAMENTO (44) Il D.L. 31 maggio 2010, n. 78, convertito, con modificazioni, dalla L. 30 luglio 2010, n. 122) ha disposto (con l'art. 7, comma 31-ter) che l'Agenzia autonoma per la gestione dell'albo dei segretari comunali e provinciali, istituita dal presente articolo e' soppressa e (con l'art. 7, comma 31-septies) che tutti i richiami alla soppressa Agenzia sono da intendere riferiti al Ministero dell'interno. Inoltre, ha disposto (con l'art. 7, comma 31-sexies) che il contributo a carico delle amministrazioni provinciali e dei comuni previsto dal comma 5 del presente articolo e' soppresso dal 1° gennaio 2011 e dalla medesima data sono corrispondentemente ridotti i contributi ordinari delle amministrazioni provinciali e dei comuni, per essere destinati alla copertura degli oneri derivanti dall'applicazione del comma 31-ter del medesimo d.l. 78/2010. ------------- AGGIORNAMENTO (54) Il D.L. 29 dicembre 2011, n. 216, convertito con modificazioni dalla L. 24 febbraio 2012, n. 14, nel modificare l'art. 7, comma 31-sexies del D.L. 31 maggio 2010, n. 78, convertito con modificazioni dalla L. 30 luglio 2010, n. 122, ha conseguentemente disposto (con l'art. 15, comma 5) che il termine di cui all'articolo 7, comma 31-sexies, primo periodo, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, che dispone la modifica del comma 5 del presente articolo, e' ulteriormente prorogato di 180 giorni decorrenti dalla data di entrata in vigore della legge di conversione del presente decreto.

### Art. 103.

((ARTICOLO ABROGATO DAL D.L. 31 MAGGIO 2010, N. 78, CONVERTITO CON MODIFICAZIONI DALLA L. 30 LUGLIO 2010, N. 122 ))

### Articolo 104 - Scuola superiore della pubblica amministrazione locale e scuole regionali e interregionali

1. L'organizzazione, il funzionamento e l'ordinamento contabile della Scuola superiore per la formazione e la specializzazione dei dirigenti della pubblica amministrazione locale e delle scuole di cui al comma 2 sono disciplinati con regolamento, determinando i criteri per l'eventuale stipula di convenzioni per l'attivita' formativa anche in sede decentrata con istituti, enti, societa' di formazione e ricerca.

2. L'Agenzia istituisce scuole regionali ed interregionali per la formazione e la specializzazione dei segretari comunali e provinciali e dei dirigenti della pubblica amministrazione locale ovvero puo' avvalersi, previa convenzione, della sezione autonoma della Scuola superiore dell'amministrazione dell'interno.

### Articolo 105 - Regioni a statuto speciale

1. Le regioni a statuto speciale e le province autonome di Trento e di Bolzano disciplinano le materie di cui al presente capo con propria legislazione.

2. Nel territorio della regione Trentino - Alto Adige, fino, all'emanazione di apposita legge regionale, rimane ferma l'applicazione del titolo VI della legge 11 marzo 1972, n. 118.

### Articolo 106 - Disposizioni finali e transitorie

1. Fino alla stipulazione di una diversa disciplina del contratto collettivo nazionale di lavoro resta ferma la classificazione dei comuni e delle province ai fini dell'assegnazione del segretario prevista dalle tabelle A e B allegate al decreto del Presidente della Repubblica 23 giugno 1972, n. 749.

2. I segretari gia' iscritti alla sezione speciale dell'albo ai sensi dell'articolo 17, comma 82, della legge 15 maggio 1997, n. 127, e trasferiti presso altre pubbliche amministrazioni, permangono nel ruolo statale e mantengono ad esaurimento qualifica e trattamento economico pensionabile in godimento.

3. Ai fini dell'attuazione della legge 8 marzo 1999, n. 50, i segretari comunali di cui all'articolo 18, comma 14, del decreto del Presidente della Repubblica 4 dicembre 1997, n. 465, o all'articolo 39, comma 22, della legge 27 dicembre 1997, n. 449, possono essere collocati o mantenuti in posizione di fuori ruolo con decreto del Presidente del Consiglio dei Ministri, anche dopo il trasferimento alle amministrazioni di destinazione e con effetto dalla data di entrata in vigore della citata legge n. 50 del 1999. Gli oneri relativi al trattamento economico, fondamentale ed accessorio, dei predetti dipendenti rimangono a carico dell'Agenzia autonoma per la gestione dell'albo dei segretari comunali fino alla data del trasferimento alle amministrazioni di destinazione; successivamente sono a queste imputate. Analogamente si provvede, con decreto del Ministro dell'interno, di concerto con il Ministro per la funzione pubblica, per i segretari comunali in servizio presso il Ministero dell'interno ai sensi dell'articolo 34, comma 2, del decreto del Presidente della Repubblica 4 dicembre 1997, n. 465.

## Dirigenza ed incarichi

### Articolo 107 - Funzioni e responsabilta' della dirigenza

1. Spetta ai dirigenti la direzione degli uffici e dei servizi secondo i criteri e le norme dettati dagli statuti e dai regolamenti. Questi si uniformano al principio per cui i poteri di indirizzo e di controllo politico-amministrativo spettano agli organi di governo, mentre la gestione amministrativa, finanziaria e tecnica e' attribuita ai dirigenti mediante autonomi poteri di spesa, di organizzazione delle risorse umane, strumentali e di controllo.

2. Spettano ai dirigenti tutti i compiti, compresa l'adozione degli atti e provvedimenti amministrativi che impegnano l'amministrazione verso l'esterno, non ricompresi espressamente dalla legge o dallo statuto tra le funzioni di indirizzo e controllo politico-amministrativo degli organi di governo dell'ente o non rientranti tra le funzioni del segretario o del direttore generale, di cui rispettivamente agli articoli 97 e 108.

3. Sono attribuiti ai dirigenti tutti i compiti di attuazione degli obiettivi e dei programmi definiti con gli atti di indirizzo adottati dai medesimi organi tra i quali in particolare, secondo le modalita' stabilite dallo statuto o dai regolamenti dell'ente:

- a) la presidenza delle commissioni di gara e di concorso; ((la commissione giudicatrice, nel caso di aggiudicazione dei contratti di importo inferiore alle soglie europee con il criterio dell'offerta economicamente piu' vantaggiosa, puo' essere presieduta dal responsabile unico del procedimento;)) ((141))
- b) la responsabilita' delle procedure d'appalto e di concorso;
- c) la stipulazione dei contratti;
- d) gli atti di gestione finanziaria, ivi compresa l'assunzione di impegni di spesa;
- e) gli atti di amministrazione e gestione del personale;
- f) i provvedimenti di autorizzazione, concessione o analoghi, il cui rilascio presupponga accertamenti e valutazioni, anche di natura discrezionale, nel rispetto di criteri predeterminati dalla legge, dai regolamenti, da atti generali di indirizzo, ivi comprese le autorizzazioni e le concessioni edilizie;
- g) tutti i provvedimenti di sospensione dei lavori, abbattimento e riduzione in pristino di competenza comunale, nonche' i poteri di vigilanza edilizia e di irrogazione delle sanzioni amministrative previsti dalla vigente legislazione statale e regionale in materia di prevenzione e repressione dell'abusivismo edilizio e paesaggistico-ambientale;
- h) le attestazioni, certificazioni comunicazioni, diffide, verbali, autenticazioni, legalizzazioni ed ogni altro atto costituente manifestazione di giudizio e di conoscenza;
- i) gli atti ad essi attribuiti dallo statuto e dai regolamenti o, in base a questi, delegati dal sindaco.

4. Le attribuzioni dei dirigenti, in applicazione del principio di cui all'articolo 1, comma 4, possono essere derogate soltanto espressamente e ad opera di specifiche disposizioni legislative.

5. A decorrere dalla data di entrata in vigore del presente testo unico, le disposizioni che conferiscono agli organi di cui al capo I titolo III l'adozione di atti di gestione e di atti o provvedimenti amministrativi, si intendono nel senso che la relativa competenza spetta ai dirigenti, salvo quanto previsto dall'articolo 50, comma 3, e dall'articolo 54.

6. I dirigenti sono direttamente responsabili, in via esclusiva, in relazione agli obiettivi dell'ente, della correttezza amministrativa, della efficienza e dei risultati della gestione.

7. Alla valutazione dei dirigenti degli enti locali si applicano i principi contenuti nell'articolo 5, commi 1 e 2, del decreto legislativo 30 luglio 1999, n. 286, secondo le modalita' previste dall'articolo 147 del presente testo unico.

----------- AGGIORNAMENTO (141) Il D.Lgs. 31 marzo 2023, n. 36 ha disposto (con l'art. 229, comma 2) che la presente modifica acquista efficacia il 1° luglio 2023.

### Articolo 108 - Direttore generale

1. Il sindaco nei comuni con popolazione superiore ai 15.000 abitanti e il presidente della provincia, previa deliberazione della giunta comunale o provinciale, possono nominare un direttore generale, al di fuori della dotazione organica e con contratto a tempo determinato, e secondo criteri stabiliti dal regolamento di organizzazione degli uffici e dei servizi, che provvede ad attuare gli indirizzi e gli obiettivi stabiliti dagli organi di governo dell'ente, secondo le direttive impartite dal sindaco o dal presidente della provincia, e che sovrintende alla gestione dell'ente, perseguendo livelli ottimali di efficacia ed efficienza. Compete in particolare al direttore generale la predisposizione del piano dettagliato di obiettivi previsto dall'articolo 197, comma 2, lettera a), nonche' la proposta di piano esecutivo di gestione previsto dall'articolo 169. A tali fini, al direttore generale rispondono, nell'esercizio delle funzioni loro assegnate, i dirigenti dell'ente, ad eccezione del segretario del comune e della provincia. ((130))

2. Il direttore generale e' revocato dal sindaco o dal presidente della provincia, previa deliberazione della giunta comunale o provinciale. La durata dell'incarico non puo' eccedere quella del mandato del sindaco o del presidente della provincia.

3. Nei comuni con popolazione inferiore ai 15.000 abitanti e' consentito procedere alla nomina del direttore generale previa stipula di convenzione tra comuni le cui popolazioni assommate raggiungano i 15.000 abitanti. In tal caso il direttore generale dovra' provvedere anche alla gestione coordinata o unitaria dei servizi tra i comuni interessati.

4. Quando non risultino stipulate le convenzioni previste dal comma 3 e in ogni altro caso in cui il direttore generale non sia stato nominato, le relative funzioni possono essere conferite dal sindaco o dal presidente della provincia al segretario.

------------- AGGIORNAMENTO (130) Il D.P.R. 24 giugno 2022, n. 81, ha disposto (con l'art. 2, comma 1) che "Per gli enti locali di cui all'articolo 2, comma 1, del decreto legislativo 18 agosto 2000, n. 267, il piano dettagliato degli obiettivi di cui all'articolo 108, comma 1, del medesimo decreto legislativo e il piano della performance di cui all'articolo 10 del decreto legislativo 27 ottobre 2009, n. 150, sono assorbiti nel PIAO".

### Articolo 109 - Conferimento di funzioni dirigenziali

1. Gli incarichi dirigenziali sono conferiti a tempo determinato, ai sensi dell'articolo 50, comma 10, con provvedimento motivato e con le modalita' fissate dal regolamento sull'ordinamento degli uffici e dei servizi, secondo criteri di competenza professionale, in relazione agli obiettivi indicati nel programma amministrativo del sindaco o del presidente della provincia e sono revocati in caso di inosservanza delle direttive del sindaco o del presidente della provincia, della giunta o dell'assessore di riferimento, o in caso di mancato raggiungimento al termine di ciascun anno finanziario degli obiettivi assegnati nel piano esecutivo di gestione previsto dall'articolo 169 o per responsabilita' particolarmente grave o reiterata e negli altri casi disciplinati dai contratti collettivi di lavoro. L'attribuzione degli incarichi puo' prescindere dalla precedente assegnazione di funzioni di direzione a seguito di concorsi.

2. Nei comuni privi di personale di qualifica dirigenziale le funzioni di cui all'articolo 107, commi 2 e 3, fatta salva l'applicazione dell'articolo 97, comma 4, lettera d), possono essere attribuite, a seguito di provvedimento motivato del sindaco, ai responsabili degli uffici o dei servizi, indipendentemente dalla loro qualifica funzionale, anche in deroga a ogni diversa disposizione.

### Art. 110. - Incarichi a contratto

1. Lo statuto puo' prevedere che la copertura dei posti di responsabili dei servizi o degli uffici, di qualifiche dirigenziali o di alta specializzazione, possa avvenire mediante contratto a tempo determinato. Per i posti di qualifica dirigenziale, il regolamento sull'ordinamento degli uffici e dei servizi definisce la quota degli stessi attribuibile mediante contratti a tempo determinato, comunque in misura non superiore al 30 per cento dei posti istituiti nella dotazione organica della medesima qualifica e, comunque, per almeno una unita'. Fermi restando i requisiti richiesti per la qualifica da ricoprire, gli incarichi a contratto di cui al presente comma sono conferiti previa selezione pubblica volta ad accertare, in capo ai soggetti interessati, il possesso di comprovata esperienza pluriennale e specifica professionalita' nelle materie oggetto dell' incarico. ((139))

2. Il regolamento sull'ordinamento degli uffici e dei servizi, negli enti in cui e' prevista la dirigenza, stabilisce i limiti, i criteri e le modalita' con cui possono essere stipulati, al di fuori della dotazione organica, contratti a tempo determinato per i dirigenti e le alte specializzazioni, fermi restando i requisiti richiesti per la qualifica da ricoprire. Tali contratti sono stipulati in misura complessivamente non superiore al 5 per cento del totale della dotazione organica della dirigenza e dell'area direttiva e comunque per almeno una unita'. Negli altri enti, il regolamento sull'ordinamento degli uffici e dei servizi stabilisce i limiti, i criteri e le modalita' con cui possono essere stipulati, al di fuori della dotazione organica, solo in assenza di professionalita' analoghe presenti all'interno dell'ente, contratti a tempo determinato di dirigenti, alte specializzazioni o funzionari dell'area direttiva, fermi restando i requisiti richiesti per la qualifica da ricoprire. Tali contratti sono stipulati in misura complessivamente non superiore al 5 per cento della dotazione organica dell'ente arrotondando il prodotto all'unita' superiore, o ad una unita' negli enti con una dotazione organica inferiore alle 20 unita'.

3. I contratti di cui ai precedenti commi non possono avere durata superiore al mandato elettivo del sindaco o del presidente della provincia in carica. Il trattamento economico, equivalente a quello previsto dai vigenti contratti collettivi nazionali e decentrati per il personale degli enti locali, puo' essere integrato, con provvedimento motivato della giunta, da una indennita' ad personam, commisurata alla specifica qualificazione professionale e culturale, anche in considerazione della temporaneita' del rapporto e delle condizioni di mercato relative alle specifiche competenze professionali. Il trattamento economico e l'eventuale indennita' ad personam sono definiti in stretta correlazione con il bilancio dell'ente e non vanno imputati al costo contrattuale e del personale.

4. Il contratto a tempo determinato e' risolto di diritto nel caso in cui l'ente locale dichiari il dissesto o venga a trovarsi nelle situazioni strutturalmente deficitarie. ((139))

5. Per il periodo di durata degli incarichi di cui ai commi 1 e 2 del presente articolo nonche' dell'incarico di cui all'articolo 108, i dipendenti delle pubbliche amministrazioni sono collocati in aspettativa senza assegni, con riconoscimento dell'anzianita' di servizio.

6. Per obiettivi determinati e con convenzioni a termine, il regolamento puo' prevedere collaborazioni esterne ad alto contenuto di professionalita'.

--------------- AGGIORNAMENTO (139) Il D.L. 24 febbraio 2023, n. 13, convertito con modificazioni dalla L. 21 aprile 2023, n. 41, ha disposto (con l'art. 8, comma 1) che "Al fine di consentire agli enti locali di fronteggiare le esigenze connesse ai complessivi adempimenti riferiti al PNRR e, in particolare, di garantire l'attuazione delle procedure di gestione, erogazione, monitoraggio, controllo e rendicontazione delle risorse del medesimo Piano ad essi assegnate, fino al 31 dicembre 2026, la percentuale di cui all'articolo 110, comma 1, secondo periodo, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267 e' elevata al 50 per cento, limitatamente agli enti locali incaricati dell'attuazione di interventi finanziati, in tutto o in parte, con le risorse del PNRR.". Ha inoltre disposto (con l'art. 8, comma 2) che "Al fine di assicurare la continuita' dell'azione amministrativa e facilitare la realizzazione degli investimenti finanziati, in tutto o in parte, con le risorse del PNRR ovvero con le risorse dei programmi cofinanziati dall'Unione europea e dei programmi operativi complementari alle programmazioni europee 2014-2020 e 2021-2027, ai rapporti di collaborazione instaurati ai sensi dell'articolo 110 del decreto legislativo n. 267 del 2000 non si applicano, fino al 31 dicembre 2026, le disposizioni di cui al comma 4 del medesimo articolo 110. Per le medesime finalita' di cui al primo periodo e fino al 31 dicembre 2026, non si applica nei confronti degli enti locali dichiarati in dissesto o che si trovino in situazioni strutturalmente deficitarie il divieto di cui all'articolo 90, comma 1, del citato decreto legislativo n. 267 del 2000."

### Articolo 111 - Adeguamento della disciplina della dirigenza

1. Gli enti locali, tenendo conto delle proprie peculiarita' nell'esercizio della propria potesta' statutaria e regolamentare, adeguano lo statuto ed il regolamento ai principi del presente capo e del capo II del decreto legislativo del febbraio 1993, n. 29, e successive modificazioni ed integrazioni.

## SERVIZI E INTERVENTI PUBBLICI LOCALI

### Art. 112.

((ARTICOLO ABROGATO DAL D.LGS. 23 DICEMBRE 2022, N. 201))

### Art. 113.

((ARTICOLO ABROGATO DAL D.LGS. 23 DICEMBRE 2022, N. 201))

### Art. 113-bis. - (Gestione dei servizi pubblici locali privi di rilevanza economica)

1. Ferme restando le disposizioni previste per i singoli settori, i servizi pubblici locali privi di rilevanza economica sono gestiti mediante affidamento diretto a:

- a) istituzioni;
- b) aziende speciali, anche consortili;
- c) societa' a capitale interamente pubblico a condizione che gli enti pubblici titolari del capitale sociale esercitino sulla societa' un controllo analogo a quello esercitato sui propri servizi e che la societa' realizzi la parte piu' importante della propria attivita' con l'ente o gli enti pubblici che la controllano.

2. E' consentita la gestione in economia quando, per le modeste dimensioni o per le caratteristiche del servizio, non sia opportuno procedere ad affidamento ai soggetti di cui al comma 1.

3. Gli enti locali possono procedere all'affidamento diretto dei servizi culturali e del tempo libero anche ad associazioni e fondazioni da loro costituite o partecipate.

4. COMMA ABROGATO DAL D.L. 30 SETTEMBRE 2003, N. 269, CONVERTITO CON MODIFICAZIONI DALLA L. 24 NOVEMBRE 2003, N. 326

5. I rapporti tra gli enti locali ed i soggetti erogatori dei servizi di cui al presente articolo sono regolati da contratti di servizio. ((22))

--------------- AGGIORNAMENTO (22) La Corte costituzionale, con sentenza 13-27 luglio 2004, n. 272 (in G.U. 1a s.s. 4/8/2004, n. 30) ha dichiarato l'illegittimita' costituzionale del presente art. 113-bis, nel testo introdotto dal comma 15 dell'art. 35 della legge n. 448 del 2001.

### Articolo 114 - Aziende speciali ed istituzioni

1. L'azienda speciale e' ente strumentale dell'ente locale dotato di personalita' giuridica, di autonomia imprenditoriale e di proprio statuto, approvato dal consiglio comunale o provinciale. ((L'azienda speciale conforma la propria gestione ai principi contabili generali contenuti nell'allegato n. 1 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, ed ai principi del codice civile.)) ((83))

2. L'istituzione e' organismo strumentale dell'ente locale per l'esercizio di servizi sociali, dotato di autonomia gestionale. ((L'istituzione conforma la propria gestione ai principi contabili generali e applicati allegati al decreto legislativo 23 giugno 2011, n. 118 e successive modificazioni e integrazioni ed adotta il medesimo sistema contabile dell'ente locale che lo ha istituito, nel rispetto di quanto previsto dall'art. 151, comma 2. L'ente locale che si avvale della facolta' di non tenere la contabilita' economico patrimoniale di cui all'art. 232, comma 3, puo' imporre alle proprie istituzioni l'adozione della contabilita' economico-patrimoniale.)) ((83))

3. Organi dell'azienda e dell'istituzione sono il consiglio di amministrazione, il presidente e il direttore, al quale compete la responsabilita' gestionale. Le modalita' di nomina e revoca degli amministratori sono stabilite dallo statuto dell'ente locale.

4. L'azienda e l'istituzione ((conformano)) la loro attivita' a criteri di efficacia, efficienza ed economicita' ed hanno l'obbligo ((dell'equilibrio economico, considerando anche i proventi derivanti dai trasferimenti, fermo restando, per l'istituzione, l'obbligo del pareggio finanziario.)) ((83))

5. Nell'ambito della legge, l'ordinamento ed il funzionamento delle aziende speciali sono disciplinati dal proprio statuto e dai regolamenti, quelli delle istituzioni sono disciplinati dallo statuto e dai regolamenti dell'ente locale da cui dipendono.

5-bis. Le aziende speciali e le istituzioni si iscrivono e depositano i propri bilanci al registro delle imprese o nel repertorio delle notizie economico-amministrative della camera di commercio, industria, artigianato e agricoltura del proprio territorio entro il 31 maggio di ciascun anno. (75)

6. L'ente locale conferisce il capitale di dotazione; determina le finalita' e gli indirizzi; approva gli atti fondamentali; esercita la vigilanza; verifica i risultati della gestione; provvede alla copertura degli eventuali costi sociali.

7. Il collegio dei revisori dei conti dell'ente locale esercita le sue funzioni anche nei confronti delle istituzioni. Lo statuto dell'azienda speciale prevede un apposito organo, di revisione, nonche' forme autonome di verifica della gestione.

8. Ai fini di cui al comma 6 sono fondamentali i seguenti atti ((dell'azienda)) da sottoporre all'approvazione del consiglio comunale: ((83))

- a) il piano-programma, comprendente un contratto di servizio che disciplini i rapporti tra ente locale ed azienda speciale;

((8-bis. Ai fini di cui al comma 6, sono fondamentali i seguenti atti dell'istituzione da sottoporre all'approvazione del consiglio comunale:

a) il piano-programma, di durata almeno triennale, che costituisce il documento di programmazione dell'istituzione;

b) il bilancio di previsione almeno triennale, predisposto secondo lo schema di cui all'allegato n. 9 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, completo dei relativi allegati;

c) le variazioni di bilancio;

d) il rendiconto della gestione predisposto secondo lo schema di cui all'allegato n. 10 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, completo dei relativi allegati.))

((83))

-------------- AGGIORNAMENTO (75) La L. 27 dicembre 2013, n. 147 ha disposto (con l'art. 1, comma 550) che la presente modifica si applica alle aziende speciali, alle istituzioni e alle societa' partecipate dalle pubbliche amministrazioni locali indicate nell'elenco di cui all'articolo 1, comma 3, della legge 31 dicembre 2009, n. 196. Sono esclusi gli intermediari finanziari di cui all'articolo 106 del testo unico di cui al decreto legislativo 1º settembre 1993, n. 385, nonche' le societa' emittenti strumenti finanziari quotati nei mercati regolamentati e le loro controllate. -------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 115. - Trasformazione delle aziende speciali in societa' per azioni

1. I comuni, le province e gli altri enti locali possono, per atto unilaterale, trasformare le aziende speciali in societa' di capitali, di cui possono restare azionisti unici per un periodo comunque non superiore a due anni dalla trasformazione. Il capitale iniziale di tali societa' e' determinato dalla deliberazione di trasformazione in misura non inferiore al fondo di dotazione delle aziende speciali risultante dall'ultimo bilancio di esercizio approvato e comunque in misura non inferiore all'importo minimo richiesto per la costituzione delle societa' medesime. L'eventuale residuo del patrimonio netto conferito e' imputato a riserve e fondi, mantenendo ove possibile le denominazioni e le destinazioni previste nel bilancio delle aziende originarie. Le societa' conservano tutti i diritti e gli obblighi anteriori alla trasformazione e subentrano pertanto in tutti i rapporti attivi e passivi delle aziende originarie.

2. La deliberazione di trasformazione tiene luogo di tutti gli adempimenti in materia di costituzione delle societa' previsti dalla normativa vigente, ferma l'applicazione delle disposizioni degli articoli 2330, commi terzo e quarto, e 2330-bis del codice civile.

3. Ai fini della definitiva determinazione dei valori patrimoniali conferiti, entro tre mesi dalla costituzione delle societa', gli amministratori devono richiedere a un esperto designato dal presidente del tribunale una relazione giurata ai sensi e per gli effetti dell'articolo 2343, primo comma, del codice civile. Entro sei mesi dal ricevimento di tale relazione gli amministratori e i sindaci determinano i valori definitivi di conferimento dopo avere controllato le valutazioni contenute nella relazione stessa e, se sussistono fondati motivi, aver proceduto alla revisione della stima. Fino a quando i valori di conferimento non sono stati determinati in via definitiva le azioni delle societa' sono inalienabili.

4. Le societa' di cui al comma 1 possono essere costituite anche ai fini dell'applicazione delle norme di cui al decreto-legge 21 maggio 1994, n. 332, convertito, con modificazioni, dalla legge 30 luglio 1994, n. 474.

5. COMMA ABROGATO DALLA L. 28 DICEMBRE 2001, N.448.

6. Il conferimento e l'assegnazione dei beni degli enti locali e delle aziende speciali alle societa' di cui al comma 1 sono esenti da imposizioni fiscali, dirette e indirette, statali e regionali.

7. La deliberazione di cui al comma 1 puo' anche prevedere la scissione dell'Azienda, speciale e la destinazione a societa' di nuova costituzione di un ramo aziendale di questa. Si applicano, in tal caso, per quanto compatibili, le disposizioni di cui ai commi da 1 a 6 del presente articolo, nonche' agli articoli 2504-septies e 2504-decies del codice civile.

7-bis. Le disposizioni di cui ai commi precedenti si applicano anche alla trasformazione dei consorzi, intendendosi sostituita al consiglio comunale l'assemblea consortile. In questo caso le deliberazioni sono adottate a maggioranza dei componenti; gli enti locali che non intendono partecipare alla societa' hanno diritto alla liquidazione sulla base del valore nominale iscritto a bilancio della relativa quota di capitale.

((

7-ter. Alla privatizzazione di enti ed aziende delle regioni a statuto ordinario e ad autonomia speciale, fermo restando quanto stabilito dalla legislazione regionale in materia, si applicano le disposizioni di cui ai precedenti commi. Delle obbligazioni sorte anteriormente alla costituzione delle societa' di capitali di cui al comma 1 rispondono in ogni caso le regioni.

))

### Art. 116.

((ARTICOLO ABROGATO DAL D.LGS. 19 AGOSTO 2016, N. 175))

### Art. 117.

((ARTICOLO ABROGATO DAL D.LGS. 23 DICEMBRE 2022, N. 201))

### Art. 118. - Regime del trasferimento di beni

1. I trasferimenti di beni mobili ed immobili effettuati dai comuni, dalle province e dai consorzi fra tali enti a favore di aziende speciali o di (( societa' di capitali di cui al comma 13 dell'articolo 113 )) sono esenti, senza limiti di valore, dalle imposte di bollo, di registro, di incremento di valore, ipotecarie, catastali e da ogni altra imposta, spesa, tassa o diritto di qualsiasi specie o natura. Gli onorari previsti per i periti designati dal tribunale per la redazione della stima di cui all'articolo 2343 del codice civile, nonche' gli onorari previsti per i notai incaricati della redazione degli atti conseguenti ai trasferimenti, sono ridotti alla meta'.

2. Le disposizioni previste nel comma 1 si applicano anche ai trasferimenti ed alle retrocessioni di aziende, di complessi aziendali o di rami di essi posti in essere nell'ambito di procedure di liquidazione di aziende municipali e provinciali o di aziende speciali, adottate a norma delle disposizioni vigenti in materia di revoca del servizio e di liquidazione di aziende speciali, qualora dette procedure siano connesse o funzionali alla contestuale o successiva costituzione di societa' per azioni, aventi per oggetto lo svolgimento del medesimo servizio pubblico in precedenza svolto dalle aziende soppresse, purche' i beni, i diritti, le aziende o rami di aziende trasferiti o retrocessi vengano effettivamente conferiti nella costituenda societa' per azioni. Le stesse disposizioni si applicano altresi' ai conferimenti di aziende, di complessi aziendali o di rami di essi da parte delle province e dei comuni in sede di costituzione o trasformazione dei consorzi in aziende speciali e consortili ai sensi degli articoli 31 e 274, comma 4, per la costituzione di societa' per azioni ai sensi dell'articolo 116, ovvero per la costituzione, anche mediante atto unilaterale, da parte di enti locali, di societa' per azioni al fine di dismetterne le partecipazioni ai sensi del decreto-legge 31 maggio 1994, n. 232, convertito, con modificazioni, dalla legge 30 luglio 1994, n. 474, e successive modificazioni.

3. (( COMMA ABROGATO DALLA L. 28 DICEMBRE 2001, N.448 )).

### Articolo 119 - Contratti di sponsorizzazione, accordi di collaborazione e convenzioni

1. In applicazione dell'articolo 43 della legge 27 dicembre 1997, n. 449, al fine di favorire una migliore qualita' dei servizi prestati, i comuni, le province e gli altri enti locali indicati nel presente testo unico, possono stipulare contratti di sponsorizzazione ed accordi di collaborazione, nonche' convenzioni con soggetti pubblici o privati diretti a fornire consulenze o servizi aggiuntivi.

### Art. 120. - Societa' di trasformazione urbana

1. Le citta' metropolitane e i comuni, anche con la partecipazione della provincia e della regione, possono costituire societa' per azioni per progettare e realizzare interventi di trasformazione urbana, in attuazione degli strumenti urbanistici vigenti. A tal fine le deliberazioni dovranno in ogni caso prevedere che gli azionisti privati delle societa' per azioni siano scelti tramite procedura di evidenza pubblica.

((

2. Le societa' di trasformazione urbana provvedono alla preventiva acquisizione degli immobili interessati dall'intervento, alla trasformazione e alla commercializzazione degli stessi. Le acquisizioni possono avvenire consensualmente o tramite ricorso alle procedure di esproprio da parte del comune.

3. Gli immobili interessati dall'intervento di trasformazione sono individuati con delibera del consiglio comunale. L'individuazione degli immobili equivale a dichiarazione di pubblica utilita', anche per gli immobili non interessati da opere pubbliche. Gli immobili di proprieta' degli enti locali interessati dall'intervento possono essere conferiti alla societa' anche a titolo di concessione ))

4. I rapporti tra gli enti locali azionisti e la societa' per azioni di trasformazione urbana sono disciplinati da una convenzione contenente, a pena di nullita', gli obblighi e i diritti delle parti.

### Art. 121.

((ARTICOLO ABROGATO DAL D.LGS. 8 GIUGNO 2001, N. 327)) ((4))

--------------- AGGIORNAMENTO (4) Il D.P.R. 8 giugno 2001, n. 327, come modificato dal D.L. 23 novembre 2001, n. 411, convertito con modificazioni dalla L. 31 dicembre 2001, n. 463, ha disposto (con l'art. 59, comma 1) la proroga dell'entrata in vigore dell'abrogazione del presente articolo dal 1 gennaio 2002 al 30 giugno 2002. Il D.P.R. 8 giugno 2001, n. 327, come modificato dalla L. 1 agosto 2002, n. 166 ha disposto (con l'art. 59, comma 1) la proroga dell'entrata in vigore dell'abrogazione del presente articolo dal 30 giugno 2002 al 31 dicembre 2002. Il D.P.R. 8 giugno 2001, n. 327, come modificato dal D.L. 20 giugno 2002, n. 122 , convertito con modificazioni dalla L. 1 agosto 2002, n. 185 ha disposto (con l'art. 59, comma 1) la proroga dell'entrata in vigore dell'abrogazione del presente articolo dal 31 dicembre 2002 al 30 giugno 2003. Il D.P.R. 8 giugno 2001, n. 327, come modificato dal D. Lgs. 27 dicembre 2002, n. 302 ha disposto (con l'art. 59, comma 1) la proroga dell'entrata in vigore dell'abrogazione del presente articolo dal 1 gennaio 2002 al 30 giugno 2003.

### Art. 122.

((ARTICOLO ABROGATO DAL D.LGS. 19 AGOSTO 2016, N. 175))

### Art. 123. - Norma transitoria

1. Resta fermo l'obbligo per gli enti locali di adeguare l'ordinamento delle aziende speciali alle disposizioni di cui all'articolo 114; gli enti locali iscrivono per gli effetti di cui al primo comma dell'articolo 2331 del codice civile, le aziende speciali nel registro delle imprese.

2. Restano salvi gli effetti degli atti e dei contratti che le medesime aziende speciali hanno posto in essere anteriormente alla data di attuazione del registro delle imprese, di cui all'articolo 8 della legge 29 dicembre 1993, n. 580.

3. (( COMMA ABROGATO DALLA L. 28 DICEMBRE 2001, N.448 )).

## CONTROLLI CAPO I Controllo sugli atti

### Articolo 124 - Pubblicazione delle deliberazioni

1. Tutte le deliberazioni del comune e della provincia sono pubblicate mediante ((pubblicazione)) all'albo pretorio, nella sede dell'ente, per quindici giorni consecutivi, salvo specifiche disposizioni di legge.

2. Tutte le deliberazioni degli altri enti locali sono pubblicate mediante ((pubblicazione)) all'albo pretorio del comune ove ha sede l'ente, per quindici giorni consecutivi, salvo specifiche disposizioni.

### Articolo 125 - Comunicazione delle deliberazioni ai capigruppo

1. Contestualmente all'affissione all'albo le deliberazioni adottate dalla giunta sono trasmesse in elenco ai capigruppo consiliari; i relativi testi sono messi a disposizione dei consiglieri nelle norme stabilite dallo statuto o dal regolamento.

### Articolo 126 - Deliberazioni soggette in via necessaria al controllo preventivo di legittimita'

1. Il controllo preventivo di legittimita' di cui all'articolo 130 della Costituzione sugli atti degli enti locali si esercita esclusivamente sugli statuti dell'ente, sui regolamenti di competenza del consiglio, esclusi quelli attinenti all'autonomia organizzativa e contabile dello stesso consiglio, sui bilanci annuali e pluriennali e relative variazioni, adottate o ratificate dal consiglio, sul rendiconto della gestione, secondo le disposizioni del presente testo unico.

2. Il controllo preventivo di legittimita' si estende anche agli atti delle Istituzioni pubbliche di assistenza e beneficenza.

### Articolo 127 - Controllo eventuale

1. Le deliberazioni della giunta e del consiglio sono sottoposte al controllo, nei limiti delle illeggittimita' denunziate, quando un quarto dei consiglieri provinciali o un quarto dei consiglieri nei comuni con popolazione superiore a 15.000 abitanti ovvero un quinto dei consiglieri nei comuni con popolazione sino a 15.000 abitanti ne facciano richiesta scritta e motivata con l'indicazione delle norme violate, entro dieci giorni dall'affissione all'albo pretorio, quando le deliberazioni stesse riguardino:

- a) appalti e affidamento di servizi o forniture di importo superiore alla soglia di rilievo comunitario;
- b) dotazioni organiche e relative variazioni;
- c) assunzioni del personale.

2. Nei casi previsti dal comma 1, il controllo e' esercitato dal comitato regionale di controllo ovvero, se istituito, dal difensore civico comunale o provinciale. L'organo che procede al controllo, se ritiene che la deliberazione sia illegittima, ne da comunicazione all'ente, entro quindici giorni dalla richiesta, e lo invita ad eliminare i vizi riscontrati. In tal caso, se l'ente non ritiene di modificare la delibera, essa acquista efficacia se viene confermata con il voto favorevole della maggioranza assoluta dei componenti il consiglio.

3. La giunta puo' altresi' sottoporre al controllo preventivo di legittimita' dell'organo regionale di controllo ogni altra deliberazione dell'ente secondo le modalita' di cui all'articolo 133.

### Articolo 128 - Comitato regionale di controllo

1. Per l'esercizio del controllo di legittimita' e' istituito, con decreto del presidente della giunta regionale, il comitato regionale di controllo sugli atti dei comuni e delle province.

2. Sono disciplinate con legge regionale l'elezione, a maggioranza qualificata dei componenti del comitato regionale di controllo di cui all'articolo 130, comma 1, lettera a) e comma 2 prima parte, la tempestiva sostituzione degli stessi in caso di morte, dimissioni, decadenza per reiterate assenze ingiustificate o incompatibilita' sopravvenuta, nonche' per la supplenza del presidente.

3. La legge regionale puo', articolare il comitato in sezioni per territorio o per materia, salvaguardando con forme opportune l'unitarieta' di indirizzo. A tal fine la regione, in collaborazione con gli uffici del comitato, cura la pubblicazione periodica delle principali decisioni del comitato regionale di controllo con le relative motivazioni di riferimento.

4. Le pronunce degli organi di controllo previsti nel presente capo sono provvedimenti definitivi.

5. I componenti dei comitati regionali di controllo sono personalmente e solidalmente responsabili nei confronti degli enti locali per i danni a questi arrecati con dolo o colpa grave nell'esercizio delle loro funzioni.

### Articolo 129 - Servizi di consulenza del comitato regionale di controllo

1. Possono essere attivati nell'ambito dei comitati regionali di controllo servizi di consulenza ai quali gli enti locali possono rivolgersi al fine di ottenere preventivi elementi valutativi in ordine all'adozione di atti o provvedimenti di particolare complessita' o che attengano ad aspetti nuovi dell'attivita' deliberativa. La regione disciplina con propria normativa le modalita' organizzative e di espletamento dei servizi di consulenza.

### Articolo 130 - Composizione del comitato

1. Il comitato regionale di controllo e ogni sua eventuale sezione sono composti:

- a) da quattro esperti eletti dal consiglio regionale, di cui: 1) uno iscritto da almeno dieci anni nell'albo degli avvocati, scelto in una terna proposta dal competente ordine professionale; 2) uno iscritto da almeno dieci anni all'albo dei dottori commercialisti o dei ragionieri, scelto in una terna proposta dai rispettivi ordini professionali; 3) uno scelto tra chi abbia ricoperto complessivamente per almeno cinque anni la carica di sindaco, di presidente della provincia, di consigliere regionale o di parlamentare nazionale, ovvero tra i funzionari statali, regionali o degli enti locali in quiescenza, con qualifica non inferiore a dirigente od equiparata; 4) uno scelto tra i magistrati o gli avvocati dello Stato in quiescenza, o tra i professori di ruolo di universita' in materie giuridiche ed amministrative ovvero tra i segretari comunali o provinciali in quiescenza;
- b) da un esperto designato dal commissario del Governo scelto fra funzionari dell'Amministrazione civile dell'interno in servizio nelle rispettive province.

2. Il consiglio regionale elegge non piu' di due componenti supplenti aventi i requisiti di cui alla lettera a) del comma 1; un terzo supplente, avente i requisiti di cui alla lettera b) del comma 1, e' designato dal commissario del Governo.

3. In caso di assenza od impedimento dei componenti effettivi, di cui rispettivamente alle lettere a) e b) del comma 1, intervengono alle sedute i componenti supplenti, eletti o designati per la stessa categoria.

4. Il comitato ed ogni sua sezione eleggono nel proprio seno il presidente ed un vicepresidente scelti tra i componenti eletti dal consiglio regionale.

5. Funge da segretario un funzionario della regione.

6. Il comitato e le sezioni sono rinnovati integralmente a seguito di nuove elezioni del consiglio regionale, nonche' quando si dimetta contemporaneamente la maggioranza dei rispettivi componenti.

7. Il presidente ed il vicepresidente del comitato, se dipendenti pubblici, sono collocati fuori ruolo; se dipendenti privati, sono collocati in aspettativa non retribuita.

8. Ai componenti del comitato si applicano le norme relative ai permessi ed alle aspettative previsti per gli amministratori locali.

### Articolo 131 - Incompatibilita' ed ineleggibilita'

1. Non possono essere eletti e non possono far parte dei comitati regionali di controllo:

- a) i deputati, i senatori, i parlamentari europei; b)i consiglieri e gli assessori regionali; c) gli amministratori di enti locali o di altri enti soggetti a controllo del comitato, nonche' coloro che abbiano ricoperto tali cariche nell'anno precedente alla costituzione del medesimo comitato; d) coloro che si trovano nelle condizioni di ineleggibilita' alle cariche di cui alle lettere b) e c), con esclusione dei magistrati e dei funzionari dello Stato; e) i dipendenti ed i contabili della regione e degli enti locali sottoposti al controllo del comitato nonche' i dipendenti dei partiti presenti nei consigli degli enti locali della regione; f) i componenti di altro comitato regionale di controllo o delle sezioni di esso; g) coloro che prestano attivita' di consulenza o di collaborazione presso la regione o enti sottoposti al controllo regionale; h) coloro che ricoprono incarichi direttivi o esecutivi nei partiti a livello provinciale, regionale o nazionale, nonche' coloro che abbiano ricoperto tali incarichi nell'anno precedente alla costituzione del comitato.

### Articolo 132 - Funzionamento del comitato

1. Il funzionamento dei comitati regionali di controllo e delle loro sezioni, le indennita' da attribuire ai componenti, le funzioni del presidente e del vicepresidente, le forme di pubblicita' della attivita' dei comitati e di consultazione delle decisioni, nonche' il rilascio di copie di esse sono disciplinati dalla legge regionale.

2. Le spese per il funzionamento dei comitati regionali di controllo e dei loro uffici, nonche' la corresponsione di un'indennita' di carica ai componenti sono a carico della regione.

3. La regione provvede alle strutture serventi del comitato regionale di controllo ispirandosi ai principi dell'adeguatezza funzionale e dell'autonomia dell'organo.

### Articolo 133 - Modalita' del controllo preventivo di legittimita'

1. Il controllo di legittimita' comporta la verifica della conformita' dell'atto alle norme vigenti ed alle norme statutarie specificamente indicate nel provvedimento di annullamento, per quanto riguarda la competenza, la forma e la procedura, e rimanendo esclusa ogni diversa valutazione dell'interesse pubblico perseguito. Nell'esame del bilancio preventivo e del rendiconto della gestione il controllo di legittimita' comprende la coerenza interna degli atti e la corrispondenza dei dati contabili con quelli delle deliberazioni, nonche' con i documenti giustificativi allegati alle stesse.

2. Il comitato regionale di controllo, entro dieci giorni dalla ricezione degli atti di cui all'articolo 126, comma 1, puo' disporre l'audizione dei rappresentanti dell'ente deliberante o puo' richiedere, per una sola volta, chiarimenti o elementi integrativi di giudizio in forma scritta. In tal caso il termine per l'esercizio del controllo viene sospeso e riprende a decorrere dalla data della trasmissione dei chiarimenti o elementi integrativi o dell'audizione dei rappresentanti.

3. Il comitato puo' indicare all'ente interessato le modificazioni da apportare alle risultanze del rendiconto della gestione con l'invito ad adottarle entro il termine massimo di trenta giorni.

4. Nel caso di mancata adozione delle modificazioni entro il termine di cui al comma 3, o di annullamento della deliberazione di adozione del rendiconto della gestione da parte del comitato di controllo, questo provvede alla nomina di uno o piu' commissari per la redazione del conto stesso.

5. Non puo' essere riesaminato il provvedimento sottoposto a controllo nel caso di annullamento in sede giurisdizionale di una decisione negativa di controllo.

### Articolo 134 - Esecutivita' delle deliberazioni

1. La deliberazione soggetta al controllo necessario di legittimita' deve essere trasmessa a pena di decadenza entro il quinto giorno successivo all'adozione. Essa diventa esecutiva se entro 30 giorni dalla trasmissione della stessa il comitato regionale di controllo non trasmetta all'ente interessato un provvedimento motivato di annullamento. Le deliberazioni diventano comunque esecutive qualora prima del decorso dello stesso termine il comitato regionale di controllo dia comunicazione di non aver riscontrato vizi di legittimita'.

2. Nel caso delle deliberazioni soggette a controllo eventuale la richiesta di controllo sospende l'esecutivita' delle stesse fino all'avvenuto esito del controllo.

3. Le deliberazioni non soggette a controllo necessario o non sottoposte a controllo eventuale diventano esecutive dopo il decimo giorno dalla loro pubblicazione.

4. Nel caso di urgenza le deliberazioni del consiglio o della giunta possono essere dichiarate immediatamente eseguibili con il voto espresso dalla maggioranza dei componenti.

### Articolo 135 - Comunicazione deliberazioni al prefetto

1. Il Prefetto, nell'esercizio dei poteri conferitigli dalla legge o a lui delegati dal Ministro dell'interno, ai sensi dell'articolo 2, comma, 2-quater, del decreto-legge 29 ottobre 1991, n. 345, convertito, con modificazioni, dalla legge 30 dicembre 1991, n. 410, e successive modificazioni ed integrazioni, qualora ritenga, sulla base di fondati elementi comunque acquisiti, che esistano tentativi di infiltrazioni di tipo mafioso nelle attivita' riguardanti appalti, concessioni, subappalti, cottimi, noli a caldo o contratti similari per la realizzazione di opere e di lavori pubblici, ovvero quando sia necessario assicurare il regolare svolgimento delle attivita' delle pubbliche amministrazioni, richiede ai competenti organi statali e regionali gli interventi di controllo e sostitutivi previsti dalla legge.

2. Ai medesimi fini indicati nel comma 1 il prefetto puo' chiedere che siano sottoposte al controllo preventivo di legittimita' le deliberazioni degli enti locali relative ad acquisti, alienazioni, appalti ed in generale a tutti i contratti, con le modalita' e i termini previsti dall'articolo 133, comma 1. Le predette deliberazioni sono comunicate al prefetto contestualmente all'affissione all'albo.

### Articolo 136 - Poteri sostitutivi per omissione o ritardo di atti obbligatori

1. Qualora gli enti locali, sebbene invitati a provvedere entro congruo termine, ritardino o omettano di compiere atti obbligatori per legge, si provvede a mezzo di commissario ad acta nominato dal difensore civico regionale, ove costituito, ovvero dal comitato regionale di controllo. Il commissario ad acta provvede entro sessanta giorni dal conferimento dell'incarico.

### Articolo 137 - Poteri sostitutivi del Governo

1. Con riferimento alle funzioni e ai compiti spettanti agli enti locali, in caso di accertata inattivita' che comporti inadempimento agli obblighi derivanti dall'appartenenza alla Unione europea o pericolo di grave pregiudizio agli interessi nazionali, il Presidente del Consiglio dei Ministri, su proposta del Ministro competente per materia, assegna all'ente inadempiente un congruo termine per provvedere.

2. Decorso inutilmente tale termine, il Consiglio dei Ministri, sentito il soggetto inadempiente, nomina un commissario che provvede in via sostitutiva.

3. In casi di assoluta urgenza, non si applica la procedura di cui al comma 1 e il Consiglio dei Ministri puo' adottare il provvedimento di cui al comma 2, su proposta del Presidente del Consiglio dei Ministri, di concerto con il Ministro competente. Il provvedimento in tal modo adottato ha immediata esecuzione ed e' immediatamente comunicato alla Conferenza Stato-citta' e autonomie locali allargata ai rappresentanti delle comunita' montane, che ne puo' chiedere il riesame, nei termini e con gli effetti previsti dall'articolo 8, comma 3, della legge 15 marzo 1997, n. 59.

4. Restano ferme le disposizioni in materia di poteri sostitutivi previste dalla legislazione vigente.

### Articolo 138 - Annullamento straordinario

1. In applicazione dell'articolo 2, comma 3, lettera p), della legge 23 agosto 1988, n. 400, il Governo, a tutela dell'unita' dell'ordinamento, con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei Ministri, su proposta del Ministro dell'interno, ha facolta', in qualunque tempo, di annullare, d'ufficio o su denunzia, sentito il Consiglio di Stato, gli atti degli enti locali viziati da illegittimita'.

### Articolo 139 - Pareri obbligatori

1. Ai pareri obbligatori delle amministrazioni statali, anche ad ordinamento autonomo, delle regioni e di ogni altro ente sottoposto a tutela statale, regionale e subregionale, prescritti da qualsiasi norma avente forza di legge ai fini della programmazione, progettazione ed esecuzione di opere pubbliche o di altre attivita' degli enti locali, si applicano le disposizioni dell'articolo 16 della legge 7 agosto 1990, n. 241, e successive modifiche ed integrazioni, salvo specifiche disposizioni di legge.

### Articolo 140 - Norma finale

1. Le disposizioni del presente capo si applicano anche agli altri enti di cui all'articolo 2, compresi i consorzi cui partecipano enti locali, con esclusione di quelli che gestiscono attivita' aventi rilevanza economica ed imprenditoriale e, ove previsto dallo statuto, dei consorzi per la gestione dei servizi sociali, intendendosi sostituiti alla giunta e al consiglio del comune o della provincia i corrispondenti organi di governo.

## Controllo sugli organi

### Articolo 141 - Scioglimento e sospensione dei consigli comunali e provinciali

1. I consigli comunali e provinciali vengono sciolti con decreto del Presidente della Repubblica, su proposta del Ministro dell'interno:

- a) quando compiano atti contrari alla Costituzione o per gravi e persistenti violazioni di legge, nonche' per gravi motivi di ordine pubblico;
- b) quando non possa essere assicurato il normale funzionamento degli organi e dei servizi per le seguenti cause: 1) impedimento permanente, rimozione, decadenza, decesso del sindaco o del presidente della provincia; 2) dimissioni del sindaco o del presidente della provincia; 3) cessazione dalla carica per dimissioni contestuali, ovvero rese anche con atti separati purche' contemporaneamente presentati al protocollo dell'ente, della meta' piu' uno dei membri assegnati, non computando a tal fine il sindaco o il presidente della provincia; 4) riduzione dell'organo assembleare per impossibilita' di surroga alla meta' dei componenti del consiglio;
- c) quando non sia approvato nei termini il bilancio.
- c-bis) nelle ipotesi in cui gli enti territoriali al di sopra dei mille abitanti siano sprovvisti dei relativi strumenti urbanistici generali e non adottino tali strumenti entro diciotto mesi dalla data di elezione degli organi. In questo caso, il decreto di scioglimento del consiglio e' adottato su proposta del Ministro dell'interno di concerto con il Ministro delle infrastrutture e dei trasporti.

2. Nella ipotesi di cui alla lettera c) del comma 1, trascorso il termine entro il quale il bilancio deve essere approvato senza che sia stato predisposto dalla giunta il relativo schema, l'organo regionale di controllo nomina un commissario affinche' lo predisponga d'ufficio per sottoporlo al consiglio. In tal caso e comunque quando il consiglio non abbia approvato nei termini di legge lo schema di bilancio predisposto dalla giunta, l'organo regionale di controllo assegna al consiglio, con lettera notificata ai singoli consiglieri, un termine non superiore a 20 giorni per la sua approvazione, decorso il quale si sostituisce, mediante apposito commissario, all'amministrazione inadempiente. Del provvedimento sostitutivo e' data comunicazione al prefetto che inizia la procedura per lo scioglimento del consiglio. (95)

2-bis. Nell'ipotesi di cui alla lettera c-bis) del comma 1, trascorso il termine entro il quale gli strumenti urbanistici devono essere adottati, la regione segnala al prefetto gli enti inadempienti. Il prefetto invita gli enti che non abbiano provveduto ad adempiere all'obbligo nel termine di quattro mesi. A tal fine gli enti locali possono attivare gli interventi, anche sostitutivi, previsti dallo statuto secondo criteri di neutralita', di sussidiarieta' e di adeguatezza. Decorso infruttuosamente il termine di quattro mesi, il prefetto inizia la procedura per lo scioglimento del consiglio.

3. Nei casi diversi da quelli previsti dal numero 1) della lettera b) del comma 1, con il decreto di scioglimento si provvede alla nomina di un commissario, che esercita le attribuzioni conferitegli con il decreto stesso.

4. Il rinnovo del consiglio nelle ipotesi di scioglimento deve coincidere con il primo turno elettorale utile previsto dalla legge.

5. I consiglieri cessati dalla carica per effetto dello scioglimento continuano ad esercitare, fino alla nomina dei successori, gli incarichi esterni loro eventualmente attribuiti.

6. Al decreto di scioglimento e' allegata la relazione del Ministro contenente i motivi del provvedimento; dell'adozione del decreto di scioglimento e' data immediata comunicazione al Parlamento. Il decreto e' pubblicato nella Gazzetta Ufficiale della Repubblica italiana.

7. Iniziata la procedura di cui ai commi precedenti ed in attesa del decreto di scioglimento, il prefetto, per motivi di grave e urgente necessita', puo' sospendere, per un periodo comunque non superiore a novanta giorni, i consigli comunali e provinciali e nominare un commissario per la provvisoria amministrazione dell'ente. ((112))

8. Ove non diversamente previsto dalle leggi regionali le disposizioni di cui al presente articolo si applicano, in quanto compatibili, agli altri enti locali di cui all'articolo 2, comma 1 ed ai consorzi tra enti locali. Il relativo provvedimento di scioglimento degli organi comunque denominati degli enti locali di cui al presente comma e' disposto con decreto del Ministro dell'interno.

-------------- AGGIORNAMENTO (95) Il D.L. 24 aprile 2017, n. 50, convertito con modificazioni dalla L. 21 giugno 2017, n. 96, ha disposto (con l'art. 18, comma 3-ter) che "Per l'anno 2017, il termine di venti giorni, previsto dall'articolo 141, comma 2, secondo periodo, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, assegnato al consiglio comunale o provinciale che non abbia approvato nei termini di legge il rendiconto della gestione per l'esercizio 2016, e' stabilito in cinquanta giorni". -------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, convertito con modificazioni dalla L. 24 aprile 2020, n. 27, ha disposto (con l'art. 107, comma 10, alinea e lettera a)) che "In considerazione dello stato di emergenza nazionale connessa alla diffusione del virus COVID-19, dalla data di entrata in vigore del presente decreto e fino al 31 agosto 2020, sono sospesi i termini di cui agli articoli 141, comma 7, e 143, commi 3, 4 e 12, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267. Per il periodo dal 1° settembre al 31 dicembre 2020, i suddetti termini sono fissati come segue: a) il termine di cui all'articolo 141, comma 7, e' fissato in centoventi giorni".

### Art. 142. - Rimozione e sospensione di amministratori locali

1. Con decreto del Ministro dell'interno il sindaco, il presidente della provincia, i presidenti dei consorzi e delle comunita' montane, i componenti dei consigli e delle giunte, i presidenti dei consigli circoscrizionali possono essere rimossi quando compiano atti contrari alla Costituzione o per gravi e persistenti violazioni di legge o per gravi motivi di ordine pubblico.

((

1-bis. Nei territori in cui vige lo stato di emergenza nel settore dello smaltimento dei rifiuti dichiarato ai sensi della legge 24 febbraio 1992, n. 225, in caso di grave inosservanza degli obblighi posti a carico delle province inerenti alla programmazione ed organizzazione del recupero e dello smaltimento dei rifiuti a livello provinciale ed alla individuazione delle zone idonee alla localizzazione degli impianti di recupero e smaltimento dei rifiuti, ovvero in caso di grave inosservanza di specifici obblighi posti a carico dei comuni inerenti alla disciplina delle modalita' del servizio di raccolta e trasporto dei rifiuti urbani, della raccolta differenziata, della promozione del recupero delle diverse frazioni di rifiuti, della raccolta e trasporto dei rifiuti primari di imballaggio ai sensi degli articoli 197 e 198 del decreto legislativo 3 aprile 2006, n. 152, anche come precisati dalle ordinanze di protezione civile, il Sottosegretario di Stato delegato alla gestione dell'emergenza assegna all'ente interessato un congruo termine perentorio per adottare i provvedimenti dovuti o necessari; decorso inutilmente tale termine, su proposta motivata del medesimo Sottosegretario, con decreto del Ministro dell'interno possono essere rimossi il sindaco, il presidente della provincia o i componenti dei consigli e delle giunte.

))

2. In attesa del decreto, il prefetto puo' sospendere gli amministratori di cui al comma 1 qualora sussistano motivi di grave e urgente necessita'.

3. Sono fatte salve le disposizioni dettate dagli articoli 58 e 59.

### Art. 143. - (Scioglimento dei consigli comunali e provinciali conseguente a fenomeni di infiltrazione e di condizionamento di tipo mafioso o similare. Responsabilita' dei dirigenti e dipendenti)

1. Fuori dai casi previsti dall'articolo 141, i consigli comunali e provinciali sono sciolti quando, anche a seguito di accertamenti effettuati a norma dell'articolo 59, comma 7, emergono concreti, univoci e rilevanti elementi su collegamenti diretti o indiretti con la criminalita' organizzata di tipo mafioso o similare degli amministratori di cui all'articolo 77, comma 2, ovvero su forme di condizionamento degli stessi, tali da determinare un'alterazione del procedimento di formazione della volonta' degli organi elettivi ed amministrativi e da compromettere il buon andamento o l'imparzialita' delle amministrazioni comunali e provinciali, nonche' il regolare funzionamento dei servizi ad esse affidati, ovvero che risultino tali da arrecare grave e perdurante pregiudizio per lo stato della sicurezza pubblica.

2. Al fine di verificare la sussistenza degli elementi di cui al comma 1 anche con riferimento al segretario comunale o provinciale, al direttore generale, ai dirigenti ed ai dipendenti dell'ente locale, il prefetto competente per territorio dispone ogni opportuno accertamento, di norma promuovendo l'accesso presso l'ente interessato. In tal caso, il prefetto nomina una commissione d'indagine, composta da tre funzionari della pubblica amministrazione, attraverso la quale esercita i poteri di accesso e di accertamento di cui e' titolare per delega del Ministro dell'interno ai sensi dell'articolo 2, comma 2-quater, del decreto-legge 29 ottobre 1991, n. 345, convertito, con modificazioni, dalla legge 30 dicembre 1991, n. 410. Entro tre mesi dalla data di accesso, rinnovabili una volta per un ulteriore periodo massimo di tre mesi, la commissione termina gli accertamenti e rassegna al prefetto le proprie conclusioni.

3. Entro il termine di quarantacinque giorni dal deposito delle conclusioni della commissione d'indagine, ovvero quando abbia comunque diversamente acquisito gli elementi di cui al comma 1 ovvero in ordine alla sussistenza di forme di condizionamento degli organi amministrativi ed elettivi, il prefetto, sentito il comitato provinciale per l'ordine e la sicurezza pubblica integrato con la partecipazione del procuratore della Repubblica competente per territorio, invia al Ministro dell'interno una relazione nella quale si da' conto della eventuale sussistenza degli elementi di cui al comma 1 anche con riferimento al segretario comunale o provinciale, al direttore generale, ai dirigenti e ai dipendenti dell'ente locale. Nella relazione sono, altresi', indicati gli appalti, i contratti e i servizi interessati dai fenomeni di compromissione o interferenza con la criminalita' organizzata o comunque connotati da condizionamenti o da una condotta antigiuridica. Nei casi in cui per i fatti oggetto degli accertamenti di cui al presente articolo o per eventi connessi sia pendente procedimento penale, il prefetto puo' richiedere preventivamente informazioni al procuratore della Repubblica competente, il quale, in deroga all'articolo 329 del codice di procedura penale, comunica tutte le informazioni che non ritiene debbano rimanere segrete per le esigenze del procedimento.((112))

4. Lo scioglimento di cui al comma 1 e' disposto con decreto del Presidente della Repubblica, su proposta del Ministro dell'interno, previa deliberazione del Consiglio dei ministri entro tre mesi dalla trasmissione della relazione di cui al comma 3, ed e' immediatamente trasmesso alle Camere. Nella proposta di scioglimento sono indicati in modo analitico le anomalie riscontrate ed i provvedimenti necessari per rimuovere tempestivamente gli effetti piu' gravi e pregiudizievoli per l'interesse pubblico; la proposta indica, altresi', gli amministratori ritenuti responsabili delle condotte che hanno dato causa allo scioglimento. Lo scioglimento del consiglio comunale o provinciale comporta la cessazione dalla carica di consigliere, di sindaco, di presidente della provincia, di componente delle rispettive giunte e di ogni altro incarico comunque connesso alle cariche ricoperte, anche se diversamente disposto dalle leggi vigenti in materia di ordinamento e funzionamento degli organi predetti.((112))

5. Anche nei casi in cui non sia disposto lo scioglimento, qualora la relazione prefettizia rilevi la sussistenza degli elementi di cui al comma 1 con riferimento al segretario comunale o provinciale, al direttore generale, ai dirigenti o ai dipendenti a qualunque titolo dell'ente locale, con decreto del Ministro dell'interno, su proposta del prefetto, e' adottato ogni provvedimento utile a far cessare immediatamente il pregiudizio in atto e ricondurre alla normalita' la vita amministrativa dell'ente, ivi inclusa la sospensione dall'impiego del dipendente, ovvero la sua destinazione ad altro ufficio o altra mansione con obbligo di avvio del procedimento disciplinare da parte dell'autorita' competente.

6. A decorrere dalla data di pubblicazione del decreto di scioglimento sono risolti di diritto gli incarichi di cui all'articolo 110, nonche' gli incarichi di revisore dei conti e i rapporti di consulenza e di collaborazione coordinata e continuativa che non siano stati rinnovati dalla commissione straordinaria di cui all'articolo 144 entro quarantacinque giorni dal suo insediamento.

7. Nel caso in cui non sussistano i presupposti per lo scioglimento o l'adozione di altri provvedimenti di cui al comma 5, il Ministro dell'interno, entro tre mesi dalla trasmissione della relazione di cui al comma 3, emana comunque un decreto di conclusione del procedimento in cui da' conto degli esiti dell'attivita' di accertamento. Le modalita' di pubblicazione dei provvedimenti emessi in caso di insussistenza dei presupposti per la proposta di scioglimento sono disciplinate dal Ministro dell'interno con proprio decreto.

7-bis. Nell'ipotesi di cui al comma 7, qualora dalla relazione del prefetto emergano, riguardo ad uno o piu' settori amministrativi, situazioni sintomatiche di condotte illecite gravi e reiterate, tali da determinare un'alterazione delle procedure e da compromettere il buon andamento e l'imparzialita' delle amministrazioni comunali o provinciali, nonche' il regolare funzionamento dei servizi ad esse affidati, il prefetto, sulla base delle risultanze dell'accesso, al fine di far cessare le situazioni riscontrate e di ricondurre alla normalita' l'attivita' amministrativa dell'ente, individua, fatti salvi i profili di rilevanza penale, i prioritari interventi di risanamento indicando gli atti da assumere, con la fissazione di un termine per l'adozione degli stessi, e fornisce ogni utile supporto tecnico-amministrativo a mezzo dei propri uffici. Decorso inutilmente il termine fissato, il prefetto assegna all'ente un ulteriore termine, non superiore a 20 giorni, per la loro adozione, scaduto il quale si sostituisce, mediante commissario ad acta, all'amministrazione inadempiente. Ai relativi oneri gli enti locali provvedono con le risorse disponibili a legislazione vigente sui propri bilanci. (104)

8. Se dalla relazione prefettizia emergono concreti, univoci e rilevanti elementi su collegamenti tra singoli amministratori e la criminalita' organizzata di tipo mafioso, il Ministro dell'interno trasmette la relazione di cui al comma 3 all'autorita' giudiziaria competente per territorio, ai fini dell'applicazione delle misure di prevenzione previste nei confronti dei soggetti di cui all'articolo 1 della legge 31 maggio 1965, n. 575.

9. Il decreto di scioglimento e' pubblicato nella Gazzetta Ufficiale. Al decreto sono allegate la proposta del Ministro dell'interno e la relazione del prefetto, salvo che il Consiglio dei ministri disponga di mantenere la riservatezza su parti della proposta o della relazione nei casi in cui lo ritenga strettamente necessario.

10. Il decreto di scioglimento conserva i suoi effetti per un periodo da dodici mesi a diciotto mesi prorogabili fino ad un massimo di ventiquattro mesi in casi eccezionali, dandone comunicazione alle Commissioni parlamentari competenti, al fine di assicurare il regolare funzionamento dei servizi affidati alle amministrazioni, nel rispetto dei principi di imparzialita' e di buon andamento dell'azione amministrativa. Le elezioni degli organi sciolti ai sensi del presente articolo si svolgono in occasione del turno annuale ordinario di cui all'articolo 1 della legge 7 giugno 1991, n. 182, e successive modificazioni. Nel caso in cui la scadenza della durata dello scioglimento cada nel secondo semestre dell'anno, le elezioni si svolgono in un turno straordinario da tenersi in una domenica compresa tra il 15 ottobre e il 15 dicembre. La data delle elezioni e' fissata ai sensi dell'articolo 3 della citata legge n. 182 del 1991, e successive modificazioni. L'eventuale provvedimento di proroga della durata dello scioglimento e' adottato non oltre il cinquantesimo giorno antecedente alla data di scadenza della durata dello scioglimento stesso, osservando le procedure e le modalita' stabilite nel comma 4.

11. Fatta salva ogni altra misura interdittiva ed accessoria eventualmente prevista, gli amministratori responsabili delle condotte che hanno dato causa allo scioglimento di cui al presente articolo non possono essere candidati alle elezioni per la Camera dei deputati, per il Senato della Repubblica e per il Parlamento europeo nonche' alle elezioni regionali, provinciali, comunali e circoscrizionali, in relazione ai due turni elettorali successivi allo scioglimento stesso, qualora la loro incandidabilita' sia dichiarata con provvedimento definitivo. Ai fini della dichiarazione d'incandidabilita' il Ministro dell'interno invia senza ritardo la proposta di scioglimento di cui al comma 4 al tribunale competente per territorio, che valuta la sussistenza degli elementi di cui al comma 1 con riferimento agli amministratori indicati nella proposta stessa. Si applicano, in quanto compatibili, le procedure di cui al libro IV, titolo II, capo VI, del codice di procedura civile.

12. Quando ricorrono motivi di urgente necessita', il prefetto, in attesa del decreto di scioglimento, sospende gli organi dalla carica ricoperta, nonche' da ogni altro incarico ad essa connesso, assicurando la provvisoria amministrazione dell'ente mediante invio di commissari. La sospensione non puo' eccedere la durata di sessanta giorni e il termine del decreto di cui al comma 10 decorre dalla data del provvedimento di sospensione.((112))

13. Si fa luogo comunque allo scioglimento degli organi, a norma del presente articolo, quando sussistono le condizioni indicate nel comma 1, ancorche' ricorrano le situazioni previste dall'articolo 141.

--------------- AGGIORNAMENTO (104) Successivamente la Corte Costituzionale, con sentenza 20 giugno - 24 luglio 2019, n. 195 (in G.U. 1ª s.s. 31/07/2019, n. 31), ha dichiarato l'illegittimita' costituzionale dell'art. 28, comma 1 del D.L. 4 ottobre 2018, n. 113, convertito con modificazioni dalla L. 1 dicembre 2018, n. 132, (che ha introdotto il comma 7-bis al presente articolo). -------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, convertito con modificazioni dalla L. 24 aprile 2020, n. 27, ha disposto (con l'art. 107, comma 10, alinea e lettere b), c) e d)) che "In considerazione dello stato di emergenza nazionale connessa alla diffusione del virus COVID-19, dalla data di entrata in vigore del presente decreto e fino al 31 agosto 2020, sono sospesi i termini di cui agli articoli 141, comma 7, e 143, commi 3, 4 e 12, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267. Per il periodo dal 1° settembre al 31 dicembre 2020, i suddetti termini sono fissati come segue: [...] b) il termine di cui all'articolo 143, comma 3, e' fissato in novanta giorni; c) il termine di cui all'articolo 143, comma 4, e' fissato in centoventi giorni; d) il termine di cui all'articolo 143, comma 12, e' fissato in novanta giorni".

### Art. 144. - Commissione straordinaria e Comitato di sostegno e monitoraggio

1. Con il decreto di scioglimento di cui all'articolo 143 e' nominata una commissione straordinaria per la gestione dell'ente, la quale esercita le attribuzioni che le sono conferite con il decreto stesso. La commissione e' composta di tre membri scelti tra funzionari dello Stato, in servizio o in quiescenza, e tra magistrati della giurisdizione ordinaria o amministrativa in quiescenza. La commissione rimane in carica fino allo svolgimento del primo turno elettorale utile.

2. Presso il Ministero dell'interno e' istituito, con personale della amministrazione, un comitato di sostegno e di monitoraggio dell'azione delle commissioni straordinarie di cui al comma 1 e dei comuni riportati a gestione ordinaria.

3. Con decreto del Ministro dell'interno, adottato a norma dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, sono determinate le modalita' di organizzazione e funzionamento della commissione straordinaria per l'esercizio delle attribuzioni ad essa conferite, le modalita' di pubblicizzazione degli atti adottati dalla commissione stessa, nonche' le modalita' di organizzazione e funzionamento, del comitato di cui al comma 2.

### Art. 145. - Gestione straordinaria

1. Quando in relazione alle situazioni indicate nel comma 1 dell'articolo 143 sussiste la necessita' di assicurare il regolare funzionamento dei servizi degli enti nei cui confronti e' stato disposto lo scioglimento, il prefetto, su richiesta della commissione straordinaria di cui al comma 1 dell'articolo 144, puo' disporre, anche in deroga alle norme vigenti, l'assegnazione in via temporanea, in posizione di comando o distacco, di personale amministrativo e tecnico di amministrazioni ed enti pubblici, previa intesa con gli stessi, ove occorra anche in posizione di sovraordinazione. Al personale assegnato spetta un compenso mensile lordo proporzionato alle prestazioni da rendere, stabilito dal prefetto in misura non superiore al 50 per cento del compenso spettante a ciascuno dei componenti della commissione straordinaria, nonche', ove dovuto, il trattamento economico di missione stabilito dalla legge per i dipendenti dello Stato in relazione alla qualifica funzionale posseduta nell'amministrazione di appartenenza. Tali competenze sono a carico dello Stato e sono corrisposte dalla prefettura, sulla base di idonea documentazione giustificativa, sugli accreditamenti emessi, in deroga alle vigenti disposizioni di legge, dal Ministero dell'interno. La prefettura, in caso di ritardo nell'emissione degli accreditamenti e' autorizzata a prelevare le somme occorrenti sui fondi in genere della contabilita' speciale. Per il personale non dipendente dalle amministrazioni centrali o periferiche dello Stato. la prefettura provvede al rimborso al datore di lavoro dello stipendio lordo, per la parte proporzionalmente corrispondente alla durata delle prestazioni rese. Agli oneri derivanti dalla presente disposizione si provvede con una quota parte del 10 per cento delle somme di denaro confiscate ai sensi della legge 31 maggio 1965, n. 575, e successive modificazioni, nonche' del ricavato delle vendite disposte a norma dell'articolo 4, commi 4 e 6, del decreto-legge 14 giugno 1989, n. 230, convertito, con modificazioni dalla legge 4 agosto 1989, n. 282, relative ai beni mobili o immobili ed ai beni costituiti in azienda confiscati ai sensi della medesima legge n. 575 del 1965. Alla scadenza del periodo di assegnazione, la commissione straordinaria potra' rilasciare, sulla base della valutazione dell'attivita' prestata dal personale assegnato, apposita certificazione di lodevole servizio che costituisce titolo valutabile ai fini della progressione di carriera e nei concorsi interni e pubblici nelle amministrazioni dello Stato, delle regioni e degli enti locali.

2. Per far fronte a situazioni di gravi disservizi e per avviare la sollecita realizzazione di opere pubbliche indifferibili, la commissione straordinaria di cui al comma 1 dell'articolo 144, entro il termine di sessanta giorni dall'insediamento, adotta un piano di priorita' degli interventi, anche con riferimento a progetti gia' approvati e non eseguiti. Gli atti relativi devono essere nuovamente approvati dalla commissione straordinaria. La relativa deliberazione, esecutiva a norma di legge, e' inviata entro dieci giorni al prefetto il quale, sentito il comitato provinciale della pubblica amministrazione opportunamente integrato con i rappresentanti di uffici tecnici delle amministrazioni statali, regionali o locali, trasmette gli atti all'amministrazione regionale territorialmente competente per il tramite del commissario del Governo, o alla Cassa depositi e prestiti, che provvedono alla dichiarazione di priorita' di accesso ai contributi e finanziamenti a carico degli stanziamenti comunque destinati agli investimenti degli enti locali. Le disposizioni del presente comma si applicano ai predetti enti anche in deroga alla disciplina sugli enti locali dissestati, limitatamente agli importi totalmente ammortizzabili con contributi statali o regionali ad essi effettivamente assegnati.

3. Le disposizioni di cui ai commi 1 e 2 si applicano, a far tempo dalla data di insediamento degli organi e fino alla scadenza del mandato elettivo, anche alle amministrazioni comunali e provinciali, i cui organi siano rinnovati al termine del periodo di scioglimento disposto ai sensi del comma 1 dell'articolo 143.

4. Nei casi in cui lo scioglimento e' disposto anche con riferimento a situazioni di infiltrazione o di condizionamento di tipo mafioso, connesse all'aggiudicazione di appalti di opere o di lavori pubblici o di pubbliche forniture, ovvero l'affidamento in concessione di servizi pubblici locali, la commissione straordinaria di cui al comma 1 dell'articolo 144 procede alle necessarie verifiche con i poteri del collegio degli ispettori di cui all'articolo 14 del decreto-legge 13 maggio 1991, n. 152, convertito, con modificazioni, dalla legge 12 luglio 1991, n. 203. A conclusione degli accertamenti, la commissione straordinaria adotta tutti i provvedimenti ritenuti necessari e puo' disporre d'autorita' la revoca delle deliberazioni gia' adottate, in qualunque momento e fase della procedura contrattuale, o la rescissione del contratto gia' concluso.

5. Ferme restando le forme di partecipazione popolare previste dagli statuti in attuazione dell'articolo 8, comma 3, la commissione straordinaria di cui al comma 1 dell'articolo 144, allo scopo di acquisire ogni utile elemento di conoscenza e valutazione in ordine a rilevanti questioni di interesse generale si avvale, anche mediante forme di consultazione diretta, dell'apporto di rappresentanti delle forze politiche in ambito locale, dell'Anci, dell'Upi, delle organizzazioni di volontariato e di altri organismi locali particolarmente interessati alle questioni da trattare.

### Art. 145-bis. - (Gestione finanziaria)

1. Per i comuni con popolazione inferiore a 20.000 abitanti i cui organi consiliari sono stati sciolti ai sensi dell'articolo 143, su richiesta della Commissione straordinaria di cui al comma 1 dell'articolo 144, il Ministero dell'interno provvede all'anticipazione di un importo calcolato secondo i criteri di cui al comma 2 del presente articolo. L'anticipazione e' subordinata all'approvazione di un piano di risanamento della situazione finanziaria, predisposto con le stesse modalita' previste per gli enti in stato di dissesto finanziario dalle norme vigenti. Il piano e' predisposto dalla Commissione straordinaria ed e' approvato con decreto del Ministro dell'interno, su parere della ((Commissione per la stabilita' finanziaria degli enti locali)), di cui all'articolo 155.

2. L'importo dell'anticipazione di cui al comma 1 e' pari all'importo dei residui attivi derivanti dal titolo primo e dal titolo terzo dell'entrata, come risultanti dall'ultimo rendiconto approvato, sino ad un limite massimo determinato in misura pari a cinque annualita' dei trasferimenti erariali correnti e della quota di compartecipazione al gettito dell' IRPEF, e calcolato in base agli importi spettanti al singolo comune per l'anno nel quale perviene la richiesta. Dall' anticipazione spettante sono detratti gli importi gia' corrisposti a titolo di trasferimenti o di compartecipazione al gettito dell'IRPEF per l'esercizio in corso. A decorrere dall'esercizio successivo il Ministero dell'interno provvedera', in relazione al confronto tra l'anticipazione attribuita e gli importi annualmente spettanti a titolo di trasferimenti correnti e di compartecipazione al gettito dell'IRPEF, ad effettuare le compensazioni e determinare gli eventuali conguagli sino al completo recupero dell'anticipazione medesima.

3. L'organo di revisione dell'ente locale e' tenuto a vigilare sull'attuazione del piano di risanamento, segnalando alla Commissione straordinaria o all'amministrazione successivamente subentrata le difficolta' riscontrate e gli eventuali scostamenti dagli obiettivi. Il mancato svolgimento di tali compiti da parte dell'organo di revisione e' considerato grave inadempimento.

4. Il finanziamento dell'anticipazione di cui al comma 1 avviene con contestuale decurtazione dei trasferimenti erariali agli enti locali e le somme versate dall'ente sciolto ai sensi dell'articolo 143 affluiscono ai trasferimenti erariali dell'anno successivo e sono assegnate nella stessa misura della detrazione. Le modalita' di versamento dell' annualita' sono indicate dal Ministero dell'interno all'ente locale secondo le norme vigenti.

### Art. 146. - Norma finale

1. Le disposizioni di cui agli articoli 143, 144, 145 si applicano anche agli altri enti locali di cui all'articolo 2, comma 1, nonche' ai consorzi di comuni e province, agli organi comunque denominati delle aziende sanitarie locali ed ospedaliere, alle aziende speciali dei comuni e delle province e ai consigli circoscrizionali, in quanto compatibili con i relativi ordinamenti.

2. Il Ministro dell'interno presenta al Parlamento una relazione ((annuale)) sull'attivita' svolta dalla gestione straordinaria dei singoli comuni.

## Controlli interni

### Art. 147. - (Tipologia dei controlli interni).

1. Gli enti locali, nell'ambito della loro autonomia normativa e organizzativa, individuano strumenti e metodologie per garantire, attraverso il controllo di regolarita' amministrativa e contabile, la legittimita', la regolarita' e la correttezza dell'azione amministrativa.

2. Il sistema di controllo interno e' diretto a:

- a) verificare, attraverso il controllo di gestione, l'efficacia, l'efficienza e l'economicita' dell'azione amministrativa, al fine di ottimizzare, anche mediante tempestivi interventi correttivi, il rapporto tra obiettivi e azioni realizzate, nonche' tra risorse impiegate e risultati;
- b) valutare l'adeguatezza delle scelte compiute in sede di attuazione dei piani, dei programmi e degli altri strumenti di determinazione dell'indirizzo politico, in termini di congruenza tra i risultati conseguiti e gli obiettivi predefiniti;
- c) garantire il costante controllo degli equilibri finanziari della gestione di competenza, della gestione dei residui e della gestione di cassa, anche ai fini della realizzazione degli obiettivi di finanza pubblica determinati dal patto di stabilita' interno, mediante l'attivita' di coordinamento e di vigilanza da parte del responsabile del servizio finanziario, nonche' l'attivita' di controllo da parte dei responsabili dei servizi;
- d) verificare, attraverso l'affidamento e il controllo dello stato di attuazione di indirizzi e obiettivi gestionali, anche in riferimento all'articolo 170, comma 6, la redazione del bilancio consolidato ((nel rispetto di quanto previsto dal decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni)), l'efficacia, l'efficienza e l'economicita' degli organismi gestionali esterni dell'ente; (83)
- e) garantire il controllo della qualita' dei servizi erogati, sia direttamente, sia mediante organismi gestionali esterni, con l'impiego di metodologie dirette a misurare la soddisfazione degli utenti esterni e interni dell'ente.

3. Le lettere d) ed e) del comma 2 si applicano solo agli enti locali con popolazione superiore a 100.000 abitanti in fase di prima applicazione, a 50.000 abitanti per il 2014 e a 15.000 abitanti a decorrere dal 2015.

4. Nell'ambito della loro autonomia normativa e organizzativa, gli enti locali disciplinano il sistema dei controlli interni secondo il principio della distinzione tra funzioni di indirizzo e compiti di gestione, anche in deroga agli altri principi di cui all'articolo 1, comma 2, del decreto legislativo 30 luglio 1999, n. 286, e successive modificazioni. Partecipano all'organizzazione del sistema dei controlli interni il segretario dell'ente, il direttore generale, laddove previsto, i responsabili dei servizi e le unita' di controllo, laddove istituite.

5. Per l'effettuazione dei controlli di cui al comma 1, piu' enti locali possono istituire uffici unici, mediante una convenzione che ne regoli le modalita' di costituzione e di funzionamento.

------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118 come modificato dal D.Lgs. 10 agosto 2014, n. 126 ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 147-bis. - (( (Controllo di regolarita' amministrativa e contabile). ))

((

1. Il controllo di regolarita' amministrativa e contabile e' assicurato, nella fase preventiva della formazione dell'atto, da ogni responsabile di servizio ed e' esercitato attraverso il rilascio del parere di regolarita' tecnica attestante la regolarita' e la correttezza dell'azione amministrativa. Il controllo contabile e' effettuato dal responsabile del servizio finanziario ed e' esercitato attraverso il rilascio del parere di regolarita' contabile e del visto attestante la copertura finanziaria.

2. Il controllo di regolarita' amministrativa e' inoltre assicurato, nella fase successiva, secondo principi generali di revisione aziendale e modalita' definite nell'ambito dell'autonomia organizzativa dell'ente, sotto la direzione del segretario, in base alla normativa vigente. Sono soggette al controllo le determinazioni di impegno di spesa, i contratti e gli altri atti amministrativi, scelti secondo una selezione casuale effettuata con motivate tecniche di campionamento.

3. Le risultanze del controllo di cui al comma 2 sono trasmesse periodicamente, a cura del segretario, ai responsabili dei servizi, unitamente alle direttive cui conformarsi in caso di riscontrate irregolarita', nonche' ai revisori dei conti e agli organi di valutazione dei risultati dei dipendenti, come documenti utili per la valutazione, e al consiglio comunale.

))

### Art. 147-ter. - (( (Controllo strategico). ))

((

1. Per verificare lo stato di attuazione dei programmi secondo le linee approvate dal Consiglio, l'ente locale con popolazione superiore a 100.000 abitanti in fase di prima applicazione, a 50.000 abitanti per il 2014 e a 15.000 abitanti a decorrere dal 2015 definisce, secondo la propria autonomia organizzativa, metodologie di controllo strategico finalizzate alla rilevazione dei risultati conseguiti rispetto agli obiettivi predefiniti, degli aspetti economico-finanziari connessi ai risultati ottenuti, dei tempi di realizzazione rispetto alle previsioni, delle procedure operative attuate confrontate con i progetti elaborati, della qualita' dei servizi erogati e del grado di soddisfazione della domanda espressa, degli aspetti socio-economici. L'ente locale con popolazione superiore a 100.000 abitanti in fase di prima applicazione, a 50.000 abitanti per il 2014 e a 15.000 abitanti a decorrere dal 2015 puo' esercitare in forma associata la funzione di controllo strategico.

2. L'unita' preposta al controllo strategico, che e' posta sotto la direzione del direttore generale, laddove previsto, o del segretario comunale negli enti in cui non e' prevista la figura del direttore generale, elabora rapporti periodici, da sottoporre all'organo esecutivo e al consiglio per la successiva predisposizione di deliberazioni consiliari di ricognizione dei programmi.

))

### Art. 147-quater. - (Controlli sulle societa' partecipate non quotate).

1. L'ente locale definisce, secondo la propria autonomia organizzativa, un sistema di controlli sulle societa' non quotate, partecipate dallo stesso ente locale. Tali controlli sono esercitati dalle strutture proprie dell'ente locale, che ne sono responsabili.

2. Per l'attuazione di quanto previsto al comma 1 del presente articolo, l'amministrazione definisce preventivamente, in riferimento all'articolo 170, comma 6, gli obiettivi gestionali a cui deve tendere la societa' partecipata, secondo parametri qualitativi e quantitativi, e organizza un idoneo sistema informativo finalizzato a rilevare i rapporti finanziari tra l'ente proprietario e la societa', la situazione contabile, gestionale e organizzativa della societa', i contratti di servizio, la qualita' dei servizi, il rispetto delle norme di legge sui vincoli di finanza pubblica.

3. Sulla base delle informazioni di cui al comma 2, l'ente locale effettua il monitoraggio periodico sull'andamento delle societa' non quotate partecipate, analizza gli scostamenti rispetto agli obiettivi assegnati e individua le opportune azioni correttive, anche in riferimento a possibili squilibri economico-finanziari rilevanti per il bilancio dell'ente.

4. I risultati complessivi della gestione dell'ente locale e delle aziende non quotate partecipate sono rilevati mediante bilancio consolidato, secondo la competenza economica ((, predisposto secondo le modalita' previste dal decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni)). ((83))

5. Le disposizioni del presente articolo si applicano, in fase di prima applicazione, agli enti locali con popolazione superiore a 100.000 abitanti, per l'anno 2014 agli enti locali con popolazione superiore a 50.000 abitanti e, a decorrere dall'anno 2015, agli enti locali con popolazione superiore a 15.000 abitanti, ad eccezione del comma 4, che si applica a tutti gli enti locali a decorrere dall'anno 2015, secondo le disposizioni recate dal decreto legislativo 23 giugno 2011, n. 118. Le disposizioni del presente articolo non si applicano alle societa' quotate e a quelle da esse controllate ai sensi dell'articolo 2359 del codice civile. A tal fine, per societa' quotate partecipate dagli enti di cui al presente articolo si intendono le societa' emittenti strumenti finanziari quotati in mercati regolamentati.

-------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 147-quinquies. - (( (Controllo sugli equilibri finanziari). ))

((

1. Il controllo sugli equilibri finanziari e' svolto sotto la direzione e il coordinamento del responsabile del servizio finanziario e mediante la vigilanza dell'organo di revisione, prevedendo il coinvolgimento attivo degli organi di governo, del direttore generale, ove previsto, del segretario e dei responsabili dei servizi, secondo le rispettive responsabilita'.

2. Il controllo sugli equilibri finanziari e' disciplinato nel regolamento di contabilita' dell'ente ed e' svolto nel rispetto delle disposizioni dell'ordinamento finanziario e contabile degli enti locali, e delle norme che regolano il concorso degli enti locali alla realizzazione degli obiettivi di finanza pubblica, nonche' delle norme di attuazione dell'articolo 81 della Costituzione.

3. Il controllo sugli equilibri finanziari implica anche la valutazione degli effetti che si determinano per il bilancio finanziario dell'ente in relazione all'andamento economico-finanziario degli organismi gestionali esterni.

))

## Controlli esterni sulla gestione

### Art. 148. - (Controlli esterni).

((

1. Le sezioni regionali della Corte dei conti, con cadenza annuale, nell'ambito del controllo di legittimita' e regolarita' delle gestioni, verificano il funzionamento dei controlli interni ai fini del rispetto delle regole contabili e dell'equilibrio di bilancio di ciascun ente locale. A tale fine, il sindaco, relativamente ai comuni con popolazione superiore ai 15.000 abitanti, o il presidente della provincia, avvalendosi del direttore generale, quando presente, o del segretario negli enti in cui non e' prevista la figura del direttore generale, trasmette annualmente alla sezione regionale di controllo della Corte dei conti un referto sul sistema dei controlli interni, adottato sulla base delle linee guida deliberate dalla sezione delle autonomie della Corte dei conti e sui controlli effettuati nell'anno, entro trenta giorni dalla data di entrata in vigore della presente disposizione; il referto e', altresi', inviato al presidente del consiglio comunale o provinciale.

))

2. Il Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato puo' attivare verifiche sulla regolarita' della gestione amministrativo-contabile, ai sensi dell'articolo 14, comma 1, lettera d), della legge 31 dicembre 2009, n.196, oltre che negli altri casi previsti dalla legge, qualora un ente evidenzi, anche attraverso le rilevazioni SIOPE, situazioni di squilibrio finanziario riferibili ai seguenti indicatori:

- a) ripetuto utilizzo dell'anticipazione di tesoreria;
- b) disequilibrio consolidato della parte corrente del bilancio;
- c) anomale modalita' di gestione dei servizi per conto di terzi;
- d) aumento non giustificato di spesa degli organi politici istituzionali. (78)

3. Le sezioni regionali di controllo della Corte dei conti possono attivare le procedure di cui al comma 2. (78)

4. In caso di rilevata assenza o inadeguatezza degli strumenti e delle metodologie di cui al secondo periodo del comma 1 del presente articolo, fermo restando quanto previsto dall'articolo 1 della legge 14 gennaio 1994, n.20, e successive modificazioni, e dai commi 5 e 5-bis dell'articolo 248 del presente testo unico, le sezioni giurisdizionali regionali della Corte dei conti irrogano agli amministratori responsabili la condanna ad una sanzione pecuniaria da un minimo di cinque fino ad un massimo di venti volte la retribuzione mensile lorda dovuta al momento di commissione della violazione. ------------- AGGIORNEMENTO (78) La Corte Costituzione, con sentenza 26 febbraio - 6 marzo 2014, n. 39 (in G.U. 1a s.s. 12/3/2014, n. 12), ha dichiarato "l'illegittimita' costituzionale dell'art. 148, commi 2 e 3, del decreto legislativo 18 agosto 2000, n. 267 (Testo unico delle leggi sull'ordinamento degli enti locali), come modificati dall'art. 3, comma 1, lettera e), del d.l. n. 174 del 2012, con efficacia nei confronti delle Regioni autonome Friuli-Venezia Giulia e Sardegna".

### Art. 148-bis. - (( (Rafforzamento del controllo della Corte dei conti sulla gestione finanziaria degli enti locali). ))

((

1. Le sezioni regionali di controllo della Corte dei conti esaminano i bilanci preventivi e i rendiconti consuntivi degli enti locali ai sensi dell'articolo 1, commi 166 e seguenti, della legge 23 dicembre 2005, n.266, per la verifica del rispetto degli obiettivi annuali posti dal patto di stabilita' interno, dell'osservanza del vincolo previsto in materia di indebitamento dall'articolo 119, sesto comma, della Costituzione, della sostenibilita' dell'indebitamento, dell'assenza di irregolarita', suscettibili di pregiudicare, anche in prospettiva, gli equilibri economico-finanziari degli enti.

2. Ai fini della verifica prevista dal comma 1, le sezioni regionali di controllo della Corte dei conti accertano altresi' che i rendiconti degli enti locali tengano conto anche delle partecipazioni in societa' controllate e alle quali e' affidata la gestione di servizi pubblici per la collettivita' locale e di servizi strumentali all'ente.

3. Nell'ambito della verifica di cui ai commi 1 e 2, l'accertamento, da parte delle competenti sezioni regionali di controllo della Corte dei conti, di squilibri economico-finanziari, della mancata copertura di spese, della violazione di norme finalizzate a garantire la regolarita' della gestione finanziaria, o del mancato rispetto degli obiettivi posti con il patto di stabilita' interno comporta per gli enti interessati l'obbligo di adottare, entro sessanta giorni dalla comunicazione del deposito della pronuncia di accertamento, i provvedimenti idonei a rimuovere le irregolarita' e a ripristinare gli equilibri di bilancio. Tali provvedimenti sono trasmessi alle sezioni regionali di controllo della Corte dei conti che li verificano nel termine di trenta giorni dal ricevimento. Qualora l'ente non provveda alla trasmissione dei suddetti provvedimenti o la verifica delle sezioni regionali di controllo dia esito negativo, e' preclusa l'attuazione dei programmi di spesa per i quali e' stata accertata la mancata copertura o l'insussistenza della relativa sostenibilita' finanziaria))

## II ORDINAMENTO FINANZIARIO E CONTABILE TITOLO I DISPOSIZIONI GENERA LI

### Articolo 149 - Principi generali in materia di finanza propria e derivata

1. L'ordinamento della finanza locale e' riservato alla legge, che la coordina con la finanza statale e con quella regionale.

2. Ai comuni e alle province la legge riconosce, nell'ambito della finanza pubblica, autonomia finanziaria fondata su certezza di risorse proprie e trasferite.

3. La legge assicura, altresi', agli enti locali potesta' impositiva autonoma nel campo delle imposte, delle tasse e delle tariffe, con conseguente adeguamento della legislazione tributaria vigente. A tal fine i comuni e le province in forza dell'articolo 52 del decreto legislativo 15 dicembre 1997, n. 446, e successive modificazioni possono disciplinare con regolamento le proprie entrate, anche tributarie, salvo per quanto attiene alla individuazione e definizione delle fattispecie imponibili, dei soggetti passivi e dell'aliquota massima dei singoli tributi, nel rispetto delle esigenze di semplificazione degli adempimenti dei contribuenti. Per quanto non regolamentato si applicano le disposizioni di legge vigenti.

4. La finanza dei comuni e delle province e' costituita da:

- a) imposte proprie;
- b) addizionali e compartecipazioni ad imposte erariali o regionali;
- c) tasse e diritti per servizi pubblici;
- d) trasferimenti erariali;
- e) trasferimenti regionali;
- f) altre entrate proprie, anche di natura patrimoniale;
- g) risorse per investimenti;
- h) altre entrate.

5. I trasferimenti erariali sono ripartiti in base a criteri obiettivi che tengano conto della popolazione, del territorio e delle condizioni socio- economiche, nonche' in base ad una perequata distribuzione delle risorse che tenga conto degli squilibri di fiscalita' locale.

6. Lo Stato assegna specifici contributi per fronteggiare situazioni eccezionali.

7. Le entrate fiscali finanziano i servizi pubblici ritenuti necessari per lo sviluppo della comunita' ed integrano la contribuzione erariale per l'erogazione dei servizi pubblici indispensabili.

8. A ciascun ente locale spettano le tasse, i diritti, le tariffe e i corrispettivi sui servizi di propria competenza. Gli enti locali determinano per i servizi pubblici tariffe o corrispettivi a carico degli utenti, anche in modo non generalizzato. Lo Stato e le regioni, qualora prevedano per legge casi di gratuita' nei servizi di competenza dei comuni e delle province ovvero fissino prezzi e tariffe inferiori al costo effettivo della prestazione, debbono garantire agli enti locali risorse finanziarie compensative.

9. La legge determina un fondo nazionale ordinario per contribuire ad investimenti degli enti locali destinati alla realizzazione di opere pubbliche di preminente interesse sociale ed economico.

10. La legge determina un fondo nazionale speciale per finanziare con criteri perequativi gli investimenti destinati alla realizzazione di opere pubbliche unicamente in aree o per situazioni definite dalla legge statale.

11. L'ammontare complessivo dei trasferimenti e dei fondi e' determinato in base a parametri fissati dalla legge per ciascuno degli anni previsti dal bilancio pluriennale dello Stato e non e' riducibile nel triennio.

12. Le regioni concorrono al finanziamento degli enti locali per la realizzazione del piano regionale di sviluppo e dei programmi di investimento, assicurando la copertura finanziaria degli oneri necessari all'esercizio di funzioni trasferite o delegate.

13. Le risorse spettanti a comuni e province per spese di investimento previste da leggi settoriali dello Stato sono distribuite sulla base di programmi regionali. Le regioni, inoltre, determinano con legge i finanziamenti per, le funzioni da esse attribuite agli enti locali in relazione al costo di gestione dei servizi sulla base della programmazione regionale.

### Articolo 150 - Principi in materia di ordinamento finanziario e contabile

1. L'ordinamento finanziario e contabile degli enti locali e' riservato alla legge dello Stato e stabilito dalle disposizioni di principio del presente testo unico e del decreto legislativo 23 giugno 2011, n. 118. (83)

2. L'ordinamento stabilisce per gli enti locali i principi in materia di programmazione, gestione e rendicontazione, nonche' i principi relativi alle attivita' di investimento, al servizio di tesoreria, ai compiti ed alle attribuzioni dell'organo di revisione economico-finanziaria e, per gli enti cui sia applicabile, alla disciplina del risanamento finanziario.

3. ((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

-------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 151. - (Principi generali)

1. Gli enti locali ispirano la propria gestione al principio della programmazione. A tal fine presentano il Documento unico di programmazione entro il 31 luglio di ogni anno e deliberano il bilancio di previsione finanziario entro il 31 dicembre, riferiti ad un orizzonte temporale almeno triennale. Le previsioni del bilancio sono elaborate sulla base delle linee strategiche contenute nel documento unico di programmazione, osservando i principi contabili generali ed applicati allegati al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. I termini possono essere differiti con decreto del Ministro dell'interno, d'intesa con il Ministro dell'economia e delle finanze, sentita la Conferenza Stato-citta' ed autonomie locali, in presenza di motivate esigenze. (91) (92) (112) (122)

2. Il Documento unico di programmazione e' composto dalla Sezione strategica, della durata pari a quelle del mandato amministrativo, e dalla Sezione operativa di durata pari a quello del bilancio di previsione finanziario.

3. Il bilancio di previsione finanziario comprende le previsioni di competenza e di cassa del primo esercizio del periodo considerato e le previsioni di competenza degli esercizi successivi. Le previsioni riguardanti il primo esercizio costituiscono il bilancio di previsione finanziario annuale.

4. Il sistema contabile degli enti locali garantisce la rilevazione unitaria dei fatti gestionali sotto il profilo finanziario, economico e patrimoniale, attraverso l'adozione:

- a) della contabilita' finanziaria, che ha natura autorizzatoria e consente la rendicontazione della gestione finanziaria;
- b) della contabilita' economico-patrimoniale ai fini conoscitivi, per la rilevazione degli effetti economici e patrimoniali dei fatti gestionali e per consentire la rendicontazione economico e patrimoniale.

5. I risultati della gestione finanziaria, economico e patrimoniale sono dimostrati nel rendiconto comprendente il conto del bilancio, il conto economico e lo stato patrimoniale.

6. Al rendiconto e' allegata una relazione della Giunta sulla gestione che esprime le valutazioni di efficacia dell'azione condotta sulla base dei risultati conseguiti, e gli altri documenti previsti dall'art. 11, comma 4, del decreto legislativo 23 giugno 2011, n. 118.

7. Il rendiconto e' deliberato dall'organo consiliare entro il 30 aprile dell'anno successivo.

8. Entro il 30 settembre l'ente approva il bilancio consolidato con i bilanci dei propri organismi e enti strumentali e delle societa' controllate e partecipate, secondo il principio applicato n. 4/4 di cui al decreto legislativo 23 giugno 2011, n. 118.

((8-bis. Se il bilancio di previsione non e' deliberato entro il termine del primo esercizio cui si riferisce, il rendiconto della gestione relativo a tale esercizio e' approvato indicando nelle voci riguardanti le 'Previsioni definitive di competenza' gli importi delle previsioni definitive del bilancio provvisorio gestito nel corso dell'esercizio ai sensi dell'articolo 163, comma 1. Ferma restando la procedura prevista dall'articolo 141 per gli enti locali che non rispettano i termini per l'approvazione dei bilanci di previsione e dei rendiconti e fermo restando quanto previsto dall'articolo 52 del codice della giustizia contabile, di cui all'allegato 1 al decreto legislativo 26 agosto 2016, n. 174, l'approvazione del rendiconto determina il venir meno dell'obbligo di deliberare il bilancio di previsione dell'esercizio cui il rendiconto si riferisce))

--------------- AGGIORNAMENTO (38) Il Decreto 13 dicembre 2008 (in G.U. 05/01/2009, n. 3) ha disposto (con l'art. 1, comma 1) che "Il termine per la deliberazione del bilancio di previsione per l'anno 2009 da parte degli enti locali e' differito al 31 marzo 2009". -------------- AGGIORNAMENTO (63) La L. 24 dicembre 2012, n. 228 ha disposto (con l'art. 1, comma 381) che "Per l'anno 2013 e' differito al 30 giugno 2013 il termine per la deliberazione del bilancio di previsione degli enti locali di cui all'articolo 151 del Testo unico delle leggi sull'ordinamento degli enti locali approvato con decreto legislativo 18 agosto 2000, n. 267". -------------- AGGIORNAMENTO (66) La L. 24 dicembre 2012, n. 228, come modificata dal D.L. 8 aprile 2013, n. 35, convertito con modificazioni dalla L. 6 giugno 2013, n. 64, ha disposto (con l'art. 1, comma 381) che "Per l'anno 2013 e' differito al 30 settembre 2013 il termine per la deliberazione del bilancio di previsione degli enti locali di cui all'articolo 151 del Testo unico delle leggi sull'ordinamento degli enti locali approvato con decreto legislativo 18 agosto 2000, n. 267". -------------- AGGIORNAMENTO (74) Il D.L. 31 agosto 2013, n. 102, convertito con modificazioni dalla L. 28 ottobre 2013, n. 124, ha disposto (con l'art. 8, comma 1) che "Il termine per la deliberazione del bilancio annuale di previsione 2013 degli enti locali, di cui all'articolo 151 del Testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, gia' differito al 30 settembre 2013, dall'articolo 10, comma 4- quater, lettera b), numero 1), del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e' ulteriormente differito al 30 novembre 2013. Le disposizioni di cui al presente comma si applicano anche agli enti in dissesto". -------------- AGGIORNAMENTO (78) Il D.L. 6 marzo 2014, n. 16, convertito con modificazioni dalla L. 2 maggio 2014, n. 68, ha disposto (con l'art. 2-bis, comma 1) che "Il termine per la deliberazione del bilancio annuale di previsione degli enti locali per l'esercizio 2014, di cui all'articolo 151 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, e successive modificazioni, e' ulteriormente differito al 31 luglio 2014". -------------- AGGIORNAMENTO (84) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi". -------------- AGGIORNAMENTO (91) La L. 11 dicembre 2016, n. 232 ha disposto (con l'art. 1, comma 454) che "Il termine per la deliberazione del bilancio annuale di previsione degli enti locali per l'esercizio 2017, di cui all'articolo 151 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' differito al 28 febbraio 2017". -------------- AGGIORNAMENTO (92) Il D.L. 30 dicembre 2016, n. 244, convertito con modificazioni dalla L. 27 febbraio 2017, n. 19, ha disposto (con l'art. 5, comma 11) che "Il termine per la deliberazione del bilancio annuale di previsione degli enti locali, di cui all'articolo 151 del decreto legislativo 18 agosto 2000, n. 267, per l'esercizio 2017 e' differito al 31 marzo 2017". -------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, convertito con modificazioni dalla L. 24 aprile 2020, n. 27, ha disposto (con l'art. 107, comma 2) che "Per le finalita' di cui al comma 1, per l'esercizio 2020 il termine per la deliberazione del bilancio di previsione di cui all'articolo 151, comma 1, del decreto legislativo 18 agosto 2000, n. 267 e' differito al 31 luglio 2020 anche ai fini della contestuale deliberazione di controllo a salvaguardia degli equilibri di bilancio a tutti gli effetti di legge". -------------- AGGIORNAMENTO (122) Il D.L. 30 dicembre 2021, n. 228, convertito con modificazioni dalla L. 25 febbraio 2022, n. 15, ha disposto (con l'art. 3, comma 5-sexiesdecies) che "Il termine per la deliberazione del bilancio di previsione riferito al triennio 2022-2024 da parte degli enti locali, previsto all'articolo 151, comma 1, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, da ultimo differito ai sensi del decreto del Ministro dell'interno 24 dicembre 2021, pubblicato nella Gazzetta Ufficiale della Repubblica italiana n. 309 del 30 dicembre 2021, e' prorogato al 31 maggio 2022".

### Articolo 152 - Regolamento di contabilita'

1. Con il regolamento di contabilita' ciascun ente locale applica i principi contabili stabiliti dal presente testo unico ((e dal decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni)), con modalita' organizzative corrispondenti alle caratteristiche di ciascuna comunita', ferme restando le disposizioni previste dall'ordinamento per assicurare l'unitarieta' ed uniformita' del sistema finanziario e contabile. ((83))

2. Il regolamento di contabilita' assicura, di norma, la conoscenza consolidata dei risultati globali delle gestioni relative ad enti od organismi costituiti per l'esercizio di funzioni e servizi.

3. Il regolamento di contabilita' stabilisce le norme relative alle competenze specifiche dei soggetti dell'amministrazione preposti alla programmazione, adozione ed attuazione dei provvedimenti di gestione che hanno carattere finanziario e contabile, in armonia con le disposizioni del presente testo unico e delle altre leggi vigenti.

4. I regolamenti di contabilita' sono approvati nel rispetto delle norme della parte seconda del presente testo unico, da considerarsi come principi generali con valore di limite inderogabile, con eccezione delle sottoelencate norme, le quali non si applicano qualora il regolamento di contabilita' dell'ente rechi una differente disciplina: ((a) art. 177; )) ((83)) ((b) art. 185, comma 3;)) ((83)) ((c) articoli 197 e 198;)) ((83)) ((d) art. 205;)) ((83)) ((e) articoli 213 e 219)); ((83)) f) articoli 235, commi 2 e 3, 237, 238.

-------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 153 - Servizio economico-finanziario

1. Con il regolamento sull'ordinamento degli uffici e dei servizi sono disciplinati l'organizzazione del servizio finanziario, o di ragioneria o qualificazione corrispondente, secondo le dimensioni demografiche e l'importanza economico-finanziaria dell'ente. Al servizio e' affidato il coordinamento e la gestione dell'attivita' finanziaria.

2. E' consentito stipulare apposite convenzioni tra gli enti per assicurare il servizio a mezzo di strutture comuni.

3. Il responsabile del servizio finanziario di cui all'articolo 151, comma 4, si identifica con il responsabile del servizio o con i soggetti preposti alle eventuali articolazioni previste dal regolamento di contabilita'.

4. Il responsabile del servizio finanziario, di ragioneria o qualificazione corrispondente, e' preposto alla verifica di veridicita' delle previsioni di entrata e di compatibilita' delle previsioni di spesa, avanzate dai vari servizi, da iscriversi nel bilancio ((di previsione)) ed alla verifica periodica dello stato di accertamento delle entrate e di impegno delle spese, alla regolare tenuta della contabilita' economico-patrimoniale e e piu' in generale alla salvaguardia degli equilibri finanziari e complessivi della gestione e dei vincoli di finanza pubblica. Nell'esercizio di tali funzioni il responsabile del servizio finanziario agisce in autonomia nei limiti di quanto disposto dai principi finanziari e contabili, dalle norme ordinamentali e dai vincoli di finanza pubblica. (83)

5. Il regolamento di contabilita' disciplina le modalita' con le quali vengono resi i pareri di regolarita' contabile sulle, proposte di deliberazione ed apposto il visto di regolarita' contabile sulle determinazioni dei soggetti abilitati. Il responsabile dei servizio finanziario effettua le attestazioni di copertura della spesa in relazione alle disponibilita' effettive esistenti negli stanziamenti di spesa e, quando occorre, in relazione allo stato di realizzazione degli accertamenti di entrata vincolata secondo quanto previsto dal regolamento di contabilita'.

6. Il regolamento di contabilita' disciplina le segnalazioni obbligatorie dei fatti e delle valutazioni del responsabile finanziario al legale rappresentante dell'ente, al consiglio dell'ente nella persona del suo presidente, al segretario ed all'organo di revisione , nonche' alla competente sezione regionale di controllo della Corte dei conti ove si rilevi che la gestione delle entrate o delle spese correnti evidenzi il costituirsi di situazioni - non compensabili da maggiori entrate o minori spese - tali da pregiudicare gli equilibri del bilancio. In ogni caso la segnalazione e' effettuata entro sette giorni dalla conoscenza dei fatti. Il consiglio provvede al riequilibrio a norma dell'articolo 193, entro trenta giorni dal ricevimento della segnalazione, anche su proposta della giunta.

7. Lo stesso regolamento prevede l'istituzione di un servizio di economato. cui viene preposto un responsabile, per la gestione di cassa delle spese di ufficio di non rilevante ammontare.

------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118 come modificato dal D.Lgs. 10 agosto 2014, n. 126 ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 154. - Osservatorio sulla finanza e la contabilita' degli enti locali

1. E' istituito, senza nuovi o maggiori oneri per la finanza pubblica, presso il Ministero dell'interno l'Osservatorio sulla finanza e la contabilita' degli enti locali. (83)

2. L'Osservatorio ha il compito di promuovere, in raccordo con la Commissione per l'armonizzazione contabile degli enti territoriali di cui all'art. 3-bis del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, l'adeguamento e la corretta applicazione dei principi contabili da parte degli enti locali e di monitorare la situazione della finanza pubblica locale attraverso studi ed analisi, anche in relazione agli effetti prodotti dall'applicazione della procedura di riequilibrio finanziario pluriennale di cui all'art. 243-bis. Nell'ambito dei suoi compiti, l'Osservatorio esprime pareri, indirizzi ed orientamenti. (83)

3. Con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, sentita la Conferenza Stato-citta', sono disciplinate le modalita' di organizzazione e di funzionamento. (83)

4. La partecipazione ai lavori dell'Osservatorio e' a titolo gratuito e non da' diritto ad alcun compenso o rimborso spese. (83)

5. Il Ministro dell'interno puo' assegnare ulteriori funzioni nell'ambito delle finalita' generali del comma 2 ed emanare norme di funzionamento e di organizzazione.

6. L'Osservatorio si avvale delle strutture e dell'organizzazione della Direzione centrale per la finanza locale e per i servizi finanziari dell'Amministrazione civile del Ministero dell'interno.

7. ((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118 COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

-------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 155 - ((Commissione per la stabilita' finanziaria degli enti locali))

1. La ((Commissione per la stabilita' finanziaria degli enti locali)) operante presso il Ministero dell'interno, gia' denominata Commissione di ricerca per la finanza locale, svolge i seguenti compiti:

- a) controllo centrale, da esercitare prioritariamente in relazione alla verifica della compatibilita' finanziaria, sulle dotazioni organiche e sui provvedimenti di assunzione di personale degli enti dissestati e degli enti strutturalmente deficitari, ai sensi dell'articolo 243;
- b) parere da rendere al Ministro dell'interno sul provvedimento di approvazione o diniego del piano di estinzione delle passivita', ai sensi dell'articolo 256, comma 7;
- c) proposta al Ministro dell'interno di misure straordinarie per il pagamento della massa passiva in caso di insufficienza delle risorse disponibili, ai sensi dell'articolo 256, comma 12;
- d) parere da rendere in merito all'assunzione del mutuo con la Cassa depositi e prestiti da parte dell'ente locale, ai sensi dell'articolo 255, comma 5;
- e) parere da rendere al Ministro dell'interno sul provvedimento di approvazione o diniego dell'ipotesi di bilancio stabilmente riequilibrato, ai sensi dell'articolo 261;
- f) proposta al Ministro dell'interno di adozione delle misure necessarie per il risanamento dell'ente locale, a seguito del ricostituirsi di disavanzo di amministrazione o insorgenza di debiti fuori bilancio non ripianabili con i normali mezzi o mancato rispetto delle prescrizioni poste a carico dell'ente, ai sensi dell'articolo 268;
- g) parere da rendere al Ministro dell'interno sul provvedimento di sostituzione di tutto o parte dell'organo straordinario di liquidazione, ai sensi dell'articolo 254, comma 8;
- h) approvazione, previo esame, della rideterminazione della pianta organica dell'ente locale dissestato, ai sensi dell'articolo 259, comma 7.

2. La composizione e le modalita' di funzionamento della Commissione sono disciplinate con regolamento da adottarsi ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400.

### Articolo 156 - Classi demografiche e popolazione residente

1. Ai fini dell'applicazione delle disposizioni contenute nella parte seconda del presente testo unico valgono per i comuni, se non diversamente disciplinato, le seguenti classi demografiche:

- a) comuni con meno di 500 abitanti;
- b) comuni da 500 a 999 abitanti;
- c) comuni da 1.000 a 1.999 abitanti;
- d) comuni da 2.000 a 2.999 abitanti;
- e) comuni da 3.000 a 4.999 abitanti;
- f) comuni da 5.000 a 9.999 abitanti;
- g) comuni da 10.000 a 19.999 abitanti;
- h) comuni da 20.000 a 59.999 abitanti;
- i) comuni da 60.000 a 99.999 abitanti;
- l) comuni da 100.000 a 249.999 abitanti;
- m) comuni da 250.000 a 499.999 abitanti;
- n) comuni da 500.000 abitanti ed oltre.

2. Le disposizioni del presente testo unico e di altre leggi e regolamenti relative all'attribuzione di contributi erariali di qualsiasi natura, nonche' all'inclusione nel sistema di tesoreria unica di cui alla legge 29 ottobre 1984, n. 720, alla disciplina del dissesto finanziario ed alla disciplina dei revisori dei conti, che facciano riferimento alla popolazione, vanno interpretate, se non diversamente disciplinato, come concernenti la popolazione residente calcolata alla fine del penultimo anno precedente per le province ed i comuni secondo i dati dell'Istituto nazionale di statistica, ovvero secondo i dati dell'Uncem per le comunita' montane. Per le comunita' montane e i comuni di nuova istituzione si utilizza l'ultima popolazione disponibile.

### Articolo 157 - Consolidamento dei conti pubblici

1. Ai fini del consolidamento dei conti pubblici gli enti locali rispettano le disposizioni di cui agli articoli ((13, 14 e 15 della legge 31 dicembre 2009, n. 196, e successive modificazioni, e di cui al titolo I del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.)) ((83))

((1-bis. Per le stesse finalita' di cui al comma 1 gli enti locali garantiscono la rilevazione unitaria dei fatti gestionali attraverso l'adozione di un piano integrato dei conti, articolato in piano finanziario, economico e patrimoniale secondo lo schema di cui all'allegato n. 6 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. Il livello minimo di articolazione del piano dei conti finanziario, ai fini del raccordo con i capitoli e gli articoli, ove previsti, del piano esecutivo di gestione e' costituito almeno dal quarto livello.))

((83))

((1-ter. Al fine di garantire la tracciabilita' di tutte le operazioni gestionali e la movimentazione delle voci del piano dei conti integrato, ad ogni transazione e' attribuita una codifica da applicare secondo le modalita' previste dagli articoli 5, 6 e 7 del decreto legislativo 23 giugno 2011, n. 118, e successive integrazioni.))

((83))

((1-quater. Le previsioni di competenza e di cassa, aggregate secondo l'articolazione del piano dei conti di quarto livello, ed i risultati della gestione aggregati secondo l'articolazione del piano dei conti, sono trasmessi alla banca dati unitaria delle amministrazioni pubbliche di cui all'art. 13 della legge 31 dicembre 2009, n. 196, sulla base di schemi, tempi e modalita' definiti con decreto del Ministro dell'economia e delle finanze.))

((83))

-------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 158 - Rendiconto dei contributi straordinari

1. Per tutti i contributi straordinari assegnati da amministrazioni pubbliche agli enti locali e' dovuta la presentazione del rendiconto all'amministrazione erogante entro sessanta giorni dal termine dell'esercizio finanziario relativo, a cura del segretario e del responsabile del servizio finanziario.

2. Il rendiconto, oltre alla dimostrazione contabile della spesa, documenta i risultati ottenuti in termini di efficienza ed efficacia dell'intervento.

3. Il termine di cui al comma 1 e' perentorio. La sua inosservanza comporta l'obbligo di restituzione del contributo straordinario assegnato.

4. Ove il contributo attenga ad un intervento realizzato in piu' esercizi finanziari l'ente locale e' tenuto al rendiconto per ciascun esercizio.

### Art. 159. - Norme sulle esecuzioni nei confronti degli enti locali

1. Non sono ammesse procedure di esecuzione e di espropriazione forzata nei confronti degli enti locali presso soggetti diversi dai rispettivi tesorieri. Gli atti esecutivi eventualmente intrapresi non determinano vincoli sui beni oggetto della procedura espropriativa.

2. Non sono soggette ad esecuzione forzata, a pena di nullita' rilevabile anche d'ufficio dal giudice, le somme di competenza degli enti locali destinate a:

- a) pagamento delle retribuzioni al personale dipendente e dei conseguenti oneri previdenziali per i tre mesi successivi;
- b) pagamento delle rate di mutui e di prestiti obbligazionari scadenti nel semestre in corso;
- c) espletamento dei servizi locali indispensabili. ((16))

3. Per l'operativita' dei limiti all'esecuzione forzata di cui al comma 2 occorre che l'organo esecutivo, con deliberazione da adottarsi per ogni semestre e notificata al tesoriere, quantifichi preventivamente gli importi delle somme destinate alle suddette finalita'. ((16))

4. Le procedure esecutive eventualmente intraprese in violazione del comma 2 non determinano vincoli sulle somme ne' limitazioni all'attivita' del tesoriere. ((16))

5. I provvedimenti adottati dai commissari nominati a seguito dell'esperimento delle procedure di cui all'articolo 37 della legge 6 dicembre 1971, n. 1034, e di cui all'articolo 27, comma 1, numero 4, del testo unico delle leggi sul Consiglio di Stato, emanato con regio decreto 26 giugno 1924, n. 1054, devono essere muniti dell'attestazione di copertura finanziaria prevista dall'articolo 151, comma 4. e non possono avere ad oggetto le somme di cui alle lettere a), b) e c) del comma 2, quantificate ai sensi del comma 3.

--------------- AGGIORNAMENTO (16) La Corte costituzionale, con sentenza 4-18 giugno 2003, n. 211, (in G.U. 1a s.s. 25/6/2003, n. 25) ha dichiarato l'illegittimita' costituzionale dell'art. 159, commi 2, 3 e 4, "nella parte in cui non prevede che la impignorabilita' delle somme destinate ai fini indicati alle lettere a), b) e c) del comma 2 non operi qualora, dopo la adozione da parte dell'organo esecutivo della deliberazione semestrale di preventiva quantificazione degli importi delle somme destinate alle suddette finalita' e la notificazione di essa al soggetto tesoriere dell'ente locale, siano emessi mandati a titoli diversi da quelli vincolati, senza seguire l'ordine cronologico delle fatture cosi' come pervenute per il pagamento o, se non e' prescritta fattura, delle deliberazioni di impegno da parte dell'ente stesso".

### Art. 160.

((ARTICOLO ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118 COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126))

### Art. 161. - (Certificazioni finanziarie e invio di dati contabili)

1. Il Ministero dell'interno puo' richiedere ai comuni, alle province, alle citta' metropolitane, alle unioni di comuni e alle comunita' montane specifiche certificazioni su particolari dati finanziari, non presenti nella banca dati delle amministrazioni pubbliche di cui all'articolo 13 della legge 31 dicembre 2009, n. 196. Le certificazioni sono firmate dal responsabile del servizio finanziario.

2. Le modalita' per la struttura e per la redazione delle certificazioni nonche' i termini per la loro trasmissione sono stabiliti con decreto del Ministero dell'interno, adottato previo parere dell'ANCI e dell'UPI e pubblicato nella Gazzetta Ufficiale.

3. I dati delle certificazioni sono resi noti mediante pubblicazione nel sito internet istituzionale del Dipartimento per gli affari interni e territoriali del Ministero dell'interno e vengono resi disponibili per l'inserimento nella banca dati delle amministrazioni pubbliche di cui all'articolo 13 della legge 31 dicembre 2009, n. 196.

4. Decorsi trenta giorni dal termine previsto per l'approvazione dei bilanci di previsione, dei rendiconti e del bilancio consolidato, in caso di mancato invio, da parte dei comuni, delle province e delle citta' metropolitane, dei relativi dati alla banca dati delle amministrazioni pubbliche di cui all'articolo 13 della legge 31 dicembre 2009, n. 196, compresi i dati aggregati per voce del piano dei conti integrato, sono sospesi i pagamenti delle risorse finanziarie a qualsiasi titolo dovute dal Ministero dell'interno - Dipartimento per gli affari interni e territoriali, ivi comprese quelle a titolo di fondo di solidarieta' comunale. In sede di prima applicazione, con riferimento al bilancio di previsione 2019, la sanzione di cui al periodo precedente si applica a decorrere dal 1° novembre 2019.((113)) (100)

--------------- AGGIORNAMENTO (100) La L. 30 dicembre 2018, n. 145 ha disposto (con l'art. 1, comma 903) che la presente modifica ha effetto a decorrere dal 1° novembre 2019. --------------- AGGIORNAMENTO (113) L'Ordinanza 29 marzo 2020 (in G.U. 30/03/2020, n. 85) ha disposto (con l'art. 1, comma 2) che le sanzioni di cui al comma 4 del presente articolo non si applicano alle spettanze per l'anno 2020.

## PROGRAMMAZIONE E BILANCI CAPO I Programmazione

### Articolo 162 - Principi del bilancio

1. Gli enti locali deliberano annualmente il bilancio di previsione finanziario ((riferito ad almeno un triennio, comprendente le previsioni di competenza e di cassa del primo esercizio del periodo considerato e le previsioni di competenza degli esercizi successivi, osservando i principi contabili generali e applicati allegati al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni)).((83))

2. Il totale delle entrate finanzia indistintamente il totale delle spese, salvo le eccezioni di legge.

3. L'unita' temporale della gestione e' l'anno finanziario, che inizia il 1 gennaio e termina il 31 dicembre dello stesso anno; dopo tale termine non possono piu' effettuarsi accertamenti di entrate e impegni di spesa in conto dell'esercizio scaduto.

4. Tutte le entrate sono iscritte in bilancio al lordo delle spese di riscossione a carico degli enti locali e di altre eventuali spese ad esse connesse. Parimenti tutte le spese sono iscritte in bilancio integralmente, senza alcuna riduzione delle correlative entrate. La gestione finanziaria e' unica come il relativo bilancio di previsione: sono vietate le gestioni di entrate e di spese che non siano iscritte in bilancio.

5. Il bilancio di previsione e' redatto nel rispetto dei principi di veridicita' ed attendibilita', sostenuti da analisi riferite ad un adeguato arco di tempo o, in mancanza, da altri idonei parametri di riferimento. ((6.Il bilancio di previsione e' deliberato in pareggio finanziario complessivo per la competenza, comprensivo dell'utilizzo dell'avanzo di amministrazione e del recupero del disavanzo di amministrazione e garantendo un fondo di cassa finale non negativo. Inoltre, le previsioni di competenza relative alle spese correnti sommate alle previsioni di competenza relative ai trasferimenti in c/capitale,al saldo negativo delle partite finanziarie e alle quote di capitale delle rate di ammortamento dei mutui e degli altri prestiti, con l'esclusione dei rimborsi anticipati, non possono essere complessivamente superiori alle previsioni di competenza dei primi tre titoli dell'entrata, ai contribuiti destinati al rimborso dei prestiti e all'utilizzo dell'avanzo di competenza di parte corrente e non possono avere altra forma di finanziamento, salvo le eccezioni tassativamente indicate nel principio applicato alla contabilita' finanziaria necessarie a garantire elementi di flessibilita' degli equilibri di bilancio ai fini del rispetto del principio dell'integrita'.))((83)) 7. Gli enti assicurano ai cittadini ed agli organismi di partecipazione, di cui all'articolo 8, la conoscenza dei contenuti significativi e caratteristici del bilancio annuale e dei suoi allegati con le modalita' previste dallo statuto e dai regolamenti.

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 163 - (Esercizio provvisorio e gestione provvisoria)

1. Se il bilancio di previsione non e' approvato dal Consiglio entro il 31 dicembre dell'anno precedente, la gestione finanziaria dell'ente si svolge nel rispetto dei principi applicati della contabilita' finanziaria riguardanti l'esercizio provvisorio o la gestione provvisoria.Nel corso dell'esercizio provvisorio o della gestione provvisoria, gli enti gestiscono gli stanziamenti di competenza previsti nell'ultimo bilancio approvato per l'esercizio cui si riferisce la gestione o l'esercizio provvisorio, ed effettuano i pagamenti entro i limiti determinati dalla somma dei residui al 31 dicembre dell'anno precedente e degli stanziamenti di competenza al netto del fondo pluriennale vincolato.

2. Nel caso in cui il bilancio di esercizio non sia approvato entro il 31 dicembre e non sia stato autorizzato l'esercizio provvisorio, o il bilancio non sia stato approvato entro i termini previsti ai sensi del comma 3, e' consentita esclusivamente una gestione provvisoria nei limiti dei corrispondenti stanziamenti di spesa dell'ultimo bilancio approvato per l'esercizio cui si riferisce la gestione provvisoria. Nel corso della gestione provvisoria l'ente puo' assumere solo obbligazioni derivanti da provvedimenti giurisdizionali esecutivi, quelle tassativamente regolate dalla legge e quelle necessarie ad evitare che siano arrecati danni patrimoniali certi e gravi all'ente. Nel corso della gestione provvisoria l'ente puo' disporre pagamenti solo per l'assolvimento delle obbligazioni gia' assunte, delle obbligazioni derivanti da provvedimenti giurisdizionali esecutivi e di obblighi speciali tassativamente regolati dalla legge, per le spese di personale, di residui passivi, di rate di mutuo, di canoni, imposte e tasse, ed, in particolare, per le sole operazioni necessarie ad evitare che siano arrecati danni patrimoniali certi e gravi all'ente.

3. L'esercizio provvisorio e' autorizzato con legge o con decreto del Ministro dell'interno che, ai sensi di quanto previsto dall'art. 151, primo comma, differisce il termine di approvazione del bilancio, d'intesa con il Ministro dell'economia e delle finanze, sentita la Conferenza Stato-citta' ed autonomia locale, in presenza di motivate esigenze. Nel corso dell'esercizio provvisorio non e' consentito il ricorso all'indebitamento e gli enti possono impegnare solo spese correnti, le eventuali spese correlate riguardanti le partite di giro, lavori pubblici di somma urgenza o altri interventi di somma urgenza. Nel corso dell'esercizio provvisorio e' consentito il ricorso all'anticipazione di tesoreria di cui all'art. 222. (122) ((145))

4. COMMA ABROGATO DAL D.L. 14 AGOSTO 2020, N. 104.

5. Nel corso dell'esercizio provvisorio, gli enti possono impegnare mensilmente,unitamente alla quota dei dodicesimi non utilizzata nei mesi precedenti, per ciascun programma, le spese di cui al comma 3, per importi non superiori ad un dodicesimo degli stanziamenti del secondo esercizio del bilancio di previsione deliberato l'anno precedente, ridotti delle somme gia' impegnate negli esercizi precedenti e dell'importo accantonato al fondo pluriennale vincolato, con l'esclusione delle spese:

- a) tassativamente regolate dalla legge;
- b) non suscettibili di pagamento frazionato in dodicesimi;
- c) a carattere continuativo necessarie per garantire il mantenimento del livello qualitativo e quantitativo dei servizi esistenti, impegnate a seguito della scadenza dei relativi contratti.

6. COMMA ABROGATO DAL D.L. 14 AGOSTO 2020, N. 104.

7. Nel corso dell'esercizio provvisorio, sono consentite le variazioni di bilancio previste dall'art. 187, comma 3-quinquies, quelle riguardanti le variazioni del fondo pluriennale vincolato, quelle necessarie alla reimputazione agli esercizi in cui sono esigibili, di obbligazioni riguardanti entrate vincolate gia' assunte, e delle spese correlate, nei casi in cui anche la spesa e' oggetto di reimputazione l'eventuale aggiornamento delle spese gia' impegnate. Tali variazioni rilevano solo ai fini della gestione dei dodicesimi. (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi". -------------- AGGIORNAMENTO (122) Il D.L. 30 dicembre 2021, n. 228, convertito con modificazioni dalla L. 25 febbraio 2022, n. 15, ha disposto (con l'art. 3, comma 5-septiesdecies) che "Ai sensi dell'articolo 163, comma 3, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' autorizzato per gli enti locali l'esercizio provvisorio fino al termine di cui al comma 5-sexiesdecies". -------------- AGGIORNAMENTO (145) Il D.L. 10 agosto 2023, n. 104, convertito con modificazioni dalla L. 9 ottobre 2023, n. 136, ha disposto (con l'art. 21-bis, comma 1) che "All'articolo 163, comma 3, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, la previsione che gli enti possano impegnare solo spese correnti si interpreta nel senso che possono essere impegnate anche le spese per le assunzioni di personale, anche a tempo indeterminato, gia' autorizzate dal piano triennale del fabbisogno di personale, nonche' dal bilancio di previsione finanziario ai sensi dell'articolo 164, comma 2, del medesimo testo unico".

### Articolo 164 - (( (Caratteristiche del bilancio) ))

((

1. L'unita' di voto del bilancio per l'entrata e' la tipologia e per la spesa e' il programma, articolato in titoli.

2. Il bilancio di previsione finanziario ha carattere autorizzatorio, costituendo limite, per ciascuno degli esercizi considerati:

a) agli accertamenti e agli incassi riguardanti le accensioni di prestiti;

b) agli impegni e ai pagamenti di spesa. Non comportano limiti alla gestione le previsioni riguardanti i rimborsi delle anticipazioni di tesoreria e le partite di giro.))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 165 - Struttura del bilancio

1. Il bilancio di previsione ((finanziario)) e' composto da due parti, relative rispettivamente all'entrata ed alla spesa ((ed e' redatto secondo lo schema previsto dall'allegato n. 9 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.))((83))

((2. Le previsioni di entrata del bilancio di previsione sono classificate, secondo le modalita' indicate all'art. 15 del decreto legislativo 23 giugno 2011, n. 118, in:

a) titoli, definiti secondo la fonte di provenienza delle entrate;

b) tipologie, definite in base alla natura delle entrate, nell'ambito di ciascuna fonte di provenienza.))

((3. Ai fini della gestione, nel Piano esecutivo di gestione, le tipologie sono ripartite in categorie, in capitoli ed eventualmente in articoli. Le categorie di entrata degli enti locali sono individuate nell'elenco di cui all'allegato n. 13/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. Nell'ambito delle categorie e' data separata evidenza delle eventuali quote di entrata non ricorrente. La Giunta, contestualmente alla proposta di bilancio, trasmette, a fini conoscitivi, la proposta di articolazione delle tipologie in categorie.))

((4. Le previsioni di spesa del bilancio di previsione sono classificate secondo le modalita' indicate all'art. 14 del decreto legislativo 23 giugno 2011, n. 118 in:

a) missioni, che rappresentano le funzioni principali e gli obiettivi strategici perseguiti dagli enti locali, utilizzando risorse finanziarie, umane e strumentali ad esse destinate;

b) programmi, che rappresentano gli aggregati omogenei di attivita' volte a perseguire gli obiettivi definiti nell'ambito delle missioni. I programmi sono ripartiti in titoli e sono raccordati alla relativa codificazione COFOG di secondo livello (Gruppi), secondo le corrispondenze individuate nel glossario, di cui al comma 3-ter dell'art. 14, che costituisce parte integrante dell'allegato n. 14.))

((5. Ai fini della gestione, nel Piano esecutivo di gestione, i programmi sono ripartiti in titoli, macroaggregati, capitoli ed eventualmente in articoli. I macroaggregati di spesa degli enti locali sono individuati nell'elenco di cui all'allegato n. 14 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. La Giunta, contestualmente alla proposta di bilancio trasmette, a fini conoscitivi, la proposta di articolazione dei programmi in macroaggregati.))

((6. Il bilancio di previsione finanziario indica, per ciascuna unita' di voto:

a) l'ammontare presunto dei residui attivi o passivi alla chiusura dell'esercizio precedente a quello cui il bilancio si riferisce;

b) l'ammontare delle previsioni di competenza e di cassa definitive dell'anno precedente a quello cui si riferisce il bilancio;

c) l'ammontare degli accertamenti e degli impegni che si prevede di imputare in ciascuno degli esercizi cui il bilancio si riferisce, nel rispetto del principio della competenza finanziaria;

d) l'ammontare delle entrate che si prevede di riscuotere o delle spese di cui si autorizza il pagamento nel primo esercizio considerato nel bilancio, senza distinzioni fra riscossioni e pagamenti in conto competenza e in conto residui.))

((7. In bilancio, prima di tutte le entrate e le spese, sono iscritti:

a) in entrata gli importi relativi al fondo pluriennale vincolato di parte corrente e al fondo pluriennale vincolato in c/capitale;

b) in entrata del primo esercizio gli importi relativi all'utilizzo dell'avanzo di amministrazione presunto, nei casi individuati dall'art. 187, commi 3 e 3-bis, con l'indicazione della quota vincolata del risultato di amministrazione utilizzata anticipatamente;

c) in uscita l'importo del disavanzo di amministrazione presunto al 31 dicembre dell'esercizio precedente cui il bilancio si riferisce. Il disavanzo di amministrazione presunto puo' essere iscritto nella spesa degli esercizi successivi secondo le modalita' previste dall'art. 188;

d) in entrata del primo esercizio il fondo di cassa presunto dell'esercizio precedente.))

((8. In bilancio, gli stanziamenti di competenza relativi alla spesa di cui al comma 6, lettere b) e c), individuano:

a) la quota che e' gia' stata impegnata negli esercizi precedenti con imputazione all'esercizio cui si riferisce il bilancio;

b) la quota di competenza costituita dal fondo pluriennale vincolato, destinata alla copertura degli impegni che sono stati assunti negli esercizi precedenti con imputazione agli esercizi successivi e degli impegni che si prevede di assumere nell'esercizio con imputazione agli esercizi successivi. Con riferimento a tale quota non e' possibile impegnare e pagare con imputazione all'esercizio cui lo stanziamento si riferisce. Agli stanziamenti di spesa riguardanti il fondo pluriennale vincolato e' attribuito il codice della missione e del programma di spesa cui il fondo si riferisce e il codice del piano dei conti relativo al fondo pluriennale vincolato.))

((9. I bilanci di previsione degli enti locali recepiscono, per quanto non contrasta con la normativa del presente testo unico, le norme recate dalle leggi delle rispettive regioni di appartenenza riguardanti le entrate e le spese relative a funzioni delegate, al fine di consentire la possibilita' del controllo regionale sulla destinazione dei fondi assegnati agli enti locali e l'omogeneita' delle classificazioni di dette spese nei bilanci di previsione degli enti rispetto a quelle contenute nei rispettivi bilanci di previsione regionali. Le entrate e le spese per le funzioni delegate dalle regioni non possono essere collocate tra i servizi per conto di terzi nei bilanci di previsione degli enti locali.))

((10. Il bilancio di previsione si conclude con piu' quadri riepilogativi, secondo gli schemi previsti dall'allegato n. 9 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.))

((11. Formano oggetto di specifica approvazione del consiglio le previsioni di cui al comma 6, lettere c) e d), per ogni unita' di voto, e le previsioni del comma 7.))

12. ((COMMA NON PIU' PREVISTO DAL D.LGS. 23 GIUGNO 2011, N. 118 COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).((83))

13. ((COMMA NON PIU' PREVISTO DAL D.LGS. 23 GIUGNO 2011, N. 118 COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).((83))

14. ((COMMA NON PIU' PREVISTO DAL D.LGS. 23 GIUGNO 2011, N. 118 COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 166 - Fondo di riserva

((1. Nella missione "Fondi e Accantonamenti", all'interno del programma "Fondo di riserva", gli enti locali iscrivono un fondo di riserva non inferiore allo 0,30 e non superiore al 2 per cento del totale delle spese correnti di competenza inizialmente previste in bilancio.))

2. Il fondo e' utilizzato, con deliberazioni dell'organo esecutivo da comunicare all'organo consiliare nei tempi stabiliti dal regolamento di contabilita', nei casi in cui si verifichino esigenze straordinarie di bilancio o le dotazioni degli interventi di spesa corrente si rivelino insufficienti.

2-bis. La meta' della quota minima prevista dai commi 1 e 2-ter e' riservata alla copertura di eventuali spese non prevedibili, la cui mancata effettuazione comporta danni certi all'amministrazione.

2-ter. Nel caso in cui l'ente si trovi in una delle situazioni previste dagli articoli 195 e 222, il limite minimo previsto dal comma 1 e' stabilito nella misura dello 0,45 per cento del totale delle spese correnti inizialmente previste in bilancio.

((2-quater. Nella missione "Fondi e Accantonamenti", all'interno del programma "Fondo di riserva", gli enti locali iscrivono un fondo di riserva di cassa non inferiore allo 0,2 per cento delle spese finali, utilizzato con deliberazioni dell'organo esecutivo.))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 167. - (( (Fondo crediti di dubbia esigibilita' e altri fondi per spese potenziali). ))

((

1. Nella missione "Fondi e Accantonamenti", all'interno del programma "Fondo crediti di dubbia esigibilita'" e' stanziato l'accantonamento al fondo crediti di dubbia esigibilita', il cui ammontare e' determinato in considerazione dell'importo degli stanziamenti di entrata di dubbia e difficile esazione, secondo le modalita' indicate nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.

2. Una quota del risultato di amministrazione e' accantonata per il fondo crediti di dubbia esigibilita', il cui ammontare e' determinato, secondo le modalita' indicate nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 al decreto legislativo 23 giugno 2011, n. 118 e successive modificazioni e integrazioni, in considerazione dell'ammontare dei crediti di dubbia e difficile esazione, e non puo' essere destinata ad altro utilizzo.

3. E' data facolta' agli enti locali di stanziare nella missione "Fondi e accantonamenti", all'interno del programma "Altri fondi", ulteriori accantonamenti riguardanti passivita' potenziali, sui quali non e' possibile impegnare e pagare. A fine esercizio, le relative economie di bilancio confluiscono nella quota accantonata del risultato di amministrazione, utilizzabili ai sensi di quanto previsto dall'art. 187, comma 3. Quando si accerta che la spesa potenziale non puo' piu' verificarsi, la corrispondente quota del risultato di amministrazione e' liberata dal vincolo.))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 168

Servizi per conto di terzi ((e le partite di giro)) ((87))

1. Le entrate e le spese relative ai servizi per conto di terzi ((e le partite di giro)), ((...)) che costituiscono al tempo stesso un debito ed un credito per l'ente, ((comprendono le transazioni poste in essere per conto di altri soggetti, in assenza di qualsiasi discrezionalita' come individuate dal principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.))((83))

((2. Le partite di giro riguardano le operazioni effettuate come sostituto di imposta, per la gestione dei fondi economali e le altre operazioni previste nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.))

((2-bis. Le previsioni e gli accertamenti d'entrata riguardanti i servizi per conto di terzi e le partite di giro conservano l'equivalenza con le corrispondenti previsioni e impegni di spesa, e viceversa. A tal fine, le obbligazioni giuridicamente perfezionate attive e passive che danno luogo ad entrate e spese riguardanti tali operazioni sono registrate e imputate all'esercizio in cui l'obbligazione e' perfezionata, in deroga al principio contabile generale n. 16.))

((2-ter. Non comportando discrezionalita' e autonomia decisionale, gli stanziamenti riguardanti le operazioni per conto di terzi e le partite di giro non hanno natura autorizzatoria.))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 169 - (Piano esecutivo di gestione)

1. La giunta delibera il piano esecutivo di gestione (PEG) entro venti giorni dall'approvazione del bilancio di previsione, in termini di competenza . Con riferimento al primo esercizio il PEG e' redatto anche in termini di cassa. Il PEG e' riferito ai medesimi esercizi considerati nel bilancio, individua gli obiettivi della gestione ed affida gli stessi, unitamente alle dotazioni necessarie, ai responsabili dei servizi.

2. Nel PEG le entrate sono articolate in titoli, tipologie, categorie, capitoli, ed eventualmente in articoli, secondo il rispettivo oggetto. Le spese sono articolate in missioni, programmi, titoli, macroaggregati, capitoli ed eventualmente in articoli. I capitoli costituiscono le unita' elementari ai fini della gestione e della rendicontazione, e sono raccordati al quarto livello del piano dei conti finanziario di cui all'art. 157.

3. L'applicazione dei commi 1 e 2 del presente articolo e' facoltativa per gli enti locali con popolazione inferiore a 5.000 abitanti, fermo restando l'obbligo di rilevare unitariamente i fatti gestionali secondo la struttura del piano dei conti di cui all'art. 157, comma 1-bis.

3-bis. Il PEG e' deliberato in coerenza con il bilancio di previsione e con il documento unico di programmazione. Al PEG e' allegato il prospetto concernente la ripartizione delle tipologie in categorie e dei programmi in macroaggregati, secondo lo schema di cui all'allegato n. 8 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. ((PERIODO SOPPRESSO DAL D.P.R. 24 GIUGNO 2022, N. 81)). (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 170 - (Documento unico di programmazione)

1. Entro il 31 luglio di ciascun anno la Giunta presenta al Consiglio il Documento unico di programmazione per le conseguenti deliberazioni. Entro il 15 novembre di ciascun anno, con lo schema di delibera del bilancio di previsione finanziario, la Giunta presenta al Consiglio la nota di aggiornamento del Documento unico di programmazione.Con riferimento al periodo di programmazione decorrente dall'esercizio 2015, gli enti locali non sono tenuti alla predisposizione del documento unico di programmazione e allegano al bilancio annuale di previsione una relazione previsionale e programmatica che copra un periodo pari a quello del bilancio pluriennale, secondo le modalita' previste dall'ordinamento contabile vigente nell'esercizio 2014. Il primo documento unico di programmazione e' adottato con riferimento agli esercizi 2016 e successivi. Gli enti che hanno partecipato alla sperimentazione adottano la disciplina prevista dal presente articolo a decorrere dal 1° gennaio 2015.((112))

2. Il Documento unico di programmazione ha carattere generale e costituisce la guida strategica ed operativa dell'ente.

3. Il Documento unico di programmazione si compone di due sezioni: la Sezione strategica e la Sezione operativa. La prima ha un orizzonte temporale di riferimento pari a quello del mandato amministrativo, la seconda pari a quello del bilancio di previsione.

4. Il documento unico di programmazione e' predisposto nel rispetto di quanto previsto dal principio applicato della programmazione di cui all'allegato n. 4/1 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.

5. Il Documento unico di programmazione costituisce atto presupposto indispensabile per l'approvazione del bilancio di previsione.

6. Gli enti locali con popolazione fino a 5.000 abitanti predispongono il Documento unico di programmazione semplificato previsto dall'allegato n. 4/1 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.

7. Nel regolamento di contabilita' sono previsti i casi di inammissibilita' e di improcedibilita' per le deliberazioni del Consiglio e della Giunta che non sono coerenti con le previsioni del Documento unico di programmazione.(83) (91)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi". --------------- AGGIORNAMENTO (91) La L. 11 dicembre 2016, n. 232 ha disposto (con l'art. 1, comma 455) che "Per l'esercizio finanziario 2017, il termine per la deliberazione della nota di aggiornamento del Documento unico di programmazione degli enti locali, di cui all'articolo 170 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' differito al 31 dicembre 2016". ---------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, ha disposto (con l'art, 107, comma 6) che "Il termine per la deliberazione del Documento unico di programmazione, di cui all'articolo 170, comma 1, del decreto legislativo 18 agosto 2000, n. 267 e' differito al 30 settembre 2020".

### Articolo 171

((ARTICOLO ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118 COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126))

### Articolo 172 - (( (Altri allegati al bilancio di previsione). ))

((1. Al bilancio di previsione sono allegati i documenti previsti dall'art. 11, comma 3, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, e i seguenti documenti: a) l'elenco degli indirizzi internet di pubblicazione del rendiconto della gestione, del bilancio consolidato deliberati e relativi al penultimo esercizio antecedente quello cui si riferisce il bilancio di previsione, dei rendiconti e dei bilanci consolidati delle unioni di comuni e dei soggetti considerati nel gruppo "amministrazione pubblica" di cui al principio applicato del bilancio consolidato allegato al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, relativi al penultimo esercizio antecedente quello cui il bilancio si riferisce. Tali documenti contabili sono allegati al bilancio di previsione qualora non integralmente pubblicati nei siti internet indicati nell'elenco; b) la deliberazione, da adottarsi annualmente prima dell'approvazione del bilancio, con la quale i comuni verificano la quantita' e qualita' di aree e fabbricati da destinarsi alla residenza, alle attivita' produttive e terziarie - ai sensi delle leggi 18 aprile 1962, n. 167, 22 ottobre 1971, n. 865, e 5 agosto 1978, n. 457, che potranno essere ceduti in proprieta' od in diritto di superficie; con la stessa deliberazione i comuni stabiliscono il prezzo di cessione per ciascun tipo di area o di fabbricato; c) le deliberazioni con le quali sono determinati, per l'esercizio successivo, le tariffe, le aliquote d'imposta e le eventuali maggiori detrazioni, le variazioni dei limiti di reddito per i tributi locali e per i servizi locali, nonche', per i servizi a domanda individuale, i tassi di copertura in percentuale del costo di gestione dei servizi stessi; d) la tabella relativa ai parametri di riscontro della situazione di deficitarieta' strutturale prevista dalle disposizioni vigenti in materia; e) il prospetto della concordanza tra bilancio di previsione e obiettivo programmatico del patto di stabilita' interno.)) ((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 173 - Valori monetari

1. I valori monetari contenuti nel bilancio pluriennale e nella relazione previsionale e programmatica sono espressi con riferimento ai periodi ai quali si riferiscono, tenendo conto del tasso di inflazione programmato.

## Competenze in materia di bilanci

### Articolo 174 - Predisposizione ed approvazione del bilancio e dei suoi allegati

1. Lo schema di bilancio di previsione, finanziario e il Documento unico di programmazione sono predisposti dall'organo esecutivo e da questo presentati all'organo consiliare unitamente agli allegati ((...)) entro il 15 novembre di ogni anno ((secondo quanto stabilito dal regolamento di contabilita')).(83)

2. Il regolamento di contabilita', dell'ente prevede per tali adempimenti un congruo termine, nonche' i termini entro i quali possono essere presentati da parte dei membri dell'organo consiliare e dalla Giunta emendamenti agli schemi di bilancio. A seguito di variazioni del quadro normativo di riferimento sopravvenute, l'organo esecutivo presenta all'organo consiliare emendamenti allo schema di bilancio e alla nota di aggiornamento al Documento unico di programmazione in corso di approvazione. (83)

3. Il bilancio di previsione finanziario e' deliberato dall'organo consiliare entro il termine previsto dall'articolo 151. PERIODO SOPPRESSO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126.(83)

4. Nel sito internet dell'ente locale sono pubblicati il bilancio di previsione, il piano esecutivo di gestione, le variazioni al bilancio di previsione, il bilancio di previsione assestato ed il piano esecutivo di gestione assestato.(83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 175 - Variazioni al bilancio di previsione ed al piano esecutivo di gestione.

1. Il bilancio di previsione finanziario puo' subire variazioni nel corso dell'esercizio di competenza e di cassa sia nella parte prima, relativa alle entrate, che nella parte seconda, relativa alle spese,per ciascuno degli esercizi considerati nel documento. (83)

2. Le variazioni al bilancio sono di competenza dell'organo consiliare salvo quelle previste dai commi 5-bis e 5-quater. (83)

3. Le variazioni al bilancio possono essere deliberate non oltre il 30 novembre di ciascun anno, fatte salve le seguenti variazioni, che possono essere deliberate sino al 31 dicembre di ciascun anno:

- a) l'istituzione di tipologie di entrata a destinazione vincolata e il correlato programma di spesa;
- b) l'istituzione di tipologie di entrata senza vincolo di destinazione, con stanziamento pari a zero, a seguito di accertamento e riscossione di entrate non previste in bilancio, secondo le modalita' disciplinate dal principio applicato della contabilita' finanziaria;
- c) l'utilizzo delle quote del risultato di amministrazione vincolato ed accantonato per le finalita' per le quali sono stati previsti;
- d) quelle necessarie alla reimputazione agli esercizi in cui sono esigibili, di obbligazioni riguardanti entrate vincolate gia' assunte e, se necessario, delle spese correlate;
- e) le variazioni delle dotazioni di cassa di cui al comma 5-bis, lettera d);
- f) le variazioni di cui al comma 5-quater, lettera b);
- g) le variazioni degli stanziamenti riguardanti i versamenti ai conti di tesoreria statale intestati all'ente e i versamenti a depositi bancari intestati all'ente. (74) (83)

4. Ai sensi dell'articolo 42 le variazioni di bilancio possono essere adottate dall'organo esecutivo in via d'urgenza opportunamente motivata, salvo ratifica, a pena di decadenza, da parte dell'organo consiliare entro i sessanta giorni seguenti e comunque entro il 31 dicembre dell'anno in corso se a tale data non sia scaduto il predetto termine. (83)

5. In caso di mancata o parziale ratifica del provvedimento di variazione adottato dall'organo esecutivo, l'organo consiliare e' tenuto ad adottare nei successivi trenta giorni, e comunque sempre entro il 31 dicembre dell'esercizio in corso, i provvedimenti ritenuti necessari nei riguardi dei rapporti eventualmente sorti sulla base della deliberazione non ratificata.

5-bis. L'organo esecutivo con provvedimento amministrativo approva le variazioni del piano esecutivo di gestione, salvo quelle di cui al comma 5-quater, e le seguenti variazioni del bilancio di previsione non aventi natura discrezionale, che si configurano come meramente applicative delle decisioni del Consiglio, per ciascuno degli esercizi considerati nel bilancio:

- a) variazioni riguardanti l'utilizzo della quota vincolata e accantonata del risultato di amministrazione nel corso dell'esercizio provvisorio consistenti nella mera reiscrizione di economie di spesa derivanti da stanziamenti di bilancio dell'esercizio precedente corrispondenti a entrate vincolate, secondo le modalita' previste dall'art. 187, comma 3-quinquies;
- b) variazioni compensative tra le dotazioni delle missioni e dei programmi riguardanti l'utilizzo di risorse comunitarie e vincolate, nel rispetto della finalita' della spesa definita nel provvedimento di assegnazione delle risorse, o qualora le variazioni siano necessarie per l'attuazione di interventi previsti da intese istituzionali di programma o da altri strumenti di programmazione negoziata, gia' deliberati dal Consiglio;
- c) variazioni compensative tra le dotazioni delle missioni e dei programmi limitatamente alle spese per il personale, conseguenti a provvedimenti di trasferimento del personale all'interno dell'ente;
- d) variazioni delle dotazioni di cassa, salvo quelle previste dal comma 5-quater, garantendo che il fondo di cassa alla fine dell'esercizio sia non negativo;
- e) variazioni riguardanti il fondo pluriennale vincolato di cui all'art. 3, comma 5, del decreto legislativo 23 giugno 2011, n. 118, effettuata entro i termini di approvazione del rendiconto in deroga al comma 3; (83)
- e-bis) variazioni compensative tra macroaggregati dello stesso programma all'interno della stessa missione.

5-ter. Con il regolamento di contabilita' si disciplinano le modalita' di comunicazione al Consiglio delle variazioni di bilancio di cui al comma 5-bis. (83)

5-quater. Nel rispetto di quanto previsto dai regolamenti di contabilita', i responsabili della spesa o, in assenza di disciplina, il responsabile finanziario, possono effettuare, per ciascuno degli esercizi del bilancio:

- a) le variazioni compensative del piano esecutivo di gestione fra capitoli di entrata della medesima categoria e fra i capitoli di spesa del medesimo macroaggregato, escluse le variazioni dei capitoli appartenenti ai macroaggregati riguardanti i trasferimenti correnti, i contribuiti agli investimenti, ed ai trasferimenti in conto capitale, che sono di competenza della Giunta;
- b) le variazioni di bilancio fra gli stanziamenti riguardanti il fondo pluriennale vincolato e gli stanziamenti correlati, in termini di competenza e di cassa, escluse quelle previste dall'art. 3, comma 5, del decreto legislativo 23 giugno 2011, n. 118. Le variazioni di bilancio riguardanti le variazioni del fondo pluriennale vincolato sono comunicate trimestralmente alla giunta;
- c) le variazioni di bilancio riguardanti l'utilizzo della quota vincolata del risultato di amministrazione derivanti da stanziamenti di bilancio dell'esercizio precedente corrispondenti a entrate vincolate, in termini di competenza e di cassa, secondo le modalita' previste dall'art. 187, comma 3-quinquies;
- d) le variazioni degli stanziamenti riguardanti i versamenti ai conti di tesoreria statale intestati all'ente e i versamenti a depositi bancari intestati all'ente;
- e) le variazioni necessarie per l'adeguamento delle previsioni, compresa l'istituzione di tipologie e programmi, riguardanti le partite di giro e le operazioni per conto di terzi; (83)
- e-bis) in caso di variazioni di esigibilita' della spesa, le variazioni relative a stanziamenti riferiti a operazioni di indebitamento gia' autorizzate e perfezionate, contabilizzate secondo l'andamento della correlata spesa, e le variazioni a stanziamenti correlati ai contributi a rendicontazione, escluse quelle previste dall'articolo 3, comma 4, del decreto legislativo 23 giugno 2011, n. 118. Le suddette variazioni di bilancio sono comunicate trimestralmente alla giunta.

5-quinquies. Le variazioni al bilancio di previsione disposte con provvedimenti amministrativi, nei casi previsti dal presente decreto, e le variazioni del piano esecutivo di gestione non possono essere disposte con il medesimo provvedimento amministrativo. Le determinazioni dirigenziali di variazione compensativa dei capitoli del piano esecutivo di gestione di cui al comma 5-quater sono effettuate al fine di favorire il conseguimento degli obiettivi assegnati ai dirigenti. (83)

6. Sono vietate le variazioni di giunta compensative tra macroaggregati appartenenti a titoli diversi. (83)

7. Sono vietati gli spostamenti di dotazioni dai capitoli iscritti nei titoli riguardanti le entrate e le spese per conto di terzi e partite di giro in favore di altre parti del bilancio. Sono vietati gli spostamenti di somme tra residui e competenza. (83)

8. Mediante la variazione di assestamento generale, deliberata dall'organo consiliare dell'ente entro il 31 luglio di ciascun anno, si attua la verifica generale di tutte le voci di entrata e di uscita, compreso il fondo di riserva ed il fondo di cassa, al fine di assicurare il mantenimento del pareggio di bilancio. (83) (89)

9. Le variazioni al piano esecutivo di gestione di cui all'articolo 169 sono di competenza dell'organo esecutivo, salvo quelle previste dal comma 5-quater, e possono essere adottate entro il 15 dicembre di ciascun anno , fatte salve le variazioni correlate alle variazioni di bilancio previste al comma 3, che possono essere deliberate sino al 31 dicembre di ciascun anno. (83)

9-bis. ((COMMA ABROGATO DAL D.L. 14 AGOSTO 2020, N. 104)).

9-ter. Nel corso dell'esercizio 2015 sono applicate le norme concernenti le variazioni di bilancio vigenti nell'esercizio 2014, fatta salva la disciplina del fondo pluriennale vincolato e del riaccertamento straordinario dei residui. Gli enti che hanno partecipato alla sperimentazione nel 2014 adottano la disciplina prevista dal presente articolo a decorrere dal 1° gennaio 2015. (83) (84)

--------------- AGGIORNAMENTO (74) Il D.L. 30 novembre 2013, n. 133, convertito con modificazioni dalla L. 29 gennaio 2014, n. 5, ha disposto (con l'art. 1, comma 11) che "In deroga all'articolo 175 del Testo unico degli enti locali, approvato con il decreto legislativo 18 agosto 2000, n. 267, i comuni beneficiari del trasferimento compensativo di cui al comma 3 sono autorizzati ad apportare le necessarie variazioni di bilancio entro il 15 dicembre 2013". --------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi". --------------- AGGIORNAMENTO (84) La L. 23 dicembre 2014, n. 190 ha disposto (con l'art. 1, comma 693) che "I comuni, in deroga all'articolo 175 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, accertano convenzionalmente gli importi, a titolo di maggior gettito IMU, risultanti dal decreto ministeriale di cui al citato articolo 4, comma 5-bis, del decreto-legge n. 16 del 2012, sul bilancio 2014, a fronte della riduzione corrispondente dell'assegnazione dal Fondo di solidarieta' comunale. I comuni interessati dalla compensazione di cui all'ultimo periodo del medesimo comma 5-bis, in deroga all'articolo 175 del citato testo unico, accertano la relativa entrata quale integrazione del Fondo di solidarieta' comunale per il medesimo esercizio 2014". --------------- AGGIORNAMENTO (89) Il D.L. 24 giugno 2016, n. 113, convertito con modificazioni dalla L. 7 agosto 2016, n. 160, ha disposto (con l'art. 4, comma 1-bis) che "Limitatamente agli enti che comunicano le fattispecie di cui al comma 1 secondo le modalita' e i termini previsti dal comma 2, per l'anno 2016 i termini per l'approvazione della variazione di assestamento generale di cui all'articolo 175, comma 8, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e per l'adozione della delibera che da' atto del permanere degli equilibri generali di bilancio di cui all'articolo 193, comma 2, del medesimo testo unico sono fissati al 30 settembre 2016".

### Articolo 176

Prelevamenti dal fondo di riserva ((e dai fondi spese potenziali)) ((83))

1. I prelevamenti dal fondo di riserva ((, dal fondo di riserva di cassa e dai fondi spese potenziali)) sono di competenza dell'organo esecutivo e possono essere deliberati sino al 31 dicembre di ciascun anno. ((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 177 - Competenze dei responsabili dei servizi

1. Il responsabile del servizio, nel caso in cui ritiene necessaria una modifica della dotazione assegnata per sopravvenute esigenze successive all'adozione degli atti di programmazione, propone la modifica con modalita' definite dal regolamento di contabilita'.

2. La mancata accettazione della proposta di modifica della dotazione deve essere motivata dall'organo esecutivo.

## GESTIONE DEL BILANCIO CAPO I Entrate

### Articolo 178 - Fasi dell'entrata

1. Le fasi di gestione delle entrate sono l'accertamento, la riscossione ed il versamento.

### Art. 179. - Accertamento

1. L'accertamento costituisce la prima fase di gestione dell'entrata mediante la quale, sulla base di idonea documentazione, viene verificata la ragione del credito e la sussistenza di un idoneo titolo giuridico, individuato il debitore, quantificata la somma da incassare, nonche' fissata la relativa scadenza. ((Le entrate relative al titolo "Accensione prestiti" sono accertate nei limiti dei rispettivi stanziamenti di competenza del bilancio.)) ((83))

2. L'accertamento delle entrate avviene ((distinguendo le entrate ricorrenti da quelle non ricorrenti attraverso la codifica della transazione elementare di cui agli articoli 5 e 6 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, seguendo le seguenti disposizioni)): ((83))

- a) per le entrate di carattere tributario, a seguito di emissione di ruoli o a seguito di altre forme stabilite per legge;
- b) per le entrate patrimoniali e per quelle provenienti dalla gestione di servizi a carattere produttivo e di quelli connessi a tariffe o contribuzioni dell'utenza, a seguito di acquisizione diretta o di emissione di liste di carico;
- c) per le entrate relative a partite compensative delle spese ((del titolo "Servizi per conto terzi e partite di giro",)) in corrispondenza dell'assunzione del relativo impegno di spesa; ((83))
- d) per le altre entrate, anche di natura eventuale o variabile. mediante contratti, provvedimenti giudiziari o atti amministrativi specifici ((, salvo i casi, tassativamente previsti nel principio applicato della contabilita' finanziaria, per cui e' previsto l'accertamento per cassa.)) ((83))

3. Il responsabile del procedimento con il quale viene accertata l'entrata trasmette al responsabile del servizio finanziario l'idonea documentazione di cui al comma 2, ai fini dell'annotazione nelle scritture contabili, secondo i tempi ed i modi previsti dal regolamento di contabilita' dell'ente ((, nel rispetto di quanto previsto dal presente decreto e dal principio generale della competenza finanziaria e dal principio applicato della contabilita' finanziaria di cui agli allegati n. 1 e n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.)) ((83))

((3-bis. L'accertamento dell'entrata e' registrato quando l'obbligazione e' perfezionata, con imputazione alle scritture contabili riguardanti l'esercizio in cui l'obbligazione viene a scadenza. Non possono essere riferite ad un determinato esercizio finanziario le entrate il cui diritto di credito non venga a scadenza nello stesso esercizio finanziario. E' vietato l'accertamento attuale di entrate future. Le entrate sono registrate nelle scritture contabili anche se non determinano movimenti di cassa effettivi.))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 180 - Riscossione

1. La riscossione costituisce la successiva fase del procedimento dell'entrata, che consiste nel materiale introito da parte del tesoriere o di altri eventuali incaricati della riscossione delle somme dovute all'ente.

2. La riscossione e' disposta a mezzo di ordinativo di incasso, fatto pervenire al tesoriere nelle forme e nei tempi previsti dalla convenzione di cui all'articolo 210.

3. L'ordinativo d'incasso e' sottoscritto dal responsabile del servizio finanziario o da altro dipendente individuato dal regolamento di contabilita' e contiene almeno:

- a) l'indicazione del debitore;
- b) l'ammontare della somma da riscuotere;
- c) la causale;
- d) gli eventuali vincoli di destinazione delle entrate derivanti ((...)) da trasferimenti o da prestiti; (83)
- e) l'indicazione del titolo e della tipologia distintamente per residui o competenza; (83)
- f) la codifica di bilancio; (83)
- g) il numero progressivo;
- h) l'esercizio finanziario e la data di emissione;
- h-bis) la codifica SIOPE di cui all'art. 14 della legge 31 dicembre 2009, n. 196; (83)
- h-ter) i codici della transazione elementare di cui agli articoli da 5 a 7, del decreto legislativo 23 giugno 2011, n. 118. (83)

4. Il tesoriere deve accettare, senza pregiudizio per i diritti dell'ente, la riscossione di ogni somma, versata in favore dell'ente, ivi comprese le entrate di cui al comma 4-ter, anche senza la preventiva emissione di ordinativo d'incasso. In tale ipotesi il tesoriere ne da' immediata comunicazione all'ente, richiedendo la regolarizzazione. L'ente procede alla regolarizzazione dell'incasso entro i successivi 60 giorni e, comunque, entro i termini previsti per la resa del conto del tesoriere. (83)

4-bis. Gli ordinativi di incasso che si riferiscono ad entrate di competenza dell'esercizio in corso sono tenuti distinti da quelli relativi ai residui, garantendone la numerazione unica per esercizio e progressiva. Gli ordinativi di incasso, sia in conto competenza sia in conto residui, sono imputati contabilmente all'esercizio in cui il tesoriere ha incassato le relative entrate, anche se la comunicazione e' pervenuta all'ente nell'esercizio successivo. (83)

4-ter. Gli incassi derivanti dalle accensioni di prestiti sono disposti nei limiti dei rispettivi stanziamenti di cassa. (83)

4-quater. E' vietata l'imputazione provvisoria degli incassi in attesa di regolarizzazione alle partite di giro. (83)

4-quinquies. Gli ordinativi d'incasso non riscossi entro il termine dell'esercizio sono restituiti dal tesoriere all'ente per l'annullamento e la successiva emissione nell'esercizio successivo in conto residui. (83)

4-sexies. I codici di cui al comma 3, lettera h-ter), possono essere applicati all'ordinativo di incasso a decorrere dal 1° gennaio 2016. (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 181 - Versamento

1. Il versamento costituisce l'ultima fase dell'entrata, consistente nel trasferimento delle somme riscosse nelle casse dell'ente.

2. Gli incaricati della riscossione, interni ed esterni, versano al tesoriere le somme riscosse nei termini e nei modi fissati dalle disposizioni vigenti e da eventuali accordi convenzionali, salvo quelli a cui si applicano gli articoli 22 e seguenti del decreto legislativo 13 aprile 1999, n. 112.

3. Gli incaricati interni, designati con provvedimento formale dell'amministrazione, versano le somme riscosse presso la tesoreria dell'ente con cadenza stabilita dal regolamento di contabilita' ((, non superiori ai quindici giorni lavorativi)). ((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

## Spese

### Articolo 182 - Fasi della spesa

1. Le fasi di gestione della spesa sono l'impegno, la liquidazione, l'ordinazione ed il pagamento.

### Art. 183. - Impegno di spesa

1. L'impegno costituisce la prima fase del procedimento di spesa, con la quale, a seguito di obbligazione giuridicamente perfezionata e' determinata la somma da pagare, determinato il soggetto creditore, indicata la ragione e la relativa scadenza e viene costituito il vincolo sulle previsioni di bilancio, nell'ambito della disponibilita' finanziaria accertata ai sensi dell'articolo 151.(83)

2. Con l'approvazione del bilancio e successive variazioni, e senza la necessita' di ulteriori atti, e' costituito impegno sui relativi stanziamenti per le spese dovute:

- a) per il trattamento economico tabellare gia' attribuito al personale dipendente e per i relativi oneri riflessi;
- b) per le rate di ammortamento dei mutui e dei prestiti, interessi di preammortamento ed ulteriori oneri accessori nei casi in cui non si sia provveduto all'impegno nell'esercizio in cui il contratto di finanziamento e' stato perfezionato; (83)
- c) per contratti di somministrazione riguardanti prestazioni continuative, nei casi in cui l'importo dell'obbligazione sia definita contrattualmente. Se l'importo dell'obbligazione non e' predefinito nel contratto, con l'approvazione del bilancio si provvede alla prenotazione della spesa, per un importo pari al consumo dell'ultimo esercizio per il quale l'informazione e' disponibile. (83)

3. Durante la gestione possono anche essere prenotati impegni relativi a procedure in via di espletamento. I provvedimenti relativi per i quali entro il termine dell'esercizio non e' stata assunta dall'ente l'obbligazione di spesa verso i terzi decadono e costituiscono economia della previsione di bilancio alla quale erano riferiti, concorrendo alla determinazione del risultato contabile di amministrazione di cui all'articolo 186. ((Le economie riguardanti le spese di investimento per lavori pubblici concorrono alla determinazione del fondo pluriennale secondo le modalita' definite, entro il 30 aprile 2019, con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e con la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali e le autonomie, su proposta della Commissione per l'armonizzazione degli enti territoriali di cui all'articolo 3-bis del decreto legislativo 23 giugno 2011, n. 118, al fine di adeguare il principio contabile applicato concernente la contabilita' finanziaria previsto dall'allegato n. 4/2 del medesimo decreto legislativo )). (83)

4. Costituiscono inoltre economia le minori spese sostenute rispetto all'impegno assunto, verificate con la conclusione della fase della liquidazione.

5. Tutte le obbligazioni passive giuridicamente perfezionate, devono essere registrate nelle scritture contabili quando l'obbligazione e' perfezionata, con imputazione all'esercizio in cui l'obbligazione viene a scadenza, secondo le modalita' previste dal principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 del decreto legislativo 23 giugno 2011, n. 118. Non possono essere riferite ad un determinato esercizio finanziario le spese per le quali non sia venuta a scadere nello stesso esercizio finanziario la relativa obbligazione giuridica. Le spese sono registrate anche se non determinano movimenti di cassa effettivi. (83)

6. Gli impegni di spesa sono assunti nei limiti dei rispettivi stanziamenti di competenza del bilancio di previsione, con imputazione agli esercizi in cui le obbligazioni passive sono esigibili. Non possono essere assunte obbligazioni che danno luogo ad impegni di spesa corrente:

- a) sugli esercizi successivi a quello in corso, a meno che non siano connesse a contratti o convenzioni pluriennali o siano necessarie per garantire la continuita' dei servizi connessi con le funzioni fondamentali, fatta salva la costante verifica del mantenimento degli equilibri di bilancio, anche con riferimento agli esercizi successivi al primo;
- b) sugli esercizi non considerati nel bilancio, a meno delle spese derivanti da contratti di somministrazione, di locazione, relative a prestazioni periodiche o continuative di servizi di cui all'art. 1677 del codice civile, delle spese correnti correlate a finanziamenti comunitari e delle rate di ammortamento dei prestiti, inclusa la quota capitale. Le obbligazioni che comportano impegni riguardanti le partite di giro e i rimborsi delle anticipazioni di tesoreria sono assunte esclusivamente in relazione alle esigenze della gestione. (83)

7. I provvedimenti dei responsabili dei servizi che comportano impegni di spesa sono trasmessi al responsabile del servizio finanziario e sono esecutivi con l'apposizione del visto di regolarita' contabile attestante la copertura finanziaria. (83)

8. Al fine di evitare ritardi nei pagamenti e la formazione di debiti pregressi, il responsabile della spesa che adotta provvedimenti che comportano impegni di spesa ha l'obbligo di accertare preventivamente che il programma dei conseguenti pagamenti sia compatibile con i relativi stanziamenti di cassa e con le regole del patto di stabilita' interno; la violazione dell'obbligo di accertamento di cui al presente comma comporta responsabilita' disciplinare ed amministrativa. Qualora lo stanziamento di cassa, per ragioni sopravvenute, non consenta di far fronte all'obbligo contrattuale, l'amministrazione adotta le opportune iniziative, anche di tipo contabile, amministrativo o contrattuale, per evitare la formazione di debiti pregressi. (83)

9. Il regolamento di contabilita' disciplina le modalita' con le quali i responsabili dei servizi assumono atti di impegno nel rispetto dei principi contabili generali e del principio applicato della contabilita' finanziaria di cui agli allegati n. 1 e n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. A tali atti, da definire "determinazioni" e da classificarsi con sistemi di raccolta che individuano la cronologia degli atti e l'ufficio di provenienza, si applicano, in via preventiva, le procedure di cui ai commi 7 e 8. (83)

9-bis. Gli impegni sono registrati distinguendo le spese ricorrenti da quelle non ricorrenti attraverso la codifica della transazione elementare di cui agli articoli 5 e 6 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 184 - Liquidazione della spesa

1. La liquidazione costituisce la successiva fase del procedimento di spesa attraverso la quale in base ai documenti ed ai titoli atti a comprovare il diritto acquisito del creditore, si determina la somma certa e liquida da pagare nei limiti dell'ammontare dell'impegno definitivo assunto.

2. La liquidazione compete all'ufficio che ha dato esecuzione al provvedimento di spesa ed e' disposta sulla base della documentazione necessaria a comprovare il diritto del creditore, a seguito del riscontro operato sulla regolarita' della fornitura o della prestazione e sulla rispondenza della stessa ai requisiti quantitativi e qualitativi, al termini ed alle condizioni pattuite.

3. L'atto di liquidazione, sottoscritto dal responsabile del servizio proponente, con tutti i relativi documenti giustificativi ed i riferimenti contabili e' trasmesso al servizio finanziario per i conseguenti adempimenti.

4. Il servizio finanziario effettua, secondo i principi e le procedure della contabilita' pubblica, i controlli e riscontri amministrativi, contabili e fiscali sugli atti di liquidazione.

### Articolo 185 - Ordinazione e pagamento

1. Gli ordinativi di pagamento sono disposti nei limiti dei rispettivi stanziamenti di cassa, salvo i pagamenti riguardanti il rimborso delle anticipazioni di tesoreria, i servizi per conto terzi e le partite di giro. (83)

2. Il mandato di pagamento e' sottoscritto dal dipendente dell'ente individuato dal regolamento di contabilita' nel rispetto delle leggi vigenti e contiene almeno i seguenti elementi:

- a) il numero progressivo del mandato per esercizio finanziario;
- b) la data di emissione;
- c) l'indicazione della missione, del programma e del titolo di bilancio cui e' riferita la spesa e la relativa disponibilita', distintamente per residui o competenza e cassa; (83)
- d) la codifica di bilancio; (83)
- e) l'indicazione del creditore e, se si tratta di persona diversa, del soggetto tenuto a rilasciare quietanza, nonche' il relativo codice fiscale o la partita IVA; (83)
- f) l'ammontare della somma dovuta e la scadenza, qualora sia prevista dalla legge o sia stata concordata con il creditore;
- g) la causale e gli estremi dell'atto esecutivo, che legittima l'erogazione della spesa;
- h) le eventuali modalita' agevolative di pagamento se richieste dal creditore;
- i) il rispetto degli eventuali vincoli di destinazione ((...)) relativi a trasferimenti o ai prestiti; (83)
- i-bis) la codifica SIOPE di cui all'art. 14 della legge 31 dicembre 2009, n. 196; (83)
- i-ter) i codici della transazione elementare di cui agli articoli da 5 a 7, del decreto legislativo 23 giugno 2011, n. 118. (83)
- i-quater) l'identificazione delle spese non soggette al controllo dei dodicesimi di cui all'art. 163, comma 5, in caso di esercizio provvisorio. (83)

3. Il mandato di pagamento e' controllato, per quanto attiene alla sussistenza dell'impegno e della liquidazione e al rispetto dell'autorizzazione di cassa, dal servizio finanziario, che provvede altresi' alle operazioni di contabilizzazione e di trasmissione al tesoriere. (83)

4. Il tesoriere effettua i pagamenti derivanti da obblighi tributari, da somme iscritte a ruolo, da delegazioni di pagamento, e da altri obblighi di legge, anche in assenza della preventiva emissione del relativo mandato di pagamento. Entro trenta giorni l'ente locale emette il relativo mandato ai fini della regolarizzazione, imputandolo contabilmente all'esercizio in cui il tesoriere ha effettuato il pagamento, anche se la relativa comunicazione e' pervenuta all'ente nell'esercizio successivo. (83)

4-bis. I codici di cui al comma 2, lettera i-bis), possono essere applicati al mandato a decorrere dal 1° gennaio 2016. (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

## Risultato di amministrazione e residui

### Articolo 186 - Risultato contabile di amministrazione

1. Il risultato contabile di amministrazione e' accertato con l'approvazione del rendiconto dell'ultimo esercizio chiuso ed e' pari al fondo di cassa aumentato dei residui attivi e diminuito dei residui passivi. ((Tale risultato non comprende le risorse accertate che hanno finanziato spese impegnate con imputazione agli esercizi successivi, rappresentate dal fondo pluriennale vincolato determinato in spesa del conto del bilancio.)) ((83))

((1-bis. In occasione dell'approvazione del bilancio di previsione e' determinato l'importo del risultato di amministrazione presunto dell'esercizio precedente cui il bilancio si riferisce.))

((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 187. - Composizione del risultato di amministrazione

1. Il risultato di amministrazione e' distinto in fondi liberi, fondi vincolati, fondi destinati agli investimenti e fondi accantonati. I fondi destinati agli investimenti sono costituiti dalle entrate in c/capitale senza vincoli di specifica destinazione non spese, e sono utilizzabili con provvedimento di variazione di bilancio solo a seguito dell'approvazione del rendiconto. L'indicazione della destinazione nel risultato di amministrazione per le entrate in conto capitale che hanno dato luogo ad accantonamento al fondo crediti di dubbia e difficile esazione e' sospeso, per l'importo dell'accantonamento, sino all'effettiva riscossione delle stesse. I trasferimenti in conto capitale non sono destinati al finanziamento degli investimenti e non possono essere finanziati dal debito e dalle entrate in conto capitale destinate al finanziamento degli investimenti. I fondi accantonati comprendono gli accantonamenti per passivita' potenziali e il fondo crediti di dubbia esigibilita'. Nel caso in cui il risultato di amministrazione non sia sufficiente a comprendere le quote vincolate, destinate e accantonate, l'ente e' in disavanzo di amministrazione. Tale disavanzo e' iscritto come posta a se stante nel primo esercizio del bilancio di previsione secondo le modalita' previste dall'art. 188. (83)

2. La quota libera dell'avanzo di amministrazione dell'esercizio precedente, accertato ai sensi dell'art. 186 e quantificato ai sensi del comma 1, puo' essere utilizzato con provvedimento di variazione di bilancio, per le finalita' di seguito indicate in ordine di priorita':

- a) per la copertura dei debiti fuori bilancio;
- b) per i provvedimenti necessari per la salvaguardia degli equilibri di bilancio di cui all'art. 193 ove non possa provvedersi con mezzi ordinari;
- c) per il finanziamento di spese di investimento;
- d) per il finanziamento delle spese correnti a carattere non permanente;
- e) per l'estinzione anticipata dei prestiti. Resta salva la facolta' di impiegare l'eventuale quota del risultato di amministrazione "svincolata", in occasione dell'approvazione del rendiconto, sulla base della determinazione dell'ammontare definitivo della quota del risultato di amministrazione accantonata per il fondo crediti di dubbia esigibilita', per finanziare lo stanziamento riguardante il fondo crediti di dubbia esigibilita' nel bilancio di previsione dell'esercizio successivo a quello cui il rendiconto si riferisce. Nelle operazioni di estinzione anticipata di prestiti, qualora l'ente non disponga di una quota sufficiente di avanzo libero, nel caso abbia somme accantonate per una quota pari al 100 per cento del fondo crediti di dubbia esigibilita', puo' ricorrere all'utilizzo di quote dell'avanzo destinato a investimenti solo a condizione che garantisca, comunque, un pari livello di investimenti aggiuntivi. (83)

3. Le quote del risultato presunto derivanti dall'esercizio precedente, costituite da accantonamenti risultanti dall'ultimo consuntivo approvato o derivanti da fondi vincolati possono essere utilizzate per le finalita' cui sono destinate prima dell'approvazione del conto consuntivo dell'esercizio precedente, attraverso l'iscrizione di tali risorse, come posta a se' stante dell'entrata, nel primo esercizio del bilancio di previsione o con provvedimento di variazione al bilancio. L'utilizzo della quota vincolata o accantonata del risultato di amministrazione e' consentito, sulla base di una relazione documentata del dirigente competente, anche in caso di esercizio provvisorio, esclusivamente per garantire la prosecuzione o l'avvio di attivita' soggette a termini o scadenza, la cui mancata attuazione determinerebbe danno per l'ente, secondo le modalita' individuate al comma 3-quinquies. (83)

3-bis. L'avanzo di amministrazione non vincolato non puo' essere utilizzato nel caso in cui l'ente si trovi in una delle situazioni previste dagli articoli 195 e 222, fatto salvo l'utilizzo per i provvedimenti di riequilibrio di cui all'articolo 193.

3-ter. Costituiscono quota vincolata del risultato di amministrazione le entrate accertate e le corrispondenti economie di bilancio:

- a) nei casi in cui la legge o i principi contabili generali e applicati individuano un vincolo di specifica destinazione dell'entrata alla spesa;
- b) derivanti da mutui e finanziamenti contratti per il finanziamento di investimenti determinati;
- c) derivanti da trasferimenti erogati a favore dell'ente per una specifica destinazione determinata;
- d) derivanti da entrate accertate straordinarie, non aventi natura ricorrente, cui l'amministrazione ha formalmente attribuito una specifica destinazione. E' possibile attribuire un vincolo di destinazione alle entrate straordinarie non aventi natura ricorrente solo se l'ente non ha rinviato la copertura del disavanzo di amministrazione negli esercizi successivi e ha provveduto nel corso dell'esercizio alla copertura di tutti gli eventuali debiti fuori bilancio, compresi quelli di cui all'art. 193. L'indicazione del vincolo nel risultato di amministrazione per le entrate vincolate che hanno dato luogo ad accantonamento al fondo crediti di dubbia e difficile esazione e' sospeso, per l'importo dell'accantonamento, sino all'effettiva riscossione delle stesse. ((Il regime vincolistico di competenza si estende alla cassa solo relativamente alle entrate di cui alle lettere b) e c) )).(83)

3-quater. Se il bilancio di previsione impiega quote vincolate del risultato di amministrazione presunto ai sensi del comma 3, entro il 31 gennaio la Giunta verifica l'importo delle quote vincolate del risultato di amministrazione presunto sulla base di un preconsuntivo relativo alle entrate e alle spese vincolate ed approva l'aggiornamento dell'allegato al bilancio di previsione di cui all'art. 11, comma 3, lettera a), del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. Se la quota vincolata del risultato di amministrazione presunto e' inferiore rispetto all'importo applicato al bilancio di previsione, l'ente provvede immediatamente alle necessarie variazioni di bilancio che adeguano l'impiego del risultato di amministrazione vincolato. (83)

3-quinquies. Le variazioni di bilancio che, in attesa dell'approvazione del consuntivo, applicano al bilancio quote vincolate o accantonate del risultato di amministrazione, sono effettuate solo dopo l'approvazione del prospetto aggiornato del risultato di amministrazione presunto da parte della Giunta di cui al comma 3-quater. Le variazioni consistenti nella mera re-iscrizione di economie di spesa derivanti da stanziamenti di bilancio dell'esercizio precedente corrispondenti a entrate vincolate, possono essere disposte dai dirigenti se previsto dal regolamento di contabilita' o, in assenza di norme, dal responsabile finanziario. In caso di esercizio provvisorio tali variazioni sono di competenza della Giunta. (83)

3-sexies. Le quote del risultato presunto derivante dall'esercizio precedente costituite dagli accantonamenti effettuati nel corso dell'esercizio precedente possono essere utilizzate prima dell'approvazione del conto consuntivo dell'esercizio precedente, per le finalita' cui sono destinate, con provvedimento di variazione al bilancio, se la verifica di cui al comma 3-quater e l'aggiornamento dell'allegato al bilancio di previsione di cui all'art. 11, comma 3, lettera a), del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, sono effettuate con riferimento a tutte le entrate e le spese dell'esercizio precedente e non solo alle entrate e alle spese vincolate. (83)

------------- AGGIORNAMENTO (19) Il D.L. 29 marzo 2004, n. 80, convertito con L. 28 maggio 2004, n. 140, ha disposto (con l'art. 4, comma 1) che "In deroga all'articolo 187, comma 2, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, per l'anno 2004, i comuni con popolazione fino a 3.000 abitanti che abbiano avuto una riduzione dei trasferimenti erariali di parte corrente superiore al 10 per cento di quelli assegnati nell'anno 2003, senza che nel computo siano comprese le somme attribuite per conguagli di esercizi precedenti, hanno facolta' di applicare l'avanzo di amministrazione presunto dell'esercizio precedente in sede di predisposizione del bilancio di previsione per l'anno 2004. Per tali fondi si applicano le disposizioni di cui al comma 3, secondo periodo, del citato articolo 187 del testo unico.". --------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 188 - Disavanzo di amministrazione

1. L'eventuale disavanzo di amministrazione, accertato ai sensi dell'articolo 186, e' immediatamente applicato ((...)) all'esercizio in corso di gestione contestualmente alla delibera di approvazione del rendiconto. La mancata adozione della delibera che applica il disavanzo al bilancio in corso di gestione e' equiparata a tutti gli effetti alla mancata approvazione del rendiconto di gestione. Il disavanzo di amministrazione puo' anche essere ripianato negli esercizi successivi considerati nel bilancio di previsione, in ogni caso non oltre la durata della consiliatura, contestualmente all'adozione di una delibera consiliare avente ad oggetto il piano di rientro dal disavanzo nel quale siano individuati i provvedimenti necessari a ripristinare il pareggio. Il piano di rientro e' sottoposto al parere del collegio dei revisori. Ai fini del rientro possono essere utilizzate le economie di spesa e tutte le entrate, ad eccezione di quelle provenienti dall'assunzione di prestiti e di quelle con specifico vincolo di destinazione, nonche' i proventi derivanti da alienazione di beni patrimoniali disponibili e da altre entrate in c/capitale con riferimento a squilibri di parte capitale. Ai fini del rientro, in deroga all'art. 1, comma 169, della legge 27 dicembre 2006, n. 296, contestualmente, l'ente puo' modificare le tariffe e le aliquote relative ai tributi di propria competenza. La deliberazione, contiene l'analisi delle cause che hanno determinato il disavanzo, l'individuazione di misure strutturali dirette ad evitare ogni ulteriore potenziale disavanzo, ed e' allegata al bilancio di previsione e al rendiconto, costituendone parte integrante. Con periodicita' almeno semestrale il sindaco o il presidente trasmette al Consiglio una relazione riguardante lo stato di attuazione del piano di rientro, con il parere del collegio dei revisori. L'eventuale ulteriore disavanzo formatosi nel corso del periodo considerato nel piano di rientro deve essere coperto non oltre la scadenza del piano di rientro in corso. (83)

1-bis. L'eventuale disavanzo di amministrazione presunto accertato ai sensi dell'art. 186, comma 1-bis, e' applicato al bilancio di previsione dell'esercizio successivo secondo le modalita' previste al comma 1. A seguito dell'approvazione del rendiconto e dell'accertamento dell'importo definitivo del disavanzo di amministrazione dell'esercizio precedente, si provvede all'adeguamento delle iniziative assunte ai sensi del presente comma.(83)

1-ter. A seguito dell'eventuale accertamento di un disavanzo di amministrazione presunto nell'ambito delle attivita' previste dall'art. 187, comma 3-quinquies, effettuate nel corso dell'esercizio provvisorio nel rispetto di quanto previsto dall'art. 187, comma 3, si provvede alla tempestiva approvazione del bilancio di previsione. Nelle more dell'approvazione del bilancio la gestione prosegue secondo le modalita' previste dall'art. 163, comma 3. (83)

1-quater. Agli enti locali che presentino, nell'ultimo rendiconto deliberato, un disavanzo di amministrazione ovvero debiti fuori bilancio, ancorche' da riconoscere, nelle more della variazione di bilancio che dispone la copertura del disavanzo e del riconoscimento e finanziamento del debito fuori bilancio, e' fatto divieto di assumere impegni e pagare spese per servizi non espressamente previsti per legge. Sono fatte salve le spese da sostenere a fronte di impegni gia' assunti nei precedenti esercizi. (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 189. - Residui attivi

1. Costituiscono residui attivi le somme accertate e non riscosse entro il termine dell'esercizio.

2. Sono mantenute tra i residui dell'esercizio esclusivamente le entrate accertate per le quali esiste un titolo giuridico che costituisca l'ente locale creditore della correlativa entrata ((esigibile nell'esercizio, secondo i principi applicati della contabilita' finanziaria di cui all'allegato n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.)). ((83))

3. Alla chiusura dell'esercizio ((le somme rese disponibili dalla Cassa depositi e prestiti a titolo di finanziamento e non ancora prelevate dall'ente costituiscono residui attivi a valere dell'entrata classificata come prelievi da depositi bancari, nell'ambito del titolo Entrate da riduzione di attivita' finanziarie, tipologia Altre entrate per riduzione di attivita' finanziarie.)) ((83))

4. Le somme iscritte tra le entrate di competenza e non accertate entro il termine dell'esercizio costituiscono minori ((entrate)) rispetto alle previsioni ed tale titolo, concorrono a determinare i risultati finali della gestione. ((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 190 - Residui passivi

1. Costituiscono residui passivi le somme impegnate e non pagate entro il termine dell'esercizio.

2. E' vietata la conservazione nel conto dei residui di somme non impegnate ai sensi dell'articolo 183.

3. Le somme non impegnate entro il termine dell'esercizio costituiscono economia di spesa e, a tale titolo, concorrono a determinare i risultati finali della gestione.

## Principi di gestione e controllo di gestione

### Articolo 191 - Regole per l'assunzione di impegni e per l'effettuazione di spese

1. Gli enti locali possono effettuare spese solo se sussiste l'impegno contabile registrato sul competente programma del bilancio di previsione e l'attestazione della copertura finanziaria di cui all'articolo 153, comma 5. Nel caso di spese riguardanti trasferimenti e contributi ad altre amministrazioni pubbliche, somministrazioni, forniture, appalti e prestazioni professionali, il responsabile del procedimento di spesa comunica al destinatario le informazioni relative all'impegno. La comunicazione dell'avvenuto impegno e della relativa copertura finanziaria, riguardanti le somministrazioni, le forniture e le prestazioni professionali, e' effettuata contestualmente all'ordinazione della prestazione con l'avvertenza che la successiva fattura deve essere completata con gli estremi della suddetta comunicazione. Fermo restando quanto disposto al comma 4, il terzo interessato, in mancanza della comunicazione, ha facolta' di non eseguire la prestazione sino a quando i dati non gli vengano comunicati. (83)

2. Per le spese previste dai regolamenti economali l'ordinazione fatta a terzi contiene il riferimento agli stessi regolamenti, alla missione e al programma di bilancio e al relativo capitolo di spesa del piano esecutivo di gestione ed all'impegno. (83)

3. Per i lavori pubblici di somma urgenza, cagionati dal verificarsi di un evento eccezionale o imprevedibile, la Giunta, ((...)) entro venti giorni dall'ordinazione fatta a terzi, su proposta del responsabile del procedimento, sottopone al Consiglio il provvedimento di riconoscimento della spesa con le modalita' previste dall'articolo 194, comma 1, lettera e), prevedendo la relativa copertura finanziaria nei limiti delle accertate necessita' per la rimozione dello stato di pregiudizio alla pubblica incolumita'. Il provvedimento di riconoscimento e' adottato entro 30 giorni dalla data di deliberazione della proposta da parte della Giunta, e comunque entro il 31 dicembre dell'anno in corso se a tale data non sia scaduto il predetto termine. La comunicazione al terzo interessato e' data contestualmente all'adozione della deliberazione consiliare.

4. Nel caso in cui vi e' stata l'acquisizione di beni e servizi in violazione dell'obbligo indicato nei commi 1, 2 e 3, il rapporto obbligatorio intercorre, ai fini della controprestazione e per la parte non riconoscibile ai sensi dell'articolo 194, comma 1, lettera e), tra il privato fornitore e l'amministratore, funzionario o dipendente che hanno consentito la fornitura. Per le esecuzioni reiterate o continuative detto effetto si estende a coloro che hanno reso possibili le singole prestazioni.

5. Il regolamento di contabilita' dell'ente disciplina le modalita' attraverso le quali le fatture o i documenti contabili equivalenti che attestano l'avvenuta cessione di beni, lo stato di avanzamento di lavori, la prestazione di servizi nei confronti dell'ente sono protocollate ed, entro 10 giorni, annotate nel registro delle fatture ricevutesecondo le modalita' previste dall'art. 42 del decreto-legge 24 aprile 2014, n. 66, convertito in legge, con modificazioni, dalla legge 23 giugno 2014, n. 89. Per il protocollo di tali documenti e' istituito un registro uniconel rispetto della disciplina in materia di documentazione amministrativa di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, ed e' esclusa la possibilita' di ricorrere a protocolli di settore o di reparto. (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 192 - Determinazioni a contrattare e relative procedure

1. La stipulazione dei contratti deve essere preceduta da apposita determinazione del responsabile del procedimento di spesa indicante:

- a) il fine che con il contratto si intende perseguire;
- b) l'oggetto del contratto, la sua forma e le clausole ritenute essenziali;
- c) le modalita' di scelta del contraente ammesse dalle disposizioni vigenti in materia di contratti delle pubbliche amministrazioni e le ragioni che ne sono alla base.

2. Si applicano, in ogni caso, le procedure previste dalla normativa della Unione europea recepita o comunque vigente nell'ordinamento giuridico italiano.

### Articolo 193 - Salvaguardia degli equilibri di bilancio

1. Gli enti locali rispettano durante la gestione e nelle variazioni di bilancio il pareggio finanziario e tutti gli equilibri stabiliti in bilancio per la copertura delle spese correnti e per il finanziamento degli investimenti, secondo le norme contabili recate dal presente testo unico ((, con particolare riferimento agli equilibri di competenza e di cassa di cui all'art. 162, comma 6.)). ((83))

2. Con periodicita' stabilita dal regolamento di contabilita' dell'ente locale, e comunque almeno una volta entro il ((31 luglio)) di ciascun anno, l'organo consiliare provvede con delibera ((a dare)) atto del permanere degli equilibri generali di bilancio o, in caso di accertamento negativo ((ad adottare, contestualmente:)) ((a) le misure necessarie a ripristinare il pareggio qualora i dati della gestione finanziaria facciano prevedere un disavanzo, di gestione o di amministrazione, per squilibrio della gestione di competenza, di cassa ovvero della gestione dei residui; b) i provvedimenti per il ripiano degli eventuali debiti di cui all'art. 194; c) le iniziative necessarie ad adeguare il fondo crediti di dubbia esigibilita' accantonato nel risultato di amministrazione in caso di gravi squilibri riguardanti la gestione dei residui.)) La deliberazione e' allegata, al rendiconto dell'esercizio relativo. (58) (65) (71) ((83))

((3. Ai fini del comma 2, fermo restando quanto stabilito dall'art. 194, comma 2, possono essere utilizzate per l'anno in corso e per i due successivi le possibili economie di spesa e tutte le entrate, ad eccezione di quelle provenienti dall'assunzione di prestiti e di quelle con specifico vincolo di destinazione, nonche' i proventi derivanti da alienazione di beni patrimoniali disponibili e da altre entrate in c/capitale con riferimento a squilibri di parte capitale. Ove non possa provvedersi con le modalita' sopra indicate e' possibile impiegare la quota libera del risultato di amministrazione. Per il ripristino degli equilibri di bilancio e in deroga all'art. 1, comma 169, della legge 27 dicembre 2006, n. 296, l'ente puo' modificare le tariffe e le aliquote relative ai tributi di propria competenza entro la data di cui al comma 2.))

((83))

4. La mancata adozione, da parte dell'ente, dei provvedimenti di riequilibrio previsti dal presente articolo e' equiparata ad ogni effetto alla mancata approvazione del bilancio di previsione di cui all'articolo 141, con applicazione della procedura prevista dal comma 2 del medesimo articolo.

--------------- AGGIORNAMENTO (58) Il D.L. 10 ottobre 2012, n. 174, convertito con modificazioni dalla L. 7 dicembre 2012, n. 213, ha disposto (con l'art. 9, comma 1) che "Per l'anno 2012 il termine del 30 settembre previsto dall'articolo 193, comma 2, del decreto legislativo 18 agosto 2000, n. 267, e' differito al 30 novembre 2012". -------------- AGGIORNAMENTO (65) La L. 24 dicembre 2012, n. 228, come modificata dal D.L. 8 aprile 2013, n. 35, convertito con modificazioni dalla L. 6 giugno 2013, n. 64, ha disposto (con l'art. 1, comma 381) che "Ove il bilancio di previsione sia deliberato dopo il 1° settembre, per l'anno 2013 e' facoltativa l'adozione della delibera consiliare di cui all'articolo 193, comma 2, del citato testo unico di cui al decreto legislativo n. 267 del 2000". -------------- AGGIORNAMENTO (71) La L. 24 dicembre 2012, n. 228, come modificata dal D.L. 14 agosto 2013, n. 93, convertito con modificazioni dalla L. 15 ottobre 2013, n. 119, ha disposto (con l'art. 1, comma 381) che "Ove il bilancio di previsione sia deliberato dopo il 1° settembre, per l'anno 2013 e' facoltativa l'adozione della delibera consiliare di cui all'articolo 193, comma 2, del citato testo unico di cui al decreto legislativo n. 267 del 2000. Tale delibera, per gli enti locali che hanno approvato il bilancio di previsione entro il 31 agosto 2013, e' adottata entro il termine massimo del 30 novembre 2013". --------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 194 - Riconoscimento di legittimita' di debiti fuori bilancio

1. Con deliberazione consiliare di cui all'articolo 193, comma 2, o con diversa periodicita' stabilita dai regolamenti di contabilita', gli enti locali riconoscono la legittimita' dei debiti fuori bilancio derivanti da:

- a) sentenze esecutive;
- b) copertura di disavanzi di consorzi, di aziende speciali e di istituzioni, nei limiti degli obblighi derivanti da statuto, convenzione o atti costitutivi, purche' sia stato rispettato l'obbligo di pareggio del bilancio di cui all'articolo 114 ed il disavanzo derivi da fatti di gestione;
- c) ricapitalizzazione, nei limiti e nelle forme previste dal codice civile o da norme speciali, di societa' di capitali costituite per l'esercizio di servizi pubblici locali.
- d) procedure espropriative o di occupazione d'urgenza per opere di pubblica utilita';
- e) acquisizione di beni e servizi, in violazione degli obblighi di cui ai commi 1, 2 e 3 dell'articolo 191, nei limiti degli accertati e dimostrati utilita' ed arricchimento per l'ente, nell'ambito dell'espletamento di pubbliche funzioni e servizi di competenza.

2. Per il pagamento, l'ente puo' provvedere anche mediante un piano di rateizzazione, della durata di tre anni finanziari compreso quello in corso, convenuto con i creditori.

3. Per il finanziamento delle spese suddette, ove non possa documentalmente provvedersi a norma dell'articolo 193, comma 3, l'ente locale puo' far ricorso a mutui ai sensi degli articoli 202 e seguenti ((, nonche', in presenza di piani di rateizzazioni con durata diversa da quelli indicati al comma 2, puo' garantire la copertura finanziaria delle quote annuali previste negli accordi con i creditori in ciascuna annualita' dei corrispondenti bilanci, in termini di competenza e di cassa)). Nella relativa deliberazione consiliare viene dettagliatamente motivata l'impossibilita' di utilizzare altre risorse.

### Articolo 195 - ((Utilizzo di entrate vincolate))

((83))

1. Gli enti locali, ad eccezione degli enti in stato di dissesto finanziario sino all'emanazione del decreto di cui all'articolo 261, comma 3, possono disporre l'utilizzo, in termini di cassa, ((delle entrate vincolate di cui all'art. 180, comma 3, lettera d))) per il finanziamento di spese correnti, anche se provenienti dall'assunzione di mutui con istituti diversi dalla Cassa depositi e prestiti, per un importo non superiore all'anticipazione di tesoreria disponibile ai sensi dell'articolo 222. ((I movimenti di utilizzo e di reintegro delle somme vincolate di cui all'art. 180, comma 3, sono oggetto di registrazione contabile secondo le modalita' indicate nel principio applicato della contabilita' finanziaria.))((83))

2. L'utilizzo di ((entrate vincolate)) presuppone l'adozione della deliberazione della giunta relativa all'anticipazione di tesoreria di cui all'articolo 222, comma 1, e viene deliberato in termini generali all'inizio di ciascun esercizio ed e' attivato ((dall'ente con l'emissione di appositi ordinativi di incasso e pagamento di regolazione contabile)).((83))

3. Il ricorso all'utilizzo delle ((entrate vincolate)), secondo le modalita' di cui ai commi 1 e 2, vincola una quota corrispondente dell'anticipazione di tesoreria. Con i primi introiti non soggetti a vincolo di destinazione viene ricostituita la consistenza delle somme vincolate che sono state utilizzate per il pagamento di spese correnti. ((La ricostituzione dei vincoli e' perfezionata con l'emissione di appositi ordinativi di incasso e pagamento di regolazione contabile.))((83))

4. Gli enti locali che hanno deliberato alienazioni del patrimonio ai sensi dell'articolo 193 possono, nelle more del perfezionamento di tali atti, utilizzare in termini di cassa le ((entrate vincolate)), fatta eccezione per i trasferimenti di enti del settore pubblico allargato e del ricavato dei mutui e dei prestiti, con obbligo di reintegrare le somme vincolate con il ricavato delle alienazioni.((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 196 - Controllo di gestione

1. Al fine di garantire la realizzazione degli obiettivi programmati la corretta ed economica gestione delle risorse pubbliche, l'imparzialita' ed il buon andamento della pubblica amministrazione e la trasparenza dell'azione amministrativa, gli enti locali ((, ad esclusione dei comuni con popolazione fino a 5.000 abitanti,)) applicano il controllo di gestione secondo le modalita' stabilite dal presente titolo, dai propri statuti e regolamenti di contabilita'.

2. Il controllo di gestione e' la procedura diretta a verificare lo stato di attuazione degli obiettivi programmanti e, attraverso l'analisi delle risorse acquisite e della comparazione tra i costi e la quantita' e qualita' dei servizi offerti, la funzionalita' dell'organizzazione dell'ente, l'efficacia, l'efficienza ed il livello di economicita' nell'attivita' di realizzazione dei predetti obiettivi.

### Articolo 197 - Modalita' del controllo di gestione

1. Il controllo di gestione, di cui all'articolo 147, comma 1 lettera b), ha per oggetto l'intera attivita' amministrativa e gestionale delle province, dei comuni delle comunita' montane, delle unioni dei comuni e delle citta' metropolitane ed e' svolto con una cadenza periodica definita dal regolamento di contabilita' dell'ente.

2. Il controllo di gestione si articola almeno in tre fasi: ((a) predisposizione del piano esecutivo di gestione;))((83)) b) rilevazione dei dati relativi ai costi ed ai proventi nonche' rilevazione dei risultati raggiunti; c) valutazione dei dati predetti in rapporto al piano degli obiettivi al fine di verificare il loro stato di attuazione e di misurare l'efficacia, l'efficienza ed il grado di economicita' dell'azione intrapresa.

3. Il controllo di gestione e' svolto in riferimento ai singoli servizi e centri di costo, ove previsti, verificando in maniera complessiva e per ciascun servizio i mezzi finanziari acquisiti, i costi dei singoli fattori produttivi, i risultati qualitativi e quantitativi ottenuti e, per i servizi a carattere produttivo, i ricavi.

4. La verifica dell'efficacia, dell'efficienza, e della economicita' dell'azione amministrativa e' svolta rapportando le risorse acquisite ed i costi dei servizi, ove possibile per unita' di prodotto, ai dati risultanti dal rapporto annuale sui parametri gestionali dei servizi degli enti locali di cui all'articolo 228, comma 7.

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 198. - Referto del controllo di gestione

1. La struttura operativa alla quale e' assegnata la funzione dei controllo di gestione fornisce le conclusioni del predetto controllo agli amministratori ai fini della verifica dello stato di attuazione degli obiettivi programmati ed ai responsabili dei servizi affinche' questi ultimi abbiano gli elementi necessari per valutare l'andamento della gestione dei servizi di cui sono responsabili.

### Art. 198-bis. - (( (Comunicazione del referto) ))

((

1. Nell'ambito dei sistemi di controllo di gestione di cui agli articoli 196, 197 e 198, la struttura operativa alla quale e' assegnata la funzione del controllo di gestione fornisce la conclusione del predetto controllo, oltre che agli amministratori ed ai responsabili dei servizi ai sensi di quanto previsto dall'articolo 198, anche alla Corte dei conti.

))

## INVESTIMENTI CAPO I Principi generali

### Articolo 199 - Fonti di finanziamento

1. Per l'attivazione degli investimenti gli enti locali possono utilizzare:

- a) entrate correnti destinate per legge agli investimenti;
- b) ((avanzo di parte corrente del)) bilancio, ((costituito)) da eccedenze di entrate correnti rispetto alle spese correnti aumentate delle quote capitali di ammortamento dei prestiti:((83))
- c) entrate derivanti dall'alienazione di beni e diritti patrimoniali, riscossioni di crediti, proventi da concessioni edilizie e relative sanzioni;
- d) entrate derivanti da trasferimenti in conto capitale dello Stato, delle regioni, da altri interventi pubblici e privati finalizzati agli investimenti, da interventi finalizzati da parte di organismi comunitari e internazionali;
- e) avanzo di amministrazione, nelle forme disciplinate dall'articolo 187;
- f) mutui passivi;
- g) altre forme di ricorso al mercato finanziario consentite dalla legge.

((1-bis. Le entrate di cui al comma 1, lettere a), c), d) ed f) sono destinate esclusivamente al finanziamento di spese di investimento e non possono essere impiegate per la spesa corrente.))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 200 - Gli investimenti

1. Per tutti gli investimenti degli enti locali, comunque finanziati, l'organo deliberante, nell'approvare il progetto od il piano esecutivo dell'investimento, da' atto della copertura delle maggiori spese derivanti dallo stesso nel bilancio di previsione ed assume impegno di inserire nei bilanci pluriennali successivi le ulteriori o maggiori previsioni di spesa relative ad esercizi futuri, delle quali e' redatto apposito elenco. (83)

1-bis. La copertura finanziaria delle spese di investimento imputate agli esercizi successivi e' costituita:

- a) da risorse accertate esigibili nell'esercizio in corso di gestione, confluite nel fondo pluriennale vincolato accantonato per gli esercizi successivi;
- b) da risorse accertate esigibili negli esercizi successivi, la cui esigibilita' e' nella piena discrezionalita' dell'ente o di altra pubblica amministrazione;
- c) dall'utilizzo del risultato di amministrazione nel primo esercizio considerato nel bilancio di previsione, nel rispetto di quanto previsto dall'art. 187. Il risultato di amministrazione puo' confluire nel fondo pluriennale vincolato accantonato per gli esercizi successivi. (83)
- c-bis) da altre fonti di finanziamento individuate nei principi contabili allegati al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.

1-ter. Per l'attivita' di investimento che comporta impegni di spesa che vengono a scadenza in piu' esercizi finanziari, deve essere dato specificamente atto, al momento dell'attivazione del primo impegno, di aver predisposto la copertura finanziaria per l'effettuazione della complessiva spesa dell'investimento, anche se la forma di copertura e' stata gia' indicata nell'elenco annuale ((del programma triennale dei lavori pubblici previsto dall'articolo 21 del codice dei contratti pubblici, di cui al decreto legislativo 18 aprile 2016, n. 50)). (83)

------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 201. - Finanziamento di opere pubbliche e piano economico-finanziario

1. Gli enti locali e le aziende speciali sono autorizzate ((, nel rispetto dei limiti imposti dall'ordinamento alla possibilita' di indebitamento,)) ad assumere mutui, anche se assistiti da contributi dello Stato o delle regioni, per il finanziamento di opere pubbliche destinate all'esercizio di servizi pubblici, soltanto se i contratti di appalto sono realizzati sulla base di progetti "chiavi in mano" ed a prezzo non modificabile in aumento, con procedura di evidenza pubblica e con esclusione della trattativa privata.((83))

2. Per le nuove opere di cui al comma 1 il cui progetto generale comporti una spesa superiore ((a cinquecentomila euro)), gli enti di cui al comma 1 approvano un piano economico-finanziario diretto ad accertare l'equilibrio economico-finanziario dell'investimento e della connessa gestione, anche in relazione agli introiti previsti ed al fine della determinazione delle tariffe.((83))

3. COMMA ABROGATO DAL D.L. 27 DICEMBRE 2000, N. 392, CONVERTITO CON MODIFICAZIONI DALLA L. 28 FEBBRAIO 2001, N. 26.

4. Le tariffe dei servizi pubblici di cui al comma 1 sono determinati in base ai seguenti criteri:

- a) la corrispondenza tra costi e ricavi in modo da assicurare la integrale copertura dei costi, ivi compresi gli oneri di ammortamento tecnico-finanziario;
- b) l'equilibrato rapporto tra i finanziamenti raccolti ed il capitale investito;
- c) l'entita' dei costi di gestione delle opere, tenendo conto anche degli investimenti e della qualita' del servizio.

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

## Fonti di finanziamento mediante indebitamento

### Articolo 202 - Ricorso all'indebitamento

1. Il ricorso all'indebitamento da parte degli enti locali e' ammesso esclusivamente nelle forme previste dalle leggi vigenti in materia e per la realizzazione degli investimenti. Puo' essere fatto ricorso a mutui passivi per il finanziamento dei debiti fuori bilancio di cui all'articolo 194 e per altre destinazioni di legge.

2. Le relative entrate hanno destinazione vincolata.

### Articolo 203 - Attivazione delle fonti di finanziamento derivanti dal ricorso all'indebitamento

1. Il ricorso all'indebitamento e' possibile solo se sussistono le seguenti condizioni :

- a) avvenuta approvazione del rendiconto dell'esercito del penultimo anno precedente quello in cui si intende deliberare il ricorso a forme di indebitamento;
- b) avvenuta deliberazione del bilancio ((di previsione)) nel quale sono ((iscritti i relativi stanziamenti)).((83))

2. Ove nel corso dell'esercizio si renda necessario attuare nuovi investimenti o variare quelli gia' in atto, l'organo consiliare adotta apposita variazione al bilancio ((di previsione)), fermo restando l'adempimento degli obblighi di cui al comma 1. Contestualmente ((adegua il documento unico di programmazione e di conseguenza le previsioni del bilancio degli esercizi successivi)) per la copertura degli oneri derivanti dall'indebitamento e per la copertura delle spese di gestione. (65) ((83))

--------------- AGGIORNAMENTO (65) Il D.L. 8 aprile 2013, n. 35, convertito con modificazioni dalla L. 6 giugno 2013, n. 64, ha disposto (con l'art. 1, comma 13) che "Gli enti locali che non possono far fronte ai pagamenti dei debiti certi liquidi ed esigibili maturati alla data del 31 dicembre 2012, ovvero dei debiti per i quali sia stata emessa fattura o richiesta equivalente di pagamento entro il predetto termine a causa di carenza di liquidita', in deroga agli articoli 42, 203 e 204 del decreto legislativo 18 agosto 2000, n. 267, chiedono alla Cassa depositi e prestiti S.p.A., secondo le modalita' stabilite nell'addendum di cui al comma 11, entro il 30 aprile 2013 l'anticipazione di liquidita' da destinare ai predetti pagamenti". --------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 204. - Regole particolari per l'assunzione di mutui

1. Oltre al rispetto delle condizioni di cui all'articolo 203, l'ente locale puo' assumere nuovi mutui e accedere ad altre forme di finanziamento reperibili sul mercato solo se l'importo annuale degli interessi, sommato a quello dei mutui precedentemente contratti, a quello dei prestiti obbligazionari precedentemente emessi, a quello delle aperture di credito stipulate e a quello derivante da garanzie prestate ai sensi dell'articolo 207, al netto dei contributi statali e regionali in conto interessi, non supera il 12 per cento, per l'anno 2011, l'8 per cento, per gli anni dal 2012 al 2014, e il 10 per cento, a decorrere dall'anno 2015, delle entrate relative ai primi tre titoli delle entrate del rendiconto del penultimo anno precedente quello in cui viene prevista l'assunzione dei mutui. PERIODO SOPPRESSO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126. Per gli enti locali di nuova istituzione si fa riferimento, per i primi due anni, ai corrispondenti dati finanziari del bilancio di previsione. Il rispetto del limite e' verificato facendo riferimento anche agli interessi riguardanti i finanziamenti contratti e imputati contabilmente agli esercizi successivi. Non concorrono al limite di indebitamento le garanzie prestate per le quali l'ente ha accantonato l'intero importo del debito garantito.(57) (83)

2. I contratti di mutuo con enti diversi dalla Cassa depositi e prestiti, e dall'Istituto per il credito sportivo, devono, a pena di nullita', essere stipulati in forma pubblica e contenere le seguenti clausole e condizioni: (83)

- a) l'ammortamento non puo' avere durata inferiore ai cinque anni;
- b) la decorrenza dell'ammortamento deve essere fissata al 1 gennaio dell'anno successivo a quello della stipula del contratto. In alternativa, la decorrenza dell'ammortamento puo' essere posticipata al 1 luglio seguente o al 1 gen- naio dell'anno successivo e, per i contratti stipulati nel primo semestre dell'anno, puo' essere anticipata al 1 luglio dello stesso anno;
- c) la rata di ammortamento deve essere comprensiva, sin dal primo anno della quota capitale e della quota interessi;
- d) unitamente alla prima rata di ammortamento del mutuo cui si riferiscono devono, essere corrisposti gli eventuali interessi di preammortamento gravati degli ulteriori interessi, al medesimo tasso, decorrenti dalla data di inizio dell'ammortamento e sino alla scadenza della prima rata. Qualora l'ammortamento del mutuo decorra dal primo gennaio del secondo anno successivo a quello in cui e' avvenuta la stipula del contratto, gli interessi di preammortamento sono calcolati allo stesso tasso del mutuo dalla data di valuta della somministrazione al 31 dicembre successivo e dovranno essere versati dall'ente mutuatario con la medesima valuta 31 dicembre successivo;
- e) deve essere indicata la natura della spesa da finanziare con il mutuo e, ove necessario, avuto riguardo alla tipologia dell'investimento, dato atto dell'intervenuta approvazione ((del progetto di fattibilita' tecnico-economica)) o esecutivo, secondo le norme vigenti;
- f) deve essere rispettata la misura massima del tasso di interesse applicabile ai mutui, determinato periodicamente dal dal Ministro dell'economia e delle finanze con proprio decreto.(83)

2-bis. Le disposizioni del comma 2 si applicano, ove compatibili, alle altre forme di indebitamento cui l'ente locale acceda.

3. L'ente mutuatario utilizza il ricavato del mutuo sulla base dei documenti giustificativi della spesa ovvero sulla base di stati di avanzamento dei lavori. PERIODO SOPPRESSO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126. (65)

--------------- AGGIORNAMENTO (57) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 16, comma 11) che "Il comma 1 dell'articolo 204 del decreto legislativo 18 agosto 2000, n. 267, si interpreta nel senso che l'ente locale puo' assumere nuovi mutui e accedere ad altre forme di finanziamento reperibili sul mercato, qualora sia rispettato il limite nell'anno di assunzione del nuovo indebitamento". --------------- AGGIORNAMENTO (65) Il D.L. 8 aprile 2013, n. 35, convertito con modificazioni dalla L. 6 giugno 2013, n. 64, ha disposto (con l'art. 1, comma 13) che "Gli enti locali che non possono far fronte ai pagamenti dei debiti certi liquidi ed esigibili maturati alla data del 31 dicembre 2012, ovvero dei debiti per i quali sia stata emessa fattura o richiesta equivalente di pagamento entro il predetto termine a causa di carenza di liquidita', in deroga agli articoli 42, 203 e 204 del decreto legislativo 18 agosto 2000, n. 267, chiedono alla Cassa depositi e prestiti S.p.A., secondo le modalita' stabilite nell'addendum di cui al comma 11, entro il 30 aprile 2013 l'anticipazione di liquidita' da destinare ai predetti pagamenti". --------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 205 - Attivazione di prestiti obbligazionari

1. Gli enti locali sono autorizzati ad attivare prestiti obbligazionari nelle forme consentite dalla legge.

### Art. 205-bis. - (Contrazione di aperture di credito)

1. Gli enti locali sono autorizzati a contrarre aperture di credito nel rispetto della disciplina di cui al presente articolo.

2. L'utilizzo del ricavato dell'operazione e' sottoposto alla disciplina di cui all'articolo 204, comma 3.

3. I contratti di apertura di credito devono, a pena di nullita', essere stipulati in forma pubblica e contenere le seguenti clausole e condizioni:

- a) la banca e' tenuta ad effettuare erogazioni, totali o parziali, dell'importo del contratto in base alle richieste di volta in volta inoltrate dall'ente e previo rilascio da parte di quest'ultimo delle relative delegazioni di pagamento ai sensi dell'articolo 206. ((PERIODO SOPPRESSO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126, A SUA VOLTA MODIFICATO DALL'AVVISO DI RETTIFICA IN G.U. 10/03/2015, N. 57))
- b) gli interessi sulle aperture di credito devono riferirsi ai soli importi erogati. L'ammortamento di tali importi deve avere una durata non inferiore a cinque anni con decorrenza dal 1° gennaio o dal 1° luglio successivi alla data dell'erogazione;
- c) le rate di ammortamento devono essere comprensive, sin dal primo anno, della quota capitale e della quota interessi;
- d) unitamente alla prima rata di ammortamento delle somme erogate devono essere corrisposti gli eventuali interessi di preammortamento, gravati degli ulteriori interessi decorrenti dalla data di inizio dell'ammortamento e sino alla scadenza della prima rata;
- e) deve essere indicata la natura delle spese da finanziare e, ove necessario, avuto riguardo alla tipologia dell'investimento, dato atto dell'intervenuta approvazione del progetto o dei progetti definitivi o esecutivi, secondo le norme vigenti;
- f) deve essere rispettata la misura massima di tasso applicabile alle aperture di credito i cui criteri di determinazione sono demandati ad apposito decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro dell'interno.

3-bis. Il contratto di cui al comma 3 puo' prevedere l'erogazione dei singoli tiraggi sulla base di scritture private ovvero di atti di quietanza, fermo restando, al termine di periodi di tempo contrattualmente predeterminati, la formalizzazione dell'insieme dei tiraggi effettuati con unico atto pubblico. (83)

4. Le aperture di credito sono soggette, al pari delle altre forme di indebitamento, al monitoraggio di cui all'articolo 41 della legge 28 dicembre 2001, n. 448, nei termini e nelle modalita' previsti dal relativo regolamento di attuazione, di cui al decreto del Ministro dell'economia e delle finanze 1° dicembre 2003, n. 389.

------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

## Garanzie per mutui e prestiti

### Articolo 206 - Delegazione di pagamento

1. Quale garanzia del pagamento delle rate di ammortamento dei mutui e dei prestiti gli enti locali possono rilasciare delegazione di pagamento a valere sulle entrate afferenti ai primi tre titoli del bilancio di previsione. ((PERIODO SOPPRESSO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)). (83)

2. L'atto di delega, non soggetto ad accettazione, e' notificato al tesoriere da parte dell'ente locale e costituisce titolo esecutivo.

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 207 - Fideiussione

1. I comuni, le province e le citta' metropolitane possono rilasciare a mezzo di deliberazione consiliare garanzia fideiussoria per l'assunzione di mutui destinati ad investimenti e per altre operazioni di indebitamento da parte di aziende da essi dipendenti, da consorzi cui partecipano nonche' dalle comunita' montane di cui fanno parte ((che possono essere destinatari di contributi agli investimenti finanziati da debito, come definiti dall'art. 3, comma 18, lettere g) ed h), della legge 24 dicembre 2003, n. 350.))((83))

1-bis. A fronte di operazioni di emissione di prestiti obbligazionari effettuate congiuntamente da piu' enti locali, gli enti capofila possono procedere al rilascio di garanzia fideiussoria riferita all' insieme delle operazioni stesse. Contestualmente gli altri enti emittenti rilasciano garanzia fideiussoria a favore dell'ente capofila in relazione alla quota parte dei prestiti di propria competenza. Ai fini dell'applicazione del comma 4, la garanzia prestata dall'ente capofila concorre alla formazione del limite di indebitamento solo per la quota parte dei prestiti obbligazionari di competenza dell'ente stesso.

2. La garanzia fideiussoria puo' essere inoltre rilasciata a favore della societa' di capitali, costituite ai sensi dell'articolo 113 ), comma 1, lettera e), per l'assunzione di mutui destinati alla realizzazione delle opere di cui all'articolo 116, comma 1. In tali casi i comuni, le province e le citta' metropolitane rilasciano la fideiussione limitatamente alle rate di ammortamento da corrispondersi da parte della societa' sino al secondo esercizio finanziario successivo a quello dell'entrata in funzione dell'opera ed in misura non superiore alla propria quota percentuale di partecipazione alla societa'.

3. La garanzia fideiussoria puo' essere rilasciata anche a favore di terzi ((, che possono essere destinatari di contributi agli investimenti finanziati da debito, come definiti dall'art. 3, comma 18, lettere g) ed h), della legge 24 dicembre 2003, n. 350,)) per l'assunzione di mutui destinati alla realizzazione o alla ristrutturazione di opere a fini culturali, sociali o sportivi, su terreni di proprieta' dell'ente locale, purche' siano sussistenti le seguenti condizioni: ((83))

- a) il progetto sia stato approvato dall'ente locale e sia stata stipulata una convenzione con il soggetto mutuatario che regoli la possibilita' di utilizzo delle strutture in funzione delle esigenze della collettivita' locale;
- b) la struttura realizzata sia acquisita al patrimonio dell'ente al termine della concessione;
- c) la convenzione regoli i rapporti tra ente locale e mutuatario nel caso di rinuncia di questi alla realizzazione o ristrutturatone dell'opera.

4. Gli interessi annuali relativi alle operazioni di indebitamento garantite con fideiussione concorrono alla formazione del limite di cui al comma 1 dell'articolo 204 e non possono impegnare piu' di un quinto di tale limite.

((4-bis. Con il regolamento di contabilita' l'ente puo' limitare la possibilita' di rilasciare fideiussioni.))

((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

## TESORERIA CAPO I Disposizioni generali

### Art. 208. - Soggetti abilitati a svolgere il servizio di tesoreria

1. Gli enti locali hanno un servizio di tesoreria che puo' essere affidato:

- a) per i comuni capoluoghi di provincia, le province, le citta' metropolitane, ad una banca autorizzata, a svolgere l'attivita' di cui all'articolo 10 del decreto legislativo 1 settembre 1993, n. 385;
- b) per i comuni non capoluoghi di provincia, le comunita' montane e le unioni di comuni, anche a societa' per azioni regolarmente costituite con capitale sociale interamente versato non inferiore a ((cinquecentomila euro)), aventi per oggetto la gestione del servizio di tesoreria e la riscossione dei tributi degli enti locali e che alla data del 25 febbraio 1995 erano incaricate dello svolgimento del medesimo servizio a condizione che il capitale sociale risulti adeguato a quello minimo richiesto dalla normativa vigente per le banche di credito cooperativo; ((83))
- c) altri soggetti abilitati per legge. (68)

----------- AGGIORNAMENTO (68) Il D.L. 21 giugno 2013, n. 69, convertito con modificazioni dalla L. 9 agosto 2013, n. 98, ha disposto (con l'art. 54, comma 1-bis) che "Al fine di garantire in modo efficiente lo svolgimento del servizio di tesoreria nei confronti degli enti locali, l'articolo 208 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e successive modificazioni, si interpreta nel senso che il tesoriere, senza distinzione tra i soggetti di cui alle lettere a), b) e c) del comma 1 del predetto articolo 208, che rivesta la qualifica di societa' per azioni, puo' delegare, anche per i servizi di tesoreria gia' affidati, la gestione di singole fasi o processi del servizio ad una societa' per azioni che sia controllata dal tesoriere ai sensi dell'articolo 2359, primo comma, numeri 1) e 2), del codice civile. Il tesoriere che deleghi la gestione di singole fasi o processi del servizio di tesoreria garantisce che il servizio sia in ogni caso erogato all'ente locale nelle modalita' previste dalla convenzione, e mantiene la responsabilita' per gli atti posti in essere dalla societa' delegata. In nessun caso la delega della gestione di singole fasi o processi del servizio puo' generare alcun aggravio di costi per l'ente". ------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 209 - Oggetto del servizio di tesoreria

1. Il servizio di tesoreria consiste nel complesso di operazioni legate alla gestione finanziaria dell'ente locale e finalizzate in particolare alla riscossione delle entrate, al pagamento delle spese, alla custodia di titoli e valori ed agli adempimenti connessi previsti dalla legge, dallo statuto, dai regolamenti dell'ente o da norme pattizie.

2. Il tesoriere esegue le operazioni di cui al comma 1 nel rispetto della legge 29 ottobre 1984, n. 720, e successive modificazioni.

3. Ogni deposito, comunque costituito, e' intestato all'ente locale e viene gestito dal tesoriere.

((3-bis. Il tesoriere tiene contabilmente distinti gli incassi di cui all'art. 180, comma 3, lettera d). I prelievi di tali risorse sono consentiti solo con i mandati di pagamento di cui all'art. 185, comma 2, lettera i). E' consentito l'utilizzo di risorse vincolate secondo le modalita' e nel rispetto dei limiti previsti dall'art. 195.))

((83))

------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 210 - Affidamento del servizio di tesoreria

1. L'affidamento del servizio viene effettuato mediante le procedure ad evidenza pubblica stabilite nel regolamento di contabilita' di ciascun ente, con modalita' che rispettino i principi della concorrenza. Qualora ricorrano le condizioni di legge, l'ente puo' procedere, per non piu' di una volta, al rinnovo del contratto di tesoreria nei confronti del medesimo soggetto.

2. Il rapporto viene regolato in base ad una convenzione deliberata dall'organo consiliare dell'ente.

((2-bis. La convenzione di cui al comma 2 puo' prevedere l'obbligo per il tesoriere di accettare, su apposita istanza del creditore, crediti pro soluto certificati dall'ente ai sensi del comma 3-bis dell'articolo 9 del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2))

((53))

-------------- AGGIORNAMENTO (53) La L. 12 novembre 2011, n. 183 ha disposto (con l'art. 13, comma 4) che "L'obbligo di cui al comma 2-bis dell'articolo 210 del citato decreto legislativo 18 agosto 2000, n. 267, come introdotto dal comma 3 del presente articolo, trova applicazione con riferimento alle convenzioni stipulate successivamente alla data di entrata in vigore della presente legge."

### Articolo 211 - Responsabilita' del tesoriere

1. Per eventuali danni causati all'ente affidante o a terzi il tesoriere risponde con tutte le proprie attivita' e con il proprio patrimonio.

2. Il tesoriere e' responsabile di tutti i depositi, comunque costituiti, intestati all'ente.

### Articolo 212 - Servizio di tesoreria svolto per piu' enti locali

1. I soggetti di cui all'articolo 208 che gestiscono il servizio di tesoreria per conto di piu' enti locali devono tenere contabilita' distinte e separate per ciascuno di essi.

### Articolo 213 - (( Gestione informatizzata del servizio di tesoreria ))

((

1. Qualora l'organizzazione dell'ente e del tesoriere lo consentano il servizio di tesoreria puo' essere gestito con modalita' e criteri informatici e con l'uso di ordinativi di pagamento e di riscossione informatici, in luogo di quelli cartacei, le cui evidenze informatiche valgono a fini di documentazione, ivi compresa la resa del conto del tesoriere di cui all'articolo 226.

2. La convenzione di tesoreria di cui all'articolo 210 puo' prevedere che la riscossione delle entrate e il pagamento delle spese possano essere effettuati, oltre che per contanti presso gli sportelli di tesoreria, anche con le modalita' offerte dai servizi elettronici di incasso e di pagamento interbancari.

3. Gli incassi effettuati dal tesoriere mediante i servizi elettronici interbancari danno luogo al rilascio di quietanza o evidenza bancaria ad effetto liberatorio per il debitore; le somme rivenienti dai predetti incassi sono versate alle casse dell'ente, con rilascio della quietanza di cui all'articolo 214, non appena si rendono liquide ed esigibili in relazione ai servizi elettronici adottati e comunque nei tempi previsti nella predetta convenzione di tesoreria.

))

## Riscossione delle entrate

### Articolo 214 - Operazioni di riscossione

1. Per ogni somma riscossa il tesoriere rilascia quietanza, numerata in ordine cronologico per esercizio finanziario.

### Articolo 215 - Procedure per la registrazione delle entrate

1. Il regolamento di contabilita' dell'ente stabilisce le procedure per la fornitura dei modelli e per la registrazione delle entrate; disciplina, altresi' le modalita' per la comunicazione delle operazioni di riscossione eseguite, nonche' la relativa prova documentale.

((1-bis. Il tesoriere non gestisce i codici della transazione elementare di cui agli articoli da 5 a 7, del decreto legislativo 23 giugno 2011, n. 118, inseriti nei campi liberi dell'ordinativo a disposizione dell'ente.))

((83))

------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

## Pagamento delle spese

### Articolo 216 - Condizioni di legittimita' dei pagamenti effettuali dal tesoriere

1. ((COMMA ABROGATO DAL D.L. 26 OTTOBRE 2019, N. 124, CONVERTITO CON MODIFICAZIONI DALLA L. 19 DICEMBRE 2019, N. 157)).

2. Nessun mandato di pagamento puo' essere estinto dal tesoriere se privo della codifica,compresa la codifica SIOPE di cui all'art. 14 della legge 31 dicembre 2009, n. 196. Il tesoriere non gestisce i codici della transazione elementare di cui agli articoli da 5 a 7, del decreto legislativo 23 giugno 2011, n. 118, inseriti nei campi liberi del mandato a disposizione dell'ente. (83)

3. ((COMMA ABROGATO DAL D.L. 26 OTTOBRE 2019, N. 124, CONVERTITO CON MODIFICAZIONI DALLA L. 19 DICEMBRE 2019, N. 157)).

------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 217 - Estinzione dei mandati di pagamento

1. L'estinzione dei mandati da parte del tesoriere avviene nel rispetto della legge e secondo le indicazioni fornite dall'ente, con assunzione di responsabilita' da parte del tesoriere, che ne risponde con tutto il proprio patrimonio sia nei confronti dell'ente locale ordinante sia dei terzi creditori, in ordine alla regolarita' delle operazioni di pagamento eseguite.

### Articolo 218 - Annotazione della quietanza

1. Il tesoriere annota gli estremi della quietanza direttamente sul mandato o su documentazione meccanografica da consegnare all'ente, unitamente ai mandati pagati, in allegato al proprio rendiconto.

2. Su richiesta dell'ente locale il tesoriere fornisce gli estremi di qualsiasi operazione di pagamento eseguita nonche' la relativa prova documentale.

### Articolo 219 - Mandati non estinti al termine dell'esercizio

1. I mandati interamente o parzialmente non estinti alla data del 31 dicembre sono eseguiti mediante commutazione in assegni postali localizzati o con altri mezzi equipollenti offerti dal sistema bancario o postale.

### Articolo 220 - Obblighi del tesoriere per le delegazioni di pagamento

1. A seguito della notifica degli atti di delegazione di pagamento di cui all'articolo 206 il tesoriere e' tenuto a versare l'importo dovuto ai creditori alle scadenze prescritte, con comminatoria dell'indennita' di mora in caso di ritardato pagamento.

## Altre attivita'

### Articolo 221 - Gestione di titoli e valori

1. I titoli di proprieta' dell'ente, ove consentito dalla legge, sono gestiti dal tesoriere con versamento delle cedole nel conto di tesoreria alle loro rispettive scadenze.

2. Il tesoriere provvede anche alla riscossione dei depositi effettuati da terzi per spese contrattuali, d'asta e cauzionali a garanzia degli impegni assunti, previo rilascio di apposita ricevuta, diversa dalla quietanza di tesoreria, contenente tutti gli estremi identificativi dell'operazione.

3. Il regolamento di contabilita' dell'ente locale definisce le procedure per i prelievi e per le restituzioni.

### Articolo 222 - Anticipazioni di tesoreria

1. Il tesoriere, su richiesta dell'ente corredata dalla deliberazione della giunta, concede allo stesso anticipazioni di tesoreria, entro il limite massimo dei tre dodicesimi delle entrate accertate nel penultimo anno precedente, afferenti ai primi tre titoli di entrata del bilancio. (76) (83) (84) (87) (91) (97) (100) (109) (117) ((136))

2. Gli interessi sulle anticipazioni di tesoreria decorrono dall'effettivo utilizzo delle somme con le modalita' previste dalla convenzione di cui all'articolo 210.

2-bis. Per gli enti locali in dissesto economico-finanziario ai sensi dell'articolo 246, che abbiano adottato la deliberazione di cui all'articolo 251, comma 1, e che si trovino in condizione di grave indisponibilita' di cassa, certificata congiuntamente dal responsabile del servizio finanziario e dall'organo di revisione, il limite massimo di cui al comma 1 del presente articolo e' elevato a cinque dodicesimi fino al raggiungimento dell'equilibrio di cui all'articolo 259 e, comunque, per non oltre cinque anni, compreso quello in cui e' stato deliberato il dissesto. E' fatto divieto ai suddetti enti di impegnare tali maggiori risorse per spese non obbligatorie per legge e risorse proprie per partecipazione ad eventi o manifestazioni culturali e sportive, sia nazionali che internazionali. (65) (66) (74)

--------------- AGGIORNAMENTO (65) Il D.L. 8 aprile 2013, n. 35, convertito con modificazioni dalla L. 6 giugno 2013, n. 64, ha disposto (con l'art. 1, comma 9) che "Per l'anno 2013, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria di cui all'articolo 222 del decreto legislativo 18 agosto 2000, n. 267, e' incrementato, sino alla data del 30 settembre 2013, da tre a cinque dodicesimi". --------------- AGGIORNAMENTO (66) Il D.L. 21 maggio 2013, n. 54, convertito con modificazioni dalla L. 18 luglio 2013, n. 85, ha disposto (con l'art. 1, comma 2) che "Il limite massimo di ricorso all'anticipazione di tesoreria di cui all'articolo 222 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, come modificato, per l'anno 2013, dall'articolo 1, comma 9, del decreto-legge 8 aprile 2013, n. 35, e' ulteriormente incrementato fino al 30 settembre 2013, di un importo, come risultante per ciascun comune, dall'allegato A, pari al cinquanta per cento: a) del gettito relativo all'anno 2012 dell'imposta municipale propria ad aliquota di base o maggiorata se deliberata dai comuni, per l'anno medesimo con riferimento alle abitazioni principali e relative pertinenze; b) del gettito relativo all'anno 2012 dell'imposta municipale propria, comprensivo delle variazioni deliberate dai comuni per l'anno medesimo, con riferimento agli immobili di cui alla lettera b) e c) del comma 1.". --------------- AGGIORNAMENTO (74) Il D.L. 30 novembre 2013, n. 133, convertito con modificazioni dalla L. 29 gennaio 2014, n. 5, ha disposto (con l'art. 1, comma 12) che "Per l'anno 2014, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria di cui all'articolo 222 del decreto legislativo 18 agosto 2000, n. 267, e' incrementato, sino alla data del 31 marzo 2014 da tre a cinque dodicesimi." --------------- AGGIORNAMENTO (76) Il D.L. 28 gennaio 2014, n. 4 convertito con modificazioni dalla L. 28 marzo 2014, n. 50 ha disposto (con l'art. 2, comma 3-bis) che "Al fine di agevolare il rispetto dei tempi di pagamento di cui al decreto legislativo 9 ottobre 2002, n. 231, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria, di cui al comma 1 dell'articolo 222 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' elevato da tre a cinque dodicesimi sino alla data del 31 dicembre 2014". ------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi". ------------ AGGIORNAMENTO (84) Il D.L. 28 gennaio 2014, n. 4, convertito con modificazioni dalla L. 28 marzo 2014, n. 50, come modificato dalla L. 23 dicembre 2014, n. 190, ha disposto (con l'art. 2, comma 3-bis) che "Al fine di agevolare il rispetto dei tempi di pagamento di cui al decreto legislativo 9 ottobre 2002, n. 231, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria, di cui al comma 1 dell'articolo 222 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' elevato da tre a cinque dodicesimi sino alla data del 31 dicembre 2015". ------------ AGGIORNAMENTO (87) Il D.L. 28 gennaio 2014, n. 4, convertito con modificazioni dalla L. 28 marzo 2014, n. 50, come modificato dalla L. 28 dicembre 2015, n. 208, ha disposto (con l'art. 2, comma 3-bis) che "Al fine di agevolare il rispetto dei tempi di pagamento di cui al decreto legislativo 9 ottobre 2002, n. 231, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria, di cui al comma 1 dell'articolo 222 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' elevato da tre a cinque dodicesimi sino alla data del 31 dicembre 2016". ------------ AGGIORNAMENTO (91) Il D.L. 28 gennaio 2014, n. 4, convertito con modificazioni dalla L. 28 marzo 2014, n. 50, come modificato dalla L. 11 dicembre 2016, n. 232, ha disposto (con l'art. 2, comma 3-bis) che "Al fine di agevolare il rispetto dei tempi di pagamento di cui al decreto legislativo 9 ottobre 2002, n. 231, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria, di cui al comma 1 dell'articolo 222 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' elevato da tre a cinque dodicesimi sino alla data del 31 dicembre 2017". ------------- AGGIORNAMENTO (97) Il D.L. 28 gennaio 2014, n. 4, convertito con modificazioni dalla L. 28 marzo 2014, n. 50, come modificato dalla L. 27 dicembre 2017, n. 205, ha disposto (con l'art. 2, comma 3-bis) che "Al fine di agevolare il rispetto dei tempi di pagamento di cui al decreto legislativo 9 ottobre 2002, n. 231, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria, di cui al comma 1 dell'articolo 222 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' elevato da tre a cinque dodicesimi sino alla data del 31 dicembre 2018". ------------- AGGIORNAMENTO (100) La L. 30 dicembre 2018, n. 145 ha disposto (con l'art. 1, comma 906) che "Al fine di agevolare il rispetto dei tempi di pagamento di cui al decreto legislativo 9 ottobre 2002, n. 231, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria, di cui al comma 1 dell'articolo 222 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' elevato da tre a quattro dodicesimi sino alla data del 31 dicembre 2019". ------------- AGGIORNAMENTO (109) La L. 27 dicembre 2019, n. 160 ha disposto (con l'art. 1, comma 555) che "Al fine di agevolare il rispetto dei tempi di pagamento di cui al decreto legislativo 9 ottobre 2002, n. 231, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria, di cui al comma 1 dell'articolo 222 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' elevato da tre a cinque dodicesimi per ciascuno degli anni dal 2020 al 2022". ------------- AGGIORNAMENTO (117) Il D.L. 31 dicembre 2020, n. 183, convertito con modificazioni dalla L. 26 febbraio 2021, n. 21, nel modificare l'art. 1, comma 555 della L. 27 dicembre 2019, n. 160, ha conseguentemente disposto (con l'art. 3, comma 11-bis) che "Per i comuni interamente confinanti con Paesi non appartenenti all'Unione europea, la disposizione di cui all'articolo 1, comma 555, della legge 27 dicembre 2019, n. 160, e' prorogata all'anno 2027 alle medesime condizioni di cui all'articolo 1, comma 547, della citata legge n. 160 del 2019". --------------- AGGIORNAMENTO (136) La L. 27 dicembre 2019, n. 160, come modificata dalla L. 29 dicembre 2022, n. 197, ha disposto (con l'art. 1, comma 555) che "Al fine di agevolare il rispetto dei tempi di pagamento di cui al decreto legislativo 9 ottobre 2002, n. 231, il limite massimo di ricorso da parte degli enti locali ad anticipazioni di tesoreria, di cui al comma 1 dell'articolo 222 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' elevato da tre a cinque dodicesimi per ciascuno degli anni dal 2020 al 2025".

## Adempimenti e verifiche contabili

### Articolo 223 - Verifiche ordinarie di cassa

1. L'organo di revisione economico-finanziaria dell'ente provvede con cadenza trimestrale alla verifica ordinaria di cassa, alla verifica della gestione del servizio di tesoreria e di quello degli altri agenti contabili di cui all'articolo 233.

2. Il regolamento di contabilita' puo' prevedere autonome verifiche di cassa da parte dell'amministrazione dell'ente.

### Articolo 224 - Verifiche straordinarie di cassa

1. Si provvede a verifica straordinaria di cassa a seguito del mutamento della persona del sindaco, del presidente della provincia, del sindaco metropolitano e del presidente della comunita' montana. Alle operazioni di verifica intervengono gli amministratori che cessano dalla carica e coloro che la assumono, nonche' il segretario, il responsabile del servizio finanziario e l'organo di revisione dell'ente.

((1-bis. Il regolamento di contabilita' dell'ente disciplina le modalita' di svolgimento della verifica straordinaria di cassa.))

((83))

------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 225 - Obblighi di documentazione e conservazione

1. Il tesoriere e' tenuto, nel corso dell'esercizio, ai seguenti adempimenti:

- a) aggiornamento e conservazione del giornale di cassa;
- b) conservazione del verbale di verifica di cassa di cui agli articoli 223 e 224;
- c) conservazione (( per almeno cinque anni)) delle rilevazioni ((...)) di cassa previste dalla legge. ((83))

2. Le modalita' e la periodicita' di trasmissione della documentazione di cui al comma 1 sono fissate nella convenzione.

------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 226. - Conto del tesoriere

1. Entro il termine di 30 giorni dalla chiusura dell'esercizio finanziario, il tesoriere, ai sensi dell'articolo 93, rende all'ente locale il conto della propria gestione di cassa il quale lo trasmette alla competente sezione giurisdizionale della Corte dei conti entro 60 giorni dall'approvazione del rendiconto.

2. Il conto del tesoriere e' redatto su modello di cui all'allegato n. 17 al decreto legislativo 23 giugno 2011, n. 118. Il tesoriere allega al conto la seguente documentazione: (83)

- a) ((LETTERA ABROGATA DAL D.L. 26 OTTOBRE 2019, N. 124, CONVERTITO CON MODIFICAZIONI DALLA L. 19 DICEMBRE 2019, N. 157));
- b) gli ordinativi di riscossione e di pagamento;
- c) la parte delle quietanze originali rilasciate a fronte degli ordinativi di riscossione e di pagamento o, in sostituzione, i documenti informatici contenenti gli estremi delle medesime. (83)
- d) eventuali altri documenti richiesti dalla Corte dei conti.

------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

## RILEVAZIONE E DIMOSTRAZIONE DEI RISULTATI DI GESTIONE

### Art. 227. - Rendiconto della gestione

1. La dimostrazione dei risultati di gestione avviene mediante il rendiconto della gestione, il quale comprende il conto del bilancio, il conto economico e lo stato patrimoniale. (83)

2. Il rendiconto della gestione e' deliberato entro il 30 aprile dell'anno successivo dall'organo consiliare, tenuto motivatamente conto della relazione dell'organo di revisione. La proposta e' messa a disposizione dei componenti dell'organo consiliare prima dell'inizio della sessione consiliare in cui viene esaminato il rendiconto entro un termine, non inferiore a venti giorni, stabilito dal regolamento di contabilita'. (83) ((95))

2-bis. In caso di mancata approvazione del rendiconto di gestione entro il termine del 30 aprile dell'anno successivo, si applica la procedura prevista dal comma 2 dell'articolo 141. ((95))

2-ter. Contestualmente al rendiconto, l'ente approva il rendiconto consolidato, comprensivo dei risultati degli eventuali organismi strumentali secondo le modalita' previste dall'art. 11, commi 8 e 9, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. (83)

3. Nelle more dell'adozione della contabilita' economico-patrimoniale, gli enti locali con popolazione inferiore a 5.000 abitanti che si avvalgono della facolta', prevista dall'art. 232, non predispongono il conto economico, lo stato patrimoniale e il bilancio consolidato. (83)

4. Ai fini del referto di cui all'articolo 3, commi 4 e 7, della legge 14 gennaio 1994, n. 20, e del consolidamento dei conti pubblici, la Sezione enti locali potra' richiedere i rendiconti di tutti gli altri enti locali.

5. Al rendiconto della gestione sono allegati i documenti previsti dall'art. 11 comma 4 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, ed i seguenti documenti:

- a) l'elenco degli indirizzi internet di pubblicazione del rendiconto della gestione, del bilancio consolidato deliberati e relativi al penultimo esercizio antecedente quello cui si riferisce il bilancio di previsione, dei rendiconti e dei bilanci consolidati delle unioni di comuni di cui il comune fa parte e dei soggetti considerati nel gruppo "amministrazione pubblica" di cui al principio applicato del bilancio consolidato allegato al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, relativi al penultimo esercizio antecedente quello cui il bilancio si riferisce. Tali documenti contabili sono allegati al rendiconto della gestione qualora non integralmente pubblicati nei siti internet indicati nell'elenco;
- b) la tabella dei parametri di riscontro della situazione di deficitarieta' strutturale;
- c) il piano degli indicatori e dei risultati di bilancio. (83)

6. Gli enti locali di cui all'articolo 2 inviano telematicamente alle Sezioni enti locali il rendiconto completo di allegati, le informazioni relative al rispetto del patto di stabilita' interno, nonche' i certificati del conto preventivo e consuntivo. Tempi, modalita' e protocollo di comunicazione per la trasmissione telematica dei dati sono stabiliti con decreto di natura non regolamentare del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, sentite la Conferenza Stato, citta' e autonomie locali e la Corte dei conti.

6-bis. Nel sito internet dell'ente, nella sezione dedicata ai bilanci, e' pubblicata la versione integrale del rendiconto della gestione, comprensivo anche della gestione in capitoli, dell'eventuale rendiconto consolidato, comprensivo della gestione in capitoli ed una versione semplificata per il cittadino di entrambi i documenti. (83)

6-ter. I modelli relativi alla resa del conto da parte degli agenti contabili sono quelli previsti dal decreto del Presidente della Repubblica 31 gennaio 1996, n. 194. Tali modelli sono aggiornati con le procedure previste per l'aggiornamento degli allegati al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. (83)

6-quater. Contestualmente all'approvazione del rendiconto, la giunta adegua, ove necessario, i residui, le previsioni di cassa e quelle riguardanti il fondo pluriennale vincolato alle risultanze del rendiconto, fermo restando quanto previsto dall'art. 188, comma 1, in caso di disavanzo di amministrazione. (83) (77)

------------- AGGIORNAMENTO (77) La L. 27 dicembre 2013, n. 147 come modificata dal D.L. 6 marzo 2014, n. 16, convertito con modificazioni dalla L. 2 maggio 2014, n. 68, ha disposto (con l'art. 1, comma 729-quater) che "In conseguenza delle variazioni relative all'annualita' 2013, di cui al comma 729-ter, per i soli comuni interessati , il termine previsto dall'articolo 227, del decreto legislativo n. 267 del 2000 e' differito al 30 giugno 2014". ------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi". -------------- AGGIORNAMENTO (95) Il D.L. 24 aprile 2017, n. 50, convertito con modificazioni dalla L. 21 giugno 2017, n. 96, ha disposto (con l'art. 18, comma 3-quater) che "Il conto economico e lo stato patrimoniale previsti dall'articolo 227 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, relativi all'esercizio 2016, possono essere approvati entro il 31 luglio 2017 e trasmessi alla banca dati delle amministrazioni pubbliche entro trenta giorni. Il mancato rispetto di tali termini comporta l'applicazione della procedura di cui all'articolo 141, comma 2, del medesimo testo unico di cui al decreto legislativo n. 267 del 2000, con il termine ordinario di venti giorni ivi previsto, nonche' delle disposizioni dell'articolo 9, comma 1-quinquies, del decreto-legge 24 giugno 2016, n. 113, convertito, con modificazioni, dalla legge 7 agosto 2016, n. 160".

### Articolo 228 - Conto del bilancio

1. Il conto del bilancio dimostra i risultati finali della gestione rispetto alle autorizzazioni contenute nel primo esercizio considerato nel bilancio di previsione. (83)

2. Per ciascuna tipologia di entrata e per ciascun programma di spesa, il conto del bilancio comprende, distintamente per residui e competenza: (83)

- a) per l'entrata le somme accertate, con distinzione della parte riscossa e di quella ancora da riscuotere;
- b) per la spesa le somme impegnate, con distinzione della parte pagata e di quella ancora da pagare e di quella impegnata con imputazione agli esercizi successivi rappresentata dal fondo pluriennale vincolato. (83)

3. Prima dell'inserimento nel conto del bilancio dei residui attivi e passivi l'ente locale provvede all'operazione di riaccertamento degli stessi, consistente nella revisione delle ragioni del mantenimento in tutto od in parte dei residui e della corretta imputazione in bilancio, secondo le modalita' di cui all'art. 3, comma 4, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. (83)

4. Il conto del bilancio si conclude con la dimostrazione del risultato della gestione di competenza e della gestione di cassa e del risultato di amministrazione alla fine dell'esercizio. (83)

5. Al rendiconto sono allegati la tabella dei parametri di riscontro della situazione di deficitarieta' strutturale ed il piano degli indicatori e dei risultati di bilancio. ((PERIODO SOPPRESSO DAL D.L. 26 OTTOBRE 2019, N. 124)). (83)

6. Ulteriori parametri di efficacia ed efficienza contenenti indicazioni uniformi possono essere individuati dal regolamento di contabilita' dell'ente locale.

7. Il Ministero dell'interno pubblica un rapporto annuale, con rilevazione dell'andamento triennale a livello di aggregati, riguardante parametri contenuti nella apposita tabella di cui al comma 5. I parametri a livello aggregato risultanti dal rapporto sono resi disponibili mediante pubblicazione nel sito internet del Ministero dell'interno. (83)

8. I modelli relativi al conto del bilancio sono predisposti secondo lo schema di cui all'allegato n. 10 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. (83)

------------ AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 229 - Conto economico

1. Il conto economico evidenzia i componenti positivi e negativi della gestione di competenza economica dell'esercizio considerato, rilevati dalla contabilita' economico-patrimoniale ,nel rispetto del principio contabile generale n. 17 e dei principi applicati della contabilita' economico-patrimoniale di cui all'allegato n. 1 e n. 10 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, e rileva il risultato economico dell'esercizio. (83)

2. Il conto economico e' redatto secondo lo schema di cui all'allegato n. 10 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. (83)

3. ((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

4. ((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

5. ((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

6. ((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)). 7.((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)). 8. Il regolamento di contabilita' puo' prevedere la compilazione di conti economici di dettaglio per servizi o per centri di costo. 9. ((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)). 10. ((COMMA ABROGATO DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 230 - Lo stato patrimoniale e conti patrimoniali speciali

1. Lo stato patrimoniale rappresenta i risultati della gestione patrimoniale e la consistenza del patrimonio al termine dell'esercizio ed e' predisposto nel rispetto del principio contabile generale n. 17 e dei principi applicati della contabilita' economico-patrimoniale di cui all'allegato n. 1 e n. 4/3 al decreto legislativo 23 giugno 2011, n. 118, ((e successive modificazioni.)) (83)

2. Il patrimonio degli enti locali e' costituito dal complesso dei beni e dei rapporti giuridici, attivi e passivi, di pertinenza di ciascun ente. Attraverso la rappresentazione contabile del patrimonio e' determinata la consistenza netta della dotazione patrimoniale. (83)

3. Gli enti locali includono nello stato patrimoniale i beni del demanio, con specifica distinzione, ferme restando le caratteristiche proprie, in relazione alle disposizioni del codice civile. (83)

4. Gli enti locali valutano i beni del demanio e del patrimonio, comprensivi delle relative manutenzioni straordinarie, secondo le modalita' previste dal principio applicato della contabilita' economico-patrimoniale di cui all'allegato n. 4/3 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. (83)

- a) LETTERA SOPPRESSA DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126; (83)
- b) LETTERA SOPPRESSA DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126; (83)
- c) LETTERA SOPPRESSA DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126; (83)
- d) LETTERA SOPPRESSA DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126; (83)
- e) LETTERA SOPPRESSA DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126; (83)
- f) LETTERA SOPPRESSA DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126; (83)
- g) LETTERA SOPPRESSA DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126; (83)
- h) LETTERA SOPPRESSA DAL D.LGS. 23 GIUGNO 2011, N. 118, COME MODIFICATO DAL D.LGS. 10 AGOSTO 2014, N. 126; (83)

5. Lo stato patrimoniale comprende anche i crediti inesigibili, stralciati dal conto del bilancio, sino al compimento dei termini di prescrizione. Al rendiconto della gestione e' allegato l'elenco di tali crediti distintamente rispetto a quello dei residui attivi. (83)

6. Il regolamento di contabilita' puo' prevedere la compilazione di conti patrimoniali di inizio e fine mandato degli amministratori. (83)

7. Gli enti locali provvedono annualmente all'aggiornamento degli inventari.

8. Il regolamento di contabilita' definisce le categorie di beni mobili non inventariabili in ragione della natura di beni di facile consumo o del modico valore.

9. Lo stato patrimoniale e' redatto secondo lo schema di cui all'allegato n. 4/3 al decreto legislativo 23 giugno 2011, n. 118 e successive modificazioni e integrazioni. (83)

9-bis. Nell'apposita sezione dedicata ai bilanci del sito internet degli enti locali e' pubblicato il rendiconto della gestione, il conto del bilancio articolato per capitoli, e il rendiconto semplificato per il cittadino di cui all'art. 11 del decreto legislativo 23 giugno 2011, n. 118 e successive modificazioni e integrazioni. (83)

------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 231 - (( (La relazione sulla gestione). ))

((1. La relazione sulla gestione e' un documento illustrativo della gestione dell'ente, nonche' dei fatti di rilievo verificatisi dopo la chiusura dell'esercizio, contiene ogni eventuale informazione utile ad una migliore comprensione dei dati contabili, ed e' predisposto secondo le modalita' previste dall'art. 11, comma 6, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.)) ((83))

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 232 - (Contabilita' economico-patrimoniale)

Gli enti locali garantiscono la rilevazione dei fatti gestionali sotto il profilo economico-patrimoniale nel rispetto del principio contabile generale n. 17 della competenza economica e dei principi applicati della contabilita' economico-patrimoniale di cui agli allegati n. 1 e n. 4/3del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. 2. Gli enti locali con popolazione inferiore a 5.000 abitanti possono non tenere la contabilita' economico-patrimoniale ((...)). Gli enti che rinviano la contabilita' economico-patrimoniale con riferimento all'esercizio 2019 allegano al rendiconto 2019 una situazione patrimoniale al 31 dicembre 2019 redatta secondo lo schema di cui all'allegato n. 10 al decreto legislativo 23 giugno 2011, n. 118, e con modalita' semplificate individuate con decreto del Ministero dell'economia e delle finanze, di concerto con il Ministero dell'interno e con la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, da emanare entro il 31 ottobre 2019, anche sulla base delle proposte formulate dalla Commissione per l'armonizzazione degli enti territoriali, istituita ai sensi dell'articolo 3-bis del citato decreto legislativo n. 118 del 2011. ((106)) (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica ", ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi". --------------- AGGIORNAMENTO (106) Il D.L. 26 ottobre 2019, n. 124, convertito con modificazioni dalla L. 19 dicembre 2019, n. 157, ha disposto (con l'art. 57, comma 2-ter, lettera b)) che "al secondo periodo, le parole da: "Gli enti locali" fino a: "31 dicembre 2019" sono sostituite dalle seguenti: "Gli enti locali che optano per la facolta' di cui al primo periodo allegano al rendiconto una situazione patrimoniale al 31 dicembre dell'anno precedente"."

### Art. 233. - Conti degli agenti contabili interni

1. Entro il termine di (( 30 giorni )) dalla chiusura dell'esercizio finanziario, l'economo, il consegnatario di beni e gli altri soggetti di cui all'articolo 93, comma 2, rendono il conto della propria gestione all'ente locale il quale lo trasmette alla competente sezione giurisdizionale della Corte dei conti entro 60 giorni dall'approvazione del rendiconto.

2. Gli agenti contabili, a danaro e a materia, allegano al conto, per quanto di rispettiva competenza:

- a) il provvedimento di legittimazione del contabile alla gestione;
- b) la lista per tipologie di beni;
- c) copia degli inventari tenuti dagli agenti contabili;
- d) la documentazione giustificativa della gestione;
- e) i verbali di passaggio di gestione;
- f) le verifiche ed i discarichi amministrativi e per annullamento, variazioni e simili;
- g) eventuali altri documenti richiesti dalla Corte dei conti.

3. Qualora l'organizzazione dell'ente locale lo consenta i conti e le informazioni relative agli allegati di cui ai precedenti commi sono trasmessi anche attraverso strumenti informatici, con modalita' da definire attraverso appositi protocolli di comunicazione.

4. I conti di cui al comma 1 sono redatti su modello approvato con il regolamento previsto dall'articolo 160.

### Articolo 233-bis - (Il bilancio consolidato)

1. Il bilancio consolidato di gruppo e' predisposto secondo le modalita' previste dal decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.

2. Il bilancio consolidato e' redatto secondo lo schema previsto dall'allegato n. 11 del decreto legislativo 23 giugno 2011. n. 118, e successive modificazioni.

3. Gli enti locali con popolazione inferiore a 5.000 abitanti possono non predisporre il bilancio consolidato ((...)). (83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica ", ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

## REVISIONE ECONONIICO-FINANZIARIA

### Art. 234. - Organo di revisione economico-finanziario

1. I consigli comunali, provinciali e delle citta' metropolitane eleggono con voto limitato a due componenti un collegio di revisori composto da tre membri.

2. I componenti del collegio dei revisori sono scelti:

- a) uno tra gli iscritti al registro dei revisori contabili, il quale svolge le funzioni di presidente del collegio;
- b) uno tra gli iscritti nell'albo dei dottori commercialisti;
- c) uno tra gli iscritti nell'albo dei ragionieri.

3. Nei comuni con popolazione inferiore a 15.000 abitanti, nelle unioni dei comuni ((, salvo quanto previsto dal comma 3-bis,)) e nelle comunita' montane la revisione economico-finanziaria e' affidata ad un solo revisore eletto dal consiglio comunale o dal consiglio dell'unione di comuni o dall'assemblea della comunita' montana a maggioranza assoluta dei membri e scelto tra i soggetti di cui al comma 2.

((3-bis. Nelle unioni di comuni che esercitano in forma associata tutte le funzioni fondamentali dei comuni che ne fanno parte, la revisione economico-finanziaria e' svolta da un collegio di revisori composto da tre membri, che svolge le medesime funzioni anche per i comuni che fanno parte dell'unione))

4. Gli enti locali comunicano ai propri tesorieri i nominativi dei soggetti cui e' affidato l'incarico entro 20 giorni dall'avvenuta esecutivita' della delibera di nomina.

### Articolo 235 - Durata dell'incarico e cause di cessazione

1. L'organo di revisione contabile dura in carica tre anni a decorrere dalla data di esecutivita' della delibera o dalla data di immediata eseguibilita' nell'ipotesi di cui all'articolo 134, comma 3, e ((i suoi componenti non possono svolgere l'incarico per piu' di due volte nello stesso ente locale)). Ove nei collegi si proceda a sostituzione di un singolo componente la durata dell'incarico del nuovo revisore e' limitata al tempo residuo sino alla scadenza del termine triennale, calcolata a decorrere dalla nomina dell'intero collegio. Si applicano le norme relative alla proroga degli organi amministrativi di cui agli articoli 2, 3, comma 1, 4, comma 1, 5, comma 1, e 6 del decreto-legge 16 maggio 1994, n. 293, convertito, con modificazioni, dalla legge 15 luglio 1994, n. 444.

2. Il revisore e' revocabile solo per inadempienza ed in particolare per la mancata presentazione della relazione alla proposta di deliberazione consiliare del rendiconto entro il termine previsto dall'articolo 239, comma 1, lettera d).

3. Il revisore cessa dall'incarico per:

- a) scadenza del mandato;
- b) dimissioni volontarie ((da comunicare con preavviso di almeno quarantacinque giorni e che non sono soggette ad accettazione da parte dell'ente));
- c) impossibilita' derivante da qualsivoglia causa a svolgere l'incarico per un periodo di tempo stabilito dal regolamento dell'ente.

### Articolo 236 - Incompatibilita' ed ineleggibilita' dei revisori

1. Valgono per i revisori le ipotesi di incompatibilita' di cui al primo comma dell'articolo 2399 del codice civile, intendendosi per amministratori i componenti dell'organo esecutivo dell'ente locale.

2. L'incarico di revisione economico-finanziaria non puo' essere esercitato dai componenti degli organi dell'ente locale e da coloro che hanno ricoperto tale incarico nel biennio precedente alla nomina, ((...)) dal segretario e dai dipendenti dell'ente locale presso cui deve essere nominato l'organo di revisione economico-finanziaria e dai dipendenti delle regioni, delle province, delle citta' metropolitane, delle comunita' montane e delle unioni di comuni relativamente agli enti locali compresi nella circoscrizione territoriale di competenza.

3. I componenti degli organi di revisione contabile non possono assumere incarichi o consulenze presso l'ente locale o presso organismi o istituzioni dipendenti o comunque sottoposti al controllo o vigilanza dello stesso.

### Articolo 237 - Funzionamento del collegio dei revisori

1. Il collegio dei revisori e' validamente costituito anche nel caso in cui siano presenti solo due componenti.

2. Il collegio dei revisori redige un verbale delle riunioni, ispezioni, verifiche, determinazioni e decisioni adottate.

### Articolo 238 - Limiti all'affidamento di incarichi

1. Salvo diversa disposizione del regolamento di contabilita' dell'ente locale ciascun revisore non puo' assumere complessivamente piu' di otto incarichi tra i quali non piu' di quattro incarichi in comuni con popolazione inferiore a 5.000 abitanti, non piu' di tre in comuni con popolazione compresa tra i 5.000 ed i 99.999 abitanti e non piu' di uno in comune con popolazione pari o superiore a 100.000 abitanti. Le province sono equiparate ai comuni con popolazione pari o superiore a 100.000 abitanti e le comunita' montane ai comuni con popolazione inferiore a 5.000 abitanti.

2. L'affidamento dell'incarico di revisione e' subordinato alla dichiarazione, resa nelle forme di cui alla legge 4 gennaio 1968, n. 15, e successive modifiche ed integrazioni, con la quale il soggetto attesta il rispetto dei limiti di cui al comma 1.

### Articolo 239 - Funzioni dell'organo di revisione

1. L'organo di revisione svolge le seguenti funzioni:

- a) attivita' di collaborazione con l'organo consiliare secondo le disposizioni dello statuto e del regolamento;
- b) pareri, con le modalita' stabilite dal regolamento, in materia di: 1) strumenti di programmazione economico-finanziaria; 2) proposta di bilancio di previsione verifica degli equilibri e variazioni di bilancio ((escluse quelle attribuite alla competenza della giunta, del responsabile finanziario e dei dirigenti, a meno che il parere dei revisori sia espressamente previsto dalle norme o dai principi contabili, fermo restando la necessita' dell'organo di revisione di verificare, in sede di esame del rendiconto della gestione, dandone conto nella propria relazione, l'esistenza dei presupposti che hanno dato luogo alle variazioni di bilancio approvate nel corso dell'esercizio, comprese quelle approvate nel corso dell'esercizio provvisorio.)); ((83)) 3) modalita' di gestione dei servizi e proposte di costituzione o di partecipazione ad organismi esterni; 4) proposte di ricorso all'indebitamento; 5) proposte di utilizzo di strumenti di finanza innovativa, nel rispetto della disciplina statale vigente in materia; 6) proposte di riconoscimento di debiti fuori bilancio e transazioni; 7) proposte di regolamento di contabilita', economato-provveditorato, patrimonio e di applicazione dei tributi locali;
- c) vigilanza sulla regolarita' contabile, finanziaria ed economica della gestione relativamente all'acquisizione delle entrate, all'effettuazione delle spese, all'attivita' contrattuale, all'amministrazione dei beni, alla completezza della documentazione, agli adempimenti fiscali ed alla tenuta della contabilita'; l'organo di revisione svolge tali funzioni anche con tecniche motivate di campionamento.
- d) relazione sulla proposta di deliberazione consiliare ((di approvazione)) del rendiconto della gestione e sullo schema di rendiconto entro il termine, previsto dal regolamento di contabilita' e comunque non inferiore a 20 giorni decorrente dalla trasmissione della stessa proposta approvata dall'organo esecutivo. La relazione ((dedica un'apposita sezione all'eventuale rendiconto consolidato di cui all'art. 11, commi 8 e 9, e)) contiene l'attestazione sulla corrispondenza del rendiconto alle risultanze della gestione nonche' rilievi, considerazioni e proposte tendenti a conseguire efficienza, produttivita' ed economicita' della gestione; ((83))
- e) referto all'organo consiliare su gravi irregolarita' di gestione con contestuale denuncia ai competenti organi giurisdizionali ove si configurino ipotesi di responsabilita';
- f) verifiche di cassa di cui all'articolo 223.

1-bis. Nei pareri di cui alla lettera b) del comma 1 e' espresso un motivato giudizio di congruita', di coerenza e di attendibilita' contabile delle previsioni di bilancio e dei programmi e progetti, anche tenuto conto dell'attestazione del responsabile del servizio finanziario ai sensi dell'articolo 153, delle variazioni rispetto all'anno precedente, dell'applicazione dei parametri di deficitarieta' strutturale e di ogni altro elemento utile. Nei pareri sono suggerite all'organo consiliare le misure atte ad assicurare l'attendibilita' delle impostazioni. I pareri sono obbligatori. L'organo consiliare e' tenuto ad adottare i provvedimenti conseguenti o a motivare adeguatamente la mancata adozione delle misure proposte dall'organo di revisione.

2. Al fine di garantire l'adempimento delle funzioni di cui al precedente comma, l'organo di revisione ha diritto di accesso agli atti e documenti dell'ente e puo' partecipare all'assemblea dell'organo consiliare per l'approvazione del bilancio di previsione e del rendiconto di gestione. Puo' altresi' partecipare alle altre assemblee dell'organo consiliare e, se previsto dallo statuto dell'ente, alle riunioni dell'organo esecutivo. Per consentire la partecipazione alle predette assemblee all'organo di revisione sono comunicati i relativi ordini del giorno. Inoltre all'organo di revisione sono trasmessi:

- a) da parte della Corte dei conti i rilievi e le decisioni assunti a tutela della sana gestione finanziaria dell'ente;
- b) da parte del responsabile del servizio finanziario le attestazioni di assenza di copertura finanziaria in ordine alle delibere di impegni di spesa.

3. L'organo di revisione e' dotato, a cura dell'ente locale, dei mezzi necessari per lo svolgimento dei propri compiti, secondo quanto stabilito dallo statuto e dai regolamenti.

4. L'organo della revisione puo' incaricare della collaborazione nella propria funzione, sotto la propria responsabilita' uno o piu' soggetti aventi i requisiti di cui all'articolo 234, comma 2. I relativi compensi rimangono a carico dell'organo di revisione.

5. I singoli componenti dell'organo di revisione collegiale hanno diritto di eseguire ispezioni e controlli individuali.

6. Lo statuto dell'ente locale puo' prevedere ampliamenti delle funzioni affidate ai revisori.

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che le presenti modifiche "si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 240 - Responsabilita' dell'organo di revisione

1. I revisori rispondono della veridicita' delle loro attestazioni e adempiono ai loro doveri con la diligenza del mandatario. Devono inoltre conservare la riservatezza sui fatti e documenti di cui hanno conoscenza per ragione dei loro ufficio.

### Articolo 241 - Compenso dei revisori

1. Con decreto del Ministro dell'interno, di concerto con il Ministro del tesoro del bilancio e della programmazione economica vengono fissati i limiti massimi del compenso base spettante ai revisori, da aggiornarsi triennalmente. Il compenso base e' determinato in relazione alla classe demografica ed alle spese di funzionamento e di investimento dell'ente locale.

2. Il compenso di cui al comma 1 puo' essere aumentato dall'ente locale fino al limite massimo del 20 per cento in relazione alle ulteriori funzioni assegnate rispetto a quelle indicate nell'articolo 239.

3. Il compenso di cui al comma 1 puo' essere aumentato dall'ente locale quando i revisori esercitano le proprie funzioni anche nei confronti delle istituzioni dell'ente sino al 10 per cento per ogni istituzione e per un massimo complessivo non superiore al 30 per cento.

4. Quando la funzione di revisione economico-finanziaria e' esercitata dal collegio dei revisori il compenso determinato ai sensi de commi 1, 2 e 3 e' aumentato per il presidente del collegio stesso del 50 per cento.

5. Per la determinazione del compenso base di cui al comma 1 spettante al revisore della comunita' montana ed al revisore dell'unione di comuni si fa riferimento, per quanto attiene alla classe demografica, rispettivamente, al comune totalmente montano piu' popoloso facente parte della comunita' stessa ed al comune piu' popoloso facente parte dell'unione.

6. Per la determinazione del compenso base di cui al comma 1 spettante ai revisori della citta' metropolitana si fa riferimento, per quanto attiene alla classe demografica, al comune capoluogo.

((6-bis. L'importo annuo del rimborso delle spese di viaggio e per vitto e alloggio, ove dovuto, ai componenti dell'organo di revisione non puo' essere superiore al 50 per cento del compenso annuo attribuito ai componenti stessi, al netto degli oneri fiscali e contributivi))

7. L'ente locale stabilisce il compenso spettante ai revisori con la stessa delibera di nomina.

## ENTI LOCALI DEFICITARI O DISSESTATI CAPO I Enti locali deficitari: disposizioni generali

### Art. 242. - Individuazione degli enti locali strutturalmente deficitari e relativi controlli

((1. Sono da considerarsi in condizioni strutturalmente deficitarie gli enti locali che presentano gravi ed incontrovertibili condizioni di squilibrio, rilevabili da un apposita tabella, da allegare al rendiconto della gestione, contenente parametri obiettivi dei quali almeno la meta' presentino valori deficitari. Il rendiconto della gestione e' quello relativo al penultimo esercizio precedente quello di riferimento.)) ((58)) ((2. Con decreto del Ministro dell'interno di natura non regolamentare, di concerto con il Ministro dell'economia e delle finanze, sono fissati i parametri obiettivi, nonche' le modalita' per la compilazione della tabella di cui al comma 1. Fino alla fissazione di nuovi parametri si applicano quelli vigenti nell'anno precedente.)) ((58))

3. Le norme di cui al presente capo si applicano a comuni, province e comunita' montane.

------------- AGGIORNAMENTO (58) Il D.L. 10 ottobre 2012, n. 174, convertito con modificazioni dalla L. 7 dicembre 2012, n. 213, ha disposto (con l'art. 3, comma 5) che "La condizione di deficitarieta' strutturale di cui all'articolo 242, del citato Testo unico n. 267 del 2000, come modificato dal comma 1, lettera p), continua ad essere rilevata, per l'anno 2013, dalla tabella allegata al certificato sul rendiconto dell'esercizio 2011".

### Articolo 243 - Controlli per gli enti locali strutturalmente deficitari, enti locali dissestati ed altri enti

1. Gli enti locali strutturalmente deficitari, individuati ai sensi dell'articolo 242, sono soggetti al controllo centrale sulle dotazioni organiche e sulle assunzioni di personale da parie della Commissione per la stabilita' finanziaria degli enti locali. Il controllo e' esercitato prioritariamente in relazione alla verifica sulla compatibilita' finanziaria.

2. Gli enti locali strutturalmente deficitari sono soggetti ai controlli centrali in materia di copertura del costo di alcuni servizi. Tali controlli verificano mediante un'apposita certificazione che:

- a) il costo complessivo della gestione dei servizi a domanda individuale, riferito ai dati della competenza, sia stato coperto con i relativi proventi tariffari e contributi finalizzati in misura non inferiore al 36 per cento, ((a tale fine sono esclusi i costi di gestione degli asili nido));
- b) il costo complessivo della gestione del servizio di acquedotto, riferito ai dati della competenza, sia stato coperto con la relativa tariffa in misura non inferiore all'80 per cento;
- c) il costo complessivo della gestione del servizio di smaltimento dei rifiuti solidi urbani interni ed equiparati, riferito ai dati della competenza, sia stato coperto con la relativa tariffa almeno nella misura prevista dalla legislazione vigente.

3. I costi complessivi di gestione dei servizi di cui al comma 2 devono comunque comprendere gli oneri diretti e indiretti di personale, le spese per l'acquisto di beni e servizi, le spese per i trasferimenti e per gli oneri di ammortamento degli impianti e delle attrezzature. Per le quote di ammortamento si applicano i coefficienti indicati nel decreto del Ministro delle finanze in data 31 dicembre 1988 e successive modifiche o integrazioni. I coefficienti si assumono ridotti del 50 per cento per i beni ammortizzabili acquisiti nell'anno di riferimento. Nei casi in cui detti servizi sono forniti da organismi di gestione degli enti locali, nei costi complessivi di gestione sono considerati gli oneri finanziari dovuti agli enti proprietari di cui all'articolo 44 del decreto del Presidente della Repubblica 4 ottobre 1986, n. 902, da versare dagli organismi di gestione agli enti proprietari entro l'esercizio successivo a quello della riscossione delle tariffe e della erogazione in conto esercizio. I costi complessivi di gestione del servizio di cui al comma 2, lettera c), sono rilevati secondo le disposizioni vigenti in materia.

3-bis. "I contratti di servizio, stipulati dagli enti locali con le societa' controllate, con esclusione di quelle quotate in borsa, devono contenere apposite clausole volte a prevedere, ove si verifichino condizioni di deficitarieta' strutturale, la riduzione delle spese di personale delle societa' medesime, anche in applicazione di quanto previsto dall'articolo 18, comma 2-bis, del decreto-legge n. 112 del 2008, convertito, con modificazioni, dalla legge n. 133 del 2008.

4. Con decreto del Ministro dell'interno, sentita la Conferenza Stato-citta' e autonomie locali, da pubblicare nella Gazzetta Ufficiale, sono determinati i tempi e le modalita' per la presentazione e il controllo della certificazione di cui al comma 2.

5. Alle province ed ai comuni in condizioni strutturalmente deficitarie che, pur essendo a cio' tenuti, non rispettano i livelli minimi di copertura dei costi di gestione di cui al comma 2 o che non danno dimostrazione di tale rispetto trasmettendo la prevista certificazione, e' applicata una sanzione pari all'1 per cento delle entrate correnti risultanti dal rendiconto della gestione del penultimo esercizio finanziario precedente a quello in cui viene rilevato il mancato rispetto dei predetti limiti minimi di copertura. Ove non risulti inviato alla banca dati delle amministrazioni pubbliche di cui all'articolo 13 della legge 31 dicembre 2009, n. 196, il rendiconto della gestione del penultimo anno precedente, si fa riferimento all'ultimo rendiconto presente nella stessa banca dati o, in caso di ulteriore indisponibilita', nella banca dati dei certificati di bilancio del Ministero dell'interno. La sanzione si applica sulle risorse attribuite dal Ministero dell'interno a titolo di trasferimenti erariali e di federalismo fiscale; in caso di incapienza l'ente locale e' tenuto a versare all'entrata del bilancio dello Stato le somme residue.

5-bis. Le disposizioni di cui al comma 5 si applicano a decorrere dalle sanzioni da applicare per il mancato rispetto dei limiti di copertura dei costi di gestione dell'esercizio 2011.

6. Sono soggetti, in via provvisoria, ai controlli centrali di cui al comma 2, sino all'adempimento:

- a) gli enti locali per i quali non sia intervenuta nei termini di legge la deliberazione del rendiconto della gestione;
- b) gli enti locali che non inviino il rendiconto della gestione alla banca dati delle amministrazioni pubbliche entro 30 giorni dal termine previsto per la deliberazione.

7. Gli enti locali che hanno deliberato lo stato di dissesto finanziario sono soggetti, per la durata del risanamento, ai controlli di cui al comma 1, sono tenuti alla presentazione della certificazione di cui al comma 2 e sono tenuti per i servizi a domanda individuale al rispetto, per il medesimo periodo, del livello minimo di copertura dei costi di gestione di cui al comma 2, lettera a).

### Art. 243-bis. - (Procedura di riequilibrio finanziario pluriennale)

1. I comuni e le province per i quali, anche in considerazione delle pronunce delle competenti sezioni regionali della Corte dei conti sui bilanci degli enti, sussistano squilibri strutturali del bilancio in grado di provocare il dissesto finanziario, nel caso in cui le misure di cui agli articoli 193 e 194 non siano sufficienti a superare le condizioni di squilibrio rilevate, possono ricorrere, con deliberazione consiliare alla procedura di riequilibrio finanziario pluriennale prevista dal presente articolo. La predetta procedura non puo' essere iniziata qualora sia decorso il termine assegnato dal prefetto, con lettera notificata ai singoli consiglieri, per la deliberazione del dissesto, di cui all'articolo 6, comma 2, del decreto legislativo 6 settembre 2011, n. 149.

2. La deliberazione di ricorso alla procedura di riequilibrio finanziario pluriennale e' trasmessa, entro 5 giorni dalla data di esecutivita', alla competente sezione regionale della Corte dei conti e al Ministero dell'interno.

3. Il ricorso alla procedura di cui al presente articolo sospende temporaneamente la possibilita' per la Corte dei Conti di assegnare, ai sensi dell'articolo 6, comma 2, del decreto legislativo 6 settembre 2011, n. 149, il termine per l'adozione delle misure correttive di cui al comma 6, lettera a), del presente articolo.

4. Le procedure esecutive intraprese nei confronti dell'ente sono sospese dalla data di deliberazione di ricorso alla procedura di riequilibrio finanziario pluriennale fino alla data di approvazione o di diniego di approvazione del piano di riequilibrio pluriennale di cui all'articolo 243-quater, commi 1 e 3.

5. Il consiglio dell'ente locale, entro il termine perentorio di novanta giorni dalla data di esecutivita' della delibera di cui al comma 1, delibera un piano di riequilibrio finanziario pluriennale di durata compresa tra quattro e venti anni, compreso quello in corso, corredato del parere dell'organo di revisione economico-finanziario. Qualora, in caso di inizio mandato, la delibera di cui al presente comma risulti gia' presentata dalla precedente amministrazione, ordinaria o commissariale, e non risulti ancora intervenuta la delibera della Corte dei conti di approvazione o di diniego di cui all'articolo 243-quater, comma 3, l'amministrazione in carica ha facolta' di rimodulare il piano di riequilibrio, presentando la relativa delibera nei sessanta giorni successivi alla sottoscrizione della relazione di cui all'articolo 4-bis, comma 2, del decreto legislativo 6 settembre 2011, n. 149. (112) (119) ((137))

5-bis. La durata massima del piano di riequilibrio finanziario pluriennale, di cui al primo periodo del comma 5, e' determinata sulla base del rapporto tra le passivita' da ripianare nel medesimo e l'ammontare degli impegni di cui al titolo I della spesa del rendiconto dell'anno precedente a quello di deliberazione del ricorso alla procedura di riequilibrio o dell'ultimo rendiconto approvato, secondo la seguente tabella: Rapporto passivita'/impegni di cui al titolo I Durata massima del piano di riequilibrio finanziario pluriennale Fino al 20 per cento 4 anni Superiore al 20 per cento e fino al 60 per cento 10 anni Superiore al 60 per cento e fino al 100 per cento per i comuni fino a 60.000 abitanti 15 anni Oltre il 60 per cento per i comuni con popolazione superiore a 60.000 abitanti e oltre il 100 per cento per tutti gli altri comuni 20 anni

6. Il piano di riequilibrio finanziario pluriennale deve tenere conto di tutte le misure necessarie a superare le condizioni di squilibrio rilevate e deve, comunque, contenere:

- a) le eventuali misure correttive adottate dall'ente locale in considerazione dei comportamenti difformi dalla sana gestione finanziaria e del mancato rispetto degli obiettivi posti con il patto di stabilita' interno accertati dalla competente sezione regionale della Corte dei conti;
- b) la puntuale ricognizione, con relativa quantificazione, dei fattori di squilibrio rilevati, dell'eventuale disavanzo di amministrazione risultante dall'ultimo rendiconto approvato e di eventuali debiti fuori bilancio;
- c) l'individuazione, con relative quantificazione e previsione dell'anno di effettivo realizzo, di tutte le misure necessarie per ripristinare l'equilibrio strutturale del bilancio, per l'integrale ripiano del disavanzo di amministrazione accertato e per il finanziamento dei debiti fuori bilancio entro il periodo massimo di dieci anni, a partire da quello in corso alla data di accettazione del piano;
- d) l'indicazione, per ciascuno degli anni del piano di riequilibrio, della percentuale di ripiano del disavanzo di amministrazione da assicurare e degli importi previsti o da prevedere nei bilanci annuali e pluriennali per il finanziamento dei debiti fuori bilancio.

7. Ai fini della predisposizione del piano, l'ente e' tenuto ad effettuare una ricognizione di tutti i debiti fuori bilancio riconoscibili ai sensi dell'articolo 194. Per il finanziamento dei debiti fuori bilancio l'ente puo' provvedere anche mediante un piano di rateizzazione, della durata massima pari agli anni del piano di riequilibrio, compreso quello in corso, convenuto con i creditori.

7-bis. Al fine di pianificare la rateizzazione dei pagamenti di cui al comma 7, l'ente locale interessato puo' richiedere all'agente della riscossione una dilazione dei carichi affidati dalle agenzie fiscali e relativi alle annualita' ricomprese nel piano di riequilibrio pluriennale dell'ente. Le rateizzazioni possono avere una durata temporale massima di dieci anni con pagamenti rateali mensili. Alle rateizzazioni concesse si applica la disciplina di cui all'articolo 19, commi 1-quater, 3 e 3-bis, del decreto del Presidente della Repubblica 29 settembre 1973, n. 602. Sono dovuti gli interessi di dilazione di cui all'articolo 21 del citato decreto del Presidente della Repubblica n. 602 del 1973.

7-ter. Le disposizioni del comma 7-bis si applicano anche ai carichi affidati dagli enti gestori di forme di previdenza e assistenza obbligatoria.

7-quater. Le modalita' di applicazione delle disposizioni dei commi 7-bis e 7-ter sono definite con decreto del Ministero dell'economia e delle finanze, di concerto con il Ministero del lavoro e delle politiche sociali, da adottare entro trenta giorni dalla data di entrata in vigore della presente disposizione.

7-quinquies. L'ente locale e' tenuto a rilasciare apposita delegazione di pagamento ai sensi dell'articolo 206 quale garanzia del pagamento delle rate relative ai carichi delle agenzie fiscali e degli enti gestori di forme di previdenza e assistenza obbligatoria di cui ai commi 7-bis e 7-ter.

8. Al fine di assicurare il prefissato graduale riequilibrio finanziario, per tutto il periodo di durata del piano, l'ente:

- a) puo' deliberare le aliquote o tariffe dei tributi locali nella misura massima consentita, anche in deroga ad eventuali limitazioni disposte dalla legislazione vigente;
- b) e' soggetto ai controlli centrali in materia di copertura di costo di alcuni servizi, di cui all'articolo 243, comma 2, ed e' tenuto ad assicurare la copertura dei costi della gestione dei servizi a domanda individuale prevista dalla lettera a) del medesimo articolo 243, comma 2;
- c) e' tenuto ad assicurare, con i proventi della relativa tariffa, la copertura integrale dei costi della gestione del servizio di smaltimento dei rifiuti solidi urbani e del servizio acquedotto;
- d) e' soggetto al controllo sulle dotazioni organiche e sulle assunzioni di personale previsto dall'articolo 243, comma 1;
- e) e' tenuto ad effettuare una revisione straordinaria di tutti i residui attivi e passivi conservati in bilancio, stralciando i residui attivi inesigibili o di dubbia esigibilita' da inserire nel conto del patrimonio fino al compimento dei termini di prescrizione, nonche' una sistematica attivita' di accertamento delle posizioni debitorie aperte con il sistema creditizio e dei procedimenti di realizzazione delle opere pubbliche ad esse sottostanti ed una verifica della consistenza ed integrale ripristino dei fondi delle entrate con vincolo di destinazione;
- f) e' tenuto ad effettuare una rigorosa revisione della spesa con indicazione di precisi obiettivi di riduzione della stessa, nonche' una verifica e relativa valutazione dei costi di tutti i servizi erogati dall'ente e della situazione di tutti gli organismi e delle societa' partecipati e dei relativi costi e oneri comunque a carico del bilancio dell'ente;
- g) puo' procedere all'assunzione di mutui per la copertura di debiti fuori bilancio riferiti a spese di investimento in deroga ai limiti di cui all'articolo 204, comma 1, previsti dalla legislazione vigente, nonche' accedere al Fondo di rotazione per assicurare la stabilita' finanziaria degli enti locali di cui all'articolo 243-ter, a condizione che si sia avvalso della facolta' di deliberare le aliquote o tariffe nella misura massima prevista dalla lettera a), che abbia previsto l'impegno ad alienare i beni patrimoniali disponibili non indispensabili per i fini istituzionali dell'ente e che abbia provveduto alla rideterminazione della dotazione organica ai sensi dell'articolo 259, comma 6, fermo restando che la stessa non puo' essere variata in aumento per la durata del piano di riequilibrio.

9. In caso di accesso al Fondo di rotazione di cui all'articolo 243-ter, l'Ente deve adottare entro il termine dell'esercizio finanziario le seguenti misure di riequilibrio della parte corrente del bilancio:

- a) a decorrere dall'esercizio finanziario successivo, riduzione delle spese di personale, da realizzare in particolare attraverso l'eliminazione dai fondi per il finanziamento della retribuzione accessoria del personale dirigente e di quello del comparto, delle risorse di cui agli articoli 15, comma 5, e 26, comma 3, dei Contratti collettivi nazionali di lavoro del 1° aprile 1999 (comparto) e del 23 dicembre 1999 (dirigenza), per la quota non connessa all'effettivo incremento delle dotazioni organiche;
- b) entro il termine di un quinquennio, riduzione almeno del 10 per cento delle spese per acquisti di beni e prestazioni di servizi di cui al macroaggregato 03 della spesa corrente, finanziate attraverso risorse proprie. Ai fini del computo della percentuale di riduzione, dalla base di calcolo sono esclusi gli stanziamenti destinati: 1) alla copertura dei costi di gestione del servizio di smaltimento dei rifiuti solidi urbani; 2) alla copertura dei costi di gestione del servizio di acquedotto; 3) al servizio di trasporto pubblico locale; 4) al servizio di illuminazione pubblica; 5) al finanziamento delle spese relative all'accoglienza, su disposizione della competente autorita' giudiziaria, di minori in strutture protette in regime di convitto e semiconvitto;
- c) entro il termine di un quinquennio, riduzione almeno del 25 per cento delle spese per trasferimenti di cui al macroaggregato 04 della spesa corrente, finanziate attraverso risorse proprie. Ai fini del computo della percentuale di riduzione, dalla base di calcolo sono escluse le somme relative a trasferimenti destinati ad altri livelli istituzionali, a enti, agenzie o fondazioni lirico-sinfoniche;
- c-bis) ferma restando l'obbligatorieta' delle riduzioni indicate nelle lettere b) e c), l'ente locale ha facolta' di procedere a compensazioni, in valore assoluto e mantenendo la piena equivalenza delle somme, tra importi di spesa corrente, ad eccezione della spesa per il personale e ferme restando le esclusioni di cui alle medesime lettere b) e c) del presente comma. Tali compensazioni sono puntualmente evidenziate nel piano di riequilibrio approvato;
- d) blocco dell'indebitamento, fatto salvo quanto previsto dal primo periodo del comma 8, lettera g), per i soli mutui connessi alla copertura di debiti fuori bilancio pregressi.

9-bis. In deroga al comma 8, lettera g), e al comma 9, lettera d), del presente articolo e all'articolo 243-ter, i comuni che fanno ricorso alla procedura di riequilibrio finanziario pluriennale prevista dal presente articolo possono contrarre mutui, oltre i limiti di cui al comma 1 dell'articolo 204, necessari alla copertura di spese di investimento relative a progetti e interventi che garantiscano l'ottenimento di risparmi di gestione funzionali al raggiungimento degli obiettivi fissati nel piano di riequilibrio finanziario pluriennale, per un importo non superiore alle quote di capitale dei mutui e dei prestiti obbligazionari precedentemente contratti ed emessi, rimborsate nell'esercizio precedente, nonche' alla copertura, anche a titolo di anticipazione, di spese di investimento strettamente funzionali all'ordinato svolgimento di progetti e interventi finanziati in prevalenza con risorse provenienti dall'Unione europea o da amministrazioni ed enti nazionali, pubblici o privati. (92) (130) ((137))

------------- AGGIORNAMENTO (92) Il D.L. 30 dicembre 2016, n. 244, convertito con modificazioni dalla L. 27 febbraio 2017, n. 19, ha disposto (con l'art. 5, comm 11-septies) che "Per gli enti locali che, alla data di entrata in vigore della legge di conversione del presente decreto, pur avendo avviato la procedura di riequilibrio finanziario pluriennale di cui all'articolo 243-bis del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, non abbiano rispettato il termine di cui al primo periodo del comma 5 del medesimo articolo 243-bis ovvero quello di cui articolo 2, comma 5-bis, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, non conseguendo l'accoglimento del piano secondo le modalita' di cui all'articolo 243-quater, comma 3, del citato decreto legislativo 18 agosto 2000, n. 267, il termine per poter deliberare un nuovo piano di riequilibrio finanziario pluriennale, secondo la procedura di cui all'articolo 243-bis del medesimo decreto legislativo 18 agosto 2000, n. 267, e' prorogato al 30 aprile 2017. Non si applica l'ultimo periodo del medesimo articolo 243-bis, comma 1, del decreto legislativo 18 agosto 2000, n. 267". --------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, ha disposto (con l'art, 107, comma 7) che "I termini di cui agli articoli 246 comma 2, 251 comma 1, 259 comma 1, 261 comma 4, 264 comma 1, 243-bis comma 5, 243-quater comma 1, 243-quater comma 2, 243-quater comma 5 del decreto legislativo 18 agosto 2000, n. 267 sono rinviati al 30 giugno 2020". --------------- AGGIORNAMENTO (119) La Corte Costituzionale, con sentenza 9 febbraio - 11 marzo 2021, n. 34 (in G.U. 1ª s.s. 17/03/2021, n. 11), ha dichiarato "l'illegittimita' costituzionale dell'art. 243-bis, comma 5, del decreto legislativo 18 agosto 2000, n. 267 (Testo unico delle leggi sull'ordinamento degli enti locali), nella parte in cui non prevede che, in caso di inizio mandato in pendenza del termine perentorio di cui all'art. 243-bis, comma 5, primo periodo, ove non vi abbia provveduto la precedente amministrazione, quella in carica possa deliberare il piano di riequilibrio finanziario pluriennale, presentando la relativa delibera nei sessanta giorni successivi alla sottoscrizione della relazione di cui all'art. 4-bis, comma 2, del decreto legislativo 6 settembre 2011, n. 149 (Meccanismi sanzionatori e premiali relativi a regioni, province e comuni, a norma degli articoli 2, 17 e 26 della legge 5 maggio 2009, n. 42)". --------------- AGGIORNAMENTO (130) Il D.L. 17 maggio 2022, n. 50, convertito con modificazioni dalla L. 15 luglio 2022, n. 91, ha disposto (con l'art. 43, comm 5-bis) che "I termini di presentazione o riformulazione dei piani di riequilibrio finanziario pluriennale previsti dall'articolo 243-bis del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, nonche' quelli di presentazione dell'ipotesi di bilancio stabilmente riequilibrato, prevista dall'articolo 259 del medesimo testo unico, in corso alla data di entrata in vigore del presente decreto sono prorogati di centoventi giorni per gli enti che abbiano sottoscritto gli accordi di cui al comma 2 del presente articolo e al comma 572 dell'articolo 1 della legge 30 dicembre 2021, n. 234, e fino al 31 dicembre 2022 per gli enti che abbiano presentato le proposte di cui al comma 3 del presente articolo, senza che sia successivamente intervenuta la sottoscrizione dell'accordo. I documenti oggetto della sospensione disposta ai sensi del primo periodo del presente comma tengono conto delle misure previste dall'accordo". --------------- AGGIORNAMENTO (137) Il D.L. 29 dicembre 2022, n. 198, convertito con modificazioni dalla L. 24 febbraio 2023, n. 14, ha disposto (con l'art. 3-quater, comma 1) che "Per gli enti locali che hanno proceduto al rinnovo degli organi elettivi nell'anno 2022, i termini di novanta e sessanta giorni, previsti dall'articolo 243-bis, comma 5, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, sono prorogati al 30 giugno 2023". Il D.L. 17 maggio 2022, n. 50, convertito con modificazioni dalla L. 15 luglio 2022, n. 91, come modificato dal D.L. 29 dicembre 2022, n. 198, convertito con modificazioni dalla L. 24 febbraio 2023, n. 14, ha disposto (con l'art. 43, comma 5-bis) che "I termini di presentazione o riformulazione dei piani di riequilibrio finanziario pluriennale previsti dall'articolo 243-bis del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, nonche' quelli di presentazione dell'ipotesi di bilancio stabilmente riequilibrato, prevista dall'articolo 259 del medesimo testo unico, in corso alla data di entrata in vigore del presente decreto sono prorogati di centoventi giorni per gli enti che abbiano sottoscritto gli accordi di cui al comma 2 del presente articolo e al comma 572 dell'articolo 1 della legge 30 dicembre 2021, n. 234, e fino al 31 marzo 2023 per gli enti che abbiano presentato le proposte di cui al comma 3 del presente articolo, senza che sia successivamente intervenuta la sottoscrizione dell'accordo".

### Art. 243-ter. - (( (Fondo di rotazione per assicurare la stabilita' finanziaria degli enti locali) ))

((

1. Per il risanamento finanziario degli enti locali che hanno deliberato la procedura di riequilibrio finanziario di cui all'articolo 243-bis lo Stato prevede un'anticipazione a valere sul Fondo di rotazione, denominato: "Fondo di rotazione per assicurare la stabilita' finanziaria degli enti locali".

2. Con decreto del Ministero dell'interno, di concerto con il Ministero dell'economia e delle finanze, sentita la Conferenza Stato-citta' ed autonomie locali, da emanare entro il 30 novembre 2012, sono stabiliti i criteri per la determinazione dell'importo massimo dell'anticipazione di cui al comma 1 attribuibile a ciascun ente locale, nonche' le modalita' per la concessione e per la restituzione della stessa in un periodo massimo di 10 anni decorrente dall'anno successivo a quello in cui viene erogata l'anticipazione di cui al comma 1.

3. I criteri per la determinazione dell'anticipazione attribuibile a ciascun ente locale, nei limiti dell'importo massimo fissato in euro 300 per abitante per i comuni e in euro 20 per abitante per le province o per le citta' metropolitane, e della disponibilita' annua del Fondo, devono tenere anche conto:

- a) dell'incremento percentuale delle entrate tributarie ed extratributarie previsto nell'ambito del piano di riequilibrio pluriennale;
- b) della riduzione percentuale delle spese correnti previste nell'ambito del piano di riequilibrio pluriennale.

))

### Art. 243-quater. - (Esame del piano di riequilibrio finanziario pluriennale e controllo sulla relativa attuazione)

1. Entro dieci giorni dalla data della delibera di cui all'articolo 243-bis, comma 5, il piano di riequilibrio finanziario pluriennale e' trasmesso alla competente sezione regionale di controllo della Corte dei conti, nonche' alla Commissione di cui all'articolo 155, la quale, entro il termine di sessanta giorni dalla data di presentazione del piano, svolge la necessaria istruttoria anche sulla base delle Linee guida deliberate dalla sezione delle autonomie della Corte dei conti. All'esito dell'istruttoria, la Commissione redige una relazione finale, con gli eventuali allegati, che e' trasmessa alla sezione regionale di controllo della Corte dei conti.((112))

2. In fase istruttoria, la commissione di cui all'articolo 155 puo' formulare rilievi o richieste istruttorie, cui l'ente e' tenuto a fornire risposta entro trenta giorni. Ai fini dell'espletamento delle funzioni assegnate, la Commissione di cui al comma 1 si avvale, senza diritto a compensi aggiuntivi, gettoni di presenza o rimborsi di spese, di cinque segretari comunali e provinciali in disponibilita', nonche' di cinque unita' di personale, particolarmente esperte in tematiche finanziarie degli enti locali, in posizione di comando o distacco e senza oneri aggiuntivi a carico del bilancio dello Stato.((112))

3. La sezione regionale di controllo della Corte dei Conti, entro il termine di 30 giorni dalla data di ricezione della documentazione di cui al comma 1, delibera sull'approvazione o sul diniego del piano, valutandone la congruenza ai fini del riequilibrio. In caso di approvazione del piano, la Corte dei Conti vigila sull'esecuzione dello stesso, adottando in sede di controllo, effettuato ai sensi dell'articolo 243-bis, comma 6, lettera a), apposita pronuncia.

4. La delibera di accoglimento o di diniego di approvazione del piano di riequilibrio finanziario pluriennale e' comunicata al Ministero dell'interno.

5. La delibera di approvazione o di diniego del piano puo' essere impugnata entro 30 giorni, nelle forme del giudizio ad istanza di parte, innanzi alle Sezioni riunite della Corte dei conti in speciale composizione che si pronunciano, nell'esercizio della propria giurisdizione esclusiva in tema di contabilita' pubblica, ai sensi dell'articolo 103, secondo comma, della Costituzione, entro 30 giorni dal deposito del ricorso. Fino alla scadenza del termine per impugnare e, nel caso di presentazione del ricorso, sino alla relativa decisione, le procedure esecutive intraprese nei confronti dell'ente sono sospese. Le medesime Sezioni riunite si pronunciano in unico grado, nell'esercizio della medesima giurisdizione esclusiva, sui ricorsi avverso i provvedimenti di ammissione al Fondo di rotazione di cui all'articolo 243-ter.((112))

6. Ai fini del controllo dell'attuazione del piano di riequilibrio finanziario pluriennale approvato, l'organo di revisione economico-finanziaria dell'ente trasmette al Ministero dell'interno e alla competente Sezione regionale della Corte dei Conti, entro quindici giorni successivi alla scadenza di ciascun semestre, una relazione sullo stato di attuazione del piano e sul raggiungimento degli obiettivi intermedi fissati dal piano stesso, nonche', entro il 31 gennaio dell'anno successivo all'ultimo di durata del piano, una relazione finale sulla completa attuazione dello stesso e sugli obiettivi di riequilibrio raggiunti.

7. La mancata presentazione del piano entro il termine di cui all'articolo 243-bis, comma 5, il diniego dell'approvazione del piano, l'accertamento da parte della competente Sezione regionale della Corte dei conti di grave e reiterato mancato rispetto degli obiettivi intermedi fissati dal piano, ovvero il mancato raggiungimento del riequilibrio finanziario dell'ente al termine del periodo di durata del piano stesso, comportano l'applicazione dell''articolo 6, comma 2, del decreto legislativo n. 149 del 2011, con l'assegnazione al Consiglio dell'ente, da parte del Prefetto, del termine non superiore a venti giorni per la deliberazione del dissesto. (92)

7-bis. Qualora, durante la fase di attuazione del piano, dovesse emergere, in sede di monitoraggio, un grado di raggiungimento degli obiettivi intermedi superiore rispetto a quello previsto, e' riconosciuta all'ente locale la facolta' di proporre una rimodulazione dello stesso, anche in termini di riduzione della durata del piano medesimo. Tale proposta, corredata del parere positivo dell'organo di revisione economico-finanziaria dell'ente, deve essere presentata direttamente alla competente sezione regionale di controllo della Corte dei conti. Si applicano i commi 3, 4 e 5.

7-ter. In caso di esito positivo della procedura di cui al comma 7-bis, l'ente locale provvede a rimodulare il piano di riequilibrio approvato, in funzione della minore durata dello stesso. Restano in ogni caso fermi gli obblighi posti a carico dell'organo di revisione economico-finanziaria previsti dal comma 6. (97)

------------- AGGIORNAMENTO (92) Il D.L. 30 dicembre 2016, n. 244, convertito con modificazioni dalla L. 27 febbraio 2017, n. 19, ha disposto (con l'art. 5, comm 11-septies) che "Nelle more del termine di cui al primo periodo del presente comma e sino alla conclusione della relativa procedura, non si applica l'articolo 243-quater, comma 7, del decreto legislativo 18 agosto 2000, n. 267, con sospensione delle procedure eventualmente avviate in esecuzione del medesimo". ------------- AGGIORNAMENTO (92) La L. 27 dicembre 2017, n. 205, ha disposto (con l'art. 1, comma 849) che i termini previsti dal presente articolo sono ridotti a meta'. ---------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, ha disposto (con l'art, 107, comma 7) che "I termini di cui agli articoli 246 comma 2, 251 comma 1, 259 comma 1, 261 comma 4, 264 comma 1, 243-bis comma 5, 243-quater comma 1, 243-quater comma 2, 243-quater comma 5 del decreto legislativo 18 agosto 2000, n. 267 sono rinviati al 30 giugno 2020".

### Art. 243-quinquies. - Misure per garantire la stabilita' finanziaria degli enti locali sciolti per fenomeni di infiltrazione e di condizionamento di tipo mafioso).

1. Per la gestione finanziaria degli enti locali sciolti ai sensi dell'articolo 143, per i quali sussistono squilibri strutturali di bilancio, in grado di provocare il dissesto finanziario, la commissione straordinaria per la gestione dell'ente, entro sei mesi dal suo insediamento, puo' richiedere una anticipazione di cassa da destinare alle finalita' di cui al comma 2.((112))

2. L'anticipazione di cui al comma 1, nel limite massimo di euro 200 per abitante, e' destinata esclusivamente al pagamento delle retribuzioni al personale dipendente e ai conseguenti oneri previdenziali, al pagamento delle rate di mutui e di prestiti obbligazionari, nonche' all'espletamento dei servizi locali indispensabili. Le somme a tal fine concesse non sono oggetto di procedure di esecuzione e di espropriazione forzata.

3. L'anticipazione e' concessa con decreto del Ministero dell'interno di concerto con il Ministero dell'economia e delle finanze, nei limiti di 20 milioni di euro annui a valere sulle dotazioni del fondo di rotazione di cui all'articolo 243-ter.

4. Il decreto ministeriale di cui al comma 3 stabilisce altresi' le modalita' per la restituzione dell'anticipazione straordinaria in un periodo massimo di dieci anni a decorrere dall'anno successivo a quello in cui e' erogata l'anticipazione.

---------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, ha disposto (con l'art. 107, comma 9) che "Il termine di cui all'articolo 243-quinquies comma 1 del decreto legislativo 18 agosto 2000, n. 267 e' fissato al 31 dicembre 2020".

### Art. 243-sexies. - (Pagamento di debiti)

1. In considerazione dell'esigenza di dare prioritario impulso all'economia in attuazione dell'articolo 41 della Costituzione, le risorse provenienti dal Fondo di rotazione di cui all'articolo 243-ter del presente testo unico sono destinate esclusivamente al pagamento dei debiti presenti nel piano di riequilibrio finanziario pluriennale di cui all'articolo 243-bis. ((110))

2. Non sono ammessi atti di sequestro o di pignoramento sulle risorse di cui al comma 1.

---------- AGGIORNAMENTO (110) Il D.L. 30 dicembre 2019, n. 162, convertito con modificazioni dalla L. 28 febbraio 2020, n. 8, ha disposto (con l'art. 38, comma 2) che "In deroga al comma 1 dell'articolo 243-sexies del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, le somme anticipate possono essere utilizzate, oltre che per il pagamento di debiti presenti nel piano di riequilibrio pluriennale, anche per il pagamento delle esposizioni eventualmente derivanti dal contenzioso censito nel piano di riequilibrio stesso".

## Enti locali dissestati: disposizioni generali

### Articolo 244 - Dissesto finanziario

1. Si ha stato di dissesto finanziario se l'ente non puo' garantire l'assolvimento delle funzioni e dei servizi indispensabili ovvero esistono nei confronti dell'ente locale crediti liquidi ed esigibili di terzi cui non si possa fare validamente fronte con le modalita' di cui all'articolo 193, nonche' con le modalita' di cui all'articolo 194 per le fattispecie ivi previste.

2. Le norme sul risanamento degli enti locali dissestati si applicano solo a province e comuni.

### Articolo 245 - Soggetti della procedura di risanamento

1. Soggetti della procedura di risanamento sono l'organo straordinario di liquidazione e gli organi istituzionali dell'ente.

2. L'organo straordinario di liquidazione provvede al ripiano dell'indebitamento pregresso con i mezzi consentiti dalla legge.

3. Gli organi istituzionali dell'ente assicurano condizioni stabili di equilibrio della gestione finanziaria rimuovendo le cause strutturali che hanno determinato il dissesto.

### Articolo 246 - Deliberazione di dissesto

1. La deliberazione recante la formale ed esplicita dichiarazione di dissesto finanziario e' adottata dal consiglio dell'ente locale nelle ipotesi di cui all'articolo 244 e valuta le cause che hanno determinato il dissesto. La deliberazione dello stato di dissesto non e' revocabile. Alla stessa e' allegata una dettagliata relazione dell'organo di revisione economico finanziaria che analizza le cause che hanno provocato il dissesto.

2. La deliberazione dello stato di dissesto e' trasmessa, entro 5 giorni dalla data di esecutivita', al Ministero dell'interno ed alla Procura regionale presso la Corte dei conti competente per territorio, unitamente alla relazione dell'organo di revisione. La deliberazione e' pubblicata per estratto nella Gazzetta Ufficiale della Repubblica italiana a cura del Ministero dell'interno unitamente al decreto del Presidente della Repubblica di nomina dell'organo straordinario di liquidazione.((112))

3. L'obbligo di deliberazione dello stato di dissesto si estende, ove ne ricorrano le condizioni, al commissario nominato ai sensi dell'articolo 141, comma 3.

4. Se, per l'esercizio nel corso del quale si rende necessaria la dichiarazione di dissesto, e' stato validamente deliberato il bilancio di previsione, tale atto continua ad esplicare la sua efficacia per l'intero esercizio finanziario, intendendosi operanti per l'ente locale i divieti e gli obblighi previsti dall'articolo 191, comma 5. In tal caso, la deliberazione di dissesto puo' essere validamente adottata, esplicando gli effetti di cui all'articolo 248. Gli ulteriori adempimenti e relativi termini iniziali, propri dell'organo straordinario di liquidazione e del consiglio dell'ente, sono differiti al 1^ gennaio dell'anno successivo a quello in cui e' stato deliberato il dissesto. Ove sia stato gia' approvato il bilancio di previsione per il triennio successivo, il consiglio provvede alla revoca dello stesso.(83)

5. Le disposizioni relative alla valutazione delle cause di dissesto sulla base della dettagliata relazione dell'organo di revisione di cui al comma 1 ed ai conseguenti oneri di trasmissione di cui al comma 2, si applicano solo ai dissesti finanziari deliberati a decorrere dal 25 ottobre 1997.

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi". ---------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, ha disposto (con l'art, 107, comma 7) che "I termini di cui agli articoli 246 comma 2, 251 comma 1, 259 comma 1, 261 comma 4, 264 comma 1, 243-bis comma 5, 243-quater comma 1, 243-quater comma 2, 243-quater comma 5 del decreto legislativo 18 agosto 2000, n. 267 sono rinviati al 30 giugno 2020".

### Articolo 247 - Omissione della deliberazione di dissesto

1. Ove dalle deliberazioni dell'ente, dai bilanci di previsione, dai rendiconti o da altra fonte l'organo regionale di controllo venga a conoscenza dell'eventuale condizione di dissesto, chiede chiarimenti all'ente e motivata relazione all'organo di revisione contabile assegnando un termine, non prorogabile, di trenta giorni.

2. Ove sia ritenuta sussistente l'ipotesi di dissesto l'organo regionale di controllo assegna al consiglio, con lettera notificata ai singoli consiglieri, un termine, non superiore a venti giorni, per la deliberazione del dissesto.

3. Decorso infruttuosamente tale termine l'organo regionale di controllo nomina un commissario ad acta per la deliberazione dello stato di dissesto.

4. Del provvedimento sostitutivo e' data comunicazione al prefetto che inizia la procedura per lo scioglimento del consiglio dell'ente, ai sensi dell'articolo 141.

### Articolo 248 - Conseguenze della dichiarazione di dissesto

1. A seguito della dichiarazione di dissesto, e sino all'emanazione del decreto di cui all'articolo 261, sono sospesi i termini per la deliberazione del bilancio.

2. Dalla data della dichiarazione di dissesto e sino all'approvazione del rendiconto di cui all'articolo 256 non possono essere intraprese o proseguite azioni esecutive nei confronti dell'ente per i debiti che rientrano nella competenza dell'organo straordinario di liquidazione. Le procedure esecutive pendenti alla data della dichiarazione di dissesto, nelle quali sono scaduti i termini per l'opposizione giudiziale da parte dell'ente, o la stessa benche' proposta e' stata rigettata, sono dichiarate estinte d'ufficio dal giudice con inserimento nella massa passiva dell'importo dovuto a titolo di capitale, accessori e spese.

3. I pignoramenti eventualmente eseguiti dopo la deliberazione dello stato di dissesto non vincolano l'ente ed il tesoriere, i quali possono disporre delle somme per i fini dell'ente e le finalita' di legge.

4. Dalla data della deliberazione di dissesto e sino all'approvazione del rendiconto di cui all'articolo 256 i debiti insoluti a tale data e le somme dovute per anticipazioni di cassa gia' erogate non producono piu' interessi ne' sono soggetti a rivalutazione monetaria. Uguale disciplina si applica ai crediti nei confronti dell'ente che rientrano nella competenza dell'organo straordinario di liquidazione a decorrere dal momento della loro liquidita' ed esigibilita'.

5. Fermo restando quanto previsto dall'articolo 1 della legge 14 gennaio 1994, n. 20, gli amministratori che la Corte dei conti ha riconosciuto, ((anche con provvedimento non definitivo)), responsabili di aver contribuito con condotte, dolose o gravemente colpose, sia omissive che commissive, al verificarsi del dissesto finanziario, non possono ricoprire, per un periodo di dieci anni, incarichi di assessore, di revisore dei conti di enti locali e di rappresentante di enti locali presso altri enti, istituzioni ed organismi pubblici e privati. I sindaci e i presidenti di provincia ritenuti responsabili ai sensi del periodo precedente, inoltre, non sono candidabili, per un periodo di dieci anni, alle cariche di sindaco, di presidente di provincia, di presidente di Giunta regionale, nonche' di membro dei consigli comunali, dei consigli provinciali, delle assemblee e dei consigli regionali, del Parlamento e del Parlamento europeo. Non possono altresi' ricoprire per un periodo di tempo di dieci anni la carica di assessore comunale, provinciale o regionale ne' alcuna carica in enti vigilati o partecipati da enti pubblici. Ai medesimi soggetti, ove riconosciuti responsabili, le sezioni giurisdizionali regionali della Corte dei conti irrogano una sanzione pecuniaria pari ad un minimo di cinque e fino ad un massimo di venti volte la retribuzione mensile lorda dovuta al momento di commissione della violazione. Le disposizioni di cui al primo, secondo e terzo periodo del presente comma non si applicano agli amministratori che, nei soli casi in cui la responsabilita' sia attribuita per colpa grave, abbiano adottato un piano di riequilibrio finanziario pluriennale approvato dalla Corte dei conti, ai sensi dell'articolo 243-bis, entro due anni dall'insediamento del loro primo mandato e a seguito di delibera della Corte dei conti ai sensi dell'articolo 148-bis, comma 3, di accertamento di gravi irregolarita' o criticita' relative agli esercizi precedenti l'elezione. ((153))

5-bis. Fermo restando quanto previsto dall'articolo 1 della legge 14 gennaio 1994, n. 20, qualora, a seguito della dichiarazione di dissesto, la Corte dei conti accerti gravi responsabilita' nello svolgimento dell'attivita' del collegio dei revisori, o ritardata o mancata comunicazione, secondo le normative vigenti, delle informazioni, i componenti del collegio riconosciuti responsabili in sede di giudizio della predetta Corte non possono essere nominati nel collegio dei revisori degli enti locali e degli enti ed organismi agli stessi riconducibili fino a dieci anni, in funzione della gravita' accertata. La Corte dei conti trasmette l'esito dell'accertamento anche all'ordine professionale di appartenenza dei revisori per valutazioni inerenti all'eventuale avvio di procedimenti disciplinari, nonche' al Ministero dell'interno per la conseguente sospensione dall'elenco di cui all'articolo 16, comma 25, del decreto-legge 13 agosto 2011, n. 138, convertito, con modificazioni, dalla legge 14 settembre 2011, n. 148. Ai medesimi soggetti, ove ritenuti responsabili, le sezioni giurisdizionali regionali della Corte dei conti irrogano una sanzione pecuniaria pari ad un minimo di cinque e fino ad un massimo di venti volte la retribuzione mensile lorda dovuta al momento di commissione della violazione.

-------------- AGGIORNAMENTO (153) Il D.L. 14 marzo 2025, n. 25, convertito con modificazioni dalla L. 9 maggio 2025, n. 69, ha disposto (con l'art. 8, comma 7-bis) che "Le disposizioni di cui al comma 7 si applicano anche ai giudizi che, alla data di entrata in vigore del presente decreto, non sono stati ancora definiti con sentenza passata in giudicato".

### Articolo 249 - Limiti alla contrazione di nuovi mutui

1. Dalla data di deliberazione di dissesto e sino all'emanazione del decreto di cui all'articolo 261, comma 3, gli enti locali non possono contrarre nuovi mutui, con eccezione dei mutui previsti dall'articolo 255 e dei mutui con oneri a totale carico dello Stato o delle regioni ((, nonche' dei mutui per la copertura, anche a titolo di anticipazione, di spese di investimento strettamente funzionali all'ordinato svolgimento di progetti e interventi finanziati in prevalenza con risorse provenienti dall'Unione europea o da amministrazioni ed enti nazionali, pubblici o privati)).

### Articolo 250 - Gestione del bilancio durante la procedura di risanamento

1. Dalla data di deliberazione del dissesto finanziario e sino alla data di approvazione dell'ipotesi di bilancio riequilibrato di cui all'articolo 261 l'ente locale non puo' impegnare per ciascun intervento somme complessivamente superiori a quelle definitivamente previste nell'ultimo bilancio approvato ((con riferimento all'esercizio in corso,)), comunque nei limiti delle entrate accertate. I relativi pagamenti in conto competenza non possono mensilmente superare un dodicesimo delle rispettive somme impegnabili, con esclusione delle spese non suscettibili di pagamento frazionato in dodicesimi. L'ente applica principi di buona amministrazione al fine di non aggravare la posizione debitoria e mantenere la coerenza con l'ipotesi di bilancio riequilibrato predisposta dallo stesso.((83))

2. Per le spese disposte dalla legge e per quelle relative ai servizi locali indispensabili, nei casi in cui nell'ultimo bilancio approvato mancano del tutto gli stanziamenti ovvero gli stessi sono previsti per importi insufficienti, il consiglio o la giunta con i poteri del primo, salvo ratifica, individua con deliberazione le spese da finanziare, con gli interventi relativi, motiva nel dettaglio le ragioni per le quali mancano o sono insufficienti gli stanziamenti nell'ultimo bilancio approvato e determina le fonti di finanziamento. Sulla base di tali deliberazioni possono essere assunti gli impegni corrispondenti. Le deliberazioni, da sottoporre all'esame dell'organo regionale di controllo, sono notificate al tesoriere.

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Articolo 251 - Attivazione delle entrate proprie

1. Nella prima riunione successiva alla dichiarazione di dissesto e comunque entro trenta giorni dalla data di esecutivita' della delibera il consiglio dell'ente, o il commissario nominato ai sensi dell'articolo 247, comma 1, e' tenuto a deliberare per le imposte e tasse locali di spettanza dell'ente dissestato, diverse dalla tassa per lo smaltimento dei rifiuti solidi urbani, le aliquote e le tariffe di base nella misura massima consentita, nonche' i limiti reddituali, agli effetti dell'applicazione dell'imposta comunale per l'esercizio di imprese, arti e professioni, che determinano gli importi massimi del tributo dovuto.((112))

2. La delibera non e' revocabile ed ha efficacia per cinque anni, che decorrono da quello dell'ipotesi di bilancio riequilibrato. In caso di mancata adozione della delibera nei termini predetti l'organo regionale di controllo procede a norma dell'articolo 136.

3. Per le imposte e tasse locali di istituzione successiva alla deliberazione del dissesto, l'organo dell'ente dissestato che risulta competente ai sensi della legge istitutiva del tributo deve deliberare, entro i termini previsti per la prima applicazione del tributo medesimo, le aliquote e le tariffe di base nella misura massima consentita. La delibera ha efficacia per un numero di anni necessario al raggiungimento di un quinquennio a decorrere da quello dell'ipotesi di bilancio riequilibrato.

4. Resta fermo il potere dell'ente dissestato di deliberare, secondo le competenze, le modalita', i termini ed i limiti stabiliti dalle disposizioni vigenti, le maggiorazioni, riduzioni, graduazioni ed agevolazioni previste per le imposte e tasse di cui ai commi 1 e 3, nonche' di deliberare la maggiore aliquota dell'imposta comunale sugli immobili consentita per straordinarie esigenze di bilancio.

5. Per il periodo di cinque anni, decorrente dall'anno dell'ipotesi di bilancio riequilibrato, ai fini della tassa smaltimento rifiuti solidi urbani, gli enti che hanno dichiarato il dissesto devono applicare misure tariffarie che assicurino complessivamente la copertura integrale dei costi di gestione del servizio e, per i servizi produttivi ed i canoni patrimoniali, devono applicare le tariffe nella misura massima consentita dalle disposizioni vigenti. Per i servizi a domanda individuale il costo di gestione deve essere coperto con proventi tariffari e con contributi finalizzati almeno nella misura prevista dalle norme vigenti. Per i termini di adozione delle delibere, per la loro efficacia e per la individuazione dell'organo competente si applicano le norme ordinarie vigenti in materia. Per la prima delibera il termine di adozione e' fissato al trentesimo giorno successivo alla deliberazione del dissesto.

6. Le delibere di cui ai commi 1, 3 e 5 devono essere comunicate alla Commissione per la stabilita' finanziaria degli enti locali presso il Ministero dell'interno entro 30 giorni dalla data di adozione; nel caso di mancata osservanza delle disposizioni di cui ai predetti commi sono sospesi i contributi erariali.

---------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, ha disposto (con l'art, 107, comma 7) che "I termini di cui agli articoli 246 comma 2, 251 comma 1, 259 comma 1, 261 comma 4, 264 comma 1, 243-bis comma 5, 243-quater comma 1, 243-quater comma 2, 243-quater comma 5 del decreto legislativo 18 agosto 2000, n. 267 sono rinviati al 30 giugno 2020".

## Attivita' dell'organo straordinario di liquidazione

### Articolo 252 - Composizione, nomina e attribuzioni

1. Per i comuni con popolazione sino a 5.000 abitanti l'organo straordinario di liquidazione e' composto da un singolo commissario; per i comuni con popolazione superiore ai 5.000 abitanti e per le province l'organo straordinario di liquidazione e' composto da una commissione di tre membri. Il commissario straordinario di liquidazione, per i comuni sino a 5.000 abitanti, o i componenti della commissione straordinaria di liquidazione, per i comuni con popolazione superiore a 5.000 abitanti e per le province, sono nominati fra magistrati a riposo della Corte dei conti, della magistratura ordinaria, del Consiglio di Stato, fra funzionari dotati di un'idonea esperienza nel campo finanziario e contabile in servizio o in quiescenza degli uffici centrali o periferici del Ministero dell'interno, del Ministero del tesoro, del bilancio e della programmazione economica, del Ministero delle finanze e di altre amministrazioni dello Stato, fra i segretari ed i ragionieri comunali e provinciali particolarmente esperti, anche in quiescenza, fra gli iscritti nel registro dei revisori contabili, gli iscritti nell'albo dei dottori commercialisti e gli iscritti nell'albo dei ragionieri. La commissione straordinaria di liquidazione e' presieduta, se presente, dal magistrato a riposo della Corte dei conti o della magistratura ordinaria o del Consiglio di Stato. Diversamente la stessa provvede ad eleggere nel suo seno il presidente. La commissione straordinaria di liquidazione delibera a maggioranza dei suoi componenti.

2. La nomina dell'organo straordinario di liquidazione e' disposta con decreto del Presidente della Repubblica su proposta del Ministro dell'interno. L'insediamento presso l'ente avviene entro 5 giorni dalla notifica del provvedimento di nomina.

3. Per i componenti dell'organo straordinario di liquidazione valgono le incompatibilita' di cui all'articolo 236.

4. L'organo straordinario di liquidazione ha competenza relativamente a fatti ed atti di gestione verificatisi entro il 31 dicembre dell'anno precedente a quello dell'ipotesi di bilancio riequilibrato e provvede alla:

- a) rilevazione della massa passiva;
- b) acquisizione e gestione dei mezzi finanziari disponibili ai fini del risanamento anche mediante alienazione dei beni patrimoniali;
- c) liquidazione e pagamento della massa passiva.

5. In ogni caso di accertamento di danni cagionati all'ente locale o all'erario, l'organo straordinario di liquidazione provvede alla denuncia dei fatti alla Procura Regionale presso la Corte dei conti ed alla relativa segnalazione al Ministero dell'interno tramite le prefetture.

### Articolo 253 - Poteri organizzatori

1. L'organo straordinario di liquidazione ha potere di accesso a tutti gli atti dell'ente locale, puo' utilizzare il personale ed i mezzi operativi dell'ente locale ed emanare direttive burocratiche.

2. L'ente locale e' tenuto a fornire, a richiesta dell'organo straordinario di liquidazione, idonei locali ed attrezzature nonche' il personale necessario.

3. Organo straordinario di liquidazione puo' auto organizzarsi, e, per motivate esigenze, dotarsi di personale, acquisire consulenze e attrezzature le quali, al termine dell'attivita' di ripiano dei debiti rientrano nel patrimonio dell'ente locale.

((3-bis. L'organo straordinario di liquidazione e' tenuto a richiedere l'apertura di un conto presso la Tesoreria dello Stato, ai sensi dell'articolo 1 della legge 29 ottobre 1984, n. 720))

### Art. 254. - Rilevazione della massa passiva

1. L'organo straordinario di liquidazione provvede all'accertamento della massa passiva mediante la formazione, entro 180 giorni dall'insediamento, di un piano di rilevazione. Il termine e' elevato di ulteriori 180 giorni per i comuni con popolazione superiore a 250.000 abitanti o capoluogo di provincia e per le province.

2. Ai fini della formazione del piano di rilevazione, l'organo straordinario di liquidazione entro 10 giorni dalla data dell'insediamento, da' avviso, mediante affissione all'albo pretorio ed anche a mezzo stampa, dell'avvio della procedura di rilevazione delle passivita' dell'ente locale. Con l'avviso l'organo straordinario di liquidazione invita chiunque ritenga di averne diritto a presentare, entro un termine perentorio di sessanta giorni prorogabile per una sola volta di ulteriori trenta giorni con provvedimento motivato del predetto organo, la domanda in carta libera, corredata da idonea documentazione, atta a dimostrare la sussistenza del debito dell'ente, il relativo importo ed eventuali cause di prelazione, per l'inserimento nel piano di rilevazione.

3. Nel piano di rilevazione della massa passiva sono inclusi;

- a) i debiti di bilancio e fuori bilancio di cui all'articolo 194 verificatisi entro il 31 dicembre dell'anno precedente quello dell'ipotesi di bilancio riequilibrato;
- b) i debiti derivanti dalle procedure esecutive estinte ai sensi dell'articolo 248, comma 2;
- c) i debiti derivanti da transazioni compiute dall'organo straordinario di liquidazione ai sensi del comma 7.

4. L'organo straordinario di liquidazione, ove lo ritenga necessario, richiede all'ente che i responsabili dei servizi competenti per materia attestino che la prestazione e' stata effettivamente resa e che la stessa rientra nell'ambito dell'espletamento di pubbliche funzioni e servizi di competenza dell'ente locale. I responsabili dei servizi attestano altresi' che non e' avvenuto, nemmeno parzialmente, il pagamento del corrispettivo e che il debito non e' caduto in prescrizione alla data della dichiarazione di dissesto. I responsabili dei servizi provvedono entro sessanta giorni dalla richiesta, decorsi i quali l'attestazione si intende resa dagli stessi in senso negativo circa la sussistenza del debito.

5. Sull'inserimento nel piano di rilevazione delle domande di cui al comma 2 e delle posizioni debitorie di cui al comma 3 decide l'organo straordinario di liquidazione con provvedimento da notificare agli istanti al momento dell'approvazione del piano di rilevazione, tenendo conto degli elementi di prova del debito desunti dalla documentazione prodotta dal terzo creditore, da altri atti e dall'eventuale attestazione di cui al comma 4.

6. COMMA ABROGATO DAL D.L. 29 MARZO 2004, N. 80, CONVERTITO CON MODIFICAZIONI DALLA L. 28 MAGGIO 2004, N. 140.

7. L'organo straordinario di liquidazione e' autorizzato a transigere vertenze giudiziali e stragiudiziali relative a debiti rientranti nelle fattispecie di cui al comma 3, inserendo il debito risultante dall'atto di transazione nel piano di rilevazione.

8. In caso di inosservanza del termine di cui al comma 1, di negligenza o di ritardi non giustificati negli adempimenti di competenza, puo' essere disposta la sostituzione di tutti o parte dei componenti dell'organo straordinario della liquidazione. In tali casi, il Ministro dell'interno, previo parere della ((Commissione per la stabilita' finanziaria degli enti locali)), dal quale si prescinde ove non espresso entro trenta giorni dalla richiesta, e sentiti gli interessati, propone al Presidente della Repubblica l'adozione del provvedimento di sostituzione. Il Ministero dell'interno stabilisce con proprio provvedimento il trattamento economico dei commissari sostituiti.

### Art. 255. - Acquisizione e gestione dei mezzi finanziari per il risanamento

1. Nell'ambito dei compiti di cui all'articolo 252, comma 4, lettera b), l'organo straordinario di liquidazione provvede all'accertamento della massa attiva, costituita dal contributo dello Stato di cui al presente articolo, da residui da riscuotere, da ratei di mutuo disponibili in quanto non utilizzati dall'ente, da altre entrate e, se necessari, da proventi derivanti da alienazione di beni del patrimonio disponibile.

2. Per il risanamento dell'ente locale dissestato lo Stato finanzia gli oneri di un mutuo, assunto dall'organo straordinario di liquidazione, in nome e per conto dell'ente, in unica soluzione con la Cassa depositi e prestiti al tasso vigente ed ammortizzato in venti anni, con pagamento diretto di ogni onere finanziario da parte del Ministero dell'interno.

3. L'importo massimo del mutuo finanziato dallo Stato, e' determinato sulla base di una rata di ammortamento pari al contributo statale indicato al comma 4.

4. Detto contributo e' pari a cinque volte un importo composto da una quota fissa, solo per taluni enti, ed una quota per abitante, spettante ad ogni ente. La quota fissa spetta ai comuni con popolazione sino a 999 abitanti per lire 13.000.000, ai comuni con popolazione da 1.000 a 1.999 abitanti per lire 15.000.000, ai comuni con popolazione da 2.000 a 2.999 abitanti per lire 18.000.000, ai comuni con popolazione da 3.000 a 4.999 abitanti per lire 20.000.000, ai comuni con popolazione da 5.000 a 9.999 abitanti per lire 22.000.000 ed ai comuni con popolazione da 10.000 a 19.999 per lire 25.000.000. La quota per abitante e' pari a lire 7.930 per i comuni e lire 1.241 per le province.

5. Il fondo costituito ai sensi del comma 4 e' finalizzato agli interventi a favore degli enti locali in stato di dissesto finanziario. Le eventuali disponibilita' residue del fondo, rinvenienti dall'utilizzazione dei contributi erariali per un importo inferiore ai limiti massimi indicati nel comma 4, possono essere destinate su richiesta motivata dell'organo consiliare dell'ente locale, secondo parametri e modalita' definiti con decreto del Ministro dell'interno, all'assunzione di mutui integrativi per permettere all'ente locale di realizzare il risanamento finanziario, se non raggiunto con l'approvazione del rendiconto della gestione. Il mutuo, da assumere con la Cassa depositi e prestiti, e' autorizzato dal Ministero dell'interno, previo parere della Commissione per la stabilita' finanziaria degli enti locali. La priorita' nell'assegnazione e' accordata agli enti locali che non hanno usufruito dell'intera quota disponibile ai sensi del comma 4.

6. Per l'assunzione del mutuo concesso ai sensi del presente articolo agli enti locali in stato di dissesto finanziario per il ripiano delle posizioni debitorie non si applica il limite all'assunzione dei mutui di cui all'articolo 204, comma 1.

7. Secondo le disposizioni vigenti il fondo per lo sviluppo degli investimenti, di cui all'articolo 28, comma 1, lettera c), del decreto legislativo 30 dicembre 1992, n. 504, sul quale sono imputati gli oneri per la concessione dei nuovi mutui agli enti locali dissestati, puo' essere integrato, con le modalita' di cui all'articolo 11, comma 3, lettera d), della legge 5 agosto 1978, n. 468, e successive modificazioni ed integrazioni, in considerazione delle eventuali procedure di risanamento attivate rispetto a quelle gia' definite.

8. L'organo straordinario di liquidazione provvede a riscuotere i ruoli pregressi emessi dall'ente e non ancora riscossi, totalmente o parzialmente, nonche' all'accertamento delle entrate tributarie per le quali l'ente ha omesso la predisposizione dei ruoli o del titolo di entrata previsto per legge.

9. Ove necessario ai fini del finanziamento della massa passiva, ed in deroga a disposizioni vigenti che attribuiscono specifiche destinazioni ai proventi derivanti da alienazioni di beni, l'organo straordinario di liquidazione procede alla rilevazione dei beni patrimoniali disponibili non indispensabili per i fini dell'ente, avviando, nel contempo, le procedure per l'alienazione di tali beni. Ai fini dell'alienazione dei beni immobili possono essere affidati incarichi a societa' di intermediazione immobiliare, anche appositamente costituite. Si applicano, in quanto compatibili, le disposizioni recate dall'articolo 3 del decreto-legge 31 ottobre 1990, n. 310, convertito, con modificazioni, dalla legge 22 dicembre 1990, n. 403, e successive modificazioni ed integrazioni, intendendosi attribuite all'organo straordinario di liquidazione le facolta' ivi disciplinate. L'ente locale, qualora intenda evitare le alienazioni di beni patrimoniali disponibili, e' tenuto ad assegnare proprie risorse finanziarie liquide, anche con la contrazione di un mutuo passivo, con onere a proprio carico, per il valore stimato di realizzo dei beni. Il mutuo puo' essere assunto con la Cassa depositi e prestiti ed altri istituti di credito. Il limite di cui all'articolo 204, comma 1, e' elevato sino al 40 per cento.

10. Non compete all'organo straordinario di liquidazione l'amministrazione delle anticipazioni di tesoreria di cui ((all'articolo 222, delle anticipazioni di liquidita' previste dal decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successivi rifinanziamenti, e dal decreto-legge 19 maggio 2020, n. 34, convertito, con modificazioni, dalla legge 17 luglio 2020, n. 77, e successivi rifinanziamenti e strumenti finanziari assimilabili, e dei residui)) attivi e passivi relativi ai fondi a gestione vincolata, ai mutui passivi gia' attivati per investimenti, ivi compreso il pagamento delle relative spese, nonche' l'amministrazione dei debiti assistiti dalla garanzia della delegazione di pagamento di cui all'articolo 206. (89)(91)(95)

11. Per il finanziamento delle passivita' l'ente locale puo' destinare quota dell'avanzo di amministrazione non vincolato.

12. Nei confronti della massa attiva determinata ai sensi del presente articolo non sono ammessi sequestri o procedure esecutive. Le procedure esecutive eventualmente intraprese non determinano vincoli sulle somme.

--------------- AGGIORNAMENTO (89) Il D.L. 24 giugno 2016, n. 113, convertito con modificazioni dalla L. 7 agosto 2016, n. 160, ha disposto (con l'art. 2-bis, comma 1) che "In deroga a quanto previsto dall'articolo 255, comma 10, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, per le amministrazioni provinciali in stato di dissesto, l'amministrazione dei residui attivi e passivi relativi ai fondi a gestione vincolata compete all'organo straordinario di liquidazione". --------------- AGGIORNAMENTO (91) La L. 11 dicembre 2016, n. 232 ha disposto (con l'art. 1, comma 457) che "In deroga a quanto previsto dall'articolo 255, comma 10, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, per i comuni in stato di dissesto, l'amministrazione dei residui attivi e passivi relativi ai fondi a gestione vincolata compete all'organo straordinario di liquidazione". --------------- AGGIORNAMENTO (95) Il D.L. 24 aprile 2017, n. 50, convertito con modificazioni dalla L. 21 giugno 2017, n. 96, nel modificare l'art. 1, comma 457 della L. 11 dicembre 2016, n. 232, che a sua volta modifica l'art. 2-bis del D.L. 24 giugno 2016, n. 113, convertito, con modificazioni, dalla L. 7 agosto 2016, n. 160, ha conseguentemente disposto (con l'art. 36, comma 2) che "In deroga a quanto previsto dall'articolo 255, comma 10, del decreto legislativo 18 agosto 2000, n. 267, per i comuni e per le province in stato di dissesto finanziario l'amministrazione dei residui attivi e passivi relativi ai fondi a gestione vincolata compete all'organo straordinario della liquidazione".

### Art. 256. - Liquidazione e pagamento della massa passiva

1. Il piano di rilevazione della massa passiva acquista esecutivita' con il deposito presso il Ministero dell'interno, cui provvede l'organo straordinario di liquidazione entro 5 giorni dall'approvazione di cui all'articolo 254, comma 1. Al piano e' allegato l'elenco delle passivita' non inserite nel piano, corredato dai provvedimenti di diniego e dalla documentazione relativa.

2. Unitamente al deposito l'organo straordinario di liquidazione chiede l'autorizzazione al perfezionamento del mutuo di cui all'articolo 255 nella misura necessaria per il finanziamento delle passivita' risultanti dal piano di rilevazione e dall'elenco delle passivita' non inserite, e comunque entro i limiti massimi stabiliti dall'articolo 255.

3. Il Ministero dell'interno, accertata la regolarita' del deposito, autorizza l'erogazione del mutuo da parte della Cassa depositi e prestiti.

4. Entro 30 giorni dall'erogazione del mutuo l'organo straordinario della liquidazione deve provvedere al pagamento di acconti in misura proporzionale uguale per tutte le passivita' inserite nel piano di rilevazione. Nel determinare l'entita' dell'acconto l'organo di liquidazione deve provvedere ad accantonamenti per le pretese creditorie in contestazione esattamente quantificate. Gli accantonamenti sono effettuati in misura proporzionale uguale a quella delle passivita' inserite nel piano. Ai fini di cui al presente comma l'organo straordinario di liquidazione utilizza il mutuo erogato da parte della Cassa depositi e prestiti e le poste attive effettivamente disponibili, recuperando alla massa attiva disponibile gli importi degli accantonamenti non piu' necessari.

5. Successivamente all'erogazione del primo acconto l'organo straordinario della liquidazione puo' disporre ulteriori acconti per le passivita' gia' inserite nel piano di rilevazione e per quelle accertate successivamente, utilizzando le disponibilita' nuove e residue, ivi compresa l'eventuale quota di mutuo a carico dello Stato ancora disponibile, previa autorizzazione del Ministero dell'interno, in quanto non richiesta ai sensi del comma 2. Nel caso di pagamento definitivo in misura parziale dei debiti l'ente locale e' autorizzato ad assumere un mutuo a proprio carico con la Cassa depositi e prestiti o con altri istituti di credito, nel rispetto del limite del 40 per cento di cui all'articolo 255, comma 9, per il pagamento a saldo delle passivita' rilevate. A tale fine, entro 30 giorni dalla data di notifica del decreto ministeriale di approvazione del piano di estinzione, l'organo consiliare adotta apposita deliberazione, dandone comunicazione all'organo straordinario di liquidazione, che provvede al pagamento delle residue passivita' ad intervenuta erogazione del mutuo contratto dall'ente. La Cassa depositi e prestiti o altri istituti di credito erogano la relativa somma sul conto esistente intestato all'organo di liquidazione.

6. A seguito del definitivo accertamento della massa passiva e dei mezzi finanziari disponibili, di cui all'articolo 255, e comunque entro il termine di 24 mesi dall'insediamento, l'organo straordinario di liquidazione predispone il piano di estinzione delle passivita', includendo le passivita' accertate successivamente all'esecutivita' del piano di rilevazione dei debiti e lo deposita presso il Ministero dell'interno.

7. Il piano di estinzione e' sottoposto all'approvazione, entro 120 giorni dal deposito, del Ministro dell'interno, il quale valuta la correttezza della formazione della massa passiva e la correttezza e validita' delle scelte nell'acquisizione di risorse proprie. Il Ministro dell'interno si avvale del parere consultivo da parte della Commissione per la stabilita' finanziaria degli enti locali, la quale puo' formulare rilievi e richieste istruttorie cui l'organo straordinario di liquidazione e' tenuto a rispondere entro sessanta giorni dalla comunicazione. In tale ipotesi il termine per l'approvazione del piano, di cui al presente comma, e' sospeso.

8. Il decreto di approvazione del piano di estinzione da parte del Ministro dell'interno e' notificato all'ente locale ed all'organo straordinario di liquidazione per il tramite della prefettura.

9. A seguito dell'approvazione del piano di estinzione l'organo straordinario di liquidazione provvede, entro 20 giorni dalla notifica del decreto, al pagamento delle residue passivita' sino alla concorrenza della massa attiva realizzata.

10. Con l'eventuale decreto di diniego dell'approvazione del piano il Ministro dell'interno prescrive all'organo straordinario di liquidazione di presentare, entro l'ulteriore termine di sessanta giorni decorrenti dalla data di notifica del provvedimento, un nuovo piano di estinzione che tenga conto delle prescrizioni contenute nel provvedimento.

11. Entro il termine di sessanta giorni dall'ultimazione delle operazioni di pagamento, l'organo straordinario della liquidazione e' tenuto ad approvare il rendiconto della gestione ed a trasmetterlo all'organo regionale di controllo ed all'organo di revisione contabile dell'ente, il quale e' competente sul riscontro della liquidazione e verifica la rispondenza tra il piano di estinzione e l'effettiva liquidazione.

((11-bis. L'organo straordinario di liquidazione, una volta approvato il rendiconto della gestione, e' tenuto a richiedere la chiusura del conto aperto presso la Tesoreria dello Stato ai sensi dell'articolo 253, comma 3-bis. Nell'ipotesi di rilevata mancata chiusura del conto da parte dell'organismo di liquidazione, il Ministero dell'interno procede, senza ulteriori oneri a carico dello Stato, alla richiesta di chiusura del conto di Tesoreria, con riversamento all'ente delle somme eventualmente residue. Nell'ipotesi in cui tra gli importi riversati all'ente locale siano presenti contributi assegnati dal Ministero dell'interno e non rendicontati, questi ultimi sono destinati dall'ente locale al soddisfacimento dei debiti censiti nel piano di rilevazione della massa passiva di cui all'articolo 254 e non ancora liquidati))

12. Nel caso in cui l'insufficienza della massa attiva, non diversamente rimediabile, e' tale da compromettere il risanamento dell'ente, il Ministro dell'interno, su proposta della Commissione per la stabilita' finanziaria degli enti locali, puo' stabilire misure straordinarie per il pagamento integrale della massa passiva della liquidazione, anche in deroga alle norme vigenti, comunque senza oneri a carico dello Stato. Tra le misure straordinarie e' data la possibilita' all'ente di aderire alla procedura di riequilibrio finanziario pluriennale prevista dall'articolo 243-bis.

### Articolo 257 - Debiti non ammessi alla liquidazione

1. In allegato al provvedimento di approvazione di cui all'articolo 256, comma 8, sono individuate le pretese escluse dalla liquidazione.

2. Il consiglio dell'ente individua con propria delibera, da adottare entro 60 giorni dalla notifica del decreto di cui all'articolo 256, comma 8, i soggetti ritenuti responsabili di debiti esclusi dalla liquidazione, dandone contestuale comunicazione ai soggetti medesimi ed ai relativi creditori. 3 Se il consiglio non provvede nei termini di cui al comma 2 si applicano le disposizioni di cui all'articolo 136.

### Articolo 258 - Modalita' semplificate di accertamento e liquidazione dei debiti

1. L'organo straordinario di liquidazione, valutato l'importo complessivo di tutti i debiti censiti in base alle richieste pervenute, il numero delle pratiche relative, la consistenza della documentazione allegata ed il tempo necessario per il loro definitivo esame, puo' proporre all'ente locale dissestato l'adozione della modalita' semplificata di liquidazione di cui al presente articolo. Con deliberazione di giunta l'ente decide entro trenta giorni ed in caso di adesione s'impegna a mettere a disposizione le risorse finanziare di cui al comma 2.

2. L'organo straordinario di liquidazione, acquisita l'adesione dell'ente locale, delibera l'accensione del mutuo di cui all articolo 255, comma 2, nella misura necessaria agli adempimenti di cui ai successivi commi ed in relazione all'ammontare dei debiti censiti. L'ente locale dissestato e' tenuto a deliberare l'accensione di un mutuo con la Cassa depositi e prestiti o con altri istituti di credito, con oneri a proprio carico, nel rispetto del limite del 40 per cento di cui all'articolo 255, comma 9, o, in alternativa, a mettere a disposizione risorse finanziarie liquide, per un importo che consenta di finanziare, insieme al ricavato del mutuo a carico dello Stato, tutti i debiti di cui al commi 3 e 4, oltre alle spese della liquidazione. E' fatta salva la possibilita' di ridurre il mutuo a carico dell'ente.

3. L'organo straordinario di liquidazione, effettuata una sommaria delibazione sulla fondatezza del credito vantato, puo' definire transattivamente le pretese dei relativi creditori, ((ivi compreso l'erario,)) anche periodicamente, offrendo il pagamento di una somma variabile tra il 40 ed il 60 per cento del debito, in relazione all'anzianita' dello stesso, con rinuncia ad ogni altra pretesa, e con la liquidazione obbligatoria entro 30 giorni dalla conoscenza dell'accettazione della transazione. A tal fine, entro sei mesi dalla data di conseguita disponibilita' del mutuo di cui all'articolo 255, comma 2, propone individualmente ai creditori, compresi quelli che vantano crediti privilegiati, fatta eccezione per i debiti relativi alle retribuzioni per prestazioni di lavoro subordinato che sono liquidate per intero, la transazione da accettare entro un termine prefissato comunque non superiore a 30 giorni. Ricevuta l'accettazione, l'organo straordinario di liquidazione provvede al pagamento nei trenta giorni successivi.

4. L'organo straordinario di liquidazione accantona l'importo del 50 per cento dei debiti per i quali non e' stata accettata la transazione. L'accantonamento e' elevato al 100 per cento per i debiti assistiti da privilegio.

5. Si applicano, per il seguito della procedura, le disposizioni degli articoli precedenti, fatta eccezione per quelle concernenti la redazione ed il deposito del piano di rilevazione. Effettuati gli accantonamenti di cui al comma 4, l'organo straordinario di liquidazione provvede alla redazione del piano di estinzione. Qualora tutti i debiti siano liquidati nell'ambito della procedura semplificata e non sussistono debiti esclusi in tutto o in parte dalla massa passiva, l'organo straordinario provvede ad approvare direttamente il rendiconto della gestione della liquidazione ai sensi dell'articolo 256, comma 11.

6. I debiti transatti ai sensi del comma 3 sono indicati in un apposito elenco allegato al piano di estinzione della massa passiva.

7. In caso di eccedenza di disponibilita' si provvede alla riduzione dei mutui, con priorita' per quello a carico dell'ente locale dissestato. E' restituita all'ente locale dissestato la quota di risorse finanziarie liquide dallo stesso messe a disposizione esuberanti rispetto alle necessita' della liquidazione dopo il pagamento dei debiti.

## Bilancio stabilmente riequilibrato

### Articolo 259 - Ipotesi di bilancio stabilmente riequilibrato

1. Il consiglio dell'ente locale presenta al Ministro dell'interno, entro il termine perentorio di tre mesi dalla data di emanazione del decreto di cui all'articolo 252, un'ipotesi di bilancio di previsione stabilmente riequilibrato.(112)

1-bis. Nei casi in cui la dichiarazione di dissesto sia adottata nel corso del secondo semestre dell'esercizio finanziario per il quale risulta non essere stato ancora validamente deliberato il bilancio di previsione o sia adottata nell'esercizio successivo, il consiglio dell'ente presenta per l'approvazione del Ministro dell'interno, entro il termine di cui al comma 1, un'ipotesi di bilancio che garantisca l'effettivo riequilibrio entro il secondo esercizio.

1-ter. Nel caso in cui il riequilibrio del bilancio sia significativamente condizionato dall'esito delle misure di riduzione di almeno il 20 per cento dei costi dei servizi, nonche' dalla razionalizzazione di tutti gli organismi e societa' partecipati, laddove presenti, i cui costi incidono sul bilancio dell'ente, l'ente puo' raggiungere l'equilibrio, in deroga alle norme vigenti, entro l'esercizio in cui si completano la riorganizzazione dei servizi comunali e la razionalizzazione di tutti gli organismi partecipati, e comunque entro cinque anni, compreso quello in cui e' stato deliberato il dissesto. Fino al raggiungimento dell'equilibrio e per i cinque esercizi successivi, l'organo di revisione economico-finanziaria dell'ente trasmette al Ministero dell'interno, entro 30 giorni dalla scadenza di ciascun esercizio, una relazione sull'efficacia delle misure adottate e sugli obiettivi raggiunti nell'esercizio.

2. L'ipotesi di bilancio realizza il riequilibrio mediante l'attivazione di entrate proprie e la riduzione delle spese correnti.

3. Per l'attivazione delle entrate proprie, l'ente provvede con le modalita' di cui all'articolo 251, riorganizzando anche i servizi relativi all'acquisizione delle entrate ed attivando ogni altro cespite.

4. Le province ed i comuni per i quali le risorse di parte corrente, costituite dai trasferimenti in conto al fondo ordinario ed al fondo consolidato e da quella parte di tributi locali calcolata in detrazione ai trasferimenti erariali, sono disponibili in misura inferiore, rispettivamente, a quella media unica nazionale ed a quella media della fascia demografica di appartenenza, come definita con il decreto di cui all'articolo 263, comma 1, richiedono, con la presentazione dell'ipotesi, e compatibilmente con la quantificazione annua dei contributi a cio' destinati, l'adeguamento dei contributi statali alla media predetta, quale fattore del consolidamento finanziario della gestione.

5. Per la riduzione delle spese correnti l'ente locale riorganizza con criteri di efficienza tutti i servizi, rivedendo le dotazioni finanziarie ed eliminando, o quanto meno riducendo ogni previsione di spesa che non abbia per fine l'esercizio di servizi pubblici indispensabili. L'ente locale emana i provvedimenti necessari per il risanamento economico-finanziario degli enti od organismi dipendenti, nonche' delle aziende speciali, nel rispetto della normativa specifica in materia.

6. L'ente locale, ugualmente ai fini della riduzione delle spese, ridetermina la dotazione organica dichiarando eccedente il personale comunque in servizio in sovrannumero rispetto ai rapporti medi dipendenti-popolazione di cui all'articolo 263, comma 2, fermo restando l'obbligo di accertare le compatibilita' di bilancio. La spesa per il personale a tempo determinato deve altresi' essere ridotta a non oltre il 50 per cento della spesa media sostenuta a tale titolo per l'ultimo triennio antecedente l'anno cui l'ipotesi si riferisce. (97) (98) (101) (105)

7. La rideterminazione della dotazione organica e' sottoposta all'esame della Commissione per la stabilita' finanziaria degli enti locali per l'approvazione.

8. Il mancato rispetto degli adempimenti di cui al comma 6 comporta la denuncia dei fatti alla Procura regionale presso la Corte dei conti da parte del Ministero dell'interno. L'ente locale e' autorizzato ad iscrivere nella parte entrata dell'ipotesi di bilancio un importo pari alla quantificazione del danno subito. E' consentito all'ente il mantenimento dell'importo tra i residui attivi sino alla conclusione del giudizio di responsabilita'.

9. La Cassa depositi e prestiti e gli altri istituti di credito sono autorizzati, su richiesta dell'ente, a consolidare l'esposizione debitoria dell'ente locale, al 31 dicembre precedente, in un ulteriore mutuo decennale, con esclusione delle rate di ammortamento gia' scadute. Conservano validita' i contributi statali e regionali gia' concessi in relazione ai mutui preesistenti.

10. Le regioni a statuto speciale e le province autonome di Trento e di Bolzano, possono porre a proprio carico oneri per la copertura di posti negli enti locali dissestati in aggiunta a quelli di cui alla dotazione organica rideterminata, ove gli oneri predetti siano previsti per tutti gli enti operanti nell'ambito della medesima regione o provincia autonoma.

11. Per le province ed i comuni il termine di cui al comma 1 e' sospeso a seguito di indizione di elezioni amministrative per l'ente, dalla data di indizione dei comizi elettorali e sino all'insediamento dell'organo esecutivo. (130) ((137))

--------------- AGGIORNAMENTO (97) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 752) che "Per assicurare la funzionalita' degli uffici impegnati nelle attivita' connesse alla ricostruzione, i comuni di Lacco Ameno e di Casamicciola Terme possono assumere personale rispettivamente nel limite di 4 e 6 unita', con contratti di lavoro a tempo determinato della durata non superiore a quella della vigenza dello stato di emergenza e comunque nei limiti temporali di cui all'articolo 19 del decreto legislativo 15 giugno 2015, n. 81, in deroga ai vincoli assunzionali di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e di cui all'articolo 1, comma 557, della legge 27 dicembre 2006, n. 296, nonche' in deroga all'articolo 259, comma 6, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267". --------------- AGGIORNAMENTO (98) La L. 27 dicembre 2017, n. 205, come modificata dal D.L. 28 settembre 2018, n. 109, convertito con modificazioni dalla L. 16 novembre 2018, n. 130, ha disposto (con l'art. 1, comma 752) che "Per assicurare la funzionalita' degli uffici impegnati nelle attivita' connesse alla ricostruzione, i comuni di Lacco Ameno e di Casamicciola Terme possono assumere personale rispettivamente nel limite di 4 e 6 unita' per l'anno 2018, e rispettivamente 8 e 12 unita' per gli anni 2019 e 2020, e il Comune di Forio nel limite di 4 unita' per gli anni 2019 e 2020, con contratti di lavoro a tempo determinato nei limiti temporali di cui all'articolo 19 del decreto legislativo 15 giugno 2015, n. 81, in deroga ai vincoli assunzionali di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e di cui all'articolo 1, comma 557, della legge 27 dicembre 2006, n. 296, nonche' in deroga all'articolo 259, comma 6, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267". --------------- AGGIORNAMENTO (101) Il D.L. 18 aprile 2019, n. 32, convertito con modificazioni dalla L. 14 giugno 2019, n. 55, ha disposto (con l'art. 14-bis, comma 1) che "Tenuto conto degli eventi sismici di cui alla delibera del Consiglio dei ministri del 28 dicembre 2018 e del conseguente numero di procedimenti facenti carico ai comuni della citta' metropolitana di Catania indicati nell'allegato 1, gli stessi possono assumere con contratti di lavoro a tempo determinato, in deroga all'articolo 259, comma 6, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, e ai vincoli di contenimento della spesa di personale di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e di cui all'articolo 1, commi 557 e 562, della legge 27 dicembre 2006, n. 296, nel limite di spesa di euro 830.000 per l'anno 2019 e di euro 1.660.000 per l'anno 2020, ulteriori unita' di personale con professionalita' di tipo tecnico o amministrativo-contabile, in particolare fino a 40 unita' complessive per ciascuno degli anni 2019 e 2020". --------------- AGGIORNAMENTO (105) Il D.L. 18 aprile 2019, n. 32, convertito con modificazioni dalla L. 14 giugno 2019, n. 55, come modificato dal D.L. 24 ottobre 2019, n. 123, convertito con modificazioni dalla L. 12 dicembre 2019, n. 156, ha disposto (con l'art. 14-bis, comma 1) che "Tenuto conto degli eventi sismici di cui alla deliberazione del Consiglio dei ministri 28 dicembre 2018, pubblicata nella Gazzetta Ufficiale n. 13 del 16 gennaio 2019, e del conseguente numero di procedimenti gravanti sui comuni della citta' metropolitana di Catania indicati nell'allegato 1, gli stessi possono assumere con contratti di lavoro a tempo determinato, in deroga all'articolo 259, comma 6, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, e ai vincoli di contenimento della spesa di personale di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e di cui all'articolo 1, commi 557 e 562, della legge 27 dicembre 2006, n. 296, nel limite di spesa di euro 830.000 per l'anno 2019, di euro 1.660.000 per l'anno 2020 e di euro 1.660.000 per l'anno 2021, ulteriori unita' di personale con professionalita' di tipo tecnico o amministrativo-contabile fino a 40 unita' complessive per ciascuno degli anni 2020 e 2021". ------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, ha disposto (con l'art, 107, comma 7) che "I termini di cui agli articoli 246 comma 2, 251 comma 1, 259 comma 1, 261 comma 4, 264 comma 1, 243-bis comma 5, 243-quater comma 1, 243-quater comma 2, 243-quater comma 5 del decreto legislativo 18 agosto 2000, n. 267 sono rinviati al 30 giugno 2020". --------------- AGGIORNAMENTO (130) Il D.L. 17 maggio 2022, n. 50, convertito con modificazioni dalla L. 15 luglio 2022, n. 91, ha disposto (con l'art. 43, comm 5-bis) che "I termini di presentazione o riformulazione dei piani di riequilibrio finanziario pluriennale previsti dall'articolo 243-bis del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, nonche' quelli di presentazione dell'ipotesi di bilancio stabilmente riequilibrato, prevista dall'articolo 259 del medesimo testo unico, in corso alla data di entrata in vigore del presente decreto sono prorogati di centoventi giorni per gli enti che abbiano sottoscritto gli accordi di cui al comma 2 del presente articolo e al comma 572 dell'articolo 1 della legge 30 dicembre 2021, n. 234, e fino al 31 dicembre 2022 per gli enti che abbiano presentato le proposte di cui al comma 3 del presente articolo, senza che sia successivamente intervenuta la sottoscrizione dell'accordo. I documenti oggetto della sospensione disposta ai sensi del primo periodo del presente comma tengono conto delle misure previste dall'accordo". --------------- AGGIORNAMENTO (137) Il D.L. 17 maggio 2022, n. 50, convertito con modificazioni dalla L. 15 luglio 2022, n. 91, come modificato dal D.L. 29 febbraio 2022, n. 198, convertito con modificazioni dalla L. 29 febbraio 2023, n. 14 ha disposto (con l'art. 43, comm 5-bis) che "I termini di presentazione o riformulazione dei piani di riequilibrio finanziario pluriennale previsti dall'articolo 243-bis del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, nonche' quelli di presentazione dell'ipotesi di bilancio stabilmente riequilibrato, prevista dall'articolo 259 del medesimo testo unico, in corso alla data di entrata in vigore del presente decreto sono prorogati di centoventi giorni per gli enti che abbiano sottoscritto gli accordi di cui al comma 2 del presente articolo e al comma 572 dell'articolo 1 della legge 30 dicembre 2021, n. 234, e fino al 31 marzo 2023 per gli enti che abbiano presentato le proposte di cui al comma 3 del presente articolo, senza che sia successivamente intervenuta la sottoscrizione dell'accordo".

### Articolo 260 - Collocamento in disponibilita' del personale eccedente

1. I dipendenti dichiarati in eccedenza ai sensi dell'articolo 259, comma 6, sono collocati in disponibilita'. Ad essi si applicano le vigenti disposizioni, cosi' come integrate dai contratti collettivi di lavoro, in tema di eccedenza di personale e di mobilita' collettiva o individuale.

2. Il Ministero dell'interno assegna all'ente locale per il personale posto in disponibilita' un contributo pari alla spesa relativa al trattamento economico con decorrenza dalla data della deliberazione e per tutta la durata della disponibilita'. Analogo contributo, per la durata del rapporto di lavoro, e' corrisposto all'ente locale presso il quale il personale predetto assume servizio.

### Articolo 261 - Istruttoria e decisione sull'ipotesi di bilancio stabilmente riequilibrato

1. L'ipotesi di bilancio di previsione stabilmente riequilibrato e' istruita dalla Commissione per la stabilita' finanziaria degli enti locali, che formula eventuali rilievi o richieste istruttorie, cui l'ente locale fornisce risposta entro sessanta giorni.

2. Entro il termine di quattro mesi la Commissione esprime un parere sulla validita' delle misure disposte dall'ente per consolidare la propria situazione finanziaria e sulla capacita' delle misure stesse di assicurare stabilita' alla gestione finanziaria dell'ente medesimo. La formulazione di rilievi o richieste di cui al comma 1 sospende il decorso del termine.

3. In caso di esito positivo dell'esame la Commissione sottopone l'ipotesi all'approvazione del Ministro dell'interno che vi provvede con proprio decreto, stabilendo prescrizioni per la corretta ed equilibrata gestione dell'ente.

4. In caso di esito negativo dell'esame da parte della Commissione il Ministro dell'interno emana un provvedimento di diniego dell'approvazione, prescrivendo all'ente locale di presentare, previa deliberazione consiliare, entro l'ulteriore termine perentorio di quarantacinque giorni decorrenti dalla data di notifica del provvedimento di diniego, una nuova ipotesi di bilancio idonea a rimuovere le cause che non hanno consentito il parere favorevole. La mancata approvazione della nuova ipotesi di bilancio ha carattere definitivo. ((112))

4-bis. In caso di inizio del mandato, l'ipotesi di bilancio stabilmente riequilibrato gia' trasmessa al Ministero dell'interno dalla precedente amministrazione, ordinaria o commissariale, puo' essere sostituita dalla nuova amministrazione con una nuova ipotesi di bilancio entro tre mesi dall'insediamento degli organi dell'ente.

5. Con il decreto di cui al comma 3 e' disposto l'eventuale adeguamento dei contributi alla media previsto dall'articolo 259, comma 4.

--------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18, ha disposto (con l'art, 107, comma 7) che "I termini di cui agli articoli 246 comma 2, 251 comma 1, 259 comma 1, 261 comma 4, 264 comma 1, 243-bis comma 5, 243-quater comma 1, 243-quater comma 2, 243-quater comma 5 del decreto legislativo 18 agosto 2000, n. 267 sono rinviati al 30 giugno 2020".

### Articolo 262 - Inosservanza degli obblighi relativi all'ipotesi di bilancio stabilmente riequilibrato

1. L'inosservanza del termine per la presentazione dell'ipotesi di bilancio stabilmente riequilibrato o del termine per la risposta ai rilievi ed alle richieste di cui all'articolo 261, comma 1, o del termine di cui all'articolo 261, comma 4, o l'emanazione del provvedimento definitivo di diniego da parte del Ministro dell'interno integrano l'ipotesi di cui all'articolo 141, comma 1, lettera a).

2. Nel caso di emanazione del provvedimento definitivo di diniego di cui all'articolo 261, comma 4, sono attribuiti al commissario i poteri ritenuti necessari per il riequilibrio della gestione, anche in deroga alle norme vigenti, comunque senza oneri a carico dello Stato.

### Articolo 263 - Determinazione delle medie nazionali per classi demografiche delle risorse di parte corrente e della consistenza delle dotazioni organiche

1. Con decreto a cadenza triennale il Ministro dell'interno individua le medie nazionali annue, per classe demografica per i comuni ed uniche per le province, delle risorse di parte corrente di cui all'articolo 259, comma 4.

2. Con decreto a cadenza triennale il Ministro dell'interno individua con proprio decreto la media nazionale per classe demografica della consistenza delle dotazioni organiche per comuni e province ed i rapporti medi dipendenti-popolazione per classe demografica, validi per gli enti in condizione di dissesto ai fini di cui all'articolo 259, comma 6. In ogni caso agli enti spetta un numero di dipendenti non inferiore a quello spettante agli enti di maggiore dimensione della fascia demografica precedente.

## Prescrizioni e limiti conseguenti al risanamento

### Articolo 264 - Deliberazione del bilancio di previsione stabilmente riequilibrato

1. A seguito dell'approvazione ministeriale dell'ipotesi di bilancio l'ente provvede entro 30 giorni alla deliberazione del bilancio dell'esercizio cui l'ipotesi si riferisce.(112)

2. Con il decreto di cui all'articolo 261, comma 3, e' fissato un termine, non superiore a 120 giorni, per la deliberazione di eventuali altri bilanci di previsione o rendiconti non deliberati dall'ente nonche' per la presentazione delle relative certificazioni.(112) ((115))

------------- AGGIORNAMENTO (112) Il D.L. 17 marzo 2020, n. 18 ha disposto (con l'art, 107, comma 7) che "I termini di cui agli articoli 246 comma 2, 251 comma 1, 259 comma 1, 261 comma 4, 264 comma 1, 243-bis comma 5, 243-quater comma 1, 243-quater comma 2, 243-quater comma 5 del decreto legislativo 18 agosto 2000, n. 267 sono rinviati al 30 giugno 2020". Ha inoltre disposto (con l'articolo 107, comma 8) che "Il termine di cui all'articolo 264 comma 2 del decreto legislativo 18 agosto 2000, n. 267 e' fissato al 30 settembre 2020". ------------- AGGIORNAMENTO (115) Il D.L. 17 marzo 2020, n. 18, convertito con modificazioni dalla L. 24 aprile 2020, n. 27, come modificato dal D.L. 14 agosto 2020, n. 104, convertito con modificazioni dalla L. 13 ottobre 2020, n. 126, ha disposto (con l'art. 107, comma 8) che "Il termine di cui all'articolo 264, comma 2, del decreto legislativo 18 agosto 2000, n. 267, e' fissato al 30 novembre 2020".

### Articolo 265 - Durata della procedura di risanamento ed attuazione delle prescrizioni recate dal decreto di approvazione dell'ipotesi di bilancio stabilmente riequilibrato

1. Il risanamento dell'ente locale dissestato ha la durata di cinque anni decorrenti da quello per il quale viene redatta l'ipotesi di bilancio stabilmente riequilibrato. Durante tale periodo e' garantito il mantenimento dei contributi erariali.

2. Le prescrizioni contenute nel decreto di approvazione dell'ipotesi di bilancio sono eseguite dagli amministratori, ordinari o straordinari, dell'ente locale, con l'obbligo di riferire sullo stato di attuazione in un apposito capitolo della relazione sul rendiconto annuale.

3. L'organo della revisione riferisce trimestralmente al consiglio dell'ente ed all'organo regionale di controllo.

4. L'inosservanza delle prescrizioni contenute nel decreto del Ministro dell'interno di cui all'articolo 261, comma 3, comporta la segnalazione dei fatti all'Autorita' giudiziaria per l'accertamento delle ipotesi di reato.

### Articolo 266 - Prescrizioni in materia di investimenti

1. Dall'emanazione del decreto di cui all'articolo 261, comma 3, e per la durata del risanamento come definita dall'articolo 265 gli enti locali dissestati possono procedere all'assunzione di mutui per investimento ed all'emissione di prestiti obbligazionari nelle forme e nei modi consentiti dalla legge.

### Articolo 267 - Prescrizioni sulla dotazione organica

1. Per la durata del risanamento, come definita dall'articolo 265, la dotazione organica rideterminata ai sensi dell'articolo 259 non puo' essere variata in aumento.

### Articolo 268 - Ricostituzione di disavanzo di amministrazione o di debiti fuori bilancio

1. Il ricostituirsi di disavanzo di amministrazione non ripianabile con i mezzi di cui all'articolo 193, o l'insorgenza di debiti fuori bilancio non ripianabili con le modalita' di cui all'articolo 194, o il mancato rispetto delle prescrizioni di cui agli articoli 259, 265, 266 e 267, comportano da parte dell'organo regionale di controllo la segnalazione dei fatti all'Autorita' giudiziaria per l'accertamento delle ipotesi di reato e l'invio degli atti alla Corte dei conti per l'accertamento delle responsabilita' sui fatti di gestione che hanno determinato nuovi squilibri.

2. Nei casi di cui al comma 1 il Ministro dell'interno con proprio decreto, su proposta della ((Commissione per la stabilita' finanziaria degli enti locali)), stabilisce le misure necessarie per il risanamento, anche in deroga alle norme vigenti, comunque senza oneri a carico dello Stato, valutando il ricorso alle forme associative e di collaborazione tra enti locali di cui agli articoli da 30 a 34.

### Art. 268-bis. - (Procedura straordinaria per fronteggiare ulteriori passivita')

1. Nel caso in cui l'organo straordinario di liquidazione non possa concludere entro i termini di legge la procedura del dissesto per l'onerosita' degli adempimenti connessi alla compiuta determinazione della massa attiva e passiva dei debiti pregressi, il Ministro dell'interno, d'intesa con il sindaco dell'ente locale interessato, dispone con proprio decreto una chiusura anticipata e semplificata della procedura del dissesto con riferimento a quanto gia' definito entro il trentesimo giorno precedente il provvedimento. Il provvedimento fissa le modalita' della chiusura, tenuto conto del parere della Commissione per la stabilita' finanziaria degli enti locali.

1-bis. Nel caso in cui l'organo straordinario di liquidazione abbia approvato il rendiconto senza che l'ente possa raggiungere un reale risanamento finanziario, il Ministro dell'interno, d'intesa con il sindaco dell'ente locale interessato, dispone con proprio decreto, sentito il parere della Commissione per la stabilita' finanziaria degli enti locali, la prosecuzione della procedura del dissesto.

2. La prosecuzione della gestione e' affidata ad una apposita commissione, nominata dal Presidente della Repubblica su proposta del Ministro dell'interno, oltre che nei casi di cui al comma 1, anche nella fattispecie prevista dall'articolo 268 ed in quelli in cui la massa attiva sia insufficiente a coprire la massa passiva o venga accertata l'esistenza di ulteriori passivita' pregresse ((, ivi comprese passivita' sopraggiunte derivanti da soccombenza in contenziosi civili giudiziari per fatti riconducibili a periodi precedenti alla dichiarazione di dissesto finanziario, ancorche' conseguenti ad azioni intraprese contro l'ente anche per procedure concorsuali a carico di societa' controllate, in data successiva alla conclusione delle operazioni dell'organismo straordinario di liquidazione di cui all'articolo 252)).

3. La commissione e' composta da tre membri e dura in carica un anno, prorogabile per un altro anno. In casi eccezionali, su richiesta motivata dell'ente, puo' essere consentita una ulteriore proroga di un anno. I componenti sono scelti fra gli iscritti nel registro dei revisori contabili con documentata esperienza nel campo degli enti locali. Uno dei componenti, avente il requisito prescritto, e' proposto dal Ministro dell'interno su designazione del sindaco dell'ente locale interessato.

4. L'attivita' gestionale ed i poteri dell'organo previsto dal comma 2 sono regolati dalla normativa di cui al presente titolo VIII. Il compenso spettante ai commissari e' definito con decreto del Ministro dell'interno ed e' corrisposto con onere a carico della procedura anticipata di cui al comma 1.

5. Ai fini dei commi 1, 1-bis e 2 l'ente locale dissestato accantona apposita somma, considerata spesa eccezionale a carattere straordinario, in ciascuno degli esercizi considerati nel bilancio di previsione. La somma e' resa congrua ogni anno con apposita delibera dell'ente con accantonamenti nei bilanci stessi. I piani di impegno annuale e pluriennale sono sottoposti per il parere alla Commissione per la stabilita' finanziaria degli enti locali e sono approvati con decreto del Ministro dell'interno. Nel caso in cui i piani risultino inidonei a soddisfare i debiti pregressi, il Ministro dell'interno con apposito decreto, su parere della predetta Commissione, dichiara la chiusura del dissesto.(83)

--------------- AGGIORNAMENTO (83) Il D.Lgs. 23 giugno 2011, n. 118, come modificato dal D.Lgs. 10 agosto 2014, n. 126, ha disposto (con l'art. 80, comma 1) che la presente modifica si applica, "ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi".

### Art. 268-ter. - (Effetti del ricorso alla procedura straordinaria di cui all'articolo 268-bis)

1. Per gli enti i quali si avvalgono della procedura straordinaria prevista nell'articolo 268-bis vanno presi in conto, nella prosecuzione della gestione del risanamento, tutti i debiti comunque riferiti ad atti e fatti di gestione avvenuti entro il 31 dicembre dell'anno antecedente all'ipotesi di bilancio riequilibrato, anche se accertati successivamente allo svolgimento della procedura ordinaria di rilevazione della massa passiva. Questi debiti debbono comunque essere soddisfatti con i mezzi indicati nel comma 5 dello stesso articolo 268-bis, nella misura che con la stessa procedura e' definita.

2. Sempre che l'ente si attenga alle disposizioni impartite ai sensi dell'articolo 268-bis, comma 5, non e' consentito procedere all'assegnazione, a seguito di procedure esecutive, di ulteriori somme, maggiori per ciascun anno rispetto a quelle che risultano dall'applicazione del citato comma 5.

3. Fino alla conclusione della procedura prevista nell'articolo 268-bis, comma 5, nelle more della definizione dei provvedimenti previsti nel predetto articolo, per gli enti che si avvalgono di tale procedura o che comunque rientrano nella disciplina del comma 2 del medesimo articolo, non sono ammesse procedure di esecuzione o di espropriazione forzata, a pena di nullita', riferite a debiti risultanti da atti o fatti verificatisi entro il 31 dicembre dell'anno precedente quello dell'ipotesi di bilancio riequilibrato. Il divieto vale fino al compimento della procedura di cui al comma 5 del citato articolo 268-bis e comunque entro i limiti indicati nel decreto del Ministro dell'interno di cui allo stesso articolo 268-bis, comma 5, terzo periodo.

4. E' consentito in via straordinaria agli enti locali gia' dissestati (( . . . )) di accedere alla procedura di cui all'articolo 268-bis ove risulti l'insorgenza di maggiori debiti riferiti ad atti o fatti di gestione avvenuti entro il 31 dicembre dell'anno antecedente a quello del bilancio riequilibrato, tenuto conto anche di interessi, rivalutazioni e spese legali. A tal fine i consigli degli enti interessati formulano al Ministero dell'interno documentata richiesta in cui, su conforme parere del responsabile del servizio finanziario e dell'organo di revisione, e' dato atto del fatto che non sussistono mezzi sufficienti a far fronte all'evenienza. Si applicano in tal caso agli enti locali, oltre alle norme di cui all'articolo 268-bis, quelle contenute nel presente articolo.

### Articolo 269 - Modalita' applicative della procedura di risanamento

1. Le modalita' applicative della procedura di risanamento degli enti locali in stato di dissesto finanziario sono stabilite con regolamento da emanarsi ai sensi dell'articolo 17 della legge 23 agosto 1988, n. 400.

2. Nelle more dell'emanazione del regolamento di cui al comma 1 continuano ad applicarsi, in quanto compatibili, le disposizioni recate dal decreto del Presidente della Repubblica 24 agosto 1991, n. 378.

## Associazioni degli enti locali

### Articolo 270 - Contributi associativi

1. I contributi, stabiliti con delibera dagli organi statutari competenti dell'Anci, dell'Upi, dell'Aiccre, dell'Uncem, della Cispel, delle altre associazioni degli enti locali e delle loro aziende con carattere nazionale che devono essere corrisposti dagli enti associati possono essere riscossi con ruoli, formati ai sensi del decreto legislativo 26 febbraio 1999, n. 46, ed affidati ai concessionari del servizio nazionale di riscossione. Gli enti anzidetti hanno l'obbligo di garantire, sul piano nazionale, adeguate forme di pubblicita' relative alle adesioni e ai loro bilanci annuali.

2. La riscossione avviene mediante ruoli, anche in unica soluzione, su richiesta dei consigli delle associazioni suddette, secondo le modalita' stabilite nel decreto legislativo 26 febbraio 1999, n. 46.

3. Gli enti associati hanno diritto di recedere dalle associazioni entro il 31 ottobre di ogni anno, con conseguente esclusione dai ruoli dal 1^ gennaio dell'anno successivo.

### Articolo 271 - Sedi associative

1. Gli enti locali, le loro aziende e le associazioni dei comuni presso i quali hanno sede sezioni regionali e provinciali dell'Anci, dell'Upi, dell'Aiccre, dell'Uncem, della Cispel e sue federazioni, possono con apposita deliberazione, da adottarsi dal rispettivo consiglio, mettere a disposizione gratuita per tali sedi locali di loro proprieta' ed assumere le relative spese di illuminazione, riscaldamento, telefoniche e postali a carico del proprio bilancio.

2. Gli enti locali, le loro aziende e associazioni dei comuni possono disporre il distacco temporaneo, a tempo pieno o parziale, di propri dipendenti presso gli organismi nazionali e regionali dell'Anci, dell'Upi, dell'Aiccre, dell'Uncem, della Cispel e sue federazioni, ed autorizzarli a prestare la loro collaborazione in favore di tali associazioni. I dipendenti distaccati mantengono la posizione giuridica ed il corrispondente trattamento economico, a cui provvede l'ente di appartenenza. Gli enti di cui sopra possono inoltre autorizzare, a proprie spese, la partecipazione di propri dipendenti a riunioni delle associazioni sopra accennate.

3. Le associazioni di cui al comma 2 non possono utilizzare piu' di dieci dipendenti distaccati dagli enti locali o dalle loro aziende presso le rispettive sedi nazionali e non piu' di tre dipendenti predetti presso ciascuna sezione regionale.

### Articolo 272 - Attivita' delle associazioni nella cooperazione allo sviluppo

1. L'Anci e l'Upi possono essere individuate quali soggetti idonei a realizzare programmi dei Ministero degli affari esteri relativi alla cooperazione dell'Italia con i Paesi in via di sviluppo, di cui alla legge 26 febbraio 1987, n. 49, e successive modificazioni, nonche' ai relativi regolamenti di esecuzione. A tal fine il competente ufficio del Ministero degli affari esteri e' autorizzata a stipulare apposite convenzioni che prevedano uno stanziamento globale da utilizzare per iniziative di cooperazione da attuarsi anche da parte dei singoli associati.

2. I comuni e le province possono destinare un importo non superiore allo 0.80 per cento della somma dei primi tre titoli delle entrate correnti dei propri bilanci di previsione per sostenere programmi di cooperazione allo sviluppo ed interventi di solidarieta' internazionale.

## Disposizioni transitorie ed abrogazioni

### Articolo 273 - Norme transitorie

1. Resta fermo quanto previsto dall'articolo 10, comma 3, e dall'articolo 33 della legge 25 marzo 1993, n. 81, in materia di elezioni dei consigli circoscrizionali e di adeguamento degli statuti, nonche' quanto disposto dall'articolo 51, comma 01, quarto periodo, della legge 8 giugno 1990, n. 142.

2. Resta fermo altresi' quanto previsto dall'articolo 5 1, commi 3- ter e 3- quater, della legge 8 giugno 1990, n. 142, fino all'applicazione della contrattazione decentrata integrativa di cui ai C.C.N.L. per il personale del comparto delle regioni e delle autonomie locali sottoscritti il '31 marzo e il I' aprile 1999 limitamente a quanto gia' attribuito antecedentemente alla stipula di detti contratti.

3. La disposizione di cui all'articolo 5 1, comma 1, del presente testo unico relativa alla durata del mandato ha effetto dal primo rinnovo degli organi successivo alla data di entrata in vigore della legge 30 aprile 1999, n. 120.

4. Fino al completamento delle procedure di revisione dei consorzi e delle altre forme associative, resta fermo il disposto dell'articolo 60 della legge 8 giugno 1990, n. 142, e dell'articolo 5, commi 11-ter e 11-quater, del decreto-legge 28 agosto 1995, n. 361, convertito, con modificazioni, dalla legge 27 ottobre 1995, n. 437.

5. Fino all'entrata in vigore di specifica disposizione in materia, emanata ai sensi dell'articolo 11 della legge 15 marzo 1997, n. 59, resta fermo il disposto dell'articolo 19 del regio decreto marzo 1934, n. 383, per la parte compatibile con l'ordinamento vigente.

6. Le disposizioni degli articoli 125, 127 e 289 del testo unico della - legge comunale e provinciale, approvato con regio decreto 4 febbraio 1915, n. 148, si applicano fino all'adozione delle modifiche statutarie e regolamentari previste dal presente testo unico.

7. Sono fatti salvi gli effetti dei regolamenti del consiglio in materia organizzativa e contabile adottati nel periodo intercorrente tra il 18 maggio 1997 ed il 21 agosto 1999 e non sottoposti al controllo, nonche' degli atti emanati in applicazione di detti regolamenti.

### Articolo 274 - Norme abrogate

1. Sono o restano abrogate le seguenti disposizioni:

- a) regio decreto 3 marzo 1934, n. 383;
- b) articoli 31 e 32 del regio decreto 7 giugno 1943, n. 651;
- c) articoli 2, commi 1, 2 e 3, e 23, commi 2 e 3, della legge 8 marzo 1951, n. 122;
- d) articolo 63 della legge 10 febbraio 1953, n. 62;
- e) articoli 6, 9, 9-bis fatta salva l'applicabilita' delle disposizioni ivi previste agli amministratori regionali ai sensi dell'articolo 19 della legge 17 febbraio 1968, n. 108, 72, commi 3 e 4, e 75 del decreto del Presidente della Repubblica del 16 maggio 1960, n. 570;
- f) legge 13 dicembre 1965, n. 1371;
- g) articolo 6, comma 1, della legge 18 marzo 1968, n. 444;
- h) articolo 6, comma 3, della legge 3 dicembre 1971, n. 1102;
- i) articolo 16, comma 2, del decreto del Presidente della Repubblica 24 luglio 1977, n. 616;
- j) articolo 6, comma 15, del decreto-legge 29 dicembre 1977, n. 946, convertito, con modificazioni, dalla legge 27 febbraio 1978, n. 43;
- k) articolo 4, del decreto-legge 10 novembre 1978, n. 702, convertito, con modificazioni, dalla legge 8 gennaio 1979, n. 3;
- l) legge 23 aprile 1981, n. 154, fatte salve le disposizioni ivi previste per i consiglieri regionali;
- m) articoli 4 e 6 della legge 23 marzo 1981, n. 93;
- n) articolo 15, punto 4.4, limitatamente al primo periodo, articoli 35-bis e 35-ter, del decreto-legge 28 febbraio 1983, n. 55, convertito, con modificazioni, dalla legge 26 aprile 1983, n. 131;
- o) legge 27 dicembre 1985, n. 816;
- p) articoli 15, salvo per quanto riguarda gli amministratori e i componenti degli organi comunque denominati delle aziende sanitarie locali e ospedaliere, i consiglieri regionali, 15-bis e 16 della legge 19 marzo 1990, n. 55;
- q) legge 8 giugno 1990, n. 142;
- r) articolo 13-bis, del decreto-legge 12 gennaio 1991, n. 6, convertito, con modificazioni, dalla legge 15 marzo 1991, n. 80;
- s) articolo 15, del decreto-legge 13 maggio 1991, n. 152, convertito, con modificazioni, dalla legge 12 luglio 1991, n. 203;
- t) decreto-legge 31 maggio 1991, n. 164 convertito, con modificazioni, dalla legge 22 luglio 1991, n. 221;
- u) articolo 2, della legge 11 agosto 1991, n. 271;
- v) articoli 1 e 4 comma 2, della legge 18 gennaio 1992, n. 16;
- w) articolo 12 commi 1, 3, 4, 5, 7 e 8, della legge 23 dicembre 1992, n. 498;
- x) articolo 3, comma 9, del decreto legislativo 30 dicembre 1992, n. 502, limitatamente a quanto riguarda le cariche di consigliere comunale, provinciale, sindaco, assessore comunale, presidente e assessore di comunita' montane;
- y) articoli da 44 a 47, del decreto legislativo 30 dicembre 1992, n. 504;
- z) articoli 8 e 8-bis, del decreto-legge 18 gennaio 1993, n. 8, convertito, con modificazioni, dalla legge 19 marzo 1993, n. 68;
- aa) articolo 36-bis, comma 2, del decreto legislativo 3 febbraio 1993, n. 29;
- bb) articolo 3 del decreto-legge 25 febbraio 1993, n. 42, convertito, con modificazioni, dalla legge 23 aprile 1993, n. 120;
- cc) legge 25 marzo 1993, n. 81, limitatamente agli articoli: 1, 2, 3, comma 5, 5, 6, 7, 7-bis, 8, 9, 10, commi 1 e 2, da 12 a 27 e 31;
- dd) articoli 1 e 7 della legge 15 ottobre 1993, n. 415;
- ee) decreto-legge 20 dicembre 1993, n. 529, convertito dalla legge 11 febbraio 1994, n. 108;
- ff) articoli 1, 2 e 4 della legge 12 gennaio 1994, n. 30;
- gg) articolo 4, commi 2, 3 e 5 del decreto-legge 31 gennaio 1995, n. 26, convertito, con modificazioni, dalla legge 29 marzo 1995, n. 95;
- hh) articoli da 1 a 114 del decreto legislativo 25 febbraio 1995, n. 77;
- ii) articolo 5, commi 8, 8-bis, 8-ter, 9, 9-bis ed 11-bis del decreto-legge 28 agosto 1995, n. 361, convertito, con modificazioni, dalla legge 27 ottobre 1995, n. 437;
- jj) articolo 1, comma 89, ed articolo 3, comma 69, della legge 28 dicembre 1995, n. 549;
- kk) legge 15 maggio 1997, n. 127, limitatamente agli articoli: 4; 5 ad eccezione del comma 7; 6 commi 1, 2, 3, 4, 5, 7, 8, 10, 11 e 12 fatta salva l'applicabilita' delle disposizioni ivi previste per le camere di commercio, industria, artigianato e agricoltura, le aziende sanitarie locali e ospedaliere; 10; 17, commi 8, 9 e 18, secondo periodo, da 33 a 36, 37, nella parte in cui si riferisce al controllo del comitato regionale di controllo, da 38 a 45, 48, da 51 a 59, da 67 a 80 ad eccezione del 79-bis, da 84 a 86;
- ll) articolo 2, commi 12, 13, 15, 16, 29, 30 e 31 della legge 16 giugno 1998, n. 191;
- mm) articolo 4, comma 2, della legge 18 novembre 1998, n. 415;
- nn) articolo 2, comma 1, del decreto-legge 26 gennaio 1999, n. 8, convertito, con modificazioni, dalla legge 25 marzo 1999, n. 75;
- oo) articolo 9, comma 5, della legge 8 marzo 1999, n. 50;
- pp) articoli 2, 7 e 8, commi 4 e 5, della legge 30 aprile 1999, n. 120;
- qq) legge 3 agosto 1999, n. 265, limitatamente agli articoli 1; 2; 3; 4, commi 1 e 3; 5; 6 tranne il comma 8; 7 comma 1; 8; 11 tranne il comma 13; 13, commi 1, 3 e 4; 14; 16; 17, comma 3; 18, commi 1 e 2; 19; 20; 21; 22; 23; 24; 25; 26, commi da 1 a 6; 27; 28, commi 3, 5, 6 e 7; 29; 30; 32 e 33;
- rr) legge 13 dicembre 1999, n. 475, ad eccezione dell'articolo 1, comma 3, e fatte salve le disposizioni ivi previste per gli amministratori regionali.

### Articolo 275 - Norma finale

1. Salvo che sia diversamente previsto dal presente decreto e fuori dei casi di abrogazione per incompatibilita', quando leggi, regolamenti, decreti, od altre norme o provvedimenti, fanno riferimento a disposizioni espressamente abrogate dagli articoli contenuti nel presente capo, il riferimento si intende alle corrispondenti disposizioni del presente testo unico, come riportate da ciascun articolo.

